#include "monty.h"
#include "fusion_p.h"

template<typename T> struct _checked_ptr_1 
{
  T * ptr;
  size_t sz;
  _checked_ptr_1<T>(T * ptr, size_t sz) : ptr(ptr), sz(sz) {} 
  T & operator[](ptrdiff_t i) { assert(i >= 0 && i < sz); return ptr[i]; } 
  const T & operator[](ptrdiff_t i) const { assert(i >= 0 && i < sz); return ptr[i]; } 
  void update(T * ptr_, size_t sz_) { ptr = ptr_; sz = sz_; }
};

template<typename T> struct _checked_ptr_2
{
  T * ptr; 
  size_t sz0, sz1; 
  _checked_ptr_2<T>(T * ptr, size_t sz0, size_t sz1) : ptr(ptr), sz0(sz0),sz1(sz1) {} 
  T & operator()(ptrdiff_t i0, ptrdiff_t i1) { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  const T & operator()(ptrdiff_t i0, ptrdiff_t i1) const { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  void update(T * ptr_, size_t sz0_, size_t sz1_) { ptr = ptr_; sz0 = sz0_; sz1 = sz1_; }
};

// See http://www.cplusplus.com/articles/DE18T05o/
//                 A      && ( (       B      && B1 && B2      ) || (      C      &&   C1 &&   C2  ) )
// A a and b a have different signs
// B, B1, B2 a and b are both non-negative, r is less than both a and b
// C, C1, C2 a and b are both negative, r is greater than both a and b

struct InternalNumericOverflow {};

template<typename T> 
static inline T checked_add(T a, T b, bool & overflow) {
  int r = a+b;
  overflow = ((a ^ b) >= 0) && ( (( (a & b) >= 0) && r < a && r < b) || ( ((a & b) < 0) && a < r && b < r) );
  return r;
}

template<typename T>
static inline T safe_add_(T a, T b) {
  bool overflow; 
  T r = checked_add(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_add(int a, int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, int b) { return safe_add_<long long int>(a,b); }

template<typename T>
static inline T checked_mul(T a, T b, bool & overflow) {
  T r = a * b;
  overflow = b != 0 && (((a ^ b) >= 0 && a > std::numeric_limits<T>::max() / b) || ((a ^ b) < 0 && a < std::numeric_limits<T>::min() / b));
  return r;
}

template<typename T>
static inline T safe_mul_(T a, T b) {
  bool overflow; 
  T r = checked_mul(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_mul(int a, int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, int b) { return safe_mul_<long long int>(a,b); }

std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::StatusKey val){switch (val){case StatusKey::Unknown: os << "StatusKey::Unknown"; break;case StatusKey::Basic: os << "StatusKey::Basic"; break;case StatusKey::SuperBasic: os << "StatusKey::SuperBasic"; break;case StatusKey::OnBound: os << "StatusKey::OnBound"; break;case StatusKey::Infinity: os << "StatusKey::Infinity"; break;default: os << "StatusKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionType val){switch (val){case SolutionType::Default: os << "SolutionType::Default"; break;case SolutionType::Basic: os << "SolutionType::Basic"; break;case SolutionType::Interior: os << "SolutionType::Interior"; break;case SolutionType::Integer: os << "SolutionType::Integer"; break;default: os << "SolutionType.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ProblemStatus val){switch (val){case ProblemStatus::Unknown: os << "ProblemStatus::Unknown"; break;case ProblemStatus::PrimalAndDualFeasible: os << "ProblemStatus::PrimalAndDualFeasible"; break;case ProblemStatus::PrimalFeasible: os << "ProblemStatus::PrimalFeasible"; break;case ProblemStatus::DualFeasible: os << "ProblemStatus::DualFeasible"; break;case ProblemStatus::PrimalInfeasible: os << "ProblemStatus::PrimalInfeasible"; break;case ProblemStatus::DualInfeasible: os << "ProblemStatus::DualInfeasible"; break;case ProblemStatus::PrimalAndDualInfeasible: os << "ProblemStatus::PrimalAndDualInfeasible"; break;case ProblemStatus::IllPosed: os << "ProblemStatus::IllPosed"; break;case ProblemStatus::PrimalInfeasibleOrUnbounded: os << "ProblemStatus::PrimalInfeasibleOrUnbounded"; break;default: os << "ProblemStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::AccSolutionStatus val){switch (val){case AccSolutionStatus::Anything: os << "AccSolutionStatus::Anything"; break;case AccSolutionStatus::Optimal: os << "AccSolutionStatus::Optimal"; break;case AccSolutionStatus::Feasible: os << "AccSolutionStatus::Feasible"; break;case AccSolutionStatus::Certificate: os << "AccSolutionStatus::Certificate"; break;default: os << "AccSolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionStatus val){switch (val){case SolutionStatus::Undefined: os << "SolutionStatus::Undefined"; break;case SolutionStatus::Unknown: os << "SolutionStatus::Unknown"; break;case SolutionStatus::Optimal: os << "SolutionStatus::Optimal"; break;case SolutionStatus::Feasible: os << "SolutionStatus::Feasible"; break;case SolutionStatus::Certificate: os << "SolutionStatus::Certificate"; break;case SolutionStatus::IllposedCert: os << "SolutionStatus::IllposedCert"; break;default: os << "SolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ObjectiveSense val){switch (val){case ObjectiveSense::Undefined: os << "ObjectiveSense::Undefined"; break;case ObjectiveSense::Minimize: os << "ObjectiveSense::Minimize"; break;case ObjectiveSense::Maximize: os << "ObjectiveSense::Maximize"; break;default: os << "ObjectiveSense.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::QConeKey val){switch (val){case QConeKey::InQCone: os << "QConeKey::InQCone"; break;case QConeKey::InRotatedQCone: os << "QConeKey::InRotatedQCone"; break;case QConeKey::InPExpCone: os << "QConeKey::InPExpCone"; break;case QConeKey::InPPowCone: os << "QConeKey::InPPowCone"; break;case QConeKey::InDExpCone: os << "QConeKey::InDExpCone"; break;case QConeKey::InDPowCone: os << "QConeKey::InDPowCone"; break;default: os << "QConeKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::PSDKey val){switch (val){case PSDKey::IsSymPSD: os << "PSDKey::IsSymPSD"; break;case PSDKey::IsTrilPSD: os << "PSDKey::IsTrilPSD"; break;default: os << "PSDKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::RelationKey val){switch (val){case RelationKey::EqualsTo: os << "RelationKey::EqualsTo"; break;case RelationKey::LessThan: os << "RelationKey::LessThan"; break;case RelationKey::GreaterThan: os << "RelationKey::GreaterThan"; break;case RelationKey::IsFree: os << "RelationKey::IsFree"; break;case RelationKey::InRange: os << "RelationKey::InRange"; break;default: os << "RelationKey.<invalid>"; break;}return os;}mosek::fusion::Sort::Sort(mosek::fusion::p_Sort *_impl) : _impl(_impl) { /*std::cout << "Sort() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Sort::~Sort() { delete _impl; _impl = nullptr; }mosek::fusion::p_Sort::p_Sort  (::mosek::fusion::Sort * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Sort::argTransposeSort  ( std::shared_ptr< monty::ndarray< long long,1 > > _151,    std::shared_ptr< monty::ndarray< long long,1 > > _152,    int _153,    int _154,    int _155,    std::shared_ptr< monty::ndarray< long long,1 > > _156) { mosek::fusion::p_Sort::argTransposeSort(_151,_152,_153,_154,_155,_156); }void mosek::fusion::p_Sort::argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156){
  _checked_ptr_1<long long> _ptr__151(_151 ? _151->raw() : nullptr, _151 ? _151->size(0) : 0);
  _checked_ptr_1<long long> _ptr__152(_152 ? _152->raw() : nullptr, _152 ? _152->size(0) : 0);
  _checked_ptr_1<long long> _ptr__156(_156 ? _156->raw() : nullptr, _156 ? _156->size(0) : 0);
  int _6661 = (int)0;
  int _6662 = safe_add( safe_mul( _153,_155 ),(int)1 );
  for (int _157 = _6661; _157 < _6662; ++_157)
  {
    {
      _ptr__152[_157] = (int)0;
    }
  }
  int _6663 = (int)0;
  int _6664 = (int)((_156)->size(0));
  for (int _158 = _6663; _158 < _6664; ++_158)
  {
    {
      ++ _ptr__152[safe_add( safe_add( safe_mul( (_ptr__156[_ptr__151[_158]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__151[_158]] % _155) ),(int)1 )];
    }
  }
  int _6665 = (int)0;
  int _6666 = safe_mul( _153,_155 );
  for (int _159 = _6665; _159 < _6666; ++_159)
  {
    {
      _ptr__152[safe_add( _159,(int)1 )] = safe_add( _ptr__152[safe_add( _159,(int)1 )],_ptr__152[_159] );
    }
  }
  std::vector<long long> _6667;
  for (int _161 = (int)0, _6668 = (int)((_151)->size(0)); _161 < _6668 ; ++_161)
  {
    _6667.push_back(_ptr__151[_161]);
  }
  auto _6669 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6667.size()),_6667.begin(),_6667.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _160 = _6669;
  _checked_ptr_1<long long> _ptr__160(_160 ? _160->raw() : nullptr,_160 ? _160->size(0) : 0);
  long long _6670 = (long long)0;
  long long _6671 = (long long)((_156)->size(0));
  for (long long _162 = _6670; _162 < _6671; ++_162)
  {
    {
      long long _163 = safe_add( safe_mul( (_ptr__156[_ptr__160[_162]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__160[_162]] % _155) );
      _ptr__151[_ptr__152[_163]] = _ptr__160[_162];
      ++ _ptr__152[_163];
    }
  }
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _164,    std::shared_ptr< monty::ndarray< long long,1 > > _165) { mosek::fusion::p_Sort::argsort(_164,_165); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165){
  _checked_ptr_1<long long> _ptr__164(_164 ? _164->raw() : nullptr, _164 ? _164->size(0) : 0);
  _checked_ptr_1<long long> _ptr__165(_165 ? _165->raw() : nullptr, _165 ? _165->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_164,_165,(long long)((int)0),(long long)((int)((_164)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _166,    std::shared_ptr< monty::ndarray< int,1 > > _167) { mosek::fusion::p_Sort::argsort(_166,_167); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167){
  _checked_ptr_1<long long> _ptr__166(_166 ? _166->raw() : nullptr, _166 ? _166->size(0) : 0);
  _checked_ptr_1<int> _ptr__167(_167 ? _167->raw() : nullptr, _167 ? _167->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_166,_167,(long long)((int)0),(long long)((int)((_166)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _168,    std::shared_ptr< monty::ndarray< long long,1 > > _169,    std::shared_ptr< monty::ndarray< long long,1 > > _170) { mosek::fusion::p_Sort::argsort(_168,_169,_170); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170){
  _checked_ptr_1<long long> _ptr__168(_168 ? _168->raw() : nullptr, _168 ? _168->size(0) : 0);
  _checked_ptr_1<long long> _ptr__169(_169 ? _169->raw() : nullptr, _169 ? _169->size(0) : 0);
  _checked_ptr_1<long long> _ptr__170(_170 ? _170->raw() : nullptr, _170 ? _170->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_168,_169,_170,(long long)((int)0),(long long)((int)((_168)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _171,    std::shared_ptr< monty::ndarray< int,1 > > _172,    std::shared_ptr< monty::ndarray< int,1 > > _173) { mosek::fusion::p_Sort::argsort(_171,_172,_173); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173){
  _checked_ptr_1<long long> _ptr__171(_171 ? _171->raw() : nullptr, _171 ? _171->size(0) : 0);
  _checked_ptr_1<int> _ptr__172(_172 ? _172->raw() : nullptr, _172 ? _172->size(0) : 0);
  _checked_ptr_1<int> _ptr__173(_173 ? _173->raw() : nullptr, _173 ? _173->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_171,_172,_173,(long long)((int)0),(long long)((int)((_171)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _174,    std::shared_ptr< monty::ndarray< long long,1 > > _175,    long long _176,    long long _177) { mosek::fusion::p_Sort::argsort(_174,_175,_176,_177); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177){
  _checked_ptr_1<long long> _ptr__174(_174 ? _174->raw() : nullptr, _174 ? _174->size(0) : 0);
  _checked_ptr_1<long long> _ptr__175(_175 ? _175->raw() : nullptr, _175 ? _175->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_174,_175,_176,_177,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _178,    std::shared_ptr< monty::ndarray< int,1 > > _179,    long long _180,    long long _181) { mosek::fusion::p_Sort::argsort(_178,_179,_180,_181); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181){
  _checked_ptr_1<long long> _ptr__178(_178 ? _178->raw() : nullptr, _178 ? _178->size(0) : 0);
  _checked_ptr_1<int> _ptr__179(_179 ? _179->raw() : nullptr, _179 ? _179->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_178,_179,_180,_181,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _182,    std::shared_ptr< monty::ndarray< long long,1 > > _183,    std::shared_ptr< monty::ndarray< long long,1 > > _184,    long long _185,    long long _186) { mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186){
  _checked_ptr_1<long long> _ptr__182(_182 ? _182->raw() : nullptr, _182 ? _182->size(0) : 0);
  _checked_ptr_1<long long> _ptr__183(_183 ? _183->raw() : nullptr, _183 ? _183->size(0) : 0);
  _checked_ptr_1<long long> _ptr__184(_184 ? _184->raw() : nullptr, _184 ? _184->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _187,    std::shared_ptr< monty::ndarray< int,1 > > _188,    std::shared_ptr< monty::ndarray< int,1 > > _189,    long long _190,    long long _191) { mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191){
  _checked_ptr_1<long long> _ptr__187(_187 ? _187->raw() : nullptr, _187 ? _187->size(0) : 0);
  _checked_ptr_1<int> _ptr__188(_188 ? _188->raw() : nullptr, _188 ? _188->size(0) : 0);
  _checked_ptr_1<int> _ptr__189(_189 ? _189->raw() : nullptr, _189 ? _189->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _192,    std::shared_ptr< monty::ndarray< long long,1 > > _193,    long long _194,    long long _195,    bool _196) { mosek::fusion::p_Sort::argsort(_192,_193,_194,_195,_196); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196){
  _checked_ptr_1<long long> _ptr__192(_192 ? _192->raw() : nullptr, _192 ? _192->size(0) : 0);
  _checked_ptr_1<long long> _ptr__193(_193 ? _193->raw() : nullptr, _193 ? _193->size(0) : 0);
  if (((!_196) || ((_195 - _194) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_192,_193,_194,_195,_196)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _197 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__197(_197 ? _197->raw() : nullptr,_197 ? _197->size(0) : 0);
      int _198 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_192,_193,nullptr,_194,_195,_197);
      if (((_ptr__197[(int)1] - _ptr__197[(int)0]) < safe_mul( _198,(_195 - _194) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_192,_193,_194,_195,_ptr__197[(int)0],_ptr__197[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _199,    std::shared_ptr< monty::ndarray< int,1 > > _200,    long long _201,    long long _202,    bool _203) { mosek::fusion::p_Sort::argsort(_199,_200,_201,_202,_203); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203){
  _checked_ptr_1<long long> _ptr__199(_199 ? _199->raw() : nullptr, _199 ? _199->size(0) : 0);
  _checked_ptr_1<int> _ptr__200(_200 ? _200->raw() : nullptr, _200 ? _200->size(0) : 0);
  if (((!_203) || ((_202 - _201) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_199,_200,_201,_202,_203)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__204(_204 ? _204->raw() : nullptr,_204 ? _204->size(0) : 0);
      int _205 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_199,_200,nullptr,_201,_202,_204);
      if (((_ptr__204[(int)1] - _ptr__204[(int)0]) < safe_mul( _205,(_202 - _201) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_199,_200,_201,_202,_ptr__204[(int)0],_ptr__204[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _206,    std::shared_ptr< monty::ndarray< long long,1 > > _207,    std::shared_ptr< monty::ndarray< long long,1 > > _208,    long long _209,    long long _210,    bool _211) { mosek::fusion::p_Sort::argsort(_206,_207,_208,_209,_210,_211); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211){
  _checked_ptr_1<long long> _ptr__206(_206 ? _206->raw() : nullptr, _206 ? _206->size(0) : 0);
  _checked_ptr_1<long long> _ptr__207(_207 ? _207->raw() : nullptr, _207 ? _207->size(0) : 0);
  _checked_ptr_1<long long> _ptr__208(_208 ? _208->raw() : nullptr, _208 ? _208->size(0) : 0);
  if (((!_211) || ((_210 - _209) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_206,_207,_208,_209,_210,_211)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _212 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__212(_212 ? _212->raw() : nullptr,_212 ? _212->size(0) : 0);
      int _213 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_206,_207,_208,_209,_210,_212);
      if ((((_ptr__212[(int)1] - _ptr__212[(int)0]) < safe_mul( _213,(_210 - _209) )) && ((_ptr__212[(int)3] - _ptr__212[(int)2]) < safe_mul( _213,(_210 - _209) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_206,_208,_209,_210,_ptr__212[(int)2],_ptr__212[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_206,_207,_209,_210,_ptr__212[(int)0],_ptr__212[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _214,    std::shared_ptr< monty::ndarray< int,1 > > _215,    std::shared_ptr< monty::ndarray< int,1 > > _216,    long long _217,    long long _218,    bool _219) { mosek::fusion::p_Sort::argsort(_214,_215,_216,_217,_218,_219); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219){
  _checked_ptr_1<long long> _ptr__214(_214 ? _214->raw() : nullptr, _214 ? _214->size(0) : 0);
  _checked_ptr_1<int> _ptr__215(_215 ? _215->raw() : nullptr, _215 ? _215->size(0) : 0);
  _checked_ptr_1<int> _ptr__216(_216 ? _216->raw() : nullptr, _216 ? _216->size(0) : 0);
  if (((!_219) || ((_218 - _217) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_214,_215,_216,_217,_218,_219)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__220(_220 ? _220->raw() : nullptr,_220 ? _220->size(0) : 0);
      int _221 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_214,_215,_216,_217,_218,_220);
      if ((((_ptr__220[(int)1] - _ptr__220[(int)0]) < safe_mul( _221,(_218 - _217) )) && ((_ptr__220[(int)3] - _ptr__220[(int)2]) < safe_mul( _221,(_218 - _217) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_214,_216,_217,_218,_ptr__220[(int)2],_ptr__220[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_214,_215,_217,_218,_ptr__220[(int)0],_ptr__220[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _222,    std::shared_ptr< monty::ndarray< long long,1 > > _223,    long long _224,    long long _225,    long long _226,    long long _227) { mosek::fusion::p_Sort::argbucketsort(_222,_223,_224,_225,_226,_227); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227){
  _checked_ptr_1<long long> _ptr__222(_222 ? _222->raw() : nullptr, _222 ? _222->size(0) : 0);
  _checked_ptr_1<long long> _ptr__223(_223 ? _223->raw() : nullptr, _223 ? _223->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_222,_224,_225,_223,_226,_227);
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _228,    std::shared_ptr< monty::ndarray< int,1 > > _229,    long long _230,    long long _231,    int _232,    int _233) { mosek::fusion::p_Sort::argbucketsort(_228,_229,_230,_231,_232,_233); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233){
  _checked_ptr_1<long long> _ptr__228(_228 ? _228->raw() : nullptr, _228 ? _228->size(0) : 0);
  _checked_ptr_1<int> _ptr__229(_229 ? _229->raw() : nullptr, _229 ? _229->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_228,_230,_231,_229,_232,_233);
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _234,    std::shared_ptr< monty::ndarray< long long,1 > > _235,    std::shared_ptr< monty::ndarray< long long,1 > > _236,    long long _237,    long long _238,    std::shared_ptr< monty::ndarray< long long,1 > > _239) { mosek::fusion::p_Sort::getminmax(_234,_235,_236,_237,_238,_239); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239){
  _checked_ptr_1<long long> _ptr__234(_234 ? _234->raw() : nullptr, _234 ? _234->size(0) : 0);
  _checked_ptr_1<long long> _ptr__235(_235 ? _235->raw() : nullptr, _235 ? _235->size(0) : 0);
  _checked_ptr_1<long long> _ptr__236(_236 ? _236->raw() : nullptr, _236 ? _236->size(0) : 0);
  _checked_ptr_1<long long> _ptr__239(_239 ? _239->raw() : nullptr, _239 ? _239->size(0) : 0);
  _ptr__239[(int)0] = _ptr__235[_ptr__234[_237]];
  _ptr__239[(int)1] = _ptr__235[_ptr__234[_237]];
  long long _6672 = safe_add( _237,(int)1 );
  long long _6673 = _238;
  for (long long _240 = _6672; _240 < _6673; ++_240)
  {
    {
      if ((_ptr__239[(int)0] > _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)0] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
      if ((_ptr__239[(int)1] < _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)1] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
    }
  }
  if ((NULL != _236.get()))
  {
    {
      _ptr__239[(int)2] = _ptr__236[_ptr__234[_237]];
      _ptr__239[(int)3] = _ptr__236[_ptr__234[_237]];
      long long _6674 = safe_add( _237,(int)1 );
      long long _6675 = _238;
      for (long long _241 = _6674; _241 < _6675; ++_241)
      {
        {
          if ((_ptr__239[(int)2] > _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)2] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
          if ((_ptr__239[(int)3] < _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)3] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _242,    std::shared_ptr< monty::ndarray< int,1 > > _243,    std::shared_ptr< monty::ndarray< int,1 > > _244,    long long _245,    long long _246,    std::shared_ptr< monty::ndarray< int,1 > > _247) { mosek::fusion::p_Sort::getminmax(_242,_243,_244,_245,_246,_247); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247){
  _checked_ptr_1<long long> _ptr__242(_242 ? _242->raw() : nullptr, _242 ? _242->size(0) : 0);
  _checked_ptr_1<int> _ptr__243(_243 ? _243->raw() : nullptr, _243 ? _243->size(0) : 0);
  _checked_ptr_1<int> _ptr__244(_244 ? _244->raw() : nullptr, _244 ? _244->size(0) : 0);
  _checked_ptr_1<int> _ptr__247(_247 ? _247->raw() : nullptr, _247 ? _247->size(0) : 0);
  _ptr__247[(int)0] = _ptr__243[_ptr__242[_245]];
  _ptr__247[(int)1] = _ptr__243[_ptr__242[_245]];
  long long _6676 = safe_add( _245,(int)1 );
  long long _6677 = _246;
  for (long long _248 = _6676; _248 < _6677; ++_248)
  {
    {
      if ((_ptr__247[(int)0] > _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)0] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
      if ((_ptr__247[(int)1] < _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)1] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
    }
  }
  if ((NULL != _244.get()))
  {
    {
      _ptr__247[(int)2] = _ptr__244[_ptr__242[_245]];
      _ptr__247[(int)3] = _ptr__244[_ptr__242[_245]];
      long long _6678 = safe_add( _245,(int)1 );
      long long _6679 = _246;
      for (long long _249 = _6678; _249 < _6679; ++_249)
      {
        {
          if ((_ptr__247[(int)2] > _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)2] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
          if ((_ptr__247[(int)3] < _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)3] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _250,    std::shared_ptr< monty::ndarray< long long,1 > > _251,    long long _252,    long long _253,    bool _254) { return mosek::fusion::p_Sort::issorted(_250,_251,_252,_253,_254); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254){
  _checked_ptr_1<long long> _ptr__250(_250 ? _250->raw() : nullptr, _250 ? _250->size(0) : 0);
  _checked_ptr_1<long long> _ptr__251(_251 ? _251->raw() : nullptr, _251 ? _251->size(0) : 0);
  long long _6680 = _252;
  long long _6681 = (_253 - (int)1);
  for (long long _255 = _6680; _255 < _6681; ++_255)
  {
    {
      if ((_ptr__251[_ptr__250[_255]] > _ptr__251[_ptr__250[safe_add( _255,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _256,    std::shared_ptr< monty::ndarray< int,1 > > _257,    long long _258,    long long _259,    bool _260) { return mosek::fusion::p_Sort::issorted(_256,_257,_258,_259,_260); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260){
  _checked_ptr_1<long long> _ptr__256(_256 ? _256->raw() : nullptr, _256 ? _256->size(0) : 0);
  _checked_ptr_1<int> _ptr__257(_257 ? _257->raw() : nullptr, _257 ? _257->size(0) : 0);
  long long _6682 = _258;
  long long _6683 = (_259 - (int)1);
  for (long long _261 = _6682; _261 < _6683; ++_261)
  {
    {
      if ((_ptr__257[_ptr__256[_261]] > _ptr__257[_ptr__256[safe_add( _261,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _262,    std::shared_ptr< monty::ndarray< long long,1 > > _263,    std::shared_ptr< monty::ndarray< long long,1 > > _264,    long long _265,    long long _266,    bool _267) { return mosek::fusion::p_Sort::issorted(_262,_263,_264,_265,_266,_267); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267){
  _checked_ptr_1<long long> _ptr__262(_262 ? _262->raw() : nullptr, _262 ? _262->size(0) : 0);
  _checked_ptr_1<long long> _ptr__263(_263 ? _263->raw() : nullptr, _263 ? _263->size(0) : 0);
  _checked_ptr_1<long long> _ptr__264(_264 ? _264->raw() : nullptr, _264 ? _264->size(0) : 0);
  long long _6684 = _265;
  long long _6685 = (_266 - (int)1);
  for (long long _268 = _6684; _268 < _6685; ++_268)
  {
    {
      if (((_ptr__263[_ptr__262[_268]] > _ptr__263[_ptr__262[safe_add( _268,(int)1 )]]) || ((_ptr__263[_ptr__262[safe_add( _268,(int)1 )]] == _ptr__263[_ptr__262[_268]]) && (_ptr__264[_ptr__262[_268]] > _ptr__264[_ptr__262[safe_add( _268,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _269,    std::shared_ptr< monty::ndarray< int,1 > > _270,    std::shared_ptr< monty::ndarray< int,1 > > _271,    long long _272,    long long _273,    bool _274) { return mosek::fusion::p_Sort::issorted(_269,_270,_271,_272,_273,_274); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274){
  _checked_ptr_1<long long> _ptr__269(_269 ? _269->raw() : nullptr, _269 ? _269->size(0) : 0);
  _checked_ptr_1<int> _ptr__270(_270 ? _270->raw() : nullptr, _270 ? _270->size(0) : 0);
  _checked_ptr_1<int> _ptr__271(_271 ? _271->raw() : nullptr, _271 ? _271->size(0) : 0);
  long long _6686 = _272;
  long long _6687 = (_273 - (int)1);
  for (long long _275 = _6686; _275 < _6687; ++_275)
  {
    {
      if (((_ptr__270[_ptr__269[_275]] > _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) || ((_ptr__270[_ptr__269[_275]] == _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) && (_ptr__271[_ptr__269[_275]] > _ptr__271[_ptr__269[safe_add( _275,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_Sort::destroy(){}void mosek::fusion::Sort::destroy() { mosek::fusion::p_Sort::_get_impl(this)->destroy(); }mosek::fusion::IndexCounter::IndexCounter(mosek::fusion::p_IndexCounter *_impl) : _impl(_impl) { /*std::cout << "IndexCounter() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::IndexCounter::~IndexCounter() { delete _impl; _impl = nullptr; }mosek::fusion::p_IndexCounter::p_IndexCounter  (::mosek::fusion::IndexCounter * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276){ return new mosek::fusion::IndexCounter(_276); }mosek::fusion::IndexCounter::IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_276); }void mosek::fusion::p_IndexCounter::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _276){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__276(_276 ? _276->raw() : nullptr, _276 ? _276->size(0) : 0);
    n = (int)((_276)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    start = (long long)0;
    strides = ::mosek::fusion::p_Set::strides(_276);
    std::vector<int> _6688;
    for (int _277 = (int)0, _6689 = (int)((_276)->size(0)); _277 < _6689 ; ++_277)
    {
      _6688.push_back(_ptr__276[_277]);
    }
    auto _6690 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6688.size()),_6688.begin(),_6688.end()));
    dims = _6690;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){ return new mosek::fusion::IndexCounter(_278,_279,_280); }mosek::fusion::IndexCounter::IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_278,_279,_280); }void mosek::fusion::p_IndexCounter::_initialize  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__279(_279 ? _279->raw() : nullptr, _279 ? _279->size(0) : 0);
    _checked_ptr_1<int> _ptr__280(_280 ? _280->raw() : nullptr, _280 ? _280->size(0) : 0);
    int _281 = (int)((_280)->size(0));
    n = (int)((_279)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6691 = (int)0;
    int _6692 = n;
    for (int _282 = _6691; _282 < _6692; ++_282)
    {
      {
        ((*st)(_282)) = _278;
      }
    }
    strides = ::mosek::fusion::p_Set::strides(_280);
    dims = _279;
    start = _278;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){ return new mosek::fusion::IndexCounter(_283,_284,_285); }mosek::fusion::IndexCounter::IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_283,_284,_285); }void mosek::fusion::p_IndexCounter::_initialize  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__284(_284 ? _284->raw() : nullptr, _284 ? _284->size(0) : 0);
    _checked_ptr_1<long long> _ptr__285(_285 ? _285->raw() : nullptr, _285 ? _285->size(0) : 0);
    n = (int)((_284)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6693 = (int)0;
    int _6694 = n;
    for (int _286 = _6693; _286 < _6694; ++_286)
    {
      {
        ((*st)(_286)) = _283;
      }
    }
    strides = _285;
    dims = _284;
    start = _283;
  }
}bool mosek::fusion::IndexCounter :: atEnd() { return mosek::fusion::p_IndexCounter::_get_impl(this)->atEnd(); }bool mosek::fusion::p_IndexCounter::atEnd(){
  return (((*ii)((n - (int)1))) >= ((*dims)((n - (int)1))));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::IndexCounter :: getIndex() { return mosek::fusion::p_IndexCounter::_get_impl(this)->getIndex(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_IndexCounter::getIndex(){
  return ii;
}
long long mosek::fusion::IndexCounter :: next() { return mosek::fusion::p_IndexCounter::_get_impl(this)->next(); }long long mosek::fusion::p_IndexCounter::next(){
  long long _287 = _pubthis->get();
  _pubthis->inc();
  return _287;
}
long long mosek::fusion::IndexCounter :: get() { return mosek::fusion::p_IndexCounter::_get_impl(this)->get(); }long long mosek::fusion::p_IndexCounter::get(){
  return ((*st)((int)0));
}
void mosek::fusion::IndexCounter :: inc() { mosek::fusion::p_IndexCounter::_get_impl(this)->inc(); }void mosek::fusion::p_IndexCounter::inc(){
  ++ ((*ii)((int)0));
  ((*st)((int)0)) = safe_add( ((*st)((int)0)),((*strides)((n - (int)1))) );
  int _288;
  {
    _288 = (int)0;
    for(;((_288 < (n - (int)1)) && (((*ii)(_288)) == ((*dims)(((n - _288) - (int)1)))));++ _288)
    {
      {
        ((*ii)(_288)) = (int)0;
        ++ ((*ii)(safe_add( _288,(int)1 )));
        ((*st)(safe_add( _288,(int)1 ))) = safe_add( ((*st)(safe_add( _288,(int)1 ))),((*strides)(((n - _288) - (int)2))) );
      }
    }
  }
  int _6695 = (int)0;
  int _6696 = _288;
  for (int _289 = _6695; _289 < _6696; ++_289)
  {
    {
      ((*st)(_289)) = ((*st)(_288));
    }
  }
}
void mosek::fusion::IndexCounter :: reset() { mosek::fusion::p_IndexCounter::_get_impl(this)->reset(); }void mosek::fusion::p_IndexCounter::reset(){
  st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
  int _6697 = (int)0;
  int _6698 = n;
  for (int _290 = _6697; _290 < _6698; ++_290)
  {
    {
      ((*st)(_290)) = start;
    }
  }
}
void mosek::fusion::p_IndexCounter::destroy(){dims.reset();strides.reset();st.reset();ii.reset();}void mosek::fusion::IndexCounter::destroy() { mosek::fusion::p_IndexCounter::_get_impl(this)->destroy(); }mosek::fusion::CommonTools::CommonTools(mosek::fusion::p_CommonTools *_impl) : _impl(_impl) { /*std::cout << "CommonTools() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::CommonTools::~CommonTools() { delete _impl; _impl = nullptr; }mosek::fusion::p_CommonTools::p_CommonTools  (::mosek::fusion::CommonTools * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< long long,1 > > _291,    int _292) { return mosek::fusion::p_CommonTools::resize(_291,_292); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292){
  _checked_ptr_1<long long> _ptr__291(_291 ? _291->raw() : nullptr, _291 ? _291->size(0) : 0);
  if ((_292 == (int)((_291)->size(0))))
  {
    {
      return _291;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _293 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_292)));
      _checked_ptr_1<long long> _ptr__293(_293 ? _293->raw() : nullptr,_293 ? _293->size(0) : 0);
      if ((_292 > (int)((_291)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,(int)((_291)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,_292);
        }
      }
      return _293;
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< int,1 > > _294,    int _295) { return mosek::fusion::p_CommonTools::resize(_294,_295); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295){
  _checked_ptr_1<int> _ptr__294(_294 ? _294->raw() : nullptr, _294 ? _294->size(0) : 0);
  if ((_295 == (int)((_294)->size(0))))
  {
    {
      return _294;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _296 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_295)));
      _checked_ptr_1<int> _ptr__296(_296 ? _296->raw() : nullptr,_296 ? _296->size(0) : 0);
      if ((_295 > (int)((_294)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,(int)((_294)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,_295);
        }
      }
      return _296;
    }
  }
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< double,1 > > _297,    int _298) { return mosek::fusion::p_CommonTools::resize(_297,_298); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298){
  _checked_ptr_1<double> _ptr__297(_297 ? _297->raw() : nullptr, _297 ? _297->size(0) : 0);
  if ((_298 == (int)((_297)->size(0))))
  {
    {
      return _297;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _299 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_298)));
      _checked_ptr_1<double> _ptr__299(_299 ? _299->raw() : nullptr,_299 ? _299->size(0) : 0);
      if ((_298 > (int)((_297)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,(int)((_297)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,_298);
        }
      }
      return _299;
    }
  }
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< int,1 > > _300,    int _301) { return mosek::fusion::p_CommonTools::binarySearch(_300,_301); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301){
  _checked_ptr_1<int> _ptr__300(_300 ? _300->raw() : nullptr, _300 ? _300->size(0) : 0);
  int _302 = (int)0;
  int _303 = (int)((_300)->size(0));
  if ((_ptr__300[_302] == _301))
  {
    {
      return _302;
    }
  }
  else if((_ptr__300[(_303 - (int)1)] == _301))
  {
    {
      return (_303 - (int)1);
    }
  }
  {}
  while ( (_302 < (_303 - (int)1)) )
  {
    {
      int _304 = ((_303 - _302) / (int)2);
      if ((_301 < _ptr__300[_304]))
      {
        {
          _302 = safe_add( _304,(int)1 );
        }
      }
      else if((_301 > _ptr__300[_304]))
      {
        {
          _303 = _304;
        }
      }
      else
      {
        {
          return _304;
        }
      }
    }
  }
  return (-(int)1);
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< long long,1 > > _305,    long long _306) { return mosek::fusion::p_CommonTools::binarySearch(_305,_306); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306){
  _checked_ptr_1<long long> _ptr__305(_305 ? _305->raw() : nullptr, _305 ? _305->size(0) : 0);
  int _307 = ::mosek::fusion::p_CommonTools::binarySearchL(_305,_306);
  if (((_307 < (int)((_305)->size(0))) && (_ptr__305[_307] == _306)))
  {
    {
      return _307;
    }
  }
  else
  {
    {
      return (-(int)1);
    }
  }
}
int mosek::fusion::CommonTools::binarySearchR  ( std::shared_ptr< monty::ndarray< long long,1 > > _308,    long long _309) { return mosek::fusion::p_CommonTools::binarySearchR(_308,_309); }int mosek::fusion::p_CommonTools::binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309){
  _checked_ptr_1<long long> _ptr__308(_308 ? _308->raw() : nullptr, _308 ? _308->size(0) : 0);
  int _310 = (int)0;
  int _311 = (int)((_308)->size(0));
  if ((_ptr__308[_310] > _309))
  {
    {
      return _310;
    }
  }
  {}
  while ( (_310 < (_311 - (int)1)) )
  {
    {
      int _312 = (safe_add( _311,_310 ) / (int)2);
      if ((_309 >= _ptr__308[_312]))
      {
        {
          _310 = _312;
        }
      }
      else
      {
        {
          _311 = _312;
        }
      }
    }
  }
  return _311;
}
int mosek::fusion::CommonTools::binarySearchL  ( std::shared_ptr< monty::ndarray< long long,1 > > _313,    long long _314) { return mosek::fusion::p_CommonTools::binarySearchL(_313,_314); }int mosek::fusion::p_CommonTools::binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314){
  _checked_ptr_1<long long> _ptr__313(_313 ? _313->raw() : nullptr, _313 ? _313->size(0) : 0);
  int _315 = (int)0;
  int _316 = (int)((_313)->size(0));
  if ((_314 <= _ptr__313[_315]))
  {
    {
      return _315;
    }
  }
  {}
  while ( (_315 < (_316 - (int)1)) )
  {
    {
      int _317 = (safe_add( _316,_315 ) / (int)2);
      if ((_ptr__313[_317] < _314))
      {
        {
          _315 = _317;
        }
      }
      else
      {
        {
          _316 = _317;
        }
      }
    }
  }
  return _316;
}
void mosek::fusion::CommonTools::ndIncr  ( std::shared_ptr< monty::ndarray< int,1 > > _318,    std::shared_ptr< monty::ndarray< int,1 > > _319,    std::shared_ptr< monty::ndarray< int,1 > > _320) { mosek::fusion::p_CommonTools::ndIncr(_318,_319,_320); }void mosek::fusion::p_CommonTools::ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320){
  _checked_ptr_1<int> _ptr__318(_318 ? _318->raw() : nullptr, _318 ? _318->size(0) : 0);
  _checked_ptr_1<int> _ptr__319(_319 ? _319->raw() : nullptr, _319 ? _319->size(0) : 0);
  _checked_ptr_1<int> _ptr__320(_320 ? _320->raw() : nullptr, _320 ? _320->size(0) : 0);
  int _321 = ((int)((_318)->size(0)) - (int)1);
  ++ _ptr__318[_321];
  while ( ((_321 > (int)0) && (_ptr__318[_321] >= _ptr__320[_321])) )
  {
    {
      _ptr__318[_321] = _ptr__319[_321];
      ++ _ptr__318[(_321 - (int)1)];
    }
  }
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _322,    std::shared_ptr< monty::ndarray< int,1 > > _323,    std::shared_ptr< monty::ndarray< double,1 > > _324,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,    long long _328,    int _329,    int _330) { mosek::fusion::p_CommonTools::transposeTriplets(_322,_323,_324,_325,_326,_327,_328,_329,_330); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330){
  _checked_ptr_1<int> _ptr__322(_322 ? _322->raw() : nullptr, _322 ? _322->size(0) : 0);
  _checked_ptr_1<int> _ptr__323(_323 ? _323->raw() : nullptr, _323 ? _323->size(0) : 0);
  _checked_ptr_1<double> _ptr__324(_324 ? _324->raw() : nullptr, _324 ? _324->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _331 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _329,(int)2 ))));
  _checked_ptr_1<long long> _ptr__331(_331 ? _331->raw() : nullptr,_331 ? _331->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _330,(int)2 ))));
  _checked_ptr_1<long long> _ptr__332(_332 ? _332->raw() : nullptr,_332 ? _332->size(0) : 0);
  {
    long long _333 = (long long)0;
    for(;(_333 < _328);++ _333)
    {
      {
        _ptr__332[safe_add( _ptr__323[_333],(int)2 )] = safe_add( _ptr__332[safe_add( _ptr__323[_333],(int)2 )],(int)1 );
        _ptr__331[safe_add( _ptr__322[_333],(int)2 )] = safe_add( _ptr__331[safe_add( _ptr__322[_333],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _334 = (int)1;
    for(;(_334 < _329);++ _334)
    {
      {
        _ptr__331[safe_add( _334,(int)1 )] = safe_add( _ptr__331[safe_add( _334,(int)1 )],_ptr__331[_334] );
      }
    }
  }
  {
    int _335 = (int)1;
    for(;(_335 < _330);++ _335)
    {
      {
        _ptr__332[safe_add( _335,(int)1 )] = safe_add( _ptr__332[safe_add( _335,(int)1 )],_ptr__332[_335] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__336(_336 ? _336->raw() : nullptr,_336 ? _336->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _337 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__337(_337 ? _337->raw() : nullptr,_337 ? _337->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _338 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_328)));
  _checked_ptr_1<double> _ptr__338(_338 ? _338->raw() : nullptr,_338 ? _338->size(0) : 0);
  int _6699 = (int)0;
  int _6700 = _329;
  for (int _339 = _6699; _339 < _6700; ++_339)
  {
    {
      {
        long long _340 = _ptr__331[_339];
        for(;(_340 < _ptr__331[safe_add( _339,(int)1 )]);++ _340)
        {
          {
            int _341 = _ptr__323[_340];
            long long _342 = _ptr__332[_341];
            _ptr__336[_342] = _339;
            _ptr__337[_342] = _341;
            _ptr__338[_342] = _ptr__324[_340];
            _ptr__332[_341] = safe_add( _342,(int)1 );
          }
        }
      }
    }
  }
  ((*_325)((int)0)) = _337;
  ((*_326)((int)0)) = _336;
  ((*_327)((int)0)) = _338;
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _343,    std::shared_ptr< monty::ndarray< int,1 > > _344,    std::shared_ptr< monty::ndarray< double,1 > > _345,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,    long long _349,    int _350,    int _351) { mosek::fusion::p_CommonTools::transposeTriplets(_343,_344,_345,_346,_347,_348,_349,_350,_351); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351){
  _checked_ptr_1<int> _ptr__343(_343 ? _343->raw() : nullptr, _343 ? _343->size(0) : 0);
  _checked_ptr_1<int> _ptr__344(_344 ? _344->raw() : nullptr, _344 ? _344->size(0) : 0);
  _checked_ptr_1<double> _ptr__345(_345 ? _345->raw() : nullptr, _345 ? _345->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _352 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _350,(int)2 ))));
  _checked_ptr_1<long long> _ptr__352(_352 ? _352->raw() : nullptr,_352 ? _352->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _353 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _351,(int)2 ))));
  _checked_ptr_1<long long> _ptr__353(_353 ? _353->raw() : nullptr,_353 ? _353->size(0) : 0);
  {
    long long _354 = (long long)0;
    for(;(_354 < _349);++ _354)
    {
      {
        _ptr__353[safe_add( _ptr__344[_354],(int)2 )] = safe_add( _ptr__353[safe_add( _ptr__344[_354],(int)2 )],(int)1 );
        _ptr__352[safe_add( _ptr__343[_354],(int)2 )] = safe_add( _ptr__352[safe_add( _ptr__343[_354],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _355 = (int)1;
    for(;(_355 < _350);++ _355)
    {
      {
        _ptr__352[safe_add( _355,(int)1 )] = safe_add( _ptr__352[safe_add( _355,(int)1 )],_ptr__352[_355] );
      }
    }
  }
  {
    int _356 = (int)1;
    for(;(_356 < _351);++ _356)
    {
      {
        _ptr__353[safe_add( _356,(int)1 )] = safe_add( _ptr__353[safe_add( _356,(int)1 )],_ptr__353[_356] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _357 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__357(_357 ? _357->raw() : nullptr,_357 ? _357->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _358 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__358(_358 ? _358->raw() : nullptr,_358 ? _358->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _359 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_349)));
  _checked_ptr_1<double> _ptr__359(_359 ? _359->raw() : nullptr,_359 ? _359->size(0) : 0);
  {
    int _360 = (int)0;
    for(;(_360 < _350);++ _360)
    {
      {
        long long _6701 = _ptr__352[_360];
        long long _6702 = _ptr__352[safe_add( _360,(int)1 )];
        for (long long _361 = _6701; _361 < _6702; ++_361)
        {
          {
            int _362 = _ptr__344[_361];
            long long _363 = _ptr__353[_362];
            _ptr__357[_363] = _360;
            _ptr__358[_363] = _362;
            _ptr__359[_363] = _ptr__345[_361];
            _ptr__353[_362] = safe_add( _363,(int)1 );
          }
        }
      }
    }
  }
  ((*_346)((int)0)) = _358;
  ((*_347)((int)0)) = _357;
  ((*_348)((int)0)) = _359;
}
void mosek::fusion::CommonTools::tripletSort  ( std::shared_ptr< monty::ndarray< int,1 > > _364,    std::shared_ptr< monty::ndarray< int,1 > > _365,    std::shared_ptr< monty::ndarray< double,1 > > _366,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,    long long _370,    int _371,    int _372) { mosek::fusion::p_CommonTools::tripletSort(_364,_365,_366,_367,_368,_369,_370,_371,_372); }void mosek::fusion::p_CommonTools::tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372){
  _checked_ptr_1<int> _ptr__364(_364 ? _364->raw() : nullptr, _364 ? _364->size(0) : 0);
  _checked_ptr_1<int> _ptr__365(_365 ? _365->raw() : nullptr, _365 ? _365->size(0) : 0);
  _checked_ptr_1<double> _ptr__366(_366 ? _366->raw() : nullptr, _366 ? _366->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__373(_373 ? _373->raw() : nullptr,_373 ? _373->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _374 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _372,(int)2 ))));
  _checked_ptr_1<long long> _ptr__374(_374 ? _374->raw() : nullptr,_374 ? _374->size(0) : 0);
  long long _6703 = (long long)0;
  long long _6704 = _370;
  for (long long _375 = _6703; _375 < _6704; ++_375)
  {
    {
      _ptr__374[safe_add( _ptr__365[_375],(int)2 )] = safe_add( _ptr__374[safe_add( _ptr__365[_375],(int)2 )],(int)1 );
    }
  }
  int _6705 = (int)1;
  int _6706 = _372;
  for (int _376 = _6705; _376 < _6706; ++_376)
  {
    {
      _ptr__374[safe_add( _376,(int)1 )] = safe_add( _ptr__374[safe_add( _376,(int)1 )],_ptr__374[_376] );
    }
  }
  int _6707 = (int)0;
  int _6708 = (int)_370;
  for (int _377 = _6707; _377 < _6708; ++_377)
  {
    {
      int _378 = _ptr__365[_377];
      _ptr__373[_ptr__374[safe_add( _378,(int)1 )]] = _377;
      _ptr__374[safe_add( _378,(int)1 )] = safe_add( _ptr__374[safe_add( _378,(int)1 )],(int)1 );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _379 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _371,(int)2 ))));
  _checked_ptr_1<long long> _ptr__379(_379 ? _379->raw() : nullptr,_379 ? _379->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _380 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__380(_380 ? _380->raw() : nullptr,_380 ? _380->size(0) : 0);
  {
    int _381 = (int)0;
    for(;(_381 < _370);++ _381)
    {
      {
        _ptr__379[safe_add( _ptr__364[_381],(int)2 )] = safe_add( _ptr__379[safe_add( _ptr__364[_381],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _382 = (int)1;
    for(;(_382 < _371);++ _382)
    {
      {
        _ptr__379[safe_add( _382,(int)1 )] = safe_add( _ptr__379[safe_add( _382,(int)1 )],_ptr__379[_382] );
      }
    }
  }
  {
    int _383 = (int)0;
    for(;(_383 < _372);++ _383)
    {
      {
        {
          long long _384 = _ptr__374[_383];
          for(;(_384 < _ptr__374[safe_add( _383,(int)1 )]);++ _384)
          {
            {
              int _385 = _ptr__364[_ptr__373[_384]];
              _ptr__380[_ptr__379[safe_add( _385,(int)1 )]] = _ptr__373[_384];
              _ptr__379[safe_add( _385,(int)1 )] = safe_add( _ptr__379[safe_add( _385,(int)1 )],(int)1 );
            }
          }
        }
      }
    }
  }
  int _386 = (int)1;
  {
    int _387 = _ptr__364[_ptr__380[(int)0]];
    int _388 = _ptr__365[_ptr__380[(int)0]];
    {
      int _389 = (int)1;
      for(;(_389 < _370);++ _389)
      {
        {
          int _390 = _ptr__380[_389];
          if (((_387 != _ptr__364[_390]) || (_388 != _ptr__365[_390])))
          {
            {
              _387 = _ptr__364[_390];
              _388 = _ptr__365[_390];
              ++ _386;
            }
          }
          {}
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__391(_391 ? _391->raw() : nullptr,_391 ? _391->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _392 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__392(_392 ? _392->raw() : nullptr,_392 ? _392->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _393 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_386)));
  _checked_ptr_1<double> _ptr__393(_393 ? _393->raw() : nullptr,_393 ? _393->size(0) : 0);
  {
    int _394 = _ptr__380[(int)0];
    _ptr__391[(int)0] = _ptr__364[_394];
    _ptr__392[(int)0] = _ptr__365[_394];
    _ptr__393[(int)0] = _ptr__366[_394];
  }
  int _395 = (int)1;
  int _6709 = (int)1;
  long long _6710 = _370;
  for (long long _396 = _6709; _396 < _6710; ++_396)
  {
    {
      int _397 = _ptr__380[_396];
      if (((_ptr__391[(_395 - (int)1)] == _ptr__364[_397]) && (_ptr__392[(_395 - (int)1)] == _ptr__365[_397])))
      {
        {
          _ptr__393[(_395 - (int)1)] = (_ptr__393[(_395 - (int)1)] + _ptr__366[_397]);
        }
      }
      else
      {
        {
          _ptr__391[_395] = _ptr__364[_397];
          _ptr__392[_395] = _ptr__365[_397];
          _ptr__393[_395] = _ptr__366[_397];
          ++ _395;
        }
      }
    }
  }
  ((*_367)((int)0)) = _391;
  ((*_368)((int)0)) = _392;
  ((*_369)((int)0)) = _393;
}
void mosek::fusion::CommonTools::argMSort  ( std::shared_ptr< monty::ndarray< int,1 > > _398,    std::shared_ptr< monty::ndarray< int,1 > > _399) { mosek::fusion::p_CommonTools::argMSort(_398,_399); }void mosek::fusion::p_CommonTools::argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399){
  _checked_ptr_1<int> _ptr__398(_398 ? _398->raw() : nullptr, _398 ? _398->size(0) : 0);
  _checked_ptr_1<int> _ptr__399(_399 ? _399->raw() : nullptr, _399 ? _399->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _400 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_398)->size(0)))));
  _checked_ptr_1<int> _ptr__400(_400 ? _400->raw() : nullptr,_400 ? _400->size(0) : 0);
  bool _401 = false;
  {
    int _402 = (int)1;
    for(;(_402 < (int)((_398)->size(0)));_402 *= (int)2)
    {
      {
        _401 = (!_401);
        int _6711 = (int)0;
        int _6712 = (int)((_398)->size(0));
        int _6713 = safe_mul( _402,(int)2 );
        for (int _403 = _6711; _403 < _6712; _403 += _6713)
        {
          {
            if (_401)
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_398,_400,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
            else
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_400,_398,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
          }
        }
      }
    }
  }
  if (_401)
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_400,(int)0,_398,(int)0,(int)((_398)->size(0)));
    }
  }
  {}
}
void mosek::fusion::p_CommonTools::mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409){
  _checked_ptr_1<int> _ptr__404(_404 ? _404->raw() : nullptr, _404 ? _404->size(0) : 0);
  _checked_ptr_1<int> _ptr__405(_405 ? _405->raw() : nullptr, _405 ? _405->size(0) : 0);
  _checked_ptr_1<int> _ptr__406(_406 ? _406->raw() : nullptr, _406 ? _406->size(0) : 0);
  int _6714;
  bool _6715 = (_409 > (int)((_404)->size(0)));
  if (_6715)
  {
    _6714 = (int)((_404)->size(0));
  }
  else
  {
    _6714 = _409;
  }
  int _410 = _6714;
  int _6716;
  bool _6717 = (_408 > _410);
  if (_6717)
  {
    _6716 = _410;
  }
  else
  {
    _6716 = _408;
  }
  int _411 = _6716;
  if ((_411 == _410))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_404,_407,_405,_407,(_411 - _407));
    }
  }
  else
  {
    {
      int _412 = _407;
      int _413 = _411;
      int _414;
      {
        _414 = _407;
        for(;((_412 < _411) && (_413 < _410));++ _414)
        {
          {
            if ((_ptr__406[_ptr__404[_412]] < _ptr__406[_ptr__404[_413]]))
            {
              {
                _ptr__405[_414] = _ptr__404[_412];
                ++ _412;
              }
            }
            else
            {
              {
                _ptr__405[_414] = _ptr__404[_413];
                ++ _413;
              }
            }
          }
        }
      }
      while ( (_412 < _411) )
      {
        {
          _ptr__405[_414] = _ptr__404[_412];
          ++ _412;
          ++ _414;
        }
      }
      while ( (_413 < _410) )
      {
        {
          _ptr__405[_414] = _ptr__404[_413];
          ++ _413;
          ++ _414;
        }
      }
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _415,    std::shared_ptr< monty::ndarray< long long,1 > > _416,    std::shared_ptr< monty::ndarray< long long,1 > > _417,    long long _418,    long long _419) { mosek::fusion::p_CommonTools::argQsort(_415,_416,_417,_418,_419); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419){
  _checked_ptr_1<long long> _ptr__415(_415 ? _415->raw() : nullptr, _415 ? _415->size(0) : 0);
  _checked_ptr_1<long long> _ptr__416(_416 ? _416->raw() : nullptr, _416 ? _416->size(0) : 0);
  _checked_ptr_1<long long> _ptr__417(_417 ? _417->raw() : nullptr, _417 ? _417->size(0) : 0);
  if ((NULL == _417.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_418,_419);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_417,_418,_419);
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _420,    std::shared_ptr< monty::ndarray< int,1 > > _421,    std::shared_ptr< monty::ndarray< int,1 > > _422,    long long _423,    long long _424) { mosek::fusion::p_CommonTools::argQsort(_420,_421,_422,_423,_424); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424){
  _checked_ptr_1<long long> _ptr__420(_420 ? _420->raw() : nullptr, _420 ? _420->size(0) : 0);
  _checked_ptr_1<int> _ptr__421(_421 ? _421->raw() : nullptr, _421 ? _421->size(0) : 0);
  _checked_ptr_1<int> _ptr__422(_422 ? _422->raw() : nullptr, _422 ? _422->size(0) : 0);
  if ((NULL == _422.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_423,_424);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_422,_423,_424);
    }
  }
}
void mosek::fusion::p_CommonTools::destroy(){}void mosek::fusion::CommonTools::destroy() { mosek::fusion::p_CommonTools::_get_impl(this)->destroy(); }mosek::fusion::SolutionStruct::SolutionStruct(mosek::fusion::p_SolutionStruct *_impl) : _impl(_impl) { /*std::cout << "SolutionStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SolutionStruct::~SolutionStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_SolutionStruct::p_SolutionStruct  (::mosek::fusion::SolutionStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_yx() { return _impl->yx; }
void mosek::fusion::SolutionStruct::set_yx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->yx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_snx() { return _impl->snx; }
void mosek::fusion::SolutionStruct::set_snx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->snx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_sux() { return _impl->sux; }
void mosek::fusion::SolutionStruct::set_sux(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->sux = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slx() { return _impl->slx; }
void mosek::fusion::SolutionStruct::set_slx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_bars() { return _impl->bars; }
void mosek::fusion::SolutionStruct::set_bars(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bars = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_barx() { return _impl->barx; }
void mosek::fusion::SolutionStruct::set_barx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->barx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_y() { return _impl->y; }
void mosek::fusion::SolutionStruct::set_y(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->y = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_suc() { return _impl->suc; }
void mosek::fusion::SolutionStruct::set_suc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->suc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slc() { return _impl->slc; }
void mosek::fusion::SolutionStruct::set_slc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xx() { return _impl->xx; }
void mosek::fusion::SolutionStruct::set_xx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xc() { return _impl->xc; }
void mosek::fusion::SolutionStruct::set_xc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xc = _val; }
double mosek::fusion::SolutionStruct::get_dobj() { return _impl->dobj; }
void mosek::fusion::SolutionStruct::set_dobj(double _val) { _impl->dobj = _val; }
double mosek::fusion::SolutionStruct::get_pobj() { return _impl->pobj; }
void mosek::fusion::SolutionStruct::set_pobj(double _val) { _impl->pobj = _val; }
mosek::fusion::ProblemStatus mosek::fusion::SolutionStruct::get_probstatus() { return _impl->probstatus; }
void mosek::fusion::SolutionStruct::set_probstatus(mosek::fusion::ProblemStatus _val) { _impl->probstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_dstatus() { return _impl->dstatus; }
void mosek::fusion::SolutionStruct::set_dstatus(mosek::fusion::SolutionStatus _val) { _impl->dstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_pstatus() { return _impl->pstatus; }
void mosek::fusion::SolutionStruct::set_pstatus(mosek::fusion::SolutionStatus _val) { _impl->pstatus = _val; }
int mosek::fusion::SolutionStruct::get_sol_numbarvar() { return _impl->sol_numbarvar; }
void mosek::fusion::SolutionStruct::set_sol_numbarvar(int _val) { _impl->sol_numbarvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcone() { return _impl->sol_numcone; }
void mosek::fusion::SolutionStruct::set_sol_numcone(int _val) { _impl->sol_numcone = _val; }
int mosek::fusion::SolutionStruct::get_sol_numvar() { return _impl->sol_numvar; }
void mosek::fusion::SolutionStruct::set_sol_numvar(int _val) { _impl->sol_numvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcon() { return _impl->sol_numcon; }
void mosek::fusion::SolutionStruct::set_sol_numcon(int _val) { _impl->sol_numcon = _val; }
mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (int _425,    int _426,    int _427,    int _428){ return new mosek::fusion::SolutionStruct(_425,_426,_427,_428); }mosek::fusion::SolutionStruct::SolutionStruct  (int _425,    int _426,    int _427,    int _428) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_425,_426,_427,_428); }void mosek::fusion::p_SolutionStruct::_initialize  (int _425,    int _426,    int _427,    int _428){monty::rc_reserve __reserve_this(_pubthis);   {
    pobj = 0.0;
    dobj = 0.0;
    pstatus = ::mosek::fusion::SolutionStatus::Unknown;
    dstatus = ::mosek::fusion::SolutionStatus::Unknown;
    probstatus = ::mosek::fusion::ProblemStatus::Unknown;
    sol_numvar = _425;
    sol_numcon = _426;
    sol_numcone = _427;
    sol_numbarvar = _428;
    slx = nullptr;
    sux = nullptr;
    xx = nullptr;
    yx = nullptr;
    slc = nullptr;
    suc = nullptr;
    y = nullptr;
    xc = nullptr;
    snx = nullptr;
    barx = nullptr;
    bars = nullptr;
    if ((_425 > (int)0))
    {
      {
        slx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        sux = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        yx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
    if ((_428 > (int)0))
    {
      {
        barx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        bars = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
      }
    }
    {}
    if ((_426 > (int)0))
    {
      {
        slc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        suc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        y = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        xc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
      }
    }
    {}
    if ((_427 > (int)0))
    {
      {
        snx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
  }
}mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){ return new mosek::fusion::SolutionStruct(_429); }mosek::fusion::SolutionStruct::SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_429); }void mosek::fusion::p_SolutionStruct::_initialize  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){monty::rc_reserve __reserve_this(_pubthis);   {
    sol_numcon = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcon;
    sol_numvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numvar;
    sol_numcone = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcone;
    sol_numbarvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numbarvar;
    pstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pstatus;
    dstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dstatus;
    probstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->probstatus;
    pobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pobj;
    dobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dobj;
    std::shared_ptr< monty::ndarray< double,1 > > _6718;
    bool _6719 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc.get());
    if (_6719)
    {
      _6718 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc);
    }
    else
    {
      _6718 = nullptr;
    }
    xc = _6718;
    std::shared_ptr< monty::ndarray< double,1 > > _6720;
    bool _6721 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx.get());
    if (_6721)
    {
      _6720 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx);
    }
    else
    {
      _6720 = nullptr;
    }
    xx = _6720;
    std::shared_ptr< monty::ndarray< double,1 > > _6722;
    bool _6723 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx.get());
    if (_6723)
    {
      _6722 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx);
    }
    else
    {
      _6722 = nullptr;
    }
    yx = _6722;
    std::shared_ptr< monty::ndarray< double,1 > > _6724;
    bool _6725 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slc.get());
    if (_6725)
    {
      _6724 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6724 = nullptr;
    }
    slc = _6724;
    std::shared_ptr< monty::ndarray< double,1 > > _6726;
    bool _6727 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->suc.get());
    if (_6727)
    {
      _6726 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6726 = nullptr;
    }
    suc = _6726;
    std::shared_ptr< monty::ndarray< double,1 > > _6728;
    bool _6729 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->y.get());
    if (_6729)
    {
      _6728 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->y);
    }
    else
    {
      _6728 = nullptr;
    }
    y = _6728;
    barx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->barx);
    bars = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->bars);
    std::shared_ptr< monty::ndarray< double,1 > > _6730;
    bool _6731 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx.get());
    if (_6731)
    {
      _6730 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6730 = nullptr;
    }
    slx = _6730;
    std::shared_ptr< monty::ndarray< double,1 > > _6732;
    bool _6733 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux.get());
    if (_6733)
    {
      _6732 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6732 = nullptr;
    }
    sux = _6732;
    std::shared_ptr< monty::ndarray< double,1 > > _6734;
    bool _6735 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx.get());
    if (_6735)
    {
      _6734 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx);
    }
    else
    {
      _6734 = nullptr;
    }
    snx = _6734;
  }
}monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct :: __mosek_2fusion_2SolutionStruct__clone() { return mosek::fusion::p_SolutionStruct::_get_impl(this)->__mosek_2fusion_2SolutionStruct__clone(); }monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct::clone() { return __mosek_2fusion_2SolutionStruct__clone(); }
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_SolutionStruct::__mosek_2fusion_2SolutionStruct__clone(){
  return ::mosek::fusion::p_SolutionStruct::_new_SolutionStruct(::mosek::fusion::SolutionStruct::t(_pubthis));
}
void mosek::fusion::SolutionStruct :: resize(int _430,int _431,int _432,int _433) { mosek::fusion::p_SolutionStruct::_get_impl(this)->resize(_430,_431,_432,_433); }void mosek::fusion::p_SolutionStruct::resize(int _430,int _431,int _432,int _433){
  if ((_433 < (int)0))
  {
    {
    }
  }
  else if((_433 <= sol_numbarvar))
  {
    {
      sol_numbarvar = _433;
    }
  }
  else if((_433 <= (int)((barx)->size(0))))
  {
    {
    }
  }
  else
  {
    {
      int _434;
      if ((safe_mul( sol_numbarvar,(int)2 ) > safe_add( _433,(int)100 )))
      {
        {
          _434 = safe_mul( sol_numbarvar,(int)2 );
        }
      }
      else
      {
        {
          _434 = safe_add( _433,(int)100 );
        }
      }
      barx = ::mosek::fusion::p_CommonTools::resize(barx,_434);
      bars = ::mosek::fusion::p_CommonTools::resize(bars,_434);
      sol_numbarvar = _434;
    }
  }
  if ((_430 < (int)0))
  {
    {
    }
  }
  else if((_430 <= sol_numvar))
  {
    {
      sol_numvar = _430;
    }
  }
  else if((_430 <= (int)((xx)->size(0))))
  {
    {
      int _6736 = sol_numvar;
      int _6737 = _430;
      for (int _435 = _6736; _435 < _6737; ++_435)
      {
        {
          ((*slx)(_435)) = 0.0;
          ((*sux)(_435)) = 0.0;
          ((*xx)(_435)) = 0.0;
          ((*yx)(_435)) = 0.0;
        }
      }
      sol_numvar = _430;
    }
  }
  else
  {
    {
      int _436;
      if ((safe_mul( sol_numvar,(int)2 ) > safe_add( _430,(int)100 )))
      {
        {
          _436 = safe_mul( sol_numvar,(int)2 );
        }
      }
      else
      {
        {
          _436 = safe_add( _430,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _437 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__437(_437 ? _437->raw() : nullptr,_437 ? _437->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slx,(int)0,_437,(int)0,(int)((slx)->size(0)));
      slx = _437;
      std::shared_ptr< monty::ndarray< double,1 > > _438 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__438(_438 ? _438->raw() : nullptr,_438 ? _438->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(sux,(int)0,_438,(int)0,(int)((sux)->size(0)));
      sux = _438;
      std::shared_ptr< monty::ndarray< double,1 > > _439 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__439(_439 ? _439->raw() : nullptr,_439 ? _439->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xx,(int)0,_439,(int)0,(int)((xx)->size(0)));
      xx = _439;
      std::shared_ptr< monty::ndarray< double,1 > > _440 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__440(_440 ? _440->raw() : nullptr,_440 ? _440->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(yx,(int)0,_440,(int)0,(int)((yx)->size(0)));
      yx = _440;
      {
        int _441 = sol_numvar;
        for(;(_441 < _430);++ _441)
        {
          {
            ((*slx)(_441)) = 0.0;
            ((*sux)(_441)) = 0.0;
            ((*xx)(_441)) = 0.0;
          }
        }
      }
      sol_numvar = _430;
    }
  }
  if ((_431 < (int)0))
  {
    {
    }
  }
  else if((_431 <= sol_numcon))
  {
    {
      sol_numcon = _431;
    }
  }
  else if((_431 <= (int)((xx)->size(0))))
  {
    {
      int _6738 = sol_numcon;
      int _6739 = _431;
      for (int _442 = _6738; _442 < _6739; ++_442)
      {
        {
          ((*slc)(_442)) = 0.0;
          ((*suc)(_442)) = 0.0;
          ((*xc)(_442)) = 0.0;
          ((*y)(_442)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  else
  {
    {
      int _443;
      if ((safe_mul( sol_numcon,(int)2 ) > safe_add( _431,(int)100 )))
      {
        {
          _443 = safe_mul( sol_numcon,(int)2 );
        }
      }
      else
      {
        {
          _443 = safe_add( _431,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _444 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__444(_444 ? _444->raw() : nullptr,_444 ? _444->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slc,(int)0,_444,(int)0,(int)((slc)->size(0)));
      slc = _444;
      std::shared_ptr< monty::ndarray< double,1 > > _445 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__445(_445 ? _445->raw() : nullptr,_445 ? _445->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(suc,(int)0,_445,(int)0,(int)((suc)->size(0)));
      suc = _445;
      std::shared_ptr< monty::ndarray< double,1 > > _446 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__446(_446 ? _446->raw() : nullptr,_446 ? _446->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xc,(int)0,_446,(int)0,(int)((xc)->size(0)));
      xc = _446;
      std::shared_ptr< monty::ndarray< double,1 > > _447 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__447(_447 ? _447->raw() : nullptr,_447 ? _447->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(y,(int)0,_447,(int)0,(int)((y)->size(0)));
      y = _447;
      int _6740 = sol_numcon;
      int _6741 = _431;
      for (int _448 = _6740; _448 < _6741; ++_448)
      {
        {
          ((*slc)(_448)) = 0.0;
          ((*suc)(_448)) = 0.0;
          ((*xc)(_448)) = 0.0;
          ((*y)(_448)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  if ((_432 < (int)0))
  {
    {
    }
  }
  else if((_432 <= sol_numcone))
  {
    {
      sol_numcone = _432;
    }
  }
  else if((_432 <= (int)((xx)->size(0))))
  {
    {
      int _6742 = sol_numcone;
      int _6743 = _432;
      for (int _449 = _6742; _449 < _6743; ++_449)
      {
        {
          ((*snx)(_449)) = 0.0;
        }
      }
      sol_numcone = _432;
    }
  }
  else
  {
    {
      int _450;
      if ((safe_mul( sol_numcone,(int)2 ) > safe_add( _432,(int)100 )))
      {
        {
          _450 = safe_mul( sol_numcone,(int)2 );
        }
      }
      else
      {
        {
          _450 = safe_add( _432,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _451 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_450)));
      _checked_ptr_1<double> _ptr__451(_451 ? _451->raw() : nullptr,_451 ? _451->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(snx,(int)0,_451,(int)0,(int)((snx)->size(0)));
      snx = _451;
      {
        int _452 = sol_numcone;
        for(;(_452 < _432);++ _452)
        {
          {
            ((*snx)(_452)) = 0.0;
          }
        }
      }
      sol_numcone = _432;
    }
  }
}
bool mosek::fusion::SolutionStruct :: isDualAcceptable(mosek::fusion::AccSolutionStatus _453) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isDualAcceptable(_453); }bool mosek::fusion::p_SolutionStruct::isDualAcceptable(mosek::fusion::AccSolutionStatus _453){
  return isAcceptable(dstatus,_453);
}
bool mosek::fusion::SolutionStruct :: isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isPrimalAcceptable(_454); }bool mosek::fusion::p_SolutionStruct::isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454){
  return isAcceptable(pstatus,_454);
}
bool mosek::fusion::p_SolutionStruct::isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456){
  if ((_456 == ::mosek::fusion::AccSolutionStatus::Anything))
  {
    {
      return true;
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Optimal))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Optimal);
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Feasible))
  {
    {
      return ((_455 == ::mosek::fusion::SolutionStatus::Optimal) || (_455 == ::mosek::fusion::SolutionStatus::Feasible));
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Certificate))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Certificate);
    }
  }
  {}
  return false;
}
void mosek::fusion::p_SolutionStruct::destroy(){yx.reset();snx.reset();sux.reset();slx.reset();bars.reset();barx.reset();y.reset();suc.reset();slc.reset();xx.reset();xc.reset();}void mosek::fusion::SolutionStruct::destroy() { mosek::fusion::p_SolutionStruct::_get_impl(this)->destroy(); }mosek::fusion::ConNZStruct::ConNZStruct(mosek::fusion::p_ConNZStruct *_impl) : _impl(_impl) { /*std::cout << "ConNZStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConNZStruct::~ConNZStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConNZStruct::p_ConNZStruct  (::mosek::fusion::ConNZStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barmidx() { return _impl->barmidx; }
void mosek::fusion::ConNZStruct::set_barmidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConNZStruct::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConNZStruct::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConNZStruct::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_cof() { return _impl->cof; }
void mosek::fusion::ConNZStruct::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_subj() { return _impl->subj; }
void mosek::fusion::ConNZStruct::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::ConNZStruct::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::ConNZStruct::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
mosek::fusion::ConNZStruct::t mosek::fusion::p_ConNZStruct::_new_ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){ return new mosek::fusion::ConNZStruct(_457,_458,_459,_460,_461,_462,_463); }mosek::fusion::ConNZStruct::ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463) :    ConNZStruct(new mosek::fusion::p_ConNZStruct(this)){ mosek::fusion::p_ConNZStruct::_get_impl(this)->_initialize(_457,_458,_459,_460,_461,_462,_463); }void mosek::fusion::p_ConNZStruct::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__457(_457 ? _457->raw() : nullptr, _457 ? _457->size(0) : 0);
    _checked_ptr_1<int> _ptr__458(_458 ? _458->raw() : nullptr, _458 ? _458->size(0) : 0);
    _checked_ptr_1<double> _ptr__459(_459 ? _459->raw() : nullptr, _459 ? _459->size(0) : 0);
    _checked_ptr_1<double> _ptr__460(_460 ? _460->raw() : nullptr, _460 ? _460->size(0) : 0);
    _checked_ptr_1<int> _ptr__461(_461 ? _461->raw() : nullptr, _461 ? _461->size(0) : 0);
    _checked_ptr_1<int> _ptr__462(_462 ? _462->raw() : nullptr, _462 ? _462->size(0) : 0);
    _checked_ptr_1<int> _ptr__463(_463 ? _463->raw() : nullptr, _463 ? _463->size(0) : 0);
    ptrb = _457;
    subj = _458;
    cof = _459;
    bfix = _460;
    barsubi = _461;
    barsubj = _462;
    barmidx = _463;
  }
}void mosek::fusion::p_ConNZStruct::destroy(){barmidx.reset();barsubj.reset();barsubi.reset();bfix.reset();cof.reset();subj.reset();ptrb.reset();}void mosek::fusion::ConNZStruct::destroy() { mosek::fusion::p_ConNZStruct::_get_impl(this)->destroy(); }mosek::fusion::Model::Model(mosek::fusion::p_Model *_impl) : mosek::fusion::BaseModel(_impl) { /*std::cout << "Model()" << this << std::endl; */ }mosek::fusion::Model::~Model() {  /* std::cout << "~Model()" << this << std::endl << std::flush; */ }mosek::fusion::p_Model::p_Model  (::mosek::fusion::Model * _pubthis) :     mosek::fusion::p_BaseModel(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (monty::rc_ptr< ::mosek::fusion::Model > _464){ return new mosek::fusion::Model(_464); }mosek::fusion::Model::Model  (monty::rc_ptr< ::mosek::fusion::Model > _464) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_464); }void mosek::fusion::p_Model::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _464){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_464);
    monty::rc_ptr< ::mosek::fusion::Model > _465 = ::mosek::fusion::Model::t(_pubthis);
    model_name = mosek::fusion::p_Model::_get_impl(_464)->model_name;
    acceptable_sol = mosek::fusion::p_Model::_get_impl(_464)->acceptable_sol;
    solutionptr = mosek::fusion::p_Model::_get_impl(_464)->solutionptr;
    natvarmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_blockid);
    natvarmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_idx);
    natvarmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_type);
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natvarmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6744;
    for (int _466 = (int)0, _6745 = (int)((mosek::fusion::p_Model::_get_impl(_464)->vars)->size(0)); _466 < _6745 ; ++_466)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6746;
      bool _6747 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get());
      if (_6747)
      {
        _6746 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6746 = nullptr;
      }
      _6744.push_back(_6746);
    }
    auto _6748 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6744.size()),_6744.begin(),_6744.end()));
    vars = _6748;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconemap);
    natconemap_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconemap_dim);
    natbarvar_numbarvarelm = mosek::fusion::p_Model::_get_impl(_464)->natbarvar_numbarvarelm;
    natbarvar_ptr = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_ptr);
    natbarvar_i = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_i);
    natbarvar_j = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_j);
    natbarvar_idx = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_idx);
    natbarvarmap_nblock = mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_nblock;
    natbarvar_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvar_dim);
    natbarvarmap_num = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_num);
    natbarvarmap_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_ptr);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6749;
    for (int _467 = (int)0, _6750 = (int)((mosek::fusion::p_Model::_get_impl(_464)->barvars)->size(0)); _467 < _6750 ; ++_467)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6751;
      bool _6752 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get());
      if (_6752)
      {
        _6751 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6751 = nullptr;
      }
      _6749.push_back(_6751);
    }
    auto _6753 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6749.size()),_6749.begin(),_6749.end()));
    barvars = _6753;
    var_map = mosek::fusion::p_Model::_get_impl(_464)->var_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    natconmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_blockid);
    natconmap_slackidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_slackidx);
    natconmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_idx);
    natconmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_type);
    natconmap_efix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_efix);
    natconmap_lb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_lb);
    natconmap_ub = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_ub);
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6754;
    for (int _468 = (int)0, _6755 = (int)((mosek::fusion::p_Model::_get_impl(_464)->cons)->size(0)); _468 < _6755 ; ++_468)
    {
      monty::rc_ptr< ::mosek::fusion::ModelConstraint > _6756;
      bool _6757 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get());
      if (_6757)
      {
        _6756 = mosek::fusion::p_ModelConstraint::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get())->__mosek_2fusion_2ModelConstraint__clone(_465);
      }
      else
      {
        _6756 = nullptr;
      }
      _6754.push_back(_6756);
    }
    auto _6758 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6754.size()),_6754.begin(),_6754.end()));
    cons = _6758;
    con_map = mosek::fusion::p_Model::_get_impl(_464)->con_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    bfixidx = mosek::fusion::p_Model::_get_impl(_464)->bfixidx;
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (const std::string &  _469){ return new mosek::fusion::Model(_469); }mosek::fusion::Model::Model  (const std::string &  _469) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_469); }void mosek::fusion::p_Model::_initialize  (const std::string &  _469){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_469,std::string (""));
    model_name = _469;
    acceptable_sol = ::mosek::fusion::AccSolutionStatus::Optimal;
    solutionptr = ::mosek::fusion::SolutionType::Default;
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natvarmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6759;
    for (int _470 = (int)0, _6760 = (int)1024; _470 < _6760 ; ++_470)
    {
      _6759.push_back(nullptr);
    }
    auto _6761 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6759.size()),_6759.begin(),_6759.end()));
    vars = _6761;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconemap_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    natbarvar_ptr = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
    natbarvar_numbarvarelm = (int)0;
    natbarvar_i = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_j = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_nblock = (int)0;
    natbarvar_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_num = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_ptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    var_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_slackidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_efix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_lb = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_ub = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6762;
    for (int _471 = (int)0, _6763 = (int)1024; _471 < _6763 ; ++_471)
    {
      _6762.push_back(nullptr);
    }
    auto _6764 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6762.size()),_6762.begin(),_6762.end()));
    cons = _6764;
    con_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    bfixidx = natvarmap_alloc((int)1);
    task_var_putboundlist_fx(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(bfixidx)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}));
    task_var_name(bfixidx,std::string ("1.0"));
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (){ return new mosek::fusion::Model(); }mosek::fusion::Model::Model  () :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(); }void mosek::fusion::p_Model::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Model::_initialize(std::string (""));
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_Model::__mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474){
  _checked_ptr_1<int> _ptr__473(_473 ? _473->raw() : nullptr, _473 ? _473->size(0) : 0);
  _checked_ptr_1<int> _ptr__474(_474 ? _474->raw() : nullptr, _474 ? _474->size(0) : 0);
  return _472;
}
void mosek::fusion::p_Model::connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string & _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478){
  _checked_ptr_1<int> _ptr__475(_475 ? _475->raw() : nullptr, _475 ? _475->size(0) : 0);
  _checked_ptr_1<int> _ptr__477(_477 ? _477->raw() : nullptr, _477 ? _477->size(0) : 0);
  _checked_ptr_1<long long> _ptr__478(_478 ? _478->raw() : nullptr, _478 ? _478->size(0) : 0);
  task_format_con_names(_475,_476,_477,_478);
}
void mosek::fusion::p_Model::varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string & _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482){
  _checked_ptr_1<int> _ptr__479(_479 ? _479->raw() : nullptr, _479 ? _479->size(0) : 0);
  _checked_ptr_1<int> _ptr__481(_481 ? _481->raw() : nullptr, _481 ? _481->size(0) : 0);
  _checked_ptr_1<long long> _ptr__482(_482 ? _482->raw() : nullptr, _482 ? _482->size(0) : 0);
  task_format_var_names(_479,_480,_481,_482);
}
void mosek::fusion::p_Model::varname(int _483,const std::string & _484){
  task_var_name(_483,_484);
}
void mosek::fusion::p_Model::natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486){
  _checked_ptr_1<int> _ptr__486(_486 ? _486->raw() : nullptr, _486 ? _486->size(0) : 0);
  int _487 = ((*natbarvarmap_ptr)(_485));
  int _488 = ((*natbarvarmap_num)(_485));
  int _6765 = (int)0;
  int _6766 = _488;
  for (int _489 = _6765; _489 < _6766; ++_489)
  {
    {
      _ptr__486[_489] = safe_add( _487,_489 );
    }
  }
}
void mosek::fusion::p_Model::natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491){
  _checked_ptr_1<long long> _ptr__491(_491 ? _491->raw() : nullptr, _491 ? _491->size(0) : 0);
  int _492 = ((*natbarvarmap_ptr)(_490));
  int _493 = ((*natbarvarmap_num)(_490));
  int _494 = ((*natbarvar_dim)(((*natbarvarmap_ptr)(_490))));
  int _495 = (safe_mul( safe_mul( _493,_494 ),safe_add( _494,(int)1 ) ) / (int)2);
  long long _496 = ((*natbarvar_ptr)(_492));
  int _6767 = (int)0;
  int _6768 = _495;
  for (int _497 = _6767; _497 < _6768; ++_497)
  {
    {
      _ptr__491[_497] = safe_add( _496,_497 );
    }
  }
}
int mosek::fusion::p_Model::natbarvarmap_alloc(int _498,int _499){
  int _500 = (int)((natbarvar_idx)->size(0));
  int _501 = task_numbarvar();
  int _502 = (safe_mul( _499,safe_add( _499,(int)1 ) ) / (int)2);
  int _503 = safe_mul( _498,_502 );
  if ((safe_add( natbarvar_numbarvarelm,_503 ) >= _500))
  {
    {
      if ((_503 < _500))
      {
        {
          _503 = _500;
        }
      }
      {}
      natbarvar_idx = ::mosek::fusion::p_CommonTools::resize(natbarvar_idx,safe_add( _500,_503 ));
      natbarvar_i = ::mosek::fusion::p_CommonTools::resize(natbarvar_i,safe_add( _500,_503 ));
      natbarvar_j = ::mosek::fusion::p_CommonTools::resize(natbarvar_j,safe_add( _500,_503 ));
    }
  }
  {}
  if ((safe_add( natbarvarmap_nblock,(int)1 ) >= (int)((natbarvarmap_num)->size(0))))
  {
    {
      int _6769;
      bool _6770 = ((int)((natbarvarmap_num)->size(0)) > (int)0);
      if (_6770)
      {
        _6769 = safe_mul( (int)((natbarvarmap_num)->size(0)),(int)2 );
      }
      else
      {
        _6769 = (int)32;
      }
      int _504 = _6769;
      natbarvarmap_num = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_num,_504);
      natbarvarmap_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_ptr,safe_add( _504,(int)1 ));
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _505 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_504)));
      int _6771 = (int)0;
      int _6772 = (int)((barvars)->size(0));
      for (int _506 = _6771; _506 < _6772; ++_506)
      {
        {
          ((*_505)(_506)) = ((*barvars)(_506));
        }
      }
      barvars = _505;
    }
  }
  {}
  if ((safe_add( _501,_498 ) > (int)((natbarvar_dim)->size(0))))
  {
    {
      int _6773;
      bool _6774 = (safe_add( _501,_498 ) < safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 ));
      if (_6774)
      {
        _6773 = safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 );
      }
      else
      {
        _6773 = safe_add( _501,_498 );
      }
      int _507 = _6773;
      natbarvar_dim = ::mosek::fusion::p_CommonTools::resize(natbarvar_dim,_507);
    }
  }
  {}
  if ((safe_add( _501,_498 ) >= (int)((natbarvar_ptr)->size(0))))
  {
    {
      int _6775;
      bool _6776 = (_498 > (int)((natbarvar_ptr)->size(0)));
      if (_6776)
      {
        _6775 = _498;
      }
      else
      {
        _6775 = (int)((natbarvar_ptr)->size(0));
      }
      int _508 = _6775;
      natbarvar_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvar_ptr,safe_add( safe_add( (int)((natbarvar_ptr)->size(0)),_508 ),(int)1 ));
    }
  }
  {}
  int _6777 = (int)0;
  int _6778 = _498;
  for (int _509 = _6777; _509 < _6778; ++_509)
  {
    {
      ((*natbarvar_dim)(safe_add( _501,_509 ))) = _499;
    }
  }
  ((*natbarvarmap_num)(natbarvarmap_nblock)) = _498;
  ((*natbarvarmap_ptr)(safe_add( natbarvarmap_nblock,(int)1 ))) = safe_add( ((*natbarvarmap_ptr)(natbarvarmap_nblock)),_498 );
  int _510 = task_append_barvar(_499,_498);
  int _511 = ((*natbarvarmap_ptr)(natbarvarmap_nblock));
  {
    long long _512 = ((*natbarvar_ptr)(_501));
    int _6779 = (int)0;
    int _6780 = _499;
    for (int _513 = _6779; _513 < _6780; ++_513)
    {
      {
        int _6781 = _513;
        int _6782 = _499;
        for (int _514 = _6781; _514 < _6782; ++_514)
        {
          {
            int _6783 = (int)0;
            int _6784 = _498;
            for (int _515 = _6783; _515 < _6784; ++_515)
            {
              {
                ((*natbarvar_idx)(safe_add( _512,safe_mul( _515,_502 ) ))) = safe_add( _511,_515 );
                ((*natbarvar_i)(safe_add( _512,safe_mul( _515,_502 ) ))) = _514;
                ((*natbarvar_j)(safe_add( _512,safe_mul( _515,_502 ) ))) = _513;
              }
            }
            ++ _512;
          }
        }
      }
    }
    int _6785 = (int)0;
    int _6786 = _498;
    for (int _516 = _6785; _516 < _6786; ++_516)
    {
      {
        ((*natbarvar_ptr)(safe_add( safe_add( _511,_516 ),(int)1 ))) = safe_add( ((*natbarvar_ptr)(safe_add( _511,_516 ))),_502 );
      }
    }
  }
  natbarvarmap_nblock += (int)1;
  natbarvar_numbarvarelm += safe_mul( _498,_502 );
  return (natbarvarmap_nblock - (int)1);
}
int mosek::fusion::p_Model::natvarmap_alloc(int _517){
  int _518 = natvarmap->alloc(_517);
  int _519 = safe_add( natvarmap->maxidx(_518),(int)1 );
  int _520 = natvarmap->capacity();
  int _521 = natvarmap->numblocks();
  if (((int)((natvarmap_idx)->size(0)) < _520))
  {
    {
      int _522 = (int)((natvarmap_idx)->size(0));
      natvarmap_idx = ::mosek::fusion::p_CommonTools::resize(natvarmap_idx,_520);
      int _6787 = _522;
      int _6788 = _520;
      for (int _523 = _6787; _523 < _6788; ++_523)
      {
        {
          ((*natvarmap_idx)(_523)) = (-(int)1);
        }
      }
      natvarmap_blockid = ::mosek::fusion::p_CommonTools::resize(natvarmap_blockid,_520);
    }
  }
  {}
  if (((int)((vars)->size(0)) < _521))
  {
    {
      natvarmap_type = ::mosek::fusion::p_CommonTools::resize(natvarmap_type,_521);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _524 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_521)));
      int _6789 = (int)0;
      int _6790 = (int)((vars)->size(0));
      for (int _525 = _6789; _525 < _6790; ++_525)
      {
        {
          ((*_524)(_525)) = ((*vars)(_525));
        }
      }
      int _6791 = (int)((vars)->size(0));
      int _6792 = (int)((_524)->size(0));
      for (int _526 = _6791; _526 < _6792; ++_526)
      {
        {
          ((*_524)(_526)) = nullptr;
        }
      }
      vars = _524;
    }
  }
  {}
  if ((task_numvar() < _519))
  {
    {
      task_append_var((_519 - task_numvar()));
    }
  }
  {}
  return _518;
}
int mosek::fusion::p_Model::natconmap_alloc(int _527){
  int _528 = natconmap->alloc(_527);
  int _529 = safe_add( natconmap->maxidx(_528),(int)1 );
  int _530 = natconmap->capacity();
  int _531 = natconmap->numblocks();
  if (((int)((natconmap_idx)->size(0)) < _530))
  {
    {
      int _532 = (int)((natconmap_idx)->size(0));
      natconmap_idx = ::mosek::fusion::p_CommonTools::resize(natconmap_idx,_530);
      int _6793 = _532;
      int _6794 = _530;
      for (int _533 = _6793; _533 < _6794; ++_533)
      {
        {
          ((*natconmap_idx)(_533)) = (-(int)1);
        }
      }
      natconmap_efix = ::mosek::fusion::p_CommonTools::resize(natconmap_efix,_530);
      natconmap_lb = ::mosek::fusion::p_CommonTools::resize(natconmap_lb,_530);
      natconmap_ub = ::mosek::fusion::p_CommonTools::resize(natconmap_ub,_530);
      natconmap_blockid = ::mosek::fusion::p_CommonTools::resize(natconmap_blockid,_530);
      natconmap_slackidx = ::mosek::fusion::p_CommonTools::resize(natconmap_slackidx,_530);
    }
  }
  {}
  if (((int)((cons)->size(0)) < _531))
  {
    {
      natconmap_type = ::mosek::fusion::p_CommonTools::resize(natconmap_type,_531);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > _534 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_531)));
      int _6795 = (int)0;
      int _6796 = (int)((cons)->size(0));
      for (int _535 = _6795; _535 < _6796; ++_535)
      {
        {
          ((*_534)(_535)) = ((*cons)(_535));
        }
      }
      int _6797 = (int)((cons)->size(0));
      int _6798 = _531;
      for (int _536 = _6797; _536 < _6798; ++_536)
      {
        {
          ((*_534)(_536)) = nullptr;
        }
      }
      cons = _534;
    }
  }
  {}
  if ((_529 > task_numcon()))
  {
    {
      task_append_con((_529 - task_numcon()));
    }
  }
  {}
  return _528;
}
int mosek::fusion::p_Model::natconemap_alloc(int _537){
  int _538 = natconemap->alloc(_537);
  int _539 = safe_add( natconemap->maxidx(_538),(int)1 );
  if ((_539 > task_numcone()))
  {
    {
      task_append_zerocones((_539 - task_numcone()));
    }
  }
  {}
  natconemap_dim = ::mosek::fusion::p_CommonTools::resize(natconemap_dim,natconemap->numblocks());
  return _538;
}
void mosek::fusion::p_Model::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540){
  _checked_ptr_1<long long> _ptr__540(_540 ? _540->raw() : nullptr, _540 ? _540->size(0) : 0);
  int _541 = (int)0;
  int _6799 = (int)0;
  int _6800 = (int)((_540)->size(0));
  for (int _542 = _6799; _542 < _6800; ++_542)
  {
    {
      if ((_ptr__540[_542] > (int)0))
      {
        {
          ++ _541;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _543 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_541)));
  _checked_ptr_1<int> _ptr__543(_543 ? _543->raw() : nullptr,_543 ? _543->size(0) : 0);
  int _544 = (int)0;
  int _6801 = (int)0;
  int _6802 = (int)((_540)->size(0));
  for (int _545 = _6801; _545 < _6802; ++_545)
  {
    {
      if ((_ptr__540[_545] > (int)0))
      {
        {
          _ptr__543[_544] = (int)(_ptr__540[_545] - (int)1);
          ++ _544;
        }
      }
      {}
    }
  }
  task_var_putcontlist(_543);
}
void mosek::fusion::p_Model::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546){
  _checked_ptr_1<long long> _ptr__546(_546 ? _546->raw() : nullptr, _546 ? _546->size(0) : 0);
  int _547 = (int)0;
  int _6803 = (int)0;
  int _6804 = (int)((_546)->size(0));
  for (int _548 = _6803; _548 < _6804; ++_548)
  {
    {
      if ((_ptr__546[_548] > (int)0))
      {
        {
          ++ _547;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_547)));
  _checked_ptr_1<int> _ptr__549(_549 ? _549->raw() : nullptr,_549 ? _549->size(0) : 0);
  int _550 = (int)0;
  int _6805 = (int)0;
  int _6806 = (int)((_546)->size(0));
  for (int _551 = _6805; _551 < _6806; ++_551)
  {
    {
      if ((_ptr__546[_551] > (int)0))
      {
        {
          _ptr__549[_550] = (int)(_ptr__546[_551] - (int)1);
          ++ _550;
        }
      }
      {}
    }
  }
  task_var_putintlist(_549);
}
void mosek::fusion::Model::putlicensewait  ( bool _552) { mosek::fusion::p_Model::putlicensewait(_552); }void mosek::fusion::p_Model::putlicensewait(bool _552){
  ::mosek::fusion::p_BaseModel::env_putlicensewait(_552);
}
void mosek::fusion::Model::putlicensepath  ( const std::string & _553) { mosek::fusion::p_Model::putlicensepath(_553); }void mosek::fusion::p_Model::putlicensepath(const std::string & _553){
  ::mosek::fusion::p_BaseModel::env_putlicensepath(_553);
}
void mosek::fusion::Model::putlicensecode  ( std::shared_ptr< monty::ndarray< int,1 > > _554) { mosek::fusion::p_Model::putlicensecode(_554); }void mosek::fusion::p_Model::putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554){
  _checked_ptr_1<int> _ptr__554(_554 ? _554->raw() : nullptr, _554 ? _554->size(0) : 0);
  ::mosek::fusion::p_BaseModel::env_putlicensecode(_554);
}
void mosek::fusion::Model :: dispose() { mosek::fusion::p_Model::_get_impl(this)->dispose(); }void mosek::fusion::p_Model::dispose(){
  int _6807 = (int)0;
  int _6808 = (int)((vars)->size(0));
  for (int _555 = _6807; _555 < _6808; ++_555)
  {
    {
      ((*vars)(_555)) = nullptr;
    }
  }
  int _6809 = (int)0;
  int _6810 = (int)((cons)->size(0));
  for (int _556 = _6809; _556 < _6810; ++_556)
  {
    {
      ((*cons)(_556)) = nullptr;
    }
  }
  ::mosek::fusion::p_BaseModel::dispose();
}
void mosek::fusion::p_Model::nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558){
  if (((_557 < (int)0) || ((_557 >= (int)((natvarmap_idx)->size(0))) || (((*natvarmap_idx)(_557)) < (int)0))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Native variable index is invalid"));
    }
  }
  {}
  ((*vars)(((*natvarmap_blockid)(_557))))->elementName((long long)(((*natvarmap_idx)(_557))),_558);
}
MSKtask_t mosek::fusion::Model :: __mosek_2fusion_2Model__getTask() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getTask(); }MSKtask_t mosek::fusion::Model::getTask() { return __mosek_2fusion_2Model__getTask(); }
MSKtask_t mosek::fusion::p_Model::__mosek_2fusion_2Model__getTask(){
  return __mosek_2fusion_2BaseModel__task_get();
}
void mosek::fusion::Model :: getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) { mosek::fusion::p_Model::_get_impl(this)->getConstraintValues(_559,_560,_561,_562); }void mosek::fusion::p_Model::getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562){
  _checked_ptr_1<int> _ptr__560(_560 ? _560->raw() : nullptr, _560 ? _560->size(0) : 0);
  _checked_ptr_1<double> _ptr__561(_561 ? _561->raw() : nullptr, _561 ? _561->size(0) : 0);
  int _563 = (int)((_560)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6811;
  bool _6812 = _559;
  if (_6812)
  {
    _6811 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6811 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _564 = _6811;
  _checked_ptr_1<double> _ptr__564(_564 ? _564->raw() : nullptr,_564 ? _564->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6813;
  bool _6814 = _559;
  if (_6814)
  {
    _6813 = getSolution_barx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6813 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _565 = _6813;
  _checked_ptr_1<double> _ptr__565(_565 ? _565->raw() : nullptr,_565 ? _565->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6815;
  bool _6816 = _559;
  if (_6816)
  {
    _6815 = getSolution_xc(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6815 = getSolution_y(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _566 = _6815;
  _checked_ptr_1<double> _ptr__566(_566 ? _566->raw() : nullptr,_566 ? _566->size(0) : 0);
  int _6817 = (int)0;
  int _6818 = _563;
  for (int _567 = _6817; _567 < _6818; ++_567)
  {
    {
      long long _568 = ((*natconmap_slackidx)(_ptr__560[_567]));
      if ((_568 < (int)0))
      {
        {
          long long _569 = (-safe_add( _568,(int)1 ));
          _ptr__561[safe_add( _562,_567 )] = _ptr__565[_569];
        }
      }
      else if((_568 > (int)0))
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__564[(_568 - (int)1)];
        }
      }
      else
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__566[_ptr__560[_567]];
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573) { mosek::fusion::p_Model::_get_impl(this)->getVariableDuals(_570,_571,_572,_573); }void mosek::fusion::p_Model::getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573){
  _checked_ptr_1<long long> _ptr__571(_571 ? _571->raw() : nullptr, _571 ? _571->size(0) : 0);
  _checked_ptr_1<double> _ptr__572(_572 ? _572->raw() : nullptr, _572 ? _572->size(0) : 0);
  int _574 = (int)((_571)->size(0));
  if (_570)
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _575 = getSolution_slx(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__575(_575 ? _575->raw() : nullptr,_575 ? _575->size(0) : 0);
      int _6819 = (int)0;
      int _6820 = _574;
      for (int _576 = _6819; _576 < _6820; ++_576)
      {
        {
          if ((_ptr__571[_576] > (int)0))
          {
            {
              _ptr__572[safe_add( _573,_576 )] = _ptr__575[(_ptr__571[_576] - (int)1)];
            }
          }
          else
          {
            {
              _ptr__572[safe_add( _573,_576 )] = (int)0;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _577 = getSolution_sux(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__577(_577 ? _577->raw() : nullptr,_577 ? _577->size(0) : 0);
      int _6821 = (int)0;
      int _6822 = _574;
      for (int _578 = _6821; _578 < _6822; ++_578)
      {
        {
          if ((_ptr__571[_578] > (int)0))
          {
            {
              _ptr__572[safe_add( _573,_578 )] = (-_ptr__577[(_ptr__571[_578] - (int)1)]);
            }
          }
          else
          {
            {
              _ptr__572[safe_add( _573,_578 )] = (int)0;
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582) { mosek::fusion::p_Model::_get_impl(this)->getVariableValues(_579,_580,_581,_582); }void mosek::fusion::p_Model::getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582){
  _checked_ptr_1<long long> _ptr__580(_580 ? _580->raw() : nullptr, _580 ? _580->size(0) : 0);
  _checked_ptr_1<double> _ptr__581(_581 ? _581->raw() : nullptr, _581 ? _581->size(0) : 0);
  int _583 = (int)((_580)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6823;
  bool _6824 = _579;
  if (_6824)
  {
    _6823 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6823 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _584 = _6823;
  _checked_ptr_1<double> _ptr__584(_584 ? _584->raw() : nullptr,_584 ? _584->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6825;
  bool _6826 = (natbarvar_numbarvarelm > (int)0);
  if (_6826)
  {
    std::shared_ptr< monty::ndarray< double,1 > > _6827;
    bool _6828 = _579;
    if (_6828)
    {
      _6827 = getSolution_barx(::mosek::fusion::SolutionType::Default);
    }
    else
    {
      _6827 = getSolution_bars(::mosek::fusion::SolutionType::Default);
    }
    _6825 = _6827;
  }
  else
  {
    _6825 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _585 = _6825;
  _checked_ptr_1<double> _ptr__585(_585 ? _585->raw() : nullptr,_585 ? _585->size(0) : 0);
  int _6829 = (int)0;
  int _6830 = _583;
  for (int _586 = _6829; _586 < _6830; ++_586)
  {
    {
      if ((_ptr__580[_586] > (int)0))
      {
        {
          _ptr__581[safe_add( _582,_586 )] = _ptr__584[(_ptr__580[_586] - (int)1)];
        }
      }
      else if((_ptr__580[_586] < (int)0))
      {
        {
          long long _587 = (-safe_add( _ptr__580[_586],(int)1 ));
          _ptr__581[safe_add( _582,_586 )] = _ptr__585[_587];
        }
      }
      else
      {
        {
          _ptr__581[safe_add( _582,_586 )] = (int)0;
        }
      }
    }
  }
}
void mosek::fusion::Model :: setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590) { mosek::fusion::p_Model::_get_impl(this)->setVariableValues(_588,_589,_590); }void mosek::fusion::p_Model::setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590){
  _checked_ptr_1<long long> _ptr__589(_589 ? _589->raw() : nullptr, _589 ? _589->size(0) : 0);
  _checked_ptr_1<double> _ptr__590(_590 ? _590->raw() : nullptr, _590 ? _590->size(0) : 0);
  if (_588)
  {
    {
      int _591 = (int)0;
      int _6831 = (int)0;
      int _6832 = (int)((_589)->size(0));
      for (int _592 = _6831; _592 < _6832; ++_592)
      {
        {
          if ((_ptr__589[_592] >= (int)0))
          {
            {
              ++ _591;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _593 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_591)));
      _checked_ptr_1<int> _ptr__593(_593 ? _593->raw() : nullptr,_593 ? _593->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6833;
      bool _6834 = (_591 == (int)((_589)->size(0)));
      if (_6834)
      {
        _6833 = _590;
      }
      else
      {
        _6833 = _590;
      }
      std::shared_ptr< monty::ndarray< double,1 > > _594 = _6833;
      _checked_ptr_1<double> _ptr__594(_594 ? _594->raw() : nullptr,_594 ? _594->size(0) : 0);
      int _595 = (int)0;
      int _6835 = (int)0;
      int _6836 = (int)((_589)->size(0));
      for (int _596 = _6835; _596 < _6836; ++_596)
      {
        {
          if ((_ptr__589[_596] > (int)0))
          {
            {
              _ptr__593[_595] = (int)(_ptr__589[_596] - (int)1);
              ++ _595;
            }
          }
          {}
        }
      }
      setSolution_xx(_593,_594);
    }
  }
  else
  {
    {
    }
  }
}
void mosek::fusion::Model :: flushNames() { mosek::fusion::p_Model::_get_impl(this)->flushNames(); }void mosek::fusion::p_Model::flushNames(){
  int _6837 = (int)0;
  int _6838 = (int)((vars)->size(0));
  for (int _597 = _6837; _597 < _6838; ++_597)
  {
    {
      if ((NULL != ((*vars)(_597)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*vars)(_597)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6839 = (int)0;
  int _6840 = (int)((barvars)->size(0));
  for (int _598 = _6839; _598 < _6840; ++_598)
  {
    {
      if ((NULL != ((*barvars)(_598)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*barvars)(_598)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6841 = (int)0;
  int _6842 = (int)((cons)->size(0));
  for (int _599 = _6841; _599 < _6842; ++_599)
  {
    {
      if ((NULL != ((*cons)(_599)).get()))
      {
        {
          mosek::fusion::p_ModelConstraint::_get_impl(((*cons)(_599)).get())->flushNames();
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: writeTask(const std::string & _600) { mosek::fusion::p_Model::_get_impl(this)->writeTask(_600); }void mosek::fusion::p_Model::writeTask(const std::string & _600){
  _pubthis->flushNames();
  task_write(_600);
}
long long mosek::fusion::Model :: getSolverLIntInfo(const std::string & _601) { return mosek::fusion::p_Model::_get_impl(this)->getSolverLIntInfo(_601); }long long mosek::fusion::p_Model::getSolverLIntInfo(const std::string & _601){
  return task_get_liinf(_601);
}
int mosek::fusion::Model :: getSolverIntInfo(const std::string & _602) { return mosek::fusion::p_Model::_get_impl(this)->getSolverIntInfo(_602); }int mosek::fusion::p_Model::getSolverIntInfo(const std::string & _602){
  return task_get_iinf(_602);
}
double mosek::fusion::Model :: getSolverDoubleInfo(const std::string & _603) { return mosek::fusion::p_Model::_get_impl(this)->getSolverDoubleInfo(_603); }double mosek::fusion::p_Model::getSolverDoubleInfo(const std::string & _603){
  return task_get_dinf(_603);
}
void mosek::fusion::Model :: setCallbackHandler(mosek::cbhandler_t _604) { mosek::fusion::p_Model::_get_impl(this)->setCallbackHandler(_604); }void mosek::fusion::p_Model::setCallbackHandler(mosek::cbhandler_t _604){
  task_setCallbackHandler(_604);
}
void mosek::fusion::Model :: setDataCallbackHandler(mosek::datacbhandler_t _605) { mosek::fusion::p_Model::_get_impl(this)->setDataCallbackHandler(_605); }void mosek::fusion::p_Model::setDataCallbackHandler(mosek::datacbhandler_t _605){
  task_setDataCallbackHandler(_605);
}
void mosek::fusion::Model :: setLogHandler(mosek::msghandler_t _606) { mosek::fusion::p_Model::_get_impl(this)->setLogHandler(_606); }void mosek::fusion::p_Model::setLogHandler(mosek::msghandler_t _606){
  task_setLogHandler(_606);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _607,double _608) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_607,_608); }void mosek::fusion::p_Model::setSolverParam(const std::string & _607,double _608){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_607,_608);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _609,int _610) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_609,_610); }void mosek::fusion::p_Model::setSolverParam(const std::string & _609,int _610){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_609,_610);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _611,const std::string & _612) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_611,_612); }void mosek::fusion::p_Model::setSolverParam(const std::string & _611,const std::string & _612){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_611,_612);
}
void mosek::fusion::Model :: breakSolver() { mosek::fusion::p_Model::_get_impl(this)->breakSolver(); }void mosek::fusion::p_Model::breakSolver(){
  task_break_solve();
}
void mosek::fusion::Model :: solve() { mosek::fusion::p_Model::_get_impl(this)->solve(); }void mosek::fusion::p_Model::solve(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
  task_solve();
}
void mosek::fusion::Model :: flushSolutions() { mosek::fusion::p_Model::_get_impl(this)->flushSolutions(); }void mosek::fusion::p_Model::flushSolutions(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
}
void mosek::fusion::p_Model::flush_initsol(mosek::fusion::SolutionType _613){
  if ((NULL != initsol_xx.get()))
  {
    {
      int _614 = task_numvar();
      std::shared_ptr< monty::ndarray< double,1 > > _615 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_614)));
      _checked_ptr_1<double> _ptr__615(_615 ? _615->raw() : nullptr,_615 ? _615->size(0) : 0);
      try
      {
        {
          monty::rc_ptr< ::mosek::fusion::SolutionStruct > _617 = __mosek_2fusion_2Model__get_sol_cache(_613,true);
          if ((NULL != mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx.get()))
          {
            {
              int _6843;
              bool _6844 = ((int)((mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx)->size(0)) <= _614);
              if (_6844)
              {
                _6843 = (int)((mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx)->size(0));
              }
              else
              {
                _6843 = _614;
              }
              ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx,(int)0,_615,(int)0,_6843);
            }
          }
          {}
        }
      }
      catch (mosek::fusion::SolutionError _616)
      {
        {
        }
      }
      int _6845;
      bool _6846 = ((int)((initsol_xx)->size(0)) <= _614);
      if (_6846)
      {
        _6845 = (int)((initsol_xx)->size(0));
      }
      else
      {
        _6845 = _614;
      }
      int _618 = _6845;
      int _6847 = (int)0;
      int _6848 = _618;
      for (int _619 = _6847; _619 < _6848; ++_619)
      {
        {
          if (((*initsol_xx_flag)(_619)))
          {
            {
              _ptr__615[_619] = ((*initsol_xx)(_619));
            }
          }
          {}
        }
      }
      task_putxx_slice(_613,(int)0,_614,_615);
    }
  }
  {}
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(){
  return _pubthis->getDualSolutionStatus(solutionptr);
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus() { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(){
  return _pubthis->getProblemStatus(solutionptr);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(){
  return _pubthis->getPrimalSolutionStatus(solutionptr);
}
double mosek::fusion::Model :: dualObjValue() { return mosek::fusion::p_Model::_get_impl(this)->dualObjValue(); }double mosek::fusion::p_Model::dualObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,false))->dobj;
}
double mosek::fusion::Model :: primalObjValue() { return mosek::fusion::p_Model::_get_impl(this)->primalObjValue(); }double mosek::fusion::p_Model::primalObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,true))->pobj;
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _620,bool _621,bool _622){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _623 = nullptr;
  mosek::fusion::SolutionType _624 = _620;
  if ((_624 == ::mosek::fusion::SolutionType::Default))
  {
    {
      _624 = solutionptr;
    }
  }
  {}
  if ((_624 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _623 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _623 = sol_bas;
        }
      }
      else
      {
        {
          _623 = sol_itr;
        }
      }
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _623 = sol_itr;
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _623 = sol_bas;
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _623 = sol_itg;
    }
  }
  {}
  if ((NULL == _623.get()))
  {
    {
      throw ::mosek::fusion::SolutionError(std::string ("Solution not available"));
    }
  }
  else
  {
    {
      if ((_622 || ((_621 && _623->isPrimalAcceptable(acceptable_sol)) || ((!_621) && _623->isDualAcceptable(acceptable_sol)))))
      {
        {
          return _623;
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _625 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          mosek::fusion::SolutionStatus _626 = mosek::fusion::p_SolutionStruct::_get_impl(_623)->pstatus;
          if ((!_621))
          {
            {
              _626 = mosek::fusion::p_SolutionStruct::_get_impl(_623)->dstatus;
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Solution status is "));
          if ((_626 == ::mosek::fusion::SolutionStatus::Undefined))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Undefined"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Unknown))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Optimal))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Feasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Certificate))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" but at least "));
          if ((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Anything))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Anything"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Optimal))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Feasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Certificate))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" is expected"));
          throw ::mosek::fusion::SolutionError(_625->toString());
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _627,bool _628){
  return __mosek_2fusion_2Model__get_sol_cache(_627,_628,false);
}
void mosek::fusion::p_Model::setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _629,std::shared_ptr< monty::ndarray< double,1 > > _630){
  _checked_ptr_1<int> _ptr__629(_629 ? _629->raw() : nullptr, _629 ? _629->size(0) : 0);
  _checked_ptr_1<double> _ptr__630(_630 ? _630->raw() : nullptr, _630 ? _630->size(0) : 0);
  ensure_initsol_xx();
  int _6849 = (int)0;
  int _6850 = (int)((_629)->size(0));
  for (int _631 = _6849; _631 < _6850; ++_631)
  {
    {
      ((*initsol_xx)(_ptr__629[_631])) = _ptr__630[_631];
      ((*initsol_xx_flag)(_ptr__629[_631])) = true;
    }
  }
}
void mosek::fusion::p_Model::ensure_initsol_xx(){
  int _632 = (int)((natvarmap_idx)->size(0));
  if ((NULL == initsol_xx.get()))
  {
    {
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_632)));
      std::vector<bool> _6851;
      for (int _633 = (int)0, _6852 = _632; _633 < _6852 ; ++_633)
      {
        _6851.push_back(false);
      }
      auto _6853 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_6851.size()),_6851.begin(),_6851.end()));
      initsol_xx_flag = _6853;
    }
  }
  else if(((int)((initsol_xx)->size(0)) < _632))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _634 = initsol_xx;
      _checked_ptr_1<double> _ptr__634(_634 ? _634->raw() : nullptr,_634 ? _634->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _635 = initsol_xx_flag;
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_632)));
      initsol_xx_flag = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_632)));
      ::mosek::fusion::Utils::Tools::arraycopy(_634,(int)0,initsol_xx,(int)0,_632);
      int _6854 = (int)0;
      int _6855 = _632;
      for (int _636 = _6854; _636 < _6855; ++_636)
      {
        {
          ((*initsol_xx_flag)(_636)) = ((*_635)(_636));
        }
      }
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_bars(mosek::fusion::SolutionType _637){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_637,false))->bars;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_barx(mosek::fusion::SolutionType _638){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_638,false))->barx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_y(mosek::fusion::SolutionType _639){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_639,false))->y;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xc(mosek::fusion::SolutionType _640){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_640,true))->xc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_snx(mosek::fusion::SolutionType _641){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_641,false))->snx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_suc(mosek::fusion::SolutionType _642){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_642,false))->suc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slc(mosek::fusion::SolutionType _643){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_643,false))->slc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_sux(mosek::fusion::SolutionType _644){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_644,false))->sux;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slx(mosek::fusion::SolutionType _645){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_645,false))->slx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_yx(mosek::fusion::SolutionType _646){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_646,true))->yx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xx(mosek::fusion::SolutionType _647){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_647,true))->xx;
}
void mosek::fusion::Model :: selectedSolution(mosek::fusion::SolutionType _648) { mosek::fusion::p_Model::_get_impl(this)->selectedSolution(_648); }void mosek::fusion::p_Model::selectedSolution(mosek::fusion::SolutionType _648){
  solutionptr = _648;
}
mosek::fusion::AccSolutionStatus mosek::fusion::Model :: getAcceptedSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getAcceptedSolutionStatus(); }mosek::fusion::AccSolutionStatus mosek::fusion::p_Model::getAcceptedSolutionStatus(){
  return acceptable_sol;
}
void mosek::fusion::Model :: acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _649) { mosek::fusion::p_Model::_get_impl(this)->acceptedSolutionStatus(_649); }void mosek::fusion::p_Model::acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _649){
  acceptable_sol = _649;
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus(mosek::fusion::SolutionType _650) { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(_650); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(mosek::fusion::SolutionType _650){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _651 = nullptr;
  if ((_650 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _651 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _651 = sol_bas;
        }
      }
      else
      {
        {
          _651 = sol_itr;
        }
      }
    }
  }
  else if((_650 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _651 = sol_itr;
    }
  }
  else if((_650 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _651 = sol_bas;
    }
  }
  else if((_650 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _651 = sol_itg;
    }
  }
  {}
  if ((NULL == _651.get()))
  {
    {
      return ::mosek::fusion::ProblemStatus::Unknown;
    }
  }
  else
  {
    {
      return mosek::fusion::p_SolutionStruct::_get_impl(_651)->probstatus;
    }
  }
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus(mosek::fusion::SolutionType _652) { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(_652); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(mosek::fusion::SolutionType _652){
  return getSolutionStatus(_652,false);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus(mosek::fusion::SolutionType _653) { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(_653); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(mosek::fusion::SolutionType _653){
  return getSolutionStatus(_653,true);
}
mosek::fusion::SolutionStatus mosek::fusion::p_Model::getSolutionStatus(mosek::fusion::SolutionType _654,bool _655){
  try
  {
    {
      monty::rc_ptr< ::mosek::fusion::SolutionStruct > _657 = __mosek_2fusion_2Model__get_sol_cache(_654,_655,true);
      if (_655)
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_657)->pstatus;
        }
      }
      else
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_657)->dstatus;
        }
      }
    }
  }
  catch (mosek::fusion::SolutionError _656)
  {
    {
      return ::mosek::fusion::SolutionStatus::Undefined;
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _658,monty::rc_ptr< ::mosek::fusion::Expression > _659){
  _checked_ptr_1<int> _ptr__658(_658 ? _658->raw() : nullptr, _658 ? _658->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_659)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _660 = ws->popi32();
  int _661 = ws->popi32(_660);
  int _662 = ws->popi32();
  int _663 = ws->popi32();
  bool _664 = ((int)0 != ws->popi32());
  int _665 = ws->popi32(safe_add( _662,(int)1 ));
  int _6856;
  bool _6857 = _664;
  if (_6857)
  {
    _6856 = ws->popi64(_662);
  }
  else
  {
    _6856 = (int)0;
  }
  int _666 = _6856;
  int _667 = ws->popi64(_663);
  int _668 = ws->popf64(_662);
  int _669 = ws->popf64(_663);
  std::shared_ptr< monty::ndarray< int,1 > > _670 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__670(_670 ? _670->raw() : nullptr,_670 ? _670->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _671 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__671(_671 ? _671->raw() : nullptr,_671 ? _671->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _672 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__672(_672 ? _672->raw() : nullptr,_672 ? _672->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _673 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _662,(int)1 ))));
  _checked_ptr_1<long long> _ptr__673(_673 ? _673->raw() : nullptr,_673 ? _673->size(0) : 0);
  int _6858 = (int)0;
  int _6859 = _662;
  for (int _674 = _6858; _674 < _6859; ++_674)
  {
    {
      int _6860 = _ptr__670[safe_add( _665,_674 )];
      int _6861 = _ptr__670[safe_add( safe_add( _665,_674 ),(int)1 )];
      for (int _675 = _6860; _675 < _6861; ++_675)
      {
        {
          if ((_ptr__671[safe_add( _667,_675 )] > (int)0))
          {
            {
              ++ _ptr__673[safe_add( _674,(int)1 )];
            }
          }
          {}
        }
      }
    }
  }
  int _6862 = (int)0;
  int _6863 = _662;
  for (int _676 = _6862; _676 < _6863; ++_676)
  {
    {
      _ptr__673[safe_add( _676,(int)1 )] += _ptr__673[_676];
    }
  }
  long long _677 = _ptr__673[_662];
  std::shared_ptr< monty::ndarray< int,1 > > _678 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_677)));
  _checked_ptr_1<int> _ptr__678(_678 ? _678->raw() : nullptr,_678 ? _678->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _679 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_677)));
  _checked_ptr_1<double> _ptr__679(_679 ? _679->raw() : nullptr,_679 ? _679->size(0) : 0);
  int _680 = (int)0;
  int _6864 = (int)0;
  int _6865 = _662;
  for (int _681 = _6864; _681 < _6865; ++_681)
  {
    {
      int _6866 = _ptr__670[safe_add( _665,_681 )];
      int _6867 = _ptr__670[safe_add( safe_add( _665,_681 ),(int)1 )];
      for (int _682 = _6866; _682 < _6867; ++_682)
      {
        {
          if ((_ptr__671[safe_add( _667,_682 )] > (int)0))
          {
            {
              _ptr__678[_680] = (int)(_ptr__671[safe_add( _667,_682 )] - (int)1);
              _ptr__679[_680] = _ptr__672[safe_add( _669,_682 )];
              ++ _680;
            }
          }
          {}
        }
      }
    }
  }
  task_putarowlist(_658,_673,_678,_679);
  std::vector<int> _6868;
  for (int _683 = (int)0, _6869 = _662; _683 < _6869 ; ++_683)
  {
    _6868.push_back(bfixidx);
  }
  auto _6870 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6868.size()),_6868.begin(),_6868.end()));
  std::vector<double> _6871;
  for (int _684 = (int)0, _6872 = _662; _684 < _6872 ; ++_684)
  {
    _6871.push_back(_ptr__672[safe_add( _668,_684 )]);
  }
  auto _6873 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6871.size()),_6871.begin(),_6871.end()));
  task_putaijlist(_658,_6870,_6873,(long long)(_662));
  int _685 = (int)0;
  int _6874 = (int)0;
  int _6875 = _662;
  for (int _686 = _6874; _686 < _6875; ++_686)
  {
    {
      if ((((*natconmap_slackidx)(_ptr__658[_686])) > (int)0))
      {
        {
          ++ _685;
        }
      }
      {}
    }
  }
  if ((_685 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _687 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_685)));
      _checked_ptr_1<int> _ptr__687(_687 ? _687->raw() : nullptr,_687 ? _687->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _688 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_685)));
      _checked_ptr_1<int> _ptr__688(_688 ? _688->raw() : nullptr,_688 ? _688->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _689 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_685)));
      _checked_ptr_1<double> _ptr__689(_689 ? _689->raw() : nullptr,_689 ? _689->size(0) : 0);
      int _690 = (int)0;
      int _6876 = (int)0;
      int _6877 = _662;
      for (int _691 = _6876; _691 < _6877; ++_691)
      {
        {
          if ((((*natconmap_slackidx)(_ptr__658[_691])) > (int)0))
          {
            {
              _ptr__687[_690] = _ptr__658[_691];
              _ptr__688[_690] = (int)(((*natconmap_slackidx)(_ptr__658[_691])) - (int)1);
              _ptr__689[_690] = (-1.0);
              ++ _690;
            }
          }
          {}
        }
      }
      task_putaijlist(_687,_688,_689,(long long)(_685));
    }
  }
  {}
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _692,monty::rc_ptr< ::mosek::fusion::Expression > _693,std::shared_ptr< monty::ndarray< int,1 > > _694,bool _695){
  _checked_ptr_1<int> _ptr__692(_692 ? _692->raw() : nullptr, _692 ? _692->size(0) : 0);
  _checked_ptr_1<int> _ptr__694(_694 ? _694->raw() : nullptr, _694 ? _694->size(0) : 0);
  int _696 = safe_mul( (int)((_692)->size(0)),(int)((_694)->size(0)) );
  std::shared_ptr< monty::ndarray< double,1 > > _697 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_696)));
  _checked_ptr_1<double> _ptr__697(_697 ? _697->raw() : nullptr,_697 ? _697->size(0) : 0);
  std::vector<int> _6878;
  for (int _699 = (int)0, _6879 = (int)((_692)->size(0)); _699 < _6879 ; ++_699)
  {
    for (int _700 = (int)0, _6880 = (int)((_694)->size(0)); _700 < _6880 ; ++_700)
    {
      _6878.push_back(_ptr__692[_699]);
    }
  }
  auto _6881 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6878.size()),_6878.begin(),_6878.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _698 = _6881;
  _checked_ptr_1<int> _ptr__698(_698 ? _698->raw() : nullptr,_698 ? _698->size(0) : 0);
  std::vector<int> _6882;
  for (int _702 = (int)0, _6883 = (int)((_692)->size(0)); _702 < _6883 ; ++_702)
  {
    for (int _703 = (int)0, _6884 = (int)((_694)->size(0)); _703 < _6884 ; ++_703)
    {
      _6882.push_back(_ptr__694[_703]);
    }
  }
  auto _6885 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6882.size()),_6882.begin(),_6882.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _701 = _6885;
  _checked_ptr_1<int> _ptr__701(_701 ? _701->raw() : nullptr,_701 ? _701->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_693)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _704 = ws->popi32();
  int _705 = ws->popi32(_704);
  int _706 = ws->popi32();
  int _707 = ws->popi32();
  bool _708 = ((int)0 != ws->popi32());
  int _709 = ws->popi32(safe_add( _706,(int)1 ));
  int _6886;
  bool _6887 = _708;
  if (_6887)
  {
    _6886 = ws->popi64(_706);
  }
  else
  {
    _6886 = (int)0;
  }
  int _710 = _6886;
  int _711 = ws->popi64(_707);
  int _712 = ws->popf64(_706);
  int _713 = ws->popf64(_707);
  std::shared_ptr< monty::ndarray< int,1 > > _714 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__714(_714 ? _714->raw() : nullptr,_714 ? _714->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _715 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__715(_715 ? _715->raw() : nullptr,_715 ? _715->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _716 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__716(_716 ? _716->raw() : nullptr,_716 ? _716->size(0) : 0);
  int _717 = (int)0;
  int _6888 = (int)0;
  int _6889 = _706;
  for (int _718 = _6888; _718 < _6889; ++_718)
  {
    {
      int _719 = _ptr__714[safe_add( _709,_718 )];
      int _720 = _ptr__714[safe_add( safe_add( _709,_718 ),(int)1 )];
      int _721 = _719;
      int _722 = (int)0;
      while ( ((_722 < (int)((_694)->size(0))) && (_721 < _720)) )
      {
        {
          if ((_ptr__694[_722] < (_ptr__715[safe_add( _711,_721 )] - (int)1)))
          {
            {
              ++ _722;
            }
          }
          else if((_ptr__694[_722] > (_ptr__715[safe_add( _711,_721 )] - (int)1)))
          {
            {
              ++ _721;
            }
          }
          else
          {
            {
              _ptr__697[safe_add( _717,_722 )] = _ptr__716[safe_add( _713,_721 )];
              ++ _722;
              ++ _721;
            }
          }
        }
      }
      _717 += (int)((_694)->size(0));
    }
  }
  task_putaijlist(_698,_701,_697,(long long)(_696));
  if (_695)
  {
    {
      std::vector<int> _6890;
      for (int _723 = (int)0, _6891 = _706; _723 < _6891 ; ++_723)
      {
        _6890.push_back(bfixidx);
      }
      auto _6892 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6890.size()),_6890.begin(),_6890.end()));
      std::vector<double> _6893;
      for (int _724 = (int)0, _6894 = _706; _724 < _6894 ; ++_724)
      {
        _6893.push_back(_ptr__716[safe_add( _712,_724 )]);
      }
      auto _6895 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6893.size()),_6893.begin(),_6893.end()));
      task_putaijlist(_692,_6892,_6895,(long long)(_706));
    }
  }
  {}
}
void mosek::fusion::Model :: updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _725,monty::rc_ptr< ::mosek::fusion::Variable > _726) { mosek::fusion::p_Model::_get_impl(this)->updateObjective(_725,_726); }void mosek::fusion::p_Model::updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _725,monty::rc_ptr< ::mosek::fusion::Variable > _726){
  if ((_725->getSize() != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _727 = _726->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _728 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_727)));
  _checked_ptr_1<long long> _ptr__728(_728 ? _728->raw() : nullptr,_728 ? _728->size(0) : 0);
  if ((_727 < _726->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _729 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_727)));
      _checked_ptr_1<long long> _ptr__729(_729 ? _729->raw() : nullptr,_729 ? _729->size(0) : 0);
      _726->inst((int)0,_729,(int)0,_728);
    }
  }
  else
  {
    {
      _726->inst((int)0,_728);
    }
  }
  int _6896 = (int)0;
  int _6897 = _727;
  for (int _730 = _6896; _730 < _6897; ++_730)
  {
    {
      if ((_ptr__728[_730] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  bool _731 = true;
  int _6898 = (int)0;
  int _6899 = (_727 - (int)1);
  for (int _732 = _6898; _732 < _6899; ++_732)
  {
    {
      _731 = (_731 && (_ptr__728[_732] < _ptr__728[(_732 - (int)1)]));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _733 = nullptr;
  _checked_ptr_1<int> _ptr__733(_733 ? _733->raw() : nullptr,_733 ? _733->size(0) : 0);
  if (_731)
  {
    {
      std::vector<int> _6900;
      for (int _734 = (int)0, _6901 = _727; _734 < _6901 ; ++_734)
      {
        _6900.push_back((int)(_ptr__728[_734] - (int)1));
      }
      auto _6902 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6900.size()),_6900.begin(),_6900.end()));
      _733 = _6902;
      _ptr__733.update(_733 ? _733->raw() : nullptr, _733 ? _733->size(0) : 0);
    }
  }
  else
  {
    {
      std::vector<long long> _6903;
      for (int _736 = (-(int)1), _6904 = _727; _736 < _6904 ; ++_736)
      {
        _6903.push_back(_736);
      }
      auto _6905 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6903.size()),_6903.begin(),_6903.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _735 = _6905;
      _checked_ptr_1<long long> _ptr__735(_735 ? _735->raw() : nullptr,_735 ? _735->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_735,_728,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_727));
      std::vector<int> _6906;
      for (int _737 = (int)0, _6907 = _727; _737 < _6907 ; ++_737)
      {
        _6906.push_back((int)(_ptr__728[_ptr__735[_737]] - (int)1));
      }
      auto _6908 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6906.size()),_6906.begin(),_6906.end()));
      _733 = _6908;
      _ptr__733.update(_733 ? _733->raw() : nullptr, _733 ? _733->size(0) : 0);
    }
  }
  int _738 = (int)((_733)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _739 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_738)));
  _checked_ptr_1<double> _ptr__739(_739 ? _739->raw() : nullptr,_739 ? _739->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _740 = _733;
  _checked_ptr_1<int> _ptr__740(_740 ? _740->raw() : nullptr,_740 ? _740->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_725)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _741 = ws->popi32();
  int _742 = ws->popi32(_741);
  int _743 = ws->popi32();
  int _744 = ws->popi32();
  bool _745 = ((int)0 != ws->popi32());
  int _746 = ws->popi32(safe_add( _743,(int)1 ));
  int _6909;
  bool _6910 = _745;
  if (_6910)
  {
    _6909 = ws->popi64(_743);
  }
  else
  {
    _6909 = (int)0;
  }
  int _747 = _6909;
  int _748 = ws->popi64(_744);
  int _749 = ws->popf64(_743);
  int _750 = ws->popf64(_744);
  std::shared_ptr< monty::ndarray< int,1 > > _751 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__751(_751 ? _751->raw() : nullptr,_751 ? _751->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _752 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__752(_752 ? _752->raw() : nullptr,_752 ? _752->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _753 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__753(_753 ? _753->raw() : nullptr,_753 ? _753->size(0) : 0);
  int _754 = (int)0;
  int _6911 = (int)0;
  int _6912 = _743;
  for (int _755 = _6911; _755 < _6912; ++_755)
  {
    {
      int _756 = _ptr__751[safe_add( _746,_755 )];
      int _757 = _ptr__751[safe_add( safe_add( _746,_755 ),(int)1 )];
      int _758 = _756;
      int _759 = (int)0;
      while ( ((_759 < (int)((_733)->size(0))) && (_758 < _757)) )
      {
        {
          if ((_ptr__733[_759] < (_ptr__752[safe_add( _748,_758 )] - (int)1)))
          {
            {
              ++ _759;
            }
          }
          else if((_ptr__733[_759] > (_ptr__752[safe_add( _748,_758 )] - (int)1)))
          {
            {
              ++ _758;
            }
          }
          else
          {
            {
              _ptr__739[safe_add( _754,_759 )] = _ptr__753[safe_add( _750,_758 )];
              ++ _759;
              ++ _758;
            }
          }
        }
      }
      _754 += (int)((_733)->size(0));
    }
  }
  task_putclist(_740,_739);
}
void mosek::fusion::p_Model::objective_(const std::string & _760,mosek::fusion::ObjectiveSense _761,monty::rc_ptr< ::mosek::fusion::Expression > _762){
  task_putobjectivename(_760);
  monty::rc_ptr< ::mosek::fusion::WorkStack > _763 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _764 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_762)).as<::mosek::fusion::Expression>())->eval(_763,_764,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _765 = mosek::fusion::p_WorkStack::_get_impl(_763)->i32;
  _checked_ptr_1<int> _ptr__765(_765 ? _765->raw() : nullptr,_765 ? _765->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _766 = mosek::fusion::p_WorkStack::_get_impl(_763)->i64;
  _checked_ptr_1<long long> _ptr__766(_766 ? _766->raw() : nullptr,_766 ? _766->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _767 = mosek::fusion::p_WorkStack::_get_impl(_763)->f64;
  _checked_ptr_1<double> _ptr__767(_767 ? _767->raw() : nullptr,_767 ? _767->size(0) : 0);
  int _768 = _763->popi32();
  int _769 = (int)1;
  int _6913 = (int)0;
  int _6914 = _768;
  for (int _770 = _6913; _770 < _6914; ++_770)
  {
    {
      _768 *= _763->popi32();
    }
  }
  if ((_769 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _771 = _763->popi32();
  if ((_771 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression for objective"));
    }
  }
  {}
  int _772 = _763->popi32();
  bool _773 = (_763->popi32() != (int)0);
  int _774 = _763->popi32(safe_add( _771,(int)1 ));
  int _775 = _763->popi64(_772);
  int _776 = _763->popf64(_771);
  int _777 = _763->popf64(_772);
  int _778 = (int)0;
  int _779 = (int)0;
  int _6915 = (int)0;
  int _6916 = _772;
  for (int _780 = _6915; _780 < _6916; ++_780)
  {
    {
      if ((_ptr__766[safe_add( _775,_780 )] < (int)0))
      {
        {
          ++ _779;
        }
      }
      else if((_ptr__766[safe_add( _775,_780 )] > (int)0))
      {
        {
          ++ _778;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _781 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_778)));
  _checked_ptr_1<int> _ptr__781(_781 ? _781->raw() : nullptr,_781 ? _781->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _782 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_778)));
  _checked_ptr_1<double> _ptr__782(_782 ? _782->raw() : nullptr,_782 ? _782->size(0) : 0);
  {
    int _783 = (int)0;
    int _6917 = (int)0;
    int _6918 = _772;
    for (int _784 = _6917; _784 < _6918; ++_784)
    {
      {
        if ((_ptr__766[safe_add( _775,_784 )] > (int)0))
        {
          {
            _ptr__781[_783] = (int)(_ptr__766[safe_add( _775,_784 )] - (int)1);
            _ptr__782[_783] = _ptr__767[safe_add( _777,_784 )];
            ++ _783;
          }
        }
        {}
      }
    }
  }
  task_putobjective((_761 == ::mosek::fusion::ObjectiveSense::Maximize),_781,_782,_ptr__767[_776]);
  if ((_779 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _785 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_779)));
      _checked_ptr_1<int> _ptr__785(_785 ? _785->raw() : nullptr,_785 ? _785->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _786 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_779)));
      _checked_ptr_1<int> _ptr__786(_786 ? _786->raw() : nullptr,_786 ? _786->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _787 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_779)));
      _checked_ptr_1<int> _ptr__787(_787 ? _787->raw() : nullptr,_787 ? _787->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _788 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_779)));
      _checked_ptr_1<double> _ptr__788(_788 ? _788->raw() : nullptr,_788 ? _788->size(0) : 0);
      int _6919 = (int)0;
      int _6920 = _779;
      for (int _789 = _6919; _789 < _6920; ++_789)
      {
        {
          long long _790 = (-safe_add( _ptr__766[safe_add( _775,_789 )],(int)1 ));
          _ptr__785[_789] = ((*natbarvar_idx)(_790));
          _ptr__786[_789] = ((*natbarvar_i)(_790));
          _ptr__787[_789] = ((*natbarvar_j)(_790));
          double _6921;
          bool _6922 = (_ptr__786[_789] == _ptr__787[_789]);
          if (_6922)
          {
            _6921 = _ptr__767[safe_add( _777,_789 )];
          }
          else
          {
            _6921 = (0.5 * _ptr__767[safe_add( _777,_789 )]);
          }
          _ptr__788[_789] = _6921;
        }
      }
      task_putbarc(_785,_786,_787,_788);
    }
  }
  {}
}
void mosek::fusion::Model :: objective(double _791) { mosek::fusion::p_Model::_get_impl(this)->objective(_791); }void mosek::fusion::p_Model::objective(double _791){
  objective_(std::string (""),::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_791));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _792,double _793) { mosek::fusion::p_Model::_get_impl(this)->objective(_792,_793); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _792,double _793){
  objective_(std::string (""),_792,::mosek::fusion::p_Expr::constTerm(_793));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _794,monty::rc_ptr< ::mosek::fusion::Expression > _795) { mosek::fusion::p_Model::_get_impl(this)->objective(_794,_795); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _794,monty::rc_ptr< ::mosek::fusion::Expression > _795){
  objective_(std::string (""),_794,_795);
}
void mosek::fusion::Model :: objective(const std::string & _796,double _797) { mosek::fusion::p_Model::_get_impl(this)->objective(_796,_797); }void mosek::fusion::p_Model::objective(const std::string & _796,double _797){
  objective_(_796,::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_797));
}
void mosek::fusion::Model :: objective(const std::string & _798,mosek::fusion::ObjectiveSense _799,double _800) { mosek::fusion::p_Model::_get_impl(this)->objective(_798,_799,_800); }void mosek::fusion::p_Model::objective(const std::string & _798,mosek::fusion::ObjectiveSense _799,double _800){
  objective_(_798,_799,::mosek::fusion::p_Expr::constTerm(_800));
}
void mosek::fusion::Model :: objective(const std::string & _801,mosek::fusion::ObjectiveSense _802,monty::rc_ptr< ::mosek::fusion::Expression > _803) { mosek::fusion::p_Model::_get_impl(this)->objective(_801,_802,_803); }void mosek::fusion::p_Model::objective(const std::string & _801,mosek::fusion::ObjectiveSense _802,monty::rc_ptr< ::mosek::fusion::Expression > _803){
  objective_(_801,_802,_803);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_804,_805); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805) { return __mosek_2fusion_2Model__constraint(_804,_805); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_804,_805);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_806,_807,_808); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808) { return __mosek_2fusion_2Model__constraint(_806,_807,_808); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808){
  return __mosek_2fusion_2Model__constraint_(_806,_807,_808);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_809,_810); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810) { return __mosek_2fusion_2Model__constraint(_809,_810); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_809,_810);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_811,_812,_813); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813) { return __mosek_2fusion_2Model__constraint(_811,_812,_813); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813){
  return __mosek_2fusion_2Model__constraint_(_811,_812,_813);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_814,_815); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815) { return __mosek_2fusion_2Model__constraint(_814,_815); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_814,_815);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_816,_817,_818); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818) { return __mosek_2fusion_2Model__constraint(_816,_817,_818); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818){
  return __mosek_2fusion_2Model__constraint_(_816,_817,_818);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_819,_820); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820) { return __mosek_2fusion_2Model__constraint(_819,_820); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_819,_820);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_821,_822,_823); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return __mosek_2fusion_2Model__constraint(_821,_822,_823); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823){
  return __mosek_2fusion_2Model__constraint_(_821,_822,_823);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_824,_825); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825) { return __mosek_2fusion_2Model__constraint(_824,_825); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_824,_825);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_826,_827,_828); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828) { return __mosek_2fusion_2Model__constraint(_826,_827,_828); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828){
  return __mosek_2fusion_2Model__constraint_(_826,_827,_828);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_829); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return __mosek_2fusion_2Model__variable(_829); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829){
  return __mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_LinPSDDomain::_get_impl(_829)->shape,_829);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_830,_831,_832); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return __mosek_2fusion_2Model__variable(_830,_831,_832); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_830),(int)(_830),(int)(_831)}),_832);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_833,_834); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834) { return __mosek_2fusion_2Model__variable(_833,_834); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_833),(int)(_833)}),_834);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_835,_836); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836) { return __mosek_2fusion_2Model__variable(_835,_836); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836){
  return __mosek_2fusion_2Model__variable_(_835,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_836);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_837,_838,_839,_840); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) { return __mosek_2fusion_2Model__variable(_837,_838,_839,_840); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840){
  return __mosek_2fusion_2Model__variable_(_837,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_838),(int)(_838),(int)(_839)}),_840);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_841,_842,_843); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843) { return __mosek_2fusion_2Model__variable(_841,_842,_843); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843){
  return __mosek_2fusion_2Model__variable_(_841,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_842),(int)(_842)}),_843);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_844,_845,_846); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) { return __mosek_2fusion_2Model__variable(_844,_845,_846); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846){
  _checked_ptr_1<int> _ptr__845(_845 ? _845->raw() : nullptr, _845 ? _845->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_844,_845,_846);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_847); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return __mosek_2fusion_2Model__variable(_847); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847){
  return (__mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_PSDDomain::_get_impl(_847)->shape,_847)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_848,_849,_850); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return __mosek_2fusion_2Model__variable(_848,_849,_850); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_848),(int)(_848),(int)(_849)}),_850)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_851,_852); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852) { return __mosek_2fusion_2Model__variable(_851,_852); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_851),(int)(_851)}),_852)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_853,_854); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854) { return __mosek_2fusion_2Model__variable(_853,_854); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854){
  return (__mosek_2fusion_2Model__variable_(_853,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_854)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_855,_856,_857,_858); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) { return __mosek_2fusion_2Model__variable(_855,_856,_857,_858); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858){
  return (__mosek_2fusion_2Model__variable_(_855,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_856),(int)(_856),(int)(_857)}),_858)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_859,_860,_861); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861) { return __mosek_2fusion_2Model__variable(_859,_860,_861); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861){
  return (__mosek_2fusion_2Model__variable_(_859,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_860),(int)(_860)}),_861)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_862,_863,_864); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) { return __mosek_2fusion_2Model__variable(_862,_863,_864); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864){
  _checked_ptr_1<int> _ptr__863(_863 ? _863->raw() : nullptr, _863 ? _863->size(0) : 0);
  return (__mosek_2fusion_2Model__variable_(_862,_863,_864)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_865); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return __mosek_2fusion_2Model__variable(_865); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_865);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_866); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866) { return __mosek_2fusion_2Model__variable(_866); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_866);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867) { return __mosek_2fusion_2Model__variable(_867); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_867);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_868,_869); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869) { return __mosek_2fusion_2Model__variable(_868,_869); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869){
  _checked_ptr_1<int> _ptr__868(_868 ? _868->raw() : nullptr, _868 ? _868->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_868,_869);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_870,_871); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871) { return __mosek_2fusion_2Model__variable(_870,_871); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871){
  _checked_ptr_1<int> _ptr__870(_870 ? _870->raw() : nullptr, _870 ? _870->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),_870,_871);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_872,_873); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) { return __mosek_2fusion_2Model__variable(_872,_873); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873){
  _checked_ptr_1<int> _ptr__872(_872 ? _872->raw() : nullptr, _872 ? _872->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_872,_873);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_874); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _874) { return __mosek_2fusion_2Model__variable(_874); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874){
  _checked_ptr_1<int> _ptr__874(_874 ? _874->raw() : nullptr, _874 ? _874->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_874,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_875,_876); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876) { return __mosek_2fusion_2Model__variable(_875,_876); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_875)}),_876);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_877,_878); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878) { return __mosek_2fusion_2Model__variable(_877,_878); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_877)}),_878);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_879,_880); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880) { return __mosek_2fusion_2Model__variable(_879,_880); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_879)}),_880);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _881) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_881); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _881) { return __mosek_2fusion_2Model__variable(_881); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _881){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_881)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable() { return __mosek_2fusion_2Model__variable(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_882,_883); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883) { return __mosek_2fusion_2Model__variable(_882,_883); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883){
  return __mosek_2fusion_2Model__variable_(_882,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_883);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_884,_885); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885) { return __mosek_2fusion_2Model__variable(_884,_885); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885){
  return __mosek_2fusion_2Model__ranged_variable(_884,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_885);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_886,_887); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887) { return __mosek_2fusion_2Model__variable(_886,_887); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887){
  return __mosek_2fusion_2Model__variable_(_886,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_887);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_888,_889,_890); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return __mosek_2fusion_2Model__variable(_888,_889,_890); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890){
  _checked_ptr_1<int> _ptr__889(_889 ? _889->raw() : nullptr, _889 ? _889->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_888,_889,_890);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_891,_892,_893); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return __mosek_2fusion_2Model__variable(_891,_892,_893); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893){
  _checked_ptr_1<int> _ptr__892(_892 ? _892->raw() : nullptr, _892 ? _892->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(_891,_892,_893);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_894,_895,_896); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return __mosek_2fusion_2Model__variable(_894,_895,_896); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896){
  _checked_ptr_1<int> _ptr__895(_895 ? _895->raw() : nullptr, _895 ? _895->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_894,_895,_896);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _897,std::shared_ptr< monty::ndarray< int,1 > > _898) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_897,_898); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _897,std::shared_ptr< monty::ndarray< int,1 > > _898) { return __mosek_2fusion_2Model__variable(_897,_898); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _897,std::shared_ptr< monty::ndarray< int,1 > > _898){
  _checked_ptr_1<int> _ptr__898(_898 ? _898->raw() : nullptr, _898 ? _898->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_897,_898,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_899,_900,_901); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901) { return __mosek_2fusion_2Model__variable(_899,_900,_901); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901){
  return __mosek_2fusion_2Model__variable_(_899,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_900)}),_901);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_902,_903,_904); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904) { return __mosek_2fusion_2Model__variable(_902,_903,_904); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904){
  return __mosek_2fusion_2Model__ranged_variable(_902,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_903)}),_904);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_905,_906,_907); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907) { return __mosek_2fusion_2Model__variable(_905,_906,_907); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907){
  return __mosek_2fusion_2Model__variable_(_905,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_906)}),_907);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _908,int _909) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_908,_909); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _908,int _909) { return __mosek_2fusion_2Model__variable(_908,_909); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _908,int _909){
  return __mosek_2fusion_2Model__variable_(_908,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_909)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _910) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_910); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _910) { return __mosek_2fusion_2Model__variable(_910); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _910){
  return __mosek_2fusion_2Model__variable_(_910,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__ranged_variable(const std::string & _911,std::shared_ptr< monty::ndarray< int,1 > > _912,monty::rc_ptr< ::mosek::fusion::RangeDomain > _913){
  _checked_ptr_1<int> _ptr__912(_912 ? _912->raw() : nullptr, _912 ? _912->size(0) : 0);
  if ((((int)((_911).size()) > (int)0) && hasVariable(_911)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_911)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6923;
  bool _6924 = (NULL != _912.get());
  if (_6924)
  {
    _6923 = _912;
  }
  else
  {
    _6923 = mosek::fusion::p_RangeDomain::_get_impl(_913)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _914 = _6923;
  _checked_ptr_1<int> _ptr__914(_914 ? _914->raw() : nullptr,_914 ? _914->size(0) : 0);
  if (((NULL != mosek::fusion::p_RangeDomain::_get_impl(_913)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_RangeDomain::_get_impl(_913)->shape,_914))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _914.get()))
  {
    {
      _914 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__914.update(_914 ? _914->raw() : nullptr, _914 ? _914->size(0) : 0);
    }
  }
  {}
  int _915 = (int)((_914)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _916 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_915)));
  _checked_ptr_1<int> _ptr__916(_916 ? _916->raw() : nullptr,_916 ? _916->size(0) : 0);
  if ((_915 > (int)0))
  {
    {
      _ptr__916[(_915 - (int)1)] = (int)1;
      int _6925 = (int)1;
      int _6926 = _915;
      for (int _917 = _6925; _917 < _6926; ++_917)
      {
        {
          _ptr__916[((_915 - _917) - (int)1)] = safe_mul( _ptr__916[(_915 - _917)],_ptr__914[(_915 - _917)] );
        }
      }
    }
  }
  {}
  int _918 = (int)1;
  int _6927 = (int)0;
  int _6928 = (int)((_914)->size(0));
  for (int _919 = _6927; _919 < _6928; ++_919)
  {
    {
      _918 *= _ptr__914[_919];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _920 = nullptr;
  _checked_ptr_1<long long> _ptr__920(_920 ? _920->raw() : nullptr,_920 ? _920->size(0) : 0);
  if ((NULL != _920.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(1)) != _915))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      _920 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(0)))));
      _ptr__920.update(_920 ? _920->raw() : nullptr, _920 ? _920->size(0) : 0);
      int _6929 = (int)0;
      int _6930 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(0));
      for (int _921 = _6929; _921 < _6930; ++_921)
      {
        {
          int _6931 = (int)0;
          int _6932 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(1));
          for (int _922 = _6931; _922 < _6932; ++_922)
          {
            {
              if (((((*mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)(_921,_922)) < (int)0) || (((*mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)(_921,_922)) >= _ptr__914[_922])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _923 = (int)0;
          int _6933 = (int)0;
          int _6934 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(1));
          for (int _924 = _6933; _924 < _6934; ++_924)
          {
            {
              _923 += safe_mul( _ptr__916[_924],((*mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)(_921,_924)) );
            }
          }
          _ptr__920[_921] = _923;
        }
      }
    }
  }
  {}
  int _6935;
  bool _6936 = (NULL != _920.get());
  if (_6936)
  {
    _6935 = (int)((_920)->size(0));
  }
  else
  {
    _6935 = _918;
  }
  int _925 = _6935;
  std::shared_ptr< monty::ndarray< double,1 > > _926;
  _checked_ptr_1<double> _ptr__926(_926 ? _926->raw() : nullptr,_926 ? _926->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _927;
  _checked_ptr_1<double> _ptr__927(_927 ? _927->raw() : nullptr,_927 ? _927->size(0) : 0);
  if (mosek::fusion::p_RangeDomain::_get_impl(_913)->scalable)
  {
    {
      std::vector<double> _6937;
      for (int _928 = (int)0, _6938 = _925; _928 < _6938 ; ++_928)
      {
        _6937.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_913)->lb)((int)0)));
      }
      auto _6939 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6937.size()),_6937.begin(),_6937.end()));
      _926 = _6939;
      _ptr__926.update(_926 ? _926->raw() : nullptr, _926 ? _926->size(0) : 0);
      std::vector<double> _6940;
      for (int _929 = (int)0, _6941 = _925; _929 < _6941 ; ++_929)
      {
        _6940.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_913)->ub)((int)0)));
      }
      auto _6942 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6940.size()),_6940.begin(),_6940.end()));
      _927 = _6942;
      _ptr__927.update(_927 ? _927->raw() : nullptr, _927 ? _927->size(0) : 0);
    }
  }
  else
  {
    {
      _926 = mosek::fusion::p_RangeDomain::_get_impl(_913)->lb;
      _ptr__926.update(_926 ? _926->raw() : nullptr, _926 ? _926->size(0) : 0);
      _927 = mosek::fusion::p_RangeDomain::_get_impl(_913)->ub;
      _ptr__927.update(_927 ? _927->raw() : nullptr, _927 ? _927->size(0) : 0);
    }
  }
  int _930 = natvarmap_alloc(_925);
  std::shared_ptr< monty::ndarray< int,1 > > _931 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_930))));
  _checked_ptr_1<int> _ptr__931(_931 ? _931->raw() : nullptr,_931 ? _931->size(0) : 0);
  natvarmap->get(_930,_931,(int)0);
  int _6943 = (int)0;
  int _6944 = _925;
  for (int _932 = _6943; _932 < _6944; ++_932)
  {
    {
      ((*natvarmap_idx)(_ptr__931[_932])) = _930;
    }
  }
  task_var_putboundlist_ra(_931,_926,_927);
  monty::rc_ptr< ::mosek::fusion::RangedVariable > _933 = ::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::Model::t(_pubthis),_911,(long long)(_930),_914,_920,_931);
  if (mosek::fusion::p_RangeDomain::_get_impl(_913)->cardinal_flag)
  {
    {
      task_var_putintlist(_931);
    }
  }
  {}
  ((*vars)(_930)) = (_933).as<::mosek::fusion::ModelVariable>();
  if (((int)((_911).size()) > (int)0))
  {
    {
      var_map->setItem(_911,_930);
    }
  }
  {}
  return (_933).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _934,std::shared_ptr< monty::ndarray< int,1 > > _935,monty::rc_ptr< ::mosek::fusion::ConeDomain > _936){
  _checked_ptr_1<int> _ptr__935(_935 ? _935->raw() : nullptr, _935 ? _935->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6945;
  bool _6946 = (NULL != _935.get());
  if (_6946)
  {
    _6945 = _935;
  }
  else
  {
    _6945 = mosek::fusion::p_ConeDomain::_get_impl(_936)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _937 = _6945;
  _checked_ptr_1<int> _ptr__937(_937 ? _937->raw() : nullptr,_937 ? _937->size(0) : 0);
  if ((((int)((_934).size()) > (int)0) && hasVariable(_934)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_934)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((NULL == _937.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape"));
    }
  }
  else if(((NULL != mosek::fusion::p_ConeDomain::_get_impl(_936)->shape.get()) && (!::mosek::fusion::p_Set::match(_937,mosek::fusion::p_ConeDomain::_get_impl(_936)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  else if((_936->getAxis() >= (int)((_937)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone dimension"));
    }
  }
  {}
  int _6947;
  bool _6948 = (NULL != mosek::fusion::p_ConeDomain::_get_impl(_936)->shape.get());
  if (_6948)
  {
    _6947 = _936->getAxis();
  }
  else
  {
    _6947 = ((int)((_937)->size(0)) - (int)1);
  }
  int _938 = _6947;
  int _939 = _ptr__937[_938];
  int _940 = (int)((_937)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _941 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_940)));
  _checked_ptr_1<int> _ptr__941(_941 ? _941->raw() : nullptr,_941 ? _941->size(0) : 0);
  _ptr__941[(_940 - (int)1)] = (int)1;
  int _6949 = (int)1;
  int _6950 = _940;
  for (int _942 = _6949; _942 < _6950; ++_942)
  {
    {
      _ptr__941[((_940 - _942) - (int)1)] = safe_mul( _ptr__941[(_940 - _942)],_ptr__937[(_940 - _942)] );
    }
  }
  int _943 = _ptr__937[(int)0];
  int _6951 = (int)1;
  int _6952 = (int)((_937)->size(0));
  for (int _944 = _6951; _944 < _6952; ++_944)
  {
    {
      _943 *= _ptr__937[_944];
    }
  }
  int _945 = (int)1;
  int _6953 = (int)0;
  int _6954 = _938;
  for (int _946 = _6953; _946 < _6954; ++_946)
  {
    {
      _945 *= _ptr__937[_946];
    }
  }
  int _947 = (int)1;
  int _6955 = safe_add( _938,(int)1 );
  int _6956 = _940;
  for (int _948 = _6955; _948 < _6956; ++_948)
  {
    {
      _947 *= _ptr__937[_948];
    }
  }
  int _949 = safe_mul( _945,_947 );
  if ((((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InQCone) && (_939 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_939 < (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_939 != (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_939 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_939 != (int)3)) || ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_939 < (int)2))))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for cone"));
    }
  }
  {}
  int _950 = natvarmap_alloc(_943);
  int _951 = natconemap_alloc(_949);
  ((*natvarmap_type)(_950)) = safe_add( _951,(int)6 );
  std::shared_ptr< monty::ndarray< int,1 > > _952 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_950))));
  _checked_ptr_1<int> _ptr__952(_952 ? _952->raw() : nullptr,_952 ? _952->size(0) : 0);
  natvarmap->get(_950,_952,(int)0);
  int _6957 = (int)0;
  int _6958 = _943;
  for (int _953 = _6957; _953 < _6958; ++_953)
  {
    {
      ((*natvarmap_idx)(_ptr__952[_953])) = _950;
    }
  }
  task_var_putboundlist_fr(_952);
  if (mosek::fusion::p_ConeDomain::_get_impl(_936)->int_flag)
  {
    {
      task_var_putintlist(_952);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _954 = _952;
  _checked_ptr_1<int> _ptr__954(_954 ? _954->raw() : nullptr,_954 ? _954->size(0) : 0);
  if ((_938 < ((int)((_937)->size(0)) - (int)1)))
  {
    {
      _954 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_952)->size(0)))));
      _ptr__954.update(_954 ? _954->raw() : nullptr, _954 ? _954->size(0) : 0);
      int _955 = (int)0;
      int _6959 = (int)0;
      int _6960 = _945;
      for (int _956 = _6959; _956 < _6960; ++_956)
      {
        {
          int _6961 = (int)0;
          int _6962 = _947;
          for (int _957 = _6961; _957 < _6962; ++_957)
          {
            {
              int _6963 = (int)0;
              int _6964 = _939;
              for (int _958 = _6963; _958 < _6964; ++_958)
              {
                {
                  _ptr__954[_955] = _ptr__952[safe_add( safe_mul( safe_add( safe_mul( _956,_939 ),_958 ),_947 ),_957 )];
                  ++ _955;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _959 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_949)));
  _checked_ptr_1<int> _ptr__959(_959 ? _959->raw() : nullptr,_959 ? _959->size(0) : 0);
  natconemap->get(_951,_959,(int)0);
  ((*natconemap_dim)(_951)) = _939;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_959,_939,_949,_954);
    }
  }
  else
  {
    {
      if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
      {
        {
          task_put_rquadcones(_959,_939,_949,_954);
        }
      }
      else
      {
        {
          if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPExpCone))
          {
            {
              task_put_pexpcones(_959,_939,_949,_954);
            }
          }
          else
          {
            {
              if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPPowCone))
              {
                {
                  std::vector<double> _6965;
                  for (int _960 = (int)0, _6966 = _949; _960 < _6966 ; ++_960)
                  {
                    _6965.push_back(mosek::fusion::p_ConeDomain::_get_impl(_936)->alpha);
                  }
                  auto _6967 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6965.size()),_6965.begin(),_6965.end()));
                  task_put_ppowcones(_959,_939,_949,_954,_6967);
                }
              }
              else
              {
                {
                  if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDExpCone))
                  {
                    {
                      task_put_dexpcones(_959,_939,_949,_954);
                    }
                  }
                  else
                  {
                    {
                      if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDPowCone))
                      {
                        {
                          std::vector<double> _6968;
                          for (int _961 = (int)0, _6969 = _949; _961 < _6969 ; ++_961)
                          {
                            _6968.push_back(mosek::fusion::p_ConeDomain::_get_impl(_936)->alpha);
                          }
                          auto _6970 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6968.size()),_6968.begin(),_6968.end()));
                          task_put_dpowcones(_959,_939,_949,_954,_6970);
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _6971 = (int)0;
  int _6972 = (int)((_959)->size(0));
  for (int _962 = _6971; _962 < _6972; ++_962)
  {
    {
      task_cone_name(_ptr__959[_962],::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__959[_962])->toString());
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicVariable > _963 = ::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::Model::t(_pubthis),_934,_950,_937,_952);
  ((*vars)(_950)) = (_963).as<::mosek::fusion::ModelVariable>();
  if (((int)((_934).size()) > (int)0))
  {
    {
      var_map->setItem(_934,_950);
    }
  }
  {}
  return (_963).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _964,std::shared_ptr< monty::ndarray< int,1 > > _965,monty::rc_ptr< ::mosek::fusion::LinearDomain > _966){
  _checked_ptr_1<int> _ptr__965(_965 ? _965->raw() : nullptr, _965 ? _965->size(0) : 0);
  if ((((int)((_964).size()) > (int)0) && hasVariable(_964)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_964)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6973;
  bool _6974 = (NULL != _965.get());
  if (_6974)
  {
    _6973 = _965;
  }
  else
  {
    _6973 = mosek::fusion::p_LinearDomain::_get_impl(_966)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _967 = _6973;
  _checked_ptr_1<int> _ptr__967(_967 ? _967->raw() : nullptr,_967 ? _967->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_966)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinearDomain::_get_impl(_966)->shape,_967))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _967.get()))
  {
    {
      _967 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__967.update(_967 ? _967->raw() : nullptr, _967 ? _967->size(0) : 0);
    }
  }
  {}
  int _968 = (int)((_967)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _969 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_968)));
  _checked_ptr_1<int> _ptr__969(_969 ? _969->raw() : nullptr,_969 ? _969->size(0) : 0);
  if ((_968 > (int)0))
  {
    {
      _ptr__969[(_968 - (int)1)] = (int)1;
      int _6975 = (int)1;
      int _6976 = _968;
      for (int _970 = _6975; _970 < _6976; ++_970)
      {
        {
          _ptr__969[((_968 - _970) - (int)1)] = safe_mul( _ptr__969[(_968 - _970)],_ptr__967[(_968 - _970)] );
        }
      }
    }
  }
  {}
  int _971 = (int)1;
  int _6977 = (int)0;
  int _6978 = (int)((_967)->size(0));
  for (int _972 = _6977; _972 < _6978; ++_972)
  {
    {
      _971 *= _ptr__967[_972];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _973 = nullptr;
  _checked_ptr_1<long long> _ptr__973(_973 ? _973->raw() : nullptr,_973 ? _973->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _974 = nullptr;
  _checked_ptr_1<int> _ptr__974(_974 ? _974->raw() : nullptr,_974 ? _974->size(0) : 0);
  if (mosek::fusion::p_LinearDomain::_get_impl(_966)->empty)
  {
    {
      _973 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
      _ptr__973.update(_973 ? _973->raw() : nullptr, _973 ? _973->size(0) : 0);
    }
  }
  else if((NULL != mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)->size(1)) != _968))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      int _975 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)->size(0));
      _973 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_975)));
      _ptr__973.update(_973 ? _973->raw() : nullptr, _973 ? _973->size(0) : 0);
      {
        bool _976 = false;
        std::shared_ptr< monty::ndarray< int,2 > > _977 = mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity;
        int _6979 = (int)0;
        int _6980 = _975;
        for (int _978 = _6979; _978 < _6980; ++_978)
        {
          {
            int _6981 = (int)0;
            int _6982 = (int)((_977)->size(1));
            for (int _979 = _6981; _979 < _6982; ++_979)
            {
              {
                _976 = (_976 || ((((*_977)(_978,_979)) < (int)0) || (((*_977)(_978,_979)) >= _ptr__967[_979])));
              }
            }
            if ((!_976))
            {
              {
                long long _980 = (int)0;
                int _6983 = (int)0;
                int _6984 = (int)((_977)->size(1));
                for (int _981 = _6983; _981 < _6984; ++_981)
                {
                  {
                    _980 += safe_mul( _ptr__969[_981],((*_977)(_978,_981)) );
                  }
                }
                _ptr__973[_978] = _980;
              }
            }
            {}
          }
        }
        if (_976)
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is out of bounds"));
          }
        }
        {}
      }
      std::shared_ptr< monty::ndarray< int,2 > > _982 = mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity;
      int _983 = (int)0;
      int _6985 = (int)0;
      int _6986 = _968;
      for (int _984 = _6985; _984 < _6986; ++_984)
      {
        {
          if ((_983 < _ptr__967[_984]))
          {
            {
              _983 = _ptr__967[_984];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _985 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_975)));
      _checked_ptr_1<int> _ptr__985(_985 ? _985->raw() : nullptr,_985 ? _985->size(0) : 0);
      int _6987 = (int)0;
      int _6988 = _975;
      for (int _986 = _6987; _986 < _6988; ++_986)
      {
        {
          _ptr__985[_986] = _986;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _987 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_975)));
      _checked_ptr_1<int> _ptr__987(_987 ? _987->raw() : nullptr,_987 ? _987->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _988 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _983,(int)1 ))));
      _checked_ptr_1<int> _ptr__988(_988 ? _988->raw() : nullptr,_988 ? _988->size(0) : 0);
      int _6989 = (int)0;
      int _6990 = _968;
      for (int _989 = _6989; _989 < _6990; ++_989)
      {
        {
          {
            int _990 = ((_968 - _989) - (int)1);
            int _6991 = (int)0;
            int _6992 = safe_add( _ptr__967[_990],(int)1 );
            for (int _991 = _6991; _991 < _6992; ++_991)
            {
              {
                _ptr__988[_991] = (int)0;
              }
            }
            int _6993 = (int)0;
            int _6994 = _975;
            for (int _992 = _6993; _992 < _6994; ++_992)
            {
              {
                ++ _ptr__988[safe_add( ((*_982)(_992,_990)),(int)1 )];
              }
            }
            int _6995 = (int)0;
            int _6996 = _ptr__967[_990];
            for (int _993 = _6995; _993 < _6996; ++_993)
            {
              {
                _ptr__988[safe_add( _993,(int)1 )] += _ptr__988[_993];
              }
            }
            int _6997 = (int)0;
            int _6998 = _975;
            for (int _994 = _6997; _994 < _6998; ++_994)
            {
              {
                int _995 = _ptr__985[_994];
                _ptr__987[_ptr__988[((*_982)(_995,_990))]] = _995;
                ++ _ptr__988[((*_982)(_995,_990))];
              }
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _996 = _985;
          _checked_ptr_1<int> _ptr__996(_996 ? _996->raw() : nullptr,_996 ? _996->size(0) : 0);
          _985 = _987;
          _ptr__985.update(_985 ? _985->raw() : nullptr, _985 ? _985->size(0) : 0);
          _987 = _996;
          _ptr__987.update(_987 ? _987->raw() : nullptr, _987 ? _987->size(0) : 0);
        }
      }
      int _6999 = (int)0;
      int _7000 = _975;
      for (int _997 = _6999; _997 < _7000; ++_997)
      {
        {
          int _998 = _ptr__985[_997];
          long long _999 = (int)0;
          int _7001 = (int)0;
          int _7002 = _968;
          for (int _1000 = _7001; _1000 < _7002; ++_1000)
          {
            {
              _999 += safe_mul( _ptr__969[_1000],((*_982)(_998,_1000)) );
            }
          }
          _ptr__973[_997] = _999;
        }
      }
    }
  }
  {}
  int _7003;
  bool _7004 = (NULL != _973.get());
  if (_7004)
  {
    _7003 = (int)((_973)->size(0));
  }
  else
  {
    _7003 = _971;
  }
  int _1001 = _7003;
  std::shared_ptr< monty::ndarray< double,1 > > _1002 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1001)));
  _checked_ptr_1<double> _ptr__1002(_1002 ? _1002->raw() : nullptr,_1002 ? _1002->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd)->size(0)) == (int)1))
      {
        {
          int _7005 = (int)0;
          int _7006 = _1001;
          for (int _1003 = _7005; _1003 < _7006; ++_1003)
          {
            {
              _ptr__1002[_1003] = ((*mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd)((int)0));
            }
          }
        }
      }
      else if(((int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd)->size(0)) == _1001))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd,(int)0,_1002,(int)0,_1001);
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid right hand side shape in domain"));
        }
      }
    }
  }
  {}
  int _1004 = natvarmap_alloc(_1001);
  std::shared_ptr< monty::ndarray< int,1 > > _1005 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_1004))));
  _checked_ptr_1<int> _ptr__1005(_1005 ? _1005->raw() : nullptr,_1005 ? _1005->size(0) : 0);
  natvarmap->get(_1004,_1005,(int)0);
  int _7007 = (int)0;
  int _7008 = _1001;
  for (int _1006 = _7007; _1006 < _7008; ++_1006)
  {
    {
      ((*natvarmap_idx)(_ptr__1005[_1006])) = _1004;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      task_var_putboundlist_fr(_1005);
      ((*natvarmap_type)(_1004)) = (int)1;
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      task_var_putboundlist_up(_1005,_1002);
      ((*natvarmap_type)(_1004)) = (int)3;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      task_var_putboundlist_lo(_1005,_1002);
      ((*natvarmap_type)(_1004)) = (int)2;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      task_var_putboundlist_fx(_1005,_1002);
      ((*natvarmap_type)(_1004)) = (int)5;
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearVariable > _1007 = ::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::Model::t(_pubthis),_964,(long long)(_1004),_967,_973,_1005);
  if (mosek::fusion::p_LinearDomain::_get_impl(_966)->cardinal_flag)
  {
    {
      task_var_putintlist(_1005);
    }
  }
  {}
  ((*vars)(_1004)) = (_1007).as<::mosek::fusion::ModelVariable>();
  if (((int)((_964).size()) > (int)0))
  {
    {
      var_map->setItem(_964,_1004);
    }
  }
  {}
  return (_1007).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1008,std::shared_ptr< monty::ndarray< int,1 > > _1009,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1010){
  _checked_ptr_1<int> _ptr__1009(_1009 ? _1009->raw() : nullptr, _1009 ? _1009->size(0) : 0);
  if ((((int)((_1008).size()) > (int)0) && hasVariable(_1008)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1008)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7009;
  bool _7010 = (NULL != _1009.get());
  if (_7010)
  {
    _7009 = _1009;
  }
  else
  {
    _7009 = mosek::fusion::p_LinPSDDomain::_get_impl(_1010)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1011 = _7009;
  _checked_ptr_1<int> _ptr__1011(_1011 ? _1011->raw() : nullptr,_1011 ? _1011->size(0) : 0);
  if ((NULL == _1011.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  else if((!::mosek::fusion::p_Set::match(mosek::fusion::p_LinPSDDomain::_get_impl(_1010)->shape,_1011)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  int _1012 = (int)((_1011)->size(0));
  int _1013 = mosek::fusion::p_LinPSDDomain::_get_impl(_1010)->conedim;
  if (((_1013 < (int)0) || (_1013 >= _1012)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone direction dimension"));
    }
  }
  {}
  int _1014 = _ptr__1011[_1013];
  int _1015 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1014 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1015,safe_add( _1015,(int)1 ) ) / (int)2) != _1014))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1016 = (int)1;
  int _1017 = _ptr__1011[_1013];
  int _1018 = (int)1;
  int _7011 = (int)0;
  int _7012 = _1013;
  for (int _1019 = _7011; _1019 < _7012; ++_1019)
  {
    {
      _1018 *= _ptr__1011[_1019];
    }
  }
  int _7013 = safe_add( _1013,(int)1 );
  int _7014 = _1012;
  for (int _1020 = _7013; _1020 < _7014; ++_1020)
  {
    {
      _1016 *= _ptr__1011[_1020];
    }
  }
  int _1021 = safe_mul( _1018,_1016 );
  int _1022 = safe_mul( _1021,_1014 );
  int _1023 = natbarvarmap_alloc(_1021,_1015);
  std::shared_ptr< monty::ndarray< int,1 > > _1024 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1022)));
  _checked_ptr_1<int> _ptr__1024(_1024 ? _1024->raw() : nullptr,_1024 ? _1024->size(0) : 0);
  natbarvarmap_get(_1023,_1024);
  std::shared_ptr< monty::ndarray< long long,1 > > _1025 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1021,_1017 ))));
  _checked_ptr_1<long long> _ptr__1025(_1025 ? _1025->raw() : nullptr,_1025 ? _1025->size(0) : 0);
  {
    int _1026 = (int)0;
    int _7015 = (int)0;
    int _7016 = _1018;
    for (int _1027 = _7015; _1027 < _7016; ++_1027)
    {
      {
        int _7017 = (int)0;
        int _7018 = _1017;
        for (int _1028 = _7017; _1028 < _7018; ++_1028)
        {
          {
            int _7019 = (int)0;
            int _7020 = safe_add( _1028,(int)1 );
            for (int _1029 = _7019; _1029 < _7020; ++_1029)
            {
              {
                int _7021 = (int)0;
                int _7022 = _1016;
                for (int _1030 = _7021; _1030 < _7022; ++_1030)
                {
                  {
                    _ptr__1025[_1026] = safe_add( ((*natbarvar_ptr)(safe_add( safe_mul( _1027,_1016 ),_1030 ))),safe_add( (safe_mul( _1028,((safe_mul( (int)2,_1015 ) - _1028) - (int)1) ) / (int)2),_1029 ) );
                    ++ _1026;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1031 = ::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::Model::t(_pubthis),_1008,_1023,_1011,_1013,_1025);
  ((*barvars)(_1023)) = (_1031).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1008).size()) > (int)0))
  {
    {
      var_map->setItem(_1008,(-safe_add( _1023,(int)1 )));
    }
  }
  {}
  return (_1031).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::SymmetricVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1032,std::shared_ptr< monty::ndarray< int,1 > > _1033,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1034){
  _checked_ptr_1<int> _ptr__1033(_1033 ? _1033->raw() : nullptr, _1033 ? _1033->size(0) : 0);
  if ((((int)((_1032).size()) > (int)0) && hasVariable(_1032)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1032)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1035 = _1033;
  _checked_ptr_1<int> _ptr__1035(_1035 ? _1035->raw() : nullptr,_1035 ? _1035->size(0) : 0);
  if ((NULL == _1035.get()))
  {
    {
      _1035 = mosek::fusion::p_PSDDomain::_get_impl(_1034)->shape;
      _ptr__1035.update(_1035 ? _1035->raw() : nullptr, _1035 ? _1035->size(0) : 0);
    }
  }
  {}
  if ((NULL == _1035.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  {}
  int _1036 = mosek::fusion::p_PSDDomain::_get_impl(_1034)->conedim1;
  int _1037 = mosek::fusion::p_PSDDomain::_get_impl(_1034)->conedim2;
  int _1038 = (int)((_1035)->size(0));
  int _1039 = _ptr__1035[_1036];
  if ((_1036 > _1037))
  {
    {
      int _1040 = _1036;
      _1036 = _1037;
      _1037 = _1040;
    }
  }
  {}
  if (((_1036 == _1037) || ((_1036 < (int)0) || (_1037 >= _1038))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone order dimensions for semidefinite variables"));
    }
  }
  {}
  if ((_ptr__1035[_1036] != _ptr__1035[_1037]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape in cone order dimensions"));
    }
  }
  {}
  int _1041 = (int)1;
  int _7023 = (int)0;
  int _7024 = _1036;
  for (int _1042 = _7023; _1042 < _7024; ++_1042)
  {
    {
      _1041 *= _ptr__1035[_1042];
    }
  }
  int _7025 = safe_add( _1036,(int)1 );
  int _7026 = _1037;
  for (int _1043 = _7025; _1043 < _7026; ++_1043)
  {
    {
      _1041 *= _ptr__1035[_1043];
    }
  }
  int _7027 = safe_add( _1037,(int)1 );
  int _7028 = _1038;
  for (int _1044 = _7027; _1044 < _7028; ++_1044)
  {
    {
      _1041 *= _ptr__1035[_1044];
    }
  }
  int _1045 = (safe_mul( safe_mul( _1041,_1039 ),safe_add( _1039,(int)1 ) ) / (int)2);
  int _1046 = natbarvarmap_alloc(_1041,_1039);
  std::shared_ptr< monty::ndarray< long long,1 > > _1047 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1045)));
  _checked_ptr_1<long long> _ptr__1047(_1047 ? _1047->raw() : nullptr,_1047 ? _1047->size(0) : 0);
  natbarvar_get(_1046,_1047);
  monty::rc_ptr< ::mosek::fusion::PSDVariable > _1048 = ::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::Model::t(_pubthis),_1032,_1046,_1035,mosek::fusion::p_PSDDomain::_get_impl(_1034)->conedim1,mosek::fusion::p_PSDDomain::_get_impl(_1034)->conedim2,_1047);
  ((*barvars)(_1046)) = (_1048).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1032).size()) > (int)0))
  {
    {
      var_map->setItem(_1032,(-safe_add( _1046,(int)1 )));
    }
  }
  {}
  return (_1048).as<::mosek::fusion::SymmetricVariable>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1049,monty::rc_ptr< ::mosek::fusion::Expression > _1050,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1051){
  if ((((int)((_1049).size()) > (int)0) && hasConstraint(_1049)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1049)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_RangeDomain::_get_impl(_1051)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1052 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1050)).as<::mosek::fusion::Expression>());
  _1052->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1053 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1053(_1053 ? _1053->raw() : nullptr,_1053 ? _1053->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1054 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1054(_1054 ? _1054->raw() : nullptr,_1054 ? _1054->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1055 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1055(_1055 ? _1055->raw() : nullptr,_1055 ? _1055->size(0) : 0);
  int _1056 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1057 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1058 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1059 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1060 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1061 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1062 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1063 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1064 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  if ((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1051)->shape.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1051)->shape)->size(0)) != _1056))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
        }
      }
      else
      {
        {
          int _7029 = (int)0;
          int _7030 = _1056;
          for (int _1065 = _7029; _1065 < _7030; ++_1065)
          {
            {
              if ((((*mosek::fusion::p_RangeDomain::_get_impl(_1051)->shape)(_1065)) != _ptr__1053[safe_add( _1057,_1065 )]))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  {}
  int _1066 = (int)1;
  int _7031 = (int)0;
  int _7032 = _1056;
  for (int _1067 = _7031; _1067 < _7032; ++_1067)
  {
    {
      _1066 *= _ptr__1053[safe_add( _1057,_1067 )];
    }
  }
  int _1068 = natconmap_alloc(_1066);
  std::shared_ptr< monty::ndarray< int,1 > > _1069 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1066)));
  _checked_ptr_1<int> _ptr__1069(_1069 ? _1069->raw() : nullptr,_1069 ? _1069->size(0) : 0);
  natconmap->get(_1068,_1069,(int)0);
  int _7033 = (int)0;
  int _7034 = _1066;
  for (int _1070 = _7033; _1070 < _7034; ++_1070)
  {
    {
      ((*natconmap_idx)(_ptr__1069[_1070])) = _1068;
      ((*natconmap_slackidx)(_ptr__1069[_1070])) = (int)0;
    }
  }
  ((*natconmap_type)(_1068)) = (int)4;
  putarows(_1069,rs,_1058,_1059,_1061,_1062,_1064);
  std::vector<int> _7035;
  for (int _1071 = (int)0, _7036 = _1058; _1071 < _7036 ; ++_1071)
  {
    _7035.push_back(bfixidx);
  }
  auto _7037 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7035.size()),_7035.begin(),_7035.end()));
  std::vector<double> _7038;
  for (int _1072 = (int)0, _7039 = _1058; _1072 < _7039 ; ++_1072)
  {
    _7038.push_back(_ptr__1055[safe_add( _1063,_1072 )]);
  }
  auto _7040 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7038.size()),_7038.begin(),_7038.end()));
  task_putaijlist(_1069,_7037,_7040,(long long)(_1058));
  std::shared_ptr< monty::ndarray< double,1 > > _1073 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1066)));
  _checked_ptr_1<double> _ptr__1073(_1073 ? _1073->raw() : nullptr,_1073 ? _1073->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1074 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1066)));
  _checked_ptr_1<double> _ptr__1074(_1074 ? _1074->raw() : nullptr,_1074 ? _1074->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1075 = natconmap_efix;
  _checked_ptr_1<double> _ptr__1075(_1075 ? _1075->raw() : nullptr,_1075 ? _1075->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1076 = mosek::fusion::p_RangeDomain::_get_impl(_1051)->lb;
  _checked_ptr_1<double> _ptr__1076(_1076 ? _1076->raw() : nullptr,_1076 ? _1076->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1077 = mosek::fusion::p_RangeDomain::_get_impl(_1051)->ub;
  _checked_ptr_1<double> _ptr__1077(_1077 ? _1077->raw() : nullptr,_1077 ? _1077->size(0) : 0);
  bool _1078 = mosek::fusion::p_RangeDomain::_get_impl(_1051)->empty;
  bool _1079 = mosek::fusion::p_RangeDomain::_get_impl(_1051)->scalable;
  std::shared_ptr< monty::ndarray< int,2 > > _1080 = mosek::fusion::p_RangeDomain::_get_impl(_1051)->sparsity;
  {
    int _7041 = (int)0;
    int _7042 = _1058;
    for (int _1081 = _7041; _1081 < _7042; ++_1081)
    {
      {
        _ptr__1075[_ptr__1069[_1081]] = _ptr__1055[safe_add( _1063,_1081 )];
      }
    }
    if (_1079)
    {
      {
        int _7043 = (int)0;
        int _7044 = _1066;
        for (int _1082 = _7043; _1082 < _7044; ++_1082)
        {
          {
            _ptr__1073[_1082] = ((*mosek::fusion::p_RangeDomain::_get_impl(_1051)->lb)((int)0));
            _ptr__1074[_1082] = ((*mosek::fusion::p_RangeDomain::_get_impl(_1051)->ub)((int)0));
          }
        }
      }
    }
    else if(_1078)
    {
      {
      }
    }
    else if((NULL != _1080.get()))
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1083 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1056)));
        _checked_ptr_1<int> _ptr__1083(_1083 ? _1083->raw() : nullptr,_1083 ? _1083->size(0) : 0);
        _ptr__1083[(_1056 - (int)1)] = (int)1;
        int _7045 = (int)1;
        int _7046 = _1056;
        for (int _1084 = _7045; _1084 < _7046; ++_1084)
        {
          {
            _ptr__1083[((_1056 - _1084) - (int)1)] = safe_mul( _ptr__1083[(_1056 - _1084)],_ptr__1053[(safe_add( _1057,_1056 ) - _1084)] );
          }
        }
        int _7047 = (int)0;
        int _7048 = (int)((_1076)->size(0));
        for (int _1085 = _7047; _1085 < _7048; ++_1085)
        {
          {
            int _1086 = (int)0;
            int _7049 = (int)0;
            int _7050 = _1056;
            for (int _1087 = _7049; _1087 < _7050; ++_1087)
            {
              {
                _1086 += safe_mul( _ptr__1083[_1087],((*_1080)(_1085,_1087)) );
              }
            }
            _ptr__1073[_1086] = _ptr__1076[_1085];
            _ptr__1074[_1086] = _ptr__1077[_1085];
          }
        }
      }
    }
    else
    {
      {
        int _7051 = (int)0;
        int _7052 = _1066;
        for (int _1088 = _7051; _1088 < _7052; ++_1088)
        {
          {
            _ptr__1073[_1088] = _ptr__1076[_1088];
            _ptr__1074[_1088] = _ptr__1077[_1088];
          }
        }
      }
    }
  }
  task_con_putboundlist_ra(_1069,_1073,_1074);
  std::vector<int> _7053;
  for (int _1090 = (int)0, _7054 = _1056; _1090 < _7054 ; ++_1090)
  {
    _7053.push_back(_ptr__1053[safe_add( _1057,_1090 )]);
  }
  auto _7055 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7053.size()),_7053.begin(),_7053.end()));
  monty::rc_ptr< ::mosek::fusion::RangedConstraint > _1089 = ::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::Model::t(_pubthis),_1049,_7055,_1069);
  ((*cons)(_1068)) = (_1089).as<::mosek::fusion::ModelConstraint>();
  return (_1089).as<::mosek::fusion::Constraint>();
}
void mosek::fusion::p_Model::update_bfix(std::shared_ptr< monty::ndarray< int,1 > > _1091,std::shared_ptr< monty::ndarray< double,1 > > _1092){
  _checked_ptr_1<int> _ptr__1091(_1091 ? _1091->raw() : nullptr, _1091 ? _1091->size(0) : 0);
  _checked_ptr_1<double> _ptr__1092(_1092 ? _1092->raw() : nullptr, _1092 ? _1092->size(0) : 0);
  std::vector<int> _7056;
  for (int _1093 = (int)0, _7057 = (int)((_1091)->size(0)); _1093 < _7057 ; ++_1093)
  {
    _7056.push_back((int)0);
  }
  auto _7058 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7056.size()),_7056.begin(),_7056.end()));
  task_putaijlist(_1091,_7058,_1092,(long long)((int)((_1091)->size(0))));
}
void mosek::fusion::p_Model::putarows(std::shared_ptr< monty::ndarray< int,1 > > _1094,monty::rc_ptr< ::mosek::fusion::WorkStack > _1095,int _1096,int _1097,int _1098,int _1099,int _1100){
  _checked_ptr_1<int> _ptr__1094(_1094 ? _1094->raw() : nullptr, _1094 ? _1094->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1101 = mosek::fusion::p_WorkStack::_get_impl(_1095)->i32;
  _checked_ptr_1<int> _ptr__1101(_1101 ? _1101->raw() : nullptr,_1101 ? _1101->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1102 = mosek::fusion::p_WorkStack::_get_impl(_1095)->i64;
  _checked_ptr_1<long long> _ptr__1102(_1102 ? _1102->raw() : nullptr,_1102 ? _1102->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1103 = mosek::fusion::p_WorkStack::_get_impl(_1095)->f64;
  _checked_ptr_1<double> _ptr__1103(_1103 ? _1103->raw() : nullptr,_1103 ? _1103->size(0) : 0);
  int _1104 = (int)0;
  int _1105 = (int)0;
  int _1106 = (int)0;
  int _7059 = (int)0;
  int _7060 = _1096;
  for (int _1107 = _7059; _1107 < _7060; ++_1107)
  {
    {
      int _1108 = _ptr__1101[safe_add( _1098,_1107 )];
      int _1109 = _ptr__1101[safe_add( safe_add( _1098,_1107 ),(int)1 )];
      int _1110 = _1108;
      while ( ((_1110 < _1109) && (_ptr__1102[safe_add( _1099,_1110 )] < (int)0)) )
      {
        {
          int _1111 = ((*natbarvar_idx)((-safe_add( _ptr__1102[safe_add( _1099,_1110 )],(int)1 ))));
          int _1112 = _1110;
          ++ _1110;
          while ( ((_1110 < _1109) && ((_ptr__1102[safe_add( _1099,_1110 )] < (int)0) && (_1111 == ((*natbarvar_idx)((-safe_add( _ptr__1102[safe_add( _1099,_1110 )],(int)1 ))))))) )
          {
            {
              ++ _1110;
            }
          }
          ++ _1105;
        }
      }
      _1106 += (_1110 - _1108);
      _1104 += (_1109 - _1110);
    }
  }
  int _1113 = (int)((_1094)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1114 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1113,(int)1 ))));
  _checked_ptr_1<long long> _ptr__1114(_1114 ? _1114->raw() : nullptr,_1114 ? _1114->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1115 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1104)));
  _checked_ptr_1<int> _ptr__1115(_1115 ? _1115->raw() : nullptr,_1115 ? _1115->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1116 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1104)));
  _checked_ptr_1<double> _ptr__1116(_1116 ? _1116->raw() : nullptr,_1116 ? _1116->size(0) : 0);
  {
    int _1117 = (int)0;
    int _7061 = (int)0;
    int _7062 = _1096;
    for (int _1118 = _7061; _1118 < _7062; ++_1118)
    {
      {
        int _1119 = (int)0;
        int _7063 = _ptr__1101[safe_add( _1098,_1118 )];
        int _7064 = _ptr__1101[safe_add( safe_add( _1098,_1118 ),(int)1 )];
        for (int _1120 = _7063; _1120 < _7064; ++_1120)
        {
          {
            if ((_ptr__1102[safe_add( _1099,_1120 )] > (int)0))
            {
              {
                _ptr__1115[safe_add( _1117,_1119 )] = (int)(_ptr__1102[safe_add( _1099,_1120 )] - (int)1);
                _ptr__1116[safe_add( _1117,_1119 )] = _ptr__1103[safe_add( _1100,_1120 )];
                ++ _1119;
              }
            }
            {}
          }
        }
        _ptr__1114[safe_add( _1118,(int)1 )] = safe_add( _ptr__1114[_1118],_1119 );
        _1117 += _1119;
      }
    }
  }
  task_putarowlist(_1094,_1114,_1115,_1116);
  if ((_1105 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1121 = _1094;
      _checked_ptr_1<int> _ptr__1121(_1121 ? _1121->raw() : nullptr,_1121 ? _1121->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1122 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1113,(int)1 ))));
      _checked_ptr_1<long long> _ptr__1122(_1122 ? _1122->raw() : nullptr,_1122 ? _1122->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1123 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1105)));
      _checked_ptr_1<int> _ptr__1123(_1123 ? _1123->raw() : nullptr,_1123 ? _1123->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1124 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1105)));
      _checked_ptr_1<int> _ptr__1124(_1124 ? _1124->raw() : nullptr,_1124 ? _1124->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1125 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1105)));
      _checked_ptr_1<long long> _ptr__1125(_1125 ? _1125->raw() : nullptr,_1125 ? _1125->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1126 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1106)));
      _checked_ptr_1<int> _ptr__1126(_1126 ? _1126->raw() : nullptr,_1126 ? _1126->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1127 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1106)));
      _checked_ptr_1<int> _ptr__1127(_1127 ? _1127->raw() : nullptr,_1127 ? _1127->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _1128 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1106)));
      _checked_ptr_1<double> _ptr__1128(_1128 ? _1128->raw() : nullptr,_1128 ? _1128->size(0) : 0);
      int _1129 = (int)0;
      int _1130 = (int)0;
      int _7065 = (int)0;
      int _7066 = _1113;
      for (int _1131 = _7065; _1131 < _7066; ++_1131)
      {
        {
          int _1132 = _ptr__1101[safe_add( _1098,_1131 )];
          int _1133 = _ptr__1101[safe_add( safe_add( _1098,_1131 ),(int)1 )];
          while ( ((_1132 < _1133) && (_ptr__1102[safe_add( _1099,_1132 )] < (int)0)) )
          {
            {
              int _1134 = _1132;
              int _1135 = ((*natbarvar_idx)((-safe_add( _ptr__1102[safe_add( _1099,_1132 )],(int)1 ))));
              while ( ((_1132 < _1133) && ((_ptr__1102[safe_add( _1099,_1132 )] < (int)0) && (((*natbarvar_idx)((-safe_add( _ptr__1102[safe_add( _1099,_1132 )],(int)1 )))) == _1135))) )
              {
                {
                  _ptr__1126[_1130] = ((*natbarvar_i)((-safe_add( _ptr__1102[safe_add( _1099,_1132 )],(int)1 ))));
                  _ptr__1127[_1130] = ((*natbarvar_j)((-safe_add( _ptr__1102[safe_add( _1099,_1132 )],(int)1 ))));
                  if ((_ptr__1126[_1130] == _ptr__1127[_1130]))
                  {
                    {
                      _ptr__1128[_1130] = _ptr__1103[safe_add( _1100,_1132 )];
                    }
                  }
                  else
                  {
                    {
                      _ptr__1128[_1130] = (0.5 * _ptr__1103[safe_add( _1100,_1132 )]);
                    }
                  }
                  ++ _1130;
                  ++ _1132;
                }
              }
              _ptr__1123[_1129] = _1135;
              _ptr__1124[_1129] = ((*natbarvar_dim)(_1135));
              _ptr__1125[_1129] = (_1132 - _1134);
              ++ _1129;
            }
          }
          _1132 = _1133;
          _ptr__1122[safe_add( _1131,(int)1 )] = _1129;
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1136 = task_appendsymmatlist(_1124,_1125,_1126,_1127,_1128);
      _checked_ptr_1<long long> _ptr__1136(_1136 ? _1136->raw() : nullptr,_1136 ? _1136->size(0) : 0);
      task_putbararowlist(_1121,_1122,_1123,_1136);
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1137,monty::rc_ptr< ::mosek::fusion::Expression > _1138,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1139){
  std::shared_ptr< monty::ndarray< int,1 > > _1140 = _1138->getShape();
  _checked_ptr_1<int> _ptr__1140(_1140 ? _1140->raw() : nullptr,_1140 ? _1140->size(0) : 0);
  if (((NULL != mosek::fusion::p_PSDDomain::_get_impl(_1139)->shape.get()) && (!::mosek::fusion::p_Set::match(_1140,mosek::fusion::p_PSDDomain::_get_impl(_1139)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  bool _1141;
  int _1142;
  int _1143;
  if (mosek::fusion::p_PSDDomain::_get_impl(_1139)->axisIsSet)
  {
    {
      _1141 = (mosek::fusion::p_PSDDomain::_get_impl(_1139)->conedim1 < mosek::fusion::p_PSDDomain::_get_impl(_1139)->conedim2);
      int _7067;
      bool _7068 = _1141;
      if (_7068)
      {
        _7067 = mosek::fusion::p_PSDDomain::_get_impl(_1139)->conedim1;
      }
      else
      {
        _7067 = mosek::fusion::p_PSDDomain::_get_impl(_1139)->conedim2;
      }
      _1143 = _7067;
      int _7069;
      bool _7070 = _1141;
      if (_7070)
      {
        _7069 = mosek::fusion::p_PSDDomain::_get_impl(_1139)->conedim2;
      }
      else
      {
        _7069 = mosek::fusion::p_PSDDomain::_get_impl(_1139)->conedim1;
      }
      _1142 = _7069;
    }
  }
  else
  {
    {
      _1141 = true;
      _1143 = ((int)((_1140)->size(0)) - (int)2);
      _1142 = ((int)((_1140)->size(0)) - (int)1);
    }
  }
  if (((_1142 >= (int)((_1140)->size(0))) || (_ptr__1140[_1143] != _ptr__1140[_1142])))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Expression > _7071;
  bool _7072 = (mosek::fusion::p_PSDDomain::_get_impl(_1139)->key == ::mosek::fusion::PSDKey::IsSymPSD);
  if (_7072)
  {
    _7071 = ::mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize(_1143,_1142,_1138).as<::mosek::fusion::Expression>();
  }
  else
  {
    _7071 = _1138;
  }
  monty::rc_ptr< ::mosek::fusion::ExprCompress > _1144 = ::mosek::fusion::p_ExprCompress::_new_ExprCompress((::mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril(_1143,_1142,_7071)).as<::mosek::fusion::Expression>());
  _1144->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1145 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1145(_1145 ? _1145->raw() : nullptr,_1145 ? _1145->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1146 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1146(_1146 ? _1146->raw() : nullptr,_1146 ? _1146->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1147 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1147(_1147 ? _1147->raw() : nullptr,_1147 ? _1147->size(0) : 0);
  int _1148 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1149 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1148)));
  _checked_ptr_1<int> _ptr__1149(_1149 ? _1149->raw() : nullptr,_1149 ? _1149->size(0) : 0);
  rs->popi32(_1148,_1149,(int)0);
  int _1150 = rs->popi32();
  int _1151 = rs->popi32();
  bool _1152 = (rs->popi32() != (int)0);
  int _1153 = rs->popi32(safe_add( _1150,(int)1 ));
  int _7073;
  bool _7074 = _1152;
  if (_7074)
  {
    _7073 = rs->popi64(_1150);
  }
  else
  {
    _7073 = (-(int)99999);
  }
  int _1154 = _7073;
  int _1155 = rs->popi64(_1151);
  int _1156 = rs->popf64(_1150);
  int _1157 = rs->popf64(_1151);
  int _1158 = _ptr__1149[_1142];
  int _1159 = (safe_mul( _1158,safe_add( _1158,(int)1 ) ) / (int)2);
  int _7075 = (int)0;
  int _7076 = _1148;
  for (int _1160 = _7075; _1160 < _7076; ++_1160)
  {
    {
      if (((_1160 != _1143) && (_1160 != _1142)))
      {
        {
          _1159 *= _ptr__1149[_1160];
        }
      }
      {}
    }
  }
  int _1161 = natconmap_alloc(_1159);
  std::shared_ptr< monty::ndarray< int,1 > > _1162 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1159)));
  _checked_ptr_1<int> _ptr__1162(_1162 ? _1162->raw() : nullptr,_1162 ? _1162->size(0) : 0);
  natconmap->get(_1161,_1162,(int)0);
  putarows(_1162,rs,_1150,_1151,_1153,_1155,_1157);
  std::vector<int> _7077;
  for (int _1163 = (int)0, _7078 = _1150; _1163 < _7078 ; ++_1163)
  {
    _7077.push_back(bfixidx);
  }
  auto _7079 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7077.size()),_7077.begin(),_7077.end()));
  std::vector<double> _7080;
  for (int _1164 = (int)0, _7081 = _1150; _1164 < _7081 ; ++_1164)
  {
    _7080.push_back(_ptr__1147[safe_add( _1156,_1164 )]);
  }
  auto _7082 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7080.size()),_7080.begin(),_7080.end()));
  task_putaijlist(_1162,_7079,_7082,(long long)(_1150));
  std::shared_ptr< monty::ndarray< int,1 > > _1165 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__1165(_1165 ? _1165->raw() : nullptr,_1165 ? _1165->size(0) : 0);
  int _7083 = (int)0;
  int _7084 = _1143;
  for (int _1166 = _7083; _1166 < _7084; ++_1166)
  {
    {
      _ptr__1165[(int)0] *= _ptr__1149[_1166];
    }
  }
  _ptr__1165[(int)1] = _ptr__1149[_1143];
  int _7085 = safe_add( _1143,(int)1 );
  int _7086 = _1142;
  for (int _1167 = _7085; _1167 < _7086; ++_1167)
  {
    {
      _ptr__1165[(int)2] *= _ptr__1149[_1167];
    }
  }
  _ptr__1165[(int)3] = _ptr__1149[_1142];
  int _7087 = safe_add( _1142,(int)1 );
  int _7088 = _1148;
  for (int _1168 = _7087; _1168 < _7088; ++_1168)
  {
    {
      _ptr__1165[(int)4] *= _ptr__1149[_1168];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1169 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__1169(_1169 ? _1169->raw() : nullptr,_1169 ? _1169->size(0) : 0);
  _ptr__1169[(int)4] = (int)1;
  int _7089 = (int)1;
  int _7090 = (int)5;
  for (int _1170 = _7089; _1170 < _7090; ++_1170)
  {
    {
      _ptr__1169[(((int)5 - _1170) - (int)1)] = safe_mul( _ptr__1169[((int)5 - _1170)],_ptr__1165[((int)5 - _1170)] );
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1171 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1159)));
  _checked_ptr_1<double> _ptr__1171(_1171 ? _1171->raw() : nullptr,_1171 ? _1171->size(0) : 0);
  if ((_1154 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Unexpected case!"));
    }
  }
  else
  {
    {
      int _7091 = (int)0;
      int _7092 = _1150;
      for (int _1172 = _7091; _1172 < _7092; ++_1172)
      {
        {
          ((*natconmap_efix)(_ptr__1162[_1172])) = _ptr__1147[safe_add( _1156,_1172 )];
          ((*natconmap_lb)(_ptr__1162[_1172])) = (int)0;
          ((*natconmap_ub)(_ptr__1162[_1172])) = (int)0;
          _ptr__1171[_1172] = 0.0;
        }
      }
    }
  }
  task_con_putboundlist_fx(_1162,_1171);
  int _1173 = safe_mul( safe_mul( _ptr__1165[(int)0],_ptr__1165[(int)2] ),_ptr__1165[(int)4] );
  int _1174 = _ptr__1165[(int)1];
  int _1175 = natbarvarmap_alloc(_1173,_1174);
  std::shared_ptr< monty::ndarray< int,1 > > _1176 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1173)));
  _checked_ptr_1<int> _ptr__1176(_1176 ? _1176->raw() : nullptr,_1176 ? _1176->size(0) : 0);
  natbarvarmap_get(_1175,_1176);
  std::vector<int> _7093;
  for (int _1178 = (int)0, _7094 = (safe_mul( _1174,safe_add( _1174,(int)1 ) ) / (int)2); _1178 < _7094 ; ++_1178)
  {
    _7093.push_back(_1174);
  }
  auto _7095 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7093.size()),_7093.begin(),_7093.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1177 = _7095;
  _checked_ptr_1<int> _ptr__1177(_1177 ? _1177->raw() : nullptr,_1177 ? _1177->size(0) : 0);
  std::vector<long long> _7096;
  for (int _1180 = (int)0, _7097 = (safe_mul( _1174,safe_add( _1174,(int)1 ) ) / (int)2); _1180 < _7097 ; ++_1180)
  {
    _7096.push_back((int)1);
  }
  auto _7098 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7096.size()),_7096.begin(),_7096.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1179 = _7098;
  _checked_ptr_1<long long> _ptr__1179(_1179 ? _1179->raw() : nullptr,_1179 ? _1179->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1181 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1174,safe_add( _1174,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1181(_1181 ? _1181->raw() : nullptr,_1181 ? _1181->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1182 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1174,safe_add( _1174,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1182(_1182 ? _1182->raw() : nullptr,_1182 ? _1182->size(0) : 0);
  std::vector<double> _7099;
  for (int _1184 = (int)0, _7100 = (safe_mul( _1174,safe_add( _1174,(int)1 ) ) / (int)2); _1184 < _7100 ; ++_1184)
  {
    _7099.push_back((-1.0));
  }
  auto _7101 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7099.size()),_7099.begin(),_7099.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1183 = _7101;
  _checked_ptr_1<double> _ptr__1183(_1183 ? _1183->raw() : nullptr,_1183 ? _1183->size(0) : 0);
  {
    int _1185 = (int)0;
    int _7102 = (int)0;
    int _7103 = _1174;
    for (int _1186 = _7102; _1186 < _7103; ++_1186)
    {
      {
        int _7104 = (int)0;
        int _7105 = safe_add( _1186,(int)1 );
        for (int _1187 = _7104; _1187 < _7105; ++_1187)
        {
          {
            _ptr__1181[_1185] = _1186;
            _ptr__1182[_1185] = _1187;
            ++ _1185;
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1188 = task_appendsymmatlist(_1177,_1179,_1181,_1182,_1183);
  _checked_ptr_1<long long> _ptr__1188(_1188 ? _1188->raw() : nullptr,_1188 ? _1188->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1189 = _1162;
  _checked_ptr_1<int> _ptr__1189(_1189 ? _1189->raw() : nullptr,_1189 ? _1189->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1190 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1159)));
  _checked_ptr_1<int> _ptr__1190(_1190 ? _1190->raw() : nullptr,_1190 ? _1190->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1191 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1159)));
  _checked_ptr_1<long long> _ptr__1191(_1191 ? _1191->raw() : nullptr,_1191 ? _1191->size(0) : 0);
  {
    int _1192 = (int)0;
    if (_1141)
    {
      {
        int _7106 = (int)0;
        int _7107 = _ptr__1165[(int)0];
        for (int _1193 = _7106; _1193 < _7107; ++_1193)
        {
          {
            int _7108 = (int)0;
            int _7109 = _ptr__1165[(int)1];
            for (int _1194 = _7108; _1194 < _7109; ++_1194)
            {
              {
                int _7110 = (int)0;
                int _7111 = _ptr__1165[(int)2];
                for (int _1195 = _7110; _1195 < _7111; ++_1195)
                {
                  {
                    int _7112 = (int)0;
                    int _7113 = safe_add( _1194,(int)1 );
                    for (int _1196 = _7112; _1196 < _7113; ++_1196)
                    {
                      {
                        int _7114 = (int)0;
                        int _7115 = _ptr__1165[(int)4];
                        for (int _1197 = _7114; _1197 < _7115; ++_1197)
                        {
                          {
                            _ptr__1191[_1192] = _ptr__1188[safe_add( (safe_mul( _1194,safe_add( _1194,(int)1 ) ) / (int)2),_1196 )];
                            _ptr__1190[_1192] = _ptr__1176[safe_add( safe_mul( safe_add( safe_mul( _1193,_ptr__1165[(int)2] ),_1195 ),_ptr__1165[(int)4] ),_1197 )];
                            ((*natconmap_slackidx)(_ptr__1162[_1192])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1190[_1192])),(safe_mul( _1196,((safe_mul( (int)2,_ptr__1165[(int)1] ) - _1196) - (int)1) ) / (int)2) ),_1194 );
                            ++ _1192;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _7116 = (int)0;
        int _7117 = _ptr__1165[(int)0];
        for (int _1198 = _7116; _1198 < _7117; ++_1198)
        {
          {
            int _7118 = (int)0;
            int _7119 = _ptr__1165[(int)1];
            for (int _1199 = _7118; _1199 < _7119; ++_1199)
            {
              {
                int _7120 = (int)0;
                int _7121 = _ptr__1165[(int)2];
                for (int _1200 = _7120; _1200 < _7121; ++_1200)
                {
                  {
                    int _7122 = _1199;
                    int _7123 = _ptr__1165[(int)1];
                    for (int _1201 = _7122; _1201 < _7123; ++_1201)
                    {
                      {
                        int _7124 = (int)0;
                        int _7125 = _ptr__1165[(int)4];
                        for (int _1202 = _7124; _1202 < _7125; ++_1202)
                        {
                          {
                            _ptr__1191[_1192] = _ptr__1188[safe_add( (safe_mul( _1201,safe_add( _1201,(int)1 ) ) / (int)2),_1199 )];
                            _ptr__1190[_1192] = _ptr__1176[safe_add( safe_mul( safe_add( safe_mul( _1198,_ptr__1165[(int)2] ),_1200 ),_ptr__1165[(int)4] ),_1202 )];
                            ((*natconmap_slackidx)(_ptr__1162[_1192])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1190[_1192])),(safe_mul( _1199,((safe_mul( (int)2,_ptr__1165[(int)1] ) - _1199) - (int)1) ) / (int)2) ),_1201 );
                            ++ _1192;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  task_putbaraijlist(_1189,_1190,_1191);
  ((*natconmap_type)(_1161)) = (-safe_add( _1175,(int)1 ));
  std::vector<long long> _7126;
  for (int _1204 = (int)0, _7127 = _1159; _1204 < _7127 ; ++_1204)
  {
    _7126.push_back(((*natconmap_slackidx)(_ptr__1162[_1204])));
  }
  auto _7128 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7126.size()),_7126.begin(),_7126.end()));
  monty::rc_ptr< ::mosek::fusion::PSDConstraint > _1203 = ::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::Model::t(_pubthis),_1137,_1161,_1149,_1143,_1142,_7128,_1162);
  ((*cons)(_1161)) = (_1203).as<::mosek::fusion::ModelConstraint>();
  return (_1203).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1205,monty::rc_ptr< ::mosek::fusion::Expression > _1206,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1207){
  if ((((int)((_1205).size()) > (int)0) && hasConstraint(_1205)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1205)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1205).size()) > (int)0) && hasConstraint(_1205)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1205)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1208 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1206)).as<::mosek::fusion::Expression>());
  _1208->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1209 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1209(_1209 ? _1209->raw() : nullptr,_1209 ? _1209->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1210 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1210(_1210 ? _1210->raw() : nullptr,_1210 ? _1210->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1211 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1211(_1211 ? _1211->raw() : nullptr,_1211 ? _1211->size(0) : 0);
  int _1212 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1213 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1212)));
  _checked_ptr_1<int> _ptr__1213(_1213 ? _1213->raw() : nullptr,_1213 ? _1213->size(0) : 0);
  rs->popi32(_1212,_1213,(int)0);
  int _1214 = rs->popi32();
  int _1215 = rs->popi32();
  bool _1216 = (rs->popi32() != (int)0);
  int _1217 = rs->popi32(safe_add( _1214,(int)1 ));
  int _1218 = rs->popi64(_1215);
  int _1219 = rs->popf64(_1214);
  int _1220 = rs->popf64(_1215);
  if (((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1207)->shape.get()) && (!::mosek::fusion::p_Set::match(_1213,mosek::fusion::p_LinPSDDomain::_get_impl(_1207)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1221 = (int)1;
  int _7129 = (int)0;
  int _7130 = _1212;
  for (int _1222 = _7129; _1222 < _7130; ++_1222)
  {
    {
      _1221 *= _ptr__1213[_1222];
    }
  }
  int _1223 = mosek::fusion::p_LinPSDDomain::_get_impl(_1207)->conedim;
  int _1224 = _ptr__1213[_1223];
  int _1225 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1224 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1225,safe_add( _1225,(int)1 ) ) / (int)2) != _1224))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1226 = (int)1;
  int _7131 = (int)0;
  int _7132 = _1223;
  for (int _1227 = _7131; _1227 < _7132; ++_1227)
  {
    {
      _1226 *= _ptr__1213[_1227];
    }
  }
  int _1228 = (int)1;
  int _7133 = safe_add( _1223,(int)1 );
  int _7134 = _1212;
  for (int _1229 = _7133; _1229 < _7134; ++_1229)
  {
    {
      _1228 *= _ptr__1213[_1229];
    }
  }
  int _1230 = safe_mul( _1226,_1228 );
  int _1231 = natconmap_alloc(_1221);
  std::shared_ptr< monty::ndarray< int,1 > > _1232 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1221)));
  _checked_ptr_1<int> _ptr__1232(_1232 ? _1232->raw() : nullptr,_1232 ? _1232->size(0) : 0);
  natconmap->get(_1231,_1232,(int)0);
  putarows(_1232,rs,_1214,_1215,_1217,_1218,_1220);
  std::vector<int> _7135;
  for (int _1233 = (int)0, _7136 = _1214; _1233 < _7136 ; ++_1233)
  {
    _7135.push_back(bfixidx);
  }
  auto _7137 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7135.size()),_7135.begin(),_7135.end()));
  std::vector<double> _7138;
  for (int _1234 = (int)0, _7139 = _1214; _1234 < _7139 ; ++_1234)
  {
    _7138.push_back(_ptr__1211[safe_add( _1219,_1234 )]);
  }
  auto _7140 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7138.size()),_7138.begin(),_7138.end()));
  task_putaijlist(_1232,_7137,_7140,(long long)(_1214));
  int _1235 = natbarvarmap_alloc(_1230,_1225);
  std::shared_ptr< monty::ndarray< int,1 > > _1236 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1230)));
  _checked_ptr_1<int> _ptr__1236(_1236 ? _1236->raw() : nullptr,_1236 ? _1236->size(0) : 0);
  natbarvarmap_get(_1235,_1236);
  ((*barvars)(_1235)) = nullptr;
  int _1237 = safe_mul( safe_mul( _1224,_1226 ),_1228 );
  std::vector<int> _7141;
  for (int _1239 = (int)0, _7142 = _1224; _1239 < _7142 ; ++_1239)
  {
    _7141.push_back(_1239);
  }
  auto _7143 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7141.size()),_7141.begin(),_7141.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1238 = _7143;
  _checked_ptr_1<int> _ptr__1238(_1238 ? _1238->raw() : nullptr,_1238 ? _1238->size(0) : 0);
  std::vector<long long> _7144;
  for (int _1241 = (int)0, _7145 = _1224; _1241 < _7145 ; ++_1241)
  {
    _7144.push_back((int)1);
  }
  auto _7146 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7144.size()),_7144.begin(),_7144.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1240 = _7146;
  _checked_ptr_1<long long> _ptr__1240(_1240 ? _1240->raw() : nullptr,_1240 ? _1240->size(0) : 0);
  std::vector<double> _7147;
  for (int _1243 = (int)0, _7148 = _1224; _1243 < _7148 ; ++_1243)
  {
    _7147.push_back((-1.0));
  }
  auto _7149 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7147.size()),_7147.begin(),_7147.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1242 = _7149;
  _checked_ptr_1<double> _ptr__1242(_1242 ? _1242->raw() : nullptr,_1242 ? _1242->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1244 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1224)));
  _checked_ptr_1<int> _ptr__1244(_1244 ? _1244->raw() : nullptr,_1244 ? _1244->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1245 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1224)));
  _checked_ptr_1<int> _ptr__1245(_1245 ? _1245->raw() : nullptr,_1245 ? _1245->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1246 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1237)));
  _checked_ptr_1<int> _ptr__1246(_1246 ? _1246->raw() : nullptr,_1246 ? _1246->size(0) : 0);
  {
    int _1247 = (int)0;
    int _7150 = (int)0;
    int _7151 = _1226;
    for (int _1248 = _7150; _1248 < _7151; ++_1248)
    {
      {
        int _7152 = (int)0;
        int _7153 = _1225;
        for (int _1249 = _7152; _1249 < _7153; ++_1249)
        {
          {
            int _7154 = (int)0;
            int _7155 = safe_add( _1249,(int)1 );
            for (int _1250 = _7154; _1250 < _7155; ++_1250)
            {
              {
                int _7156 = (int)0;
                int _7157 = _1228;
                for (int _1251 = _7156; _1251 < _7157; ++_1251)
                {
                  {
                    _ptr__1246[_1247] = safe_add( safe_mul( _1248,_1228 ),_1251 );
                    _ptr__1244[_1247] = _1249;
                    _ptr__1245[_1247] = _1250;
                    ++ _1247;
                  }
                }
              }
            }
          }
        }
      }
    }
    ((*natconmap_type)(_1231)) = (-safe_add( _1235,(int)1 ));
    int _7158 = (int)0;
    int _7159 = _1221;
    for (int _1252 = _7158; _1252 < _7159; ++_1252)
    {
      {
        ((*natconmap_blockid)(_ptr__1232[_1252])) = _1231;
        ((*natconmap_idx)(_ptr__1232[_1252])) = _1252;
        ((*natconmap_efix)(_ptr__1232[_1252])) = _ptr__1211[safe_add( _1219,_1252 )];
        ((*natconmap_lb)(_ptr__1232[_1252])) = (int)0;
        ((*natconmap_ub)(_ptr__1232[_1252])) = (int)0;
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1253 = task_appendsymmatlist(_1238,_1240,_1244,_1245,_1242);
  _checked_ptr_1<long long> _ptr__1253(_1253 ? _1253->raw() : nullptr,_1253 ? _1253->size(0) : 0);
  task_putbaraijlist(_1232,_1246,_1253);
  std::vector<double> _7160;
  for (int _1255 = (int)0, _7161 = _1221; _1255 < _7161 ; ++_1255)
  {
    _7160.push_back(0.0);
  }
  auto _7162 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7160.size()),_7160.begin(),_7160.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1254 = _7162;
  _checked_ptr_1<double> _ptr__1254(_1254 ? _1254->raw() : nullptr,_1254 ? _1254->size(0) : 0);
  task_con_putboundlist_fx(_1232,_1254);
  std::vector<long long> _7163;
  for (int _1257 = (int)0, _7164 = _1221; _1257 < _7164 ; ++_1257)
  {
    _7163.push_back(((*natconmap_slackidx)(_ptr__1232[_1257])));
  }
  auto _7165 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7163.size()),_7163.begin(),_7163.end()));
  monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _1256 = ::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::Model::t(_pubthis),_1205,_1231,_1213,_1223,_1232,_7165);
  ((*cons)(_1231)) = (_1256).as<::mosek::fusion::ModelConstraint>();
  return (_1256).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1258,monty::rc_ptr< ::mosek::fusion::Expression > _1259,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1260){
  if ((((int)((_1258).size()) > (int)0) && hasConstraint(_1258)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1258)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1258).size()) > (int)0) && hasConstraint(_1258)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1258)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_ConeDomain::_get_impl(_1260)->int_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1261 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1259)).as<::mosek::fusion::Expression>());
  _1261->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1262 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1262(_1262 ? _1262->raw() : nullptr,_1262 ? _1262->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1263 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1263(_1263 ? _1263->raw() : nullptr,_1263 ? _1263->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1264 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1264(_1264 ? _1264->raw() : nullptr,_1264 ? _1264->size(0) : 0);
  int _1265 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1266 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1267 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1268 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1269 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1270 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1271 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1272 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1273 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7166;
  for (int _1275 = (int)0, _7167 = _1265; _1275 < _7167 ; ++_1275)
  {
    _7166.push_back(_ptr__1262[safe_add( _1266,_1275 )]);
  }
  auto _7168 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7166.size()),_7166.begin(),_7166.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1274 = _7168;
  _checked_ptr_1<int> _ptr__1274(_1274 ? _1274->raw() : nullptr,_1274 ? _1274->size(0) : 0);
  if (((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1260)->shape.get()) && (!::mosek::fusion::p_Set::match(_1274,mosek::fusion::p_ConeDomain::_get_impl(_1260)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _7169;
  bool _7170 = _1260->axisIsSet();
  if (_7170)
  {
    _7169 = _1260->getAxis();
  }
  else
  {
    _7169 = (_1265 - (int)1);
  }
  int _1276 = _7169;
  int _1277 = _ptr__1274[_1276];
  int _1278 = (int)1;
  int _1279 = (int)1;
  int _1280 = (int)1;
  {
    int _7171 = (int)0;
    int _7172 = _1265;
    for (int _1281 = _7171; _1281 < _7172; ++_1281)
    {
      {
        _1280 *= _ptr__1274[_1281];
      }
    }
    int _7173 = (int)0;
    int _7174 = _1276;
    for (int _1282 = _7173; _1282 < _7174; ++_1282)
    {
      {
        _1279 *= _ptr__1274[_1282];
      }
    }
    int _7175 = safe_add( _1276,(int)1 );
    int _7176 = _1265;
    for (int _1283 = _7175; _1283 < _7176; ++_1283)
    {
      {
        _1278 *= _ptr__1274[_1283];
      }
    }
  }
  int _1284 = safe_mul( _1279,_1278 );
  if (((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InQCone) && (_1277 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1277)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1277 < (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1277)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for rotated quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1277 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1277)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1277 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1277)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for power cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1277 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1277)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1277 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1277)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual power cone"))->toString());
    }
  }
  {}
  int _1285 = natvarmap_alloc(_1280);
  std::shared_ptr< monty::ndarray< int,1 > > _1286 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1280)));
  _checked_ptr_1<int> _ptr__1286(_1286 ? _1286->raw() : nullptr,_1286 ? _1286->size(0) : 0);
  natvarmap->get(_1285,_1286,(int)0);
  int _1287 = natconemap_alloc(_1284);
  int _7177 = (int)0;
  int _7178 = _1280;
  for (int _1288 = _7177; _1288 < _7178; ++_1288)
  {
    {
      ((*natvarmap_idx)(_ptr__1286[_1288])) = _1285;
    }
  }
  task_var_putboundlist_fr(_1286);
  std::shared_ptr< monty::ndarray< int,1 > > _7179;
  bool _7180 = (_1276 < ((int)((_1274)->size(0)) - (int)1));
  if (_7180)
  {
    _7179 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1286)->size(0)))));
  }
  else
  {
    _7179 = _1286;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1289 = _7179;
  _checked_ptr_1<int> _ptr__1289(_1289 ? _1289->raw() : nullptr,_1289 ? _1289->size(0) : 0);
  if ((_1276 < ((int)((_1274)->size(0)) - (int)1)))
  {
    {
      int _1290 = (int)0;
      int _7181 = (int)0;
      int _7182 = _1279;
      for (int _1291 = _7181; _1291 < _7182; ++_1291)
      {
        {
          int _7183 = (int)0;
          int _7184 = _1278;
          for (int _1292 = _7183; _1292 < _7184; ++_1292)
          {
            {
              int _7185 = (int)0;
              int _7186 = _1277;
              for (int _1293 = _7185; _1293 < _7186; ++_1293)
              {
                {
                  _ptr__1289[_1290] = _ptr__1286[safe_add( safe_mul( safe_add( safe_mul( _1291,_1277 ),_1293 ),_1278 ),_1292 )];
                  ++ _1290;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1284)));
  _checked_ptr_1<int> _ptr__1294(_1294 ? _1294->raw() : nullptr,_1294 ? _1294->size(0) : 0);
  natconemap->get(_1287,_1294,(int)0);
  ((*natconemap_dim)(_1287)) = _1277;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1294,_1277,_1284,_1289);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
  {
    {
      task_put_rquadcones(_1294,_1277,_1284,_1289);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InPExpCone))
  {
    {
      task_put_pexpcones(_1294,_1277,_1284,_1289);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InPPowCone))
  {
    {
      std::vector<double> _7187;
      for (int _1295 = (int)0, _7188 = _1284; _1295 < _7188 ; ++_1295)
      {
        _7187.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1260)->alpha);
      }
      auto _7189 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7187.size()),_7187.begin(),_7187.end()));
      task_put_ppowcones(_1294,_1277,_1284,_1289,_7189);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InDExpCone))
  {
    {
      task_put_dexpcones(_1294,_1277,_1284,_1289);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1260)->key == ::mosek::fusion::QConeKey::InDPowCone))
  {
    {
      std::vector<double> _7190;
      for (int _1296 = (int)0, _7191 = _1284; _1296 < _7191 ; ++_1296)
      {
        _7190.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1260)->alpha);
      }
      auto _7192 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7190.size()),_7190.begin(),_7190.end()));
      task_put_dpowcones(_1294,_1277,_1284,_1289,_7192);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid cone type"));
    }
  }
  ((*vars)(_1285)) = nullptr;
  std::shared_ptr< monty::ndarray< double,1 > > _1297 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1280)));
  _checked_ptr_1<double> _ptr__1297(_1297 ? _1297->raw() : nullptr,_1297 ? _1297->size(0) : 0);
  int _1298 = natconmap_alloc(_1280);
  std::shared_ptr< monty::ndarray< int,1 > > _1299 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1280)));
  _checked_ptr_1<int> _ptr__1299(_1299 ? _1299->raw() : nullptr,_1299 ? _1299->size(0) : 0);
  natconmap->get(_1298,_1299,(int)0);
  ((*natconmap_type)(_1298)) = safe_add( _1285,(int)6 );
  {
    int _7193 = (int)0;
    int _7194 = _1280;
    for (int _1300 = _7193; _1300 < _7194; ++_1300)
    {
      {
        ((*natconmap_efix)(_ptr__1299[_1300])) = _ptr__1264[safe_add( _1272,_1300 )];
      }
    }
    int _7195 = (int)0;
    int _7196 = _1280;
    for (int _1301 = _7195; _1301 < _7196; ++_1301)
    {
      {
        ((*natconmap_lb)(_ptr__1299[_1301])) = (int)0;
      }
    }
    int _7197 = (int)0;
    int _7198 = _1280;
    for (int _1302 = _7197; _1302 < _7198; ++_1302)
    {
      {
        ((*natconmap_ub)(_ptr__1299[_1302])) = (int)0;
      }
    }
    int _7199 = (int)0;
    int _7200 = _1280;
    for (int _1303 = _7199; _1303 < _7200; ++_1303)
    {
      {
        ((*natconmap_slackidx)(_ptr__1299[_1303])) = safe_add( _ptr__1286[_1303],(int)1 );
      }
    }
    int _7201 = (int)0;
    int _7202 = _1280;
    for (int _1304 = _7201; _1304 < _7202; ++_1304)
    {
      {
        ((*natconmap_blockid)(_ptr__1299[_1304])) = _1298;
      }
    }
    int _7203 = (int)0;
    int _7204 = _1280;
    for (int _1305 = _7203; _1305 < _7204; ++_1305)
    {
      {
        ((*natconmap_idx)(_ptr__1299[_1305])) = _1305;
      }
    }
  }
  putarows(_1299,rs,_1267,_1268,_1270,_1271,_1273);
  task_con_putboundlist_fx(_1299,_1297);
  std::vector<double> _7205;
  for (int _1306 = (int)0, _7206 = (int)((_1299)->size(0)); _1306 < _7206 ; ++_1306)
  {
    _7205.push_back((-1.0));
  }
  auto _7207 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7205.size()),_7205.begin(),_7205.end()));
  task_putaijlist(_1299,_1286,_7207,(long long)((int)((_1299)->size(0))));
  std::vector<int> _7208;
  for (int _1307 = (int)0, _7209 = _1267; _1307 < _7209 ; ++_1307)
  {
    _7208.push_back(bfixidx);
  }
  auto _7210 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7208.size()),_7208.begin(),_7208.end()));
  std::vector<double> _7211;
  for (int _1308 = (int)0, _7212 = _1267; _1308 < _7212 ; ++_1308)
  {
    _7211.push_back(_ptr__1264[safe_add( _1272,_1308 )]);
  }
  auto _7213 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7211.size()),_7211.begin(),_7211.end()));
  task_putaijlist(_1299,_7210,_7213,(long long)(_1267));
  monty::rc_ptr< ::mosek::fusion::ConicConstraint > _1309 = ::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::Model::t(_pubthis),_1258,_1260,_1274,_1298,_1299,_1286);
  ((*cons)(_1298)) = (_1309).as<::mosek::fusion::ModelConstraint>();
  return (_1309).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1310,monty::rc_ptr< ::mosek::fusion::Expression > _1311,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1312){
  if ((((int)((_1310).size()) > (int)0) && hasConstraint(_1310)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1310)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_LinearDomain::_get_impl(_1312)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1313 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1311)).as<::mosek::fusion::Expression>());
  _1313->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1314 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1314(_1314 ? _1314->raw() : nullptr,_1314 ? _1314->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1315 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1315(_1315 ? _1315->raw() : nullptr,_1315 ? _1315->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1316 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1316(_1316 ? _1316->raw() : nullptr,_1316 ? _1316->size(0) : 0);
  int _1317 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1318 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1319 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1320 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1321 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1322 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1323 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1324 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1325 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7214;
  for (int _1327 = (int)0, _7215 = _1317; _1327 < _7215 ; ++_1327)
  {
    _7214.push_back(_ptr__1314[safe_add( _1318,_1327 )]);
  }
  auto _7216 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7214.size()),_7214.begin(),_7214.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1326 = _7216;
  _checked_ptr_1<int> _ptr__1326(_1326 ? _1326->raw() : nullptr,_1326 ? _1326->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1312)->shape.get()) && (!::mosek::fusion::p_Set::match(_1326,mosek::fusion::p_LinearDomain::_get_impl(_1312)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1328 = (int)1;
  int _7217 = (int)0;
  int _7218 = _1317;
  for (int _1329 = _7217; _1329 < _7218; ++_1329)
  {
    {
      _1328 *= _ptr__1326[_1329];
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1330;
  _checked_ptr_1<double> _ptr__1330(_1330 ? _1330->raw() : nullptr,_1330 ? _1330->size(0) : 0);
  int _1331 = natconmap_alloc(_1328);
  std::shared_ptr< monty::ndarray< int,1 > > _1332 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1328)));
  _checked_ptr_1<int> _ptr__1332(_1332 ? _1332->raw() : nullptr,_1332 ? _1332->size(0) : 0);
  natconmap->get(_1331,_1332,(int)0);
  putarows(_1332,rs,_1319,_1320,_1322,_1323,_1325);
  std::vector<int> _7219;
  for (int _1333 = (int)0, _7220 = _1319; _1333 < _7220 ; ++_1333)
  {
    _7219.push_back(bfixidx);
  }
  auto _7221 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7219.size()),_7219.begin(),_7219.end()));
  std::vector<double> _7222;
  for (int _1334 = (int)0, _7223 = _1319; _1334 < _7223 ; ++_1334)
  {
    _7222.push_back(_ptr__1316[safe_add( _1324,_1334 )]);
  }
  auto _7224 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7222.size()),_7222.begin(),_7222.end()));
  task_putaijlist(_1332,_7221,_7224,(long long)(_1319));
  {
    std::shared_ptr< monty::ndarray< int,2 > > _1335 = mosek::fusion::p_LinearDomain::_get_impl(_1312)->sparsity;
    bool _1336 = mosek::fusion::p_LinearDomain::_get_impl(_1312)->empty;
    std::shared_ptr< monty::ndarray< double,1 > > _1337 = mosek::fusion::p_LinearDomain::_get_impl(_1312)->bnd;
    _checked_ptr_1<double> _ptr__1337(_1337 ? _1337->raw() : nullptr,_1337 ? _1337->size(0) : 0);
    bool _1338 = mosek::fusion::p_LinearDomain::_get_impl(_1312)->scalable;
    std::shared_ptr< monty::ndarray< double,1 > > _1339 = natconmap_efix;
    _checked_ptr_1<double> _ptr__1339(_1339 ? _1339->raw() : nullptr,_1339 ? _1339->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1340 = natconmap_lb;
    _checked_ptr_1<double> _ptr__1340(_1340 ? _1340->raw() : nullptr,_1340 ? _1340->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1341 = natconmap_ub;
    _checked_ptr_1<double> _ptr__1341(_1341 ? _1341->raw() : nullptr,_1341 ? _1341->size(0) : 0);
    {
      int _7225 = (int)0;
      int _7226 = _1319;
      for (int _1342 = _7225; _1342 < _7226; ++_1342)
      {
        {
          _ptr__1339[_ptr__1332[_1342]] = _ptr__1316[safe_add( _1324,_1342 )];
        }
      }
      if ((NULL == _1337.get()))
      {
        {
          int _7227 = (int)0;
          int _7228 = _1319;
          for (int _1343 = _7227; _1343 < _7228; ++_1343)
          {
            {
              _ptr__1340[_ptr__1332[_1343]] = (int)0;
              _ptr__1341[_ptr__1332[_1343]] = (int)0;
            }
          }
        }
      }
      else if(_1338)
      {
        {
          int _7229 = (int)0;
          int _7230 = _1319;
          for (int _1344 = _7229; _1344 < _7230; ++_1344)
          {
            {
              _ptr__1340[_ptr__1332[_1344]] = _ptr__1337[(int)0];
              _ptr__1341[_ptr__1332[_1344]] = _ptr__1337[(int)0];
            }
          }
        }
      }
      else if((NULL != _1335.get()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1345 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1317)));
          _checked_ptr_1<int> _ptr__1345(_1345 ? _1345->raw() : nullptr,_1345 ? _1345->size(0) : 0);
          _ptr__1345[(_1317 - (int)1)] = (int)1;
          int _7231 = (int)1;
          int _7232 = _1317;
          for (int _1346 = _7231; _1346 < _7232; ++_1346)
          {
            {
              _ptr__1345[((_1317 - _1346) - (int)1)] = safe_mul( _ptr__1345[(_1317 - _1346)],_ptr__1326[(_1317 - _1346)] );
            }
          }
          int _7233 = (int)0;
          int _7234 = (int)((_1335)->size(0));
          for (int _1347 = _7233; _1347 < _7234; ++_1347)
          {
            {
              int _1348 = (int)0;
              int _7235 = (int)0;
              int _7236 = _1317;
              for (int _1349 = _7235; _1349 < _7236; ++_1349)
              {
                {
                  _1348 += safe_mul( _ptr__1345[_1349],((*_1335)(_1347,_1349)) );
                }
              }
              _ptr__1340[_ptr__1332[_1348]] = _ptr__1337[_1347];
              _ptr__1341[_ptr__1332[_1348]] = _ptr__1337[_1347];
            }
          }
        }
      }
      else if(_1336)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1350 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1317)));
          _checked_ptr_1<int> _ptr__1350(_1350 ? _1350->raw() : nullptr,_1350 ? _1350->size(0) : 0);
          _ptr__1350[(_1317 - (int)1)] = (int)1;
          int _7237 = (int)1;
          int _7238 = _1317;
          for (int _1351 = _7237; _1351 < _7238; ++_1351)
          {
            {
              _ptr__1350[((_1317 - _1351) - (int)1)] = safe_mul( _ptr__1350[(_1317 - _1351)],_ptr__1326[(_1317 - _1351)] );
            }
          }
          int _7239 = (int)0;
          int _7240 = (int)((_1335)->size(0));
          for (int _1352 = _7239; _1352 < _7240; ++_1352)
          {
            {
              int _1353 = (int)0;
              int _7241 = (int)0;
              int _7242 = _1317;
              for (int _1354 = _7241; _1354 < _7242; ++_1354)
              {
                {
                  _1353 += safe_mul( _ptr__1350[_1354],((*_1335)(_1352,_1354)) );
                }
              }
              _ptr__1340[_ptr__1332[_1353]] = (int)0;
              _ptr__1341[_ptr__1332[_1353]] = (int)0;
            }
          }
        }
      }
      else
      {
        {
          int _7243 = (int)0;
          int _7244 = _1319;
          for (int _1355 = _7243; _1355 < _7244; ++_1355)
          {
            {
              _ptr__1340[_ptr__1332[_1355]] = _ptr__1337[_1355];
              _ptr__1341[_ptr__1332[_1355]] = _ptr__1337[_1355];
            }
          }
        }
      }
    }
    std::vector<double> _7245;
    for (int _1356 = (int)0, _7246 = (int)((_1332)->size(0)); _1356 < _7246 ; ++_1356)
    {
      _7245.push_back(_ptr__1340[_ptr__1332[_1356]]);
    }
    auto _7247 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7245.size()),_7245.begin(),_7245.end()));
    _1330 = _7247;
    _ptr__1330.update(_1330 ? _1330->raw() : nullptr, _1330 ? _1330->size(0) : 0);
  }
  int _7248 = (int)0;
  int _7249 = _1328;
  for (int _1357 = _7248; _1357 < _7249; ++_1357)
  {
    {
      ((*natconmap_idx)(_ptr__1332[_1357])) = _1331;
      ((*natconmap_slackidx)(_ptr__1332[_1357])) = (int)0;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1312)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      ((*natconmap_type)(_1331)) = (int)1;
      task_con_putboundlist_fr(_1332);
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1312)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      ((*natconmap_type)(_1331)) = (int)3;
      task_con_putboundlist_up(_1332,_1330);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1312)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      ((*natconmap_type)(_1331)) = (int)2;
      task_con_putboundlist_lo(_1332,_1330);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1312)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      ((*natconmap_type)(_1331)) = (int)5;
      task_con_putboundlist_fx(_1332,_1330);
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearConstraint > _1358 = ::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::Model::t(_pubthis),_1310,_1331,_1326,_1332);
  ((*cons)(_1331)) = (_1358).as<::mosek::fusion::ModelConstraint>();
  return (_1358).as<::mosek::fusion::Constraint>();
}
std::string mosek::fusion::Model::getVersion  ( ) { return mosek::fusion::p_Model::getVersion(); }std::string mosek::fusion::p_Model::getVersion(){
  return ::mosek::fusion::p_BaseModel::env_getversion();
}
bool mosek::fusion::Model :: hasConstraint(const std::string & _1359) { return mosek::fusion::p_Model::_get_impl(this)->hasConstraint(_1359); }bool mosek::fusion::p_Model::hasConstraint(const std::string & _1359){
  return con_map->hasItem(_1359);
}
bool mosek::fusion::Model :: hasVariable(const std::string & _1360) { return mosek::fusion::p_Model::_get_impl(this)->hasVariable(_1360); }bool mosek::fusion::p_Model::hasVariable(const std::string & _1360){
  return var_map->hasItem(_1360);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(int _1361) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1361); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(int _1361) { return __mosek_2fusion_2Model__getConstraint(_1361); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(int _1361){
  return (((*cons)(_1361))).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(const std::string & _1362) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1362); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(const std::string &  _1362) { return __mosek_2fusion_2Model__getConstraint(_1362); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(const std::string & _1362){
  monty::rc_ptr< ::mosek::fusion::ModelConstraint > _7250;
  bool _7251 = con_map->hasItem(_1362);
  if (_7251)
  {
    _7250 = ((*cons)(con_map->getItem(_1362)));
  }
  else
  {
    _7250 = nullptr;
  }
  return (_7250).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(int _1363) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1363); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(int _1363) { return __mosek_2fusion_2Model__getVariable(_1363); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(int _1363){
  return (((*vars)(_1363))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(const std::string & _1364) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1364); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(const std::string &  _1364) { return __mosek_2fusion_2Model__getVariable(_1364); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(const std::string & _1364){
  if (var_map->hasItem(_1364))
  {
    {
      int _1365 = var_map->getItem(_1364);
      if ((_1365 < (int)0))
      {
        {
          return (((*barvars)((-safe_add( _1365,(int)1 ))))).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          return (((*vars)(_1365))).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
  else
  {
    {
      return nullptr;
    }
  }
}
std::string mosek::fusion::Model :: getName() { return mosek::fusion::p_Model::_get_impl(this)->getName(); }std::string mosek::fusion::p_Model::getName(){
  return model_name;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model :: __mosek_2fusion_2Model__clone() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__clone(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model::clone() { return __mosek_2fusion_2Model__clone(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Model::__mosek_2fusion_2Model__clone(){
  return ::mosek::fusion::p_Model::_new_Model(::mosek::fusion::Model::t(_pubthis));
}
void mosek::fusion::p_Model::destroy(){xs.reset();ws.reset();rs.reset();con_map.reset();cons.reset();natconmap_type.reset();natconmap_ub.reset();natconmap_lb.reset();natconmap_efix.reset();natconmap_idx.reset();natconmap_slackidx.reset();natconmap_blockid.reset();natconmap.reset();initsol_xx_flag.reset();initsol_xx.reset();var_map.reset();barvars.reset();natbarvarmap_ptr.reset();natbarvarmap_num.reset();natbarvar_dim.reset();natbarvar_ptr.reset();natbarvar_j.reset();natbarvar_i.reset();natbarvar_idx.reset();natvarmap_type.reset();natconemap_dim.reset();natconemap.reset();vars.reset();natvarmap_idx.reset();natvarmap_blockid.reset();natvarmap.reset();}void mosek::fusion::Model::destroy() { mosek::fusion::p_Model::_get_impl(this)->destroy(); }mosek::fusion::SliceVariable::SliceVariable(mosek::fusion::p_SliceVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "SliceVariable()" << this << std::endl; */ }mosek::fusion::SliceVariable::~SliceVariable() {  /* std::cout << "~SliceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceVariable::p_SliceVariable  (::mosek::fusion::SliceVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1366,    std::shared_ptr< monty::ndarray< int,1 > > _1367,    std::shared_ptr< monty::ndarray< long long,1 > > _1368,    std::shared_ptr< monty::ndarray< long long,1 > > _1369){ return new mosek::fusion::SliceVariable(_1366,_1367,_1368,_1369); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1366,    std::shared_ptr< monty::ndarray< int,1 > > _1367,    std::shared_ptr< monty::ndarray< long long,1 > > _1368,    std::shared_ptr< monty::ndarray< long long,1 > > _1369) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1366,_1367,_1368,_1369); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1366,    std::shared_ptr< monty::ndarray< int,1 > > _1367,    std::shared_ptr< monty::ndarray< long long,1 > > _1368,    std::shared_ptr< monty::ndarray< long long,1 > > _1369){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1367(_1367 ? _1367->raw() : nullptr, _1367 ? _1367->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1368(_1368 ? _1368->raw() : nullptr, _1368 ? _1368->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1369(_1369 ? _1369->raw() : nullptr, _1369 ? _1369->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1366,_1367,_1368,_1369);
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = _1369;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = _1368;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = _1367;
  }
}void mosek::fusion::p_SliceVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::SliceVariable::destroy() { mosek::fusion::p_SliceVariable::_get_impl(this)->destroy(); }mosek::fusion::SymRangedVariable::SymRangedVariable(mosek::fusion::p_SymRangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymRangedVariable()" << this << std::endl; */ }mosek::fusion::SymRangedVariable::~SymRangedVariable() {  /* std::cout << "~SymRangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymRangedVariable::p_SymRangedVariable  (::mosek::fusion::SymRangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1370,    monty::rc_ptr< ::mosek::fusion::Model > _1371){ return new mosek::fusion::SymRangedVariable(_1370,_1371); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1370,    monty::rc_ptr< ::mosek::fusion::Model > _1371) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1370,_1371); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1370,    monty::rc_ptr< ::mosek::fusion::Model > _1371){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1370,_1371);
    names_flushed = mosek::fusion::p_SymRangedVariable::_get_impl(_1370)->names_flushed;
    name = mosek::fusion::p_SymRangedVariable::_get_impl(_1370)->name;
    sparsity = mosek::fusion::p_SymRangedVariable::_get_impl(_1370)->sparsity;
    nativeidxs = mosek::fusion::p_SymRangedVariable::_get_impl(_1370)->nativeidxs;
    dim = mosek::fusion::p_SymRangedVariable::_get_impl(_1370)->dim;
  }
}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1372,    const std::string &  _1373,    long long _1374,    int _1375,    std::shared_ptr< monty::ndarray< long long,1 > > _1376,    std::shared_ptr< monty::ndarray< int,1 > > _1377){ return new mosek::fusion::SymRangedVariable(_1372,_1373,_1374,_1375,_1376,_1377); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1372,    const std::string &  _1373,    long long _1374,    int _1375,    std::shared_ptr< monty::ndarray< long long,1 > > _1376,    std::shared_ptr< monty::ndarray< int,1 > > _1377) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1372,_1373,_1374,_1375,_1376,_1377); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1372,    const std::string &  _1373,    long long _1374,    int _1375,    std::shared_ptr< monty::ndarray< long long,1 > > _1376,    std::shared_ptr< monty::ndarray< int,1 > > _1377){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1376(_1376 ? _1376->raw() : nullptr, _1376 ? _1376->size(0) : 0);
    _checked_ptr_1<int> _ptr__1377(_1377 ? _1377->raw() : nullptr, _1377 ? _1377->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1372,_1373,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1375),(int)(_1375)}),_1374,::mosek::fusion::p_SymRangedVariable::mirror_sp(_1375,_1376),::mosek::fusion::p_SymRangedVariable::mirror_idxs(_1375,_1376,_1377));
    names_flushed = false;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->name = _1373;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->nativeidxs = _1377;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->sparsity = _1376;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->dim = _1375;
  }
}void mosek::fusion::p_SymRangedVariable::dual_u(int _1378,std::shared_ptr< monty::ndarray< double,1 > > _1379){
  _checked_ptr_1<double> _ptr__1379(_1379 ? _1379->raw() : nullptr, _1379 ? _1379->size(0) : 0);
  dual_lu(_1378,_1379,false);
}
void mosek::fusion::p_SymRangedVariable::dual_l(int _1380,std::shared_ptr< monty::ndarray< double,1 > > _1381){
  _checked_ptr_1<double> _ptr__1381(_1381 ? _1381->raw() : nullptr, _1381 ? _1381->size(0) : 0);
  dual_lu(_1380,_1381,true);
}
void mosek::fusion::p_SymRangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1382 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7252 = (int)0;
          int _7253 = (int)((nativeidxs)->size(0));
          for (int _1383 = _7252; _1383 < _7253; ++_1383)
          {
            {
              std::string _7254;
              bool _7255 = ((int)((name).size()) == (int)0);
              if (_7255)
              {
                _7254 = std::string ("");
              }
              else
              {
                _7254 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1383 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1383 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1382.get())->varname(((*nativeidxs)(_1383)),_7254);
            }
          }
        }
      }
      else
      {
        {
          int _7256 = (int)0;
          int _7257 = (int)((sparsity)->size(0));
          for (int _1384 = _7256; _1384 < _7257; ++_1384)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1382.get())->varname(((*nativeidxs)(_1384)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1384)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1384)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymRangedVariable::__mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1385){
  return (::mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable(::mosek::fusion::SymRangedVariable::t(_pubthis),_1385)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_idxs(int _1386,std::shared_ptr< monty::ndarray< long long,1 > > _1387,std::shared_ptr< monty::ndarray< int,1 > > _1388){
  _checked_ptr_1<long long> _ptr__1387(_1387 ? _1387->raw() : nullptr, _1387 ? _1387->size(0) : 0);
  _checked_ptr_1<int> _ptr__1388(_1388 ? _1388->raw() : nullptr, _1388 ? _1388->size(0) : 0);
  if ((NULL == _1387.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1389 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1386,_1386 ))));
      _checked_ptr_1<long long> _ptr__1389(_1389 ? _1389->raw() : nullptr,_1389 ? _1389->size(0) : 0);
      int _1390 = (int)0;
      {
        int _7258 = (int)0;
        int _7259 = _1386;
        for (int _1391 = _7258; _1391 < _7259; ++_1391)
        {
          {
            _ptr__1389[safe_add( safe_mul( _1391,_1386 ),_1391 )] = safe_add( _ptr__1388[_1390],(int)1 );
            ++ _1390;
            int _7260 = safe_add( _1391,(int)1 );
            int _7261 = _1386;
            for (int _1392 = _7260; _1392 < _7261; ++_1392)
            {
              {
                _ptr__1389[safe_add( safe_mul( _1391,_1386 ),_1392 )] = safe_add( _ptr__1388[_1390],(int)1 );
                _ptr__1389[safe_add( safe_mul( _1392,_1386 ),_1391 )] = safe_add( _ptr__1388[_1390],(int)1 );
                ++ _1390;
              }
            }
          }
        }
      }
      return _1389;
    }
  }
  else
  {
    {
      int _1393 = (int)0;
      {
        int _7262 = (int)0;
        int _7263 = (int)((_1387)->size(0));
        for (int _1394 = _7262; _1394 < _7263; ++_1394)
        {
          {
            int _7264;
            bool _7265 = ((_ptr__1387[_1394] % safe_add( _1386,(int)1 )) == (int)0);
            if (_7265)
            {
              _7264 = (int)1;
            }
            else
            {
              _7264 = (int)2;
            }
            _1393 += _7264;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1395 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1393)));
      _checked_ptr_1<long long> _ptr__1395(_1395 ? _1395->raw() : nullptr,_1395 ? _1395->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1396 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1393)));
      _checked_ptr_1<long long> _ptr__1396(_1396 ? _1396->raw() : nullptr,_1396 ? _1396->size(0) : 0);
      {
        int _1397 = (int)0;
        int _7266 = (int)0;
        int _7267 = (int)((_1387)->size(0));
        for (int _1398 = _7266; _1398 < _7267; ++_1398)
        {
          {
            long long _1399 = (_ptr__1387[_1398] / _1386);
            long long _1400 = (_ptr__1387[_1398] % _1386);
            _ptr__1395[_1397] = _ptr__1387[_1398];
            _ptr__1396[_1397] = safe_add( _ptr__1388[_1398],(int)1 );
            ++ _1397;
            if ((_1399 != _1400))
            {
              {
                _ptr__1395[_1397] = safe_add( safe_mul( _1400,_1386 ),_1399 );
                _ptr__1396[_1397] = safe_add( _ptr__1388[_1398],(int)1 );
                ++ _1397;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7268;
      for (int _1402 = (int)0, _7269 = _1393; _1402 < _7269 ; ++_1402)
      {
        _7268.push_back(_1402);
      }
      auto _7270 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7268.size()),_7268.begin(),_7268.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1401 = _7270;
      _checked_ptr_1<long long> _ptr__1401(_1401 ? _1401->raw() : nullptr,_1401 ? _1401->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1401,_1395,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1393));
      std::vector<long long> _7271;
      for (int _1403 = (int)0, _7272 = _1393; _1403 < _7272 ; ++_1403)
      {
        _7271.push_back(_ptr__1396[_ptr__1401[_1403]]);
      }
      auto _7273 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7271.size()),_7271.begin(),_7271.end()));
      return _7273;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_sp(int _1404,std::shared_ptr< monty::ndarray< long long,1 > > _1405){
  _checked_ptr_1<long long> _ptr__1405(_1405 ? _1405->raw() : nullptr, _1405 ? _1405->size(0) : 0);
  if ((NULL == _1405.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1406 = (int)0;
      {
        int _7274 = (int)0;
        int _7275 = (int)((_1405)->size(0));
        for (int _1407 = _7274; _1407 < _7275; ++_1407)
        {
          {
            int _7276;
            bool _7277 = ((_ptr__1405[_1407] % safe_add( _1404,(int)1 )) == (int)0);
            if (_7277)
            {
              _7276 = (int)1;
            }
            else
            {
              _7276 = (int)2;
            }
            _1406 += _7276;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1408 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1406)));
      _checked_ptr_1<long long> _ptr__1408(_1408 ? _1408->raw() : nullptr,_1408 ? _1408->size(0) : 0);
      {
        int _1409 = (int)0;
        int _7278 = (int)0;
        int _7279 = (int)((_1405)->size(0));
        for (int _1410 = _7278; _1410 < _7279; ++_1410)
        {
          {
            long long _1411 = (_ptr__1405[_1410] / _1404);
            long long _1412 = (_ptr__1405[_1410] % _1404);
            _ptr__1408[_1409] = _ptr__1405[_1410];
            ++ _1409;
            if ((_1411 != _1412))
            {
              {
                _ptr__1408[_1409] = safe_add( safe_mul( _1412,_1404 ),_1411 );
                ++ _1409;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7280;
      for (int _1414 = (int)0, _7281 = _1406; _1414 < _7281 ; ++_1414)
      {
        _7280.push_back(_1414);
      }
      auto _7282 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7280.size()),_7280.begin(),_7280.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1413 = _7282;
      _checked_ptr_1<long long> _ptr__1413(_1413 ? _1413->raw() : nullptr,_1413 ? _1413->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1413,_1408,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1406));
      std::vector<long long> _7283;
      for (int _1415 = (int)0, _7284 = _1406; _1415 < _7284 ; ++_1415)
      {
        _7283.push_back(_ptr__1408[_ptr__1413[_1415]]);
      }
      auto _7285 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7283.size()),_7283.begin(),_7283.end()));
      return _7285;
    }
  }
}
void mosek::fusion::p_SymRangedVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymRangedVariable::destroy() { mosek::fusion::p_SymRangedVariable::_get_impl(this)->destroy(); }mosek::fusion::RangedVariable::RangedVariable(mosek::fusion::p_RangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "RangedVariable()" << this << std::endl; */ }mosek::fusion::RangedVariable::~RangedVariable() {  /* std::cout << "~RangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedVariable::p_RangedVariable  (::mosek::fusion::RangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1416,    monty::rc_ptr< ::mosek::fusion::Model > _1417){ return new mosek::fusion::RangedVariable(_1416,_1417); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1416,    monty::rc_ptr< ::mosek::fusion::Model > _1417) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1416,_1417); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1416,    monty::rc_ptr< ::mosek::fusion::Model > _1417){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1416,_1417);
    name = mosek::fusion::p_RangedVariable::_get_impl(_1416)->name;
    nativeidxs = mosek::fusion::p_RangedVariable::_get_impl(_1416)->nativeidxs;
    sparsity = mosek::fusion::p_RangedVariable::_get_impl(_1416)->sparsity;
    names_flushed = mosek::fusion::p_RangedVariable::_get_impl(_1416)->names_flushed;
    shape = mosek::fusion::p_RangedVariable::_get_impl(_1416)->shape;
  }
}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1418,    const std::string &  _1419,    long long _1420,    std::shared_ptr< monty::ndarray< int,1 > > _1421,    std::shared_ptr< monty::ndarray< long long,1 > > _1422,    std::shared_ptr< monty::ndarray< int,1 > > _1423){ return new mosek::fusion::RangedVariable(_1418,_1419,_1420,_1421,_1422,_1423); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1418,    const std::string &  _1419,    long long _1420,    std::shared_ptr< monty::ndarray< int,1 > > _1421,    std::shared_ptr< monty::ndarray< long long,1 > > _1422,    std::shared_ptr< monty::ndarray< int,1 > > _1423) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1418,_1419,_1420,_1421,_1422,_1423); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1418,    const std::string &  _1419,    long long _1420,    std::shared_ptr< monty::ndarray< int,1 > > _1421,    std::shared_ptr< monty::ndarray< long long,1 > > _1422,    std::shared_ptr< monty::ndarray< int,1 > > _1423){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1421(_1421 ? _1421->raw() : nullptr, _1421 ? _1421->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1422(_1422 ? _1422->raw() : nullptr, _1422 ? _1422->size(0) : 0);
    _checked_ptr_1<int> _ptr__1423(_1423 ? _1423->raw() : nullptr, _1423 ? _1423->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1418,_1419,_1421,_1420,_1422,::mosek::fusion::p_RangedVariable::globalNativeIndexes(_1423));
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->nativeidxs = _1423;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->sparsity = _1422;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->name = _1419;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->shape = _1421;
    names_flushed = false;
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__elementDesc(long long _1424,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1425) { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__elementDesc(_1424,_1425); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable::elementDesc(long long _1424,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1425) { return __mosek_2fusion_2RangedVariable__elementDesc(_1424,_1425); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__elementDesc(long long _1424,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1425){
  _pubthis->elementName(_1424,_1425);
  _1425->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : in range"));
  return _1425;
}
void mosek::fusion::p_RangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1426 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1427 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1427->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1427->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7286 = (int)1;
          int _7287 = _pubthis->getND();
          for (int _1428 = _7286; _1428 < _7287; ++_1428)
          {
            {
              _1427->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1428);
            }
          }
        }
      }
      {}
      _1427->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      mosek::fusion::p_Model::_get_impl(_1426.get())->varnames(nativeidxs,_1427->toString(),_pubthis->getShape(),sparsity);
      names_flushed = true;
    }
  }
  {}
}
void mosek::fusion::p_RangedVariable::dual_u(int _1429,std::shared_ptr< monty::ndarray< double,1 > > _1430){
  _checked_ptr_1<double> _ptr__1430(_1430 ? _1430->raw() : nullptr, _1430 ? _1430->size(0) : 0);
  dual_lu(_1429,_1430,false);
}
void mosek::fusion::p_RangedVariable::dual_l(int _1431,std::shared_ptr< monty::ndarray< double,1 > > _1432){
  _checked_ptr_1<double> _ptr__1432(_1432 ? _1432->raw() : nullptr, _1432 ? _1432->size(0) : 0);
  dual_lu(_1431,_1432,true);
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1433){
  return (::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::RangedVariable::t(_pubthis),_1433)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_RangedVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1434){
  _checked_ptr_1<int> _ptr__1434(_1434 ? _1434->raw() : nullptr, _1434 ? _1434->size(0) : 0);
  std::vector<long long> _7288;
  for (int _1435 = (int)0, _7289 = (int)((_1434)->size(0)); _1435 < _7289 ; ++_1435)
  {
    _7288.push_back(safe_add( _ptr__1434[_1435],(int)1 ));
  }
  auto _7290 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7288.size()),_7288.begin(),_7288.end()));
  return _7290;
}
void mosek::fusion::p_RangedVariable::destroy(){shape.reset();nativeidxs.reset();sparsity.reset();}void mosek::fusion::RangedVariable::destroy() { mosek::fusion::p_RangedVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDVariable::LinearPSDVariable(mosek::fusion::p_LinearPSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearPSDVariable()" << this << std::endl; */ }mosek::fusion::LinearPSDVariable::~LinearPSDVariable() {  /* std::cout << "~LinearPSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDVariable::p_LinearPSDVariable  (::mosek::fusion::LinearPSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1436,    monty::rc_ptr< ::mosek::fusion::Model > _1437){ return new mosek::fusion::LinearPSDVariable(_1436,_1437); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1436,    monty::rc_ptr< ::mosek::fusion::Model > _1437) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1436,_1437); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1436,    monty::rc_ptr< ::mosek::fusion::Model > _1437){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1436,_1437);
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = mosek::fusion::p_LinearPSDVariable::_get_impl(_1436)->conedim;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = mosek::fusion::p_LinearPSDVariable::_get_impl(_1436)->varid;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = mosek::fusion::p_LinearPSDVariable::_get_impl(_1436)->name;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = mosek::fusion::p_LinearPSDVariable::_get_impl(_1436)->shape;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_LinearPSDVariable::_get_impl(_1436)->nativeidxs;
  }
}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1438,    const std::string &  _1439,    int _1440,    std::shared_ptr< monty::ndarray< int,1 > > _1441,    int _1442,    std::shared_ptr< monty::ndarray< long long,1 > > _1443){ return new mosek::fusion::LinearPSDVariable(_1438,_1439,_1440,_1441,_1442,_1443); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1438,    const std::string &  _1439,    int _1440,    std::shared_ptr< monty::ndarray< int,1 > > _1441,    int _1442,    std::shared_ptr< monty::ndarray< long long,1 > > _1443) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1438,_1439,_1440,_1441,_1442,_1443); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1438,    const std::string &  _1439,    int _1440,    std::shared_ptr< monty::ndarray< int,1 > > _1441,    int _1442,    std::shared_ptr< monty::ndarray< long long,1 > > _1443){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1441(_1441 ? _1441->raw() : nullptr, _1441 ? _1441->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1443(_1443 ? _1443->raw() : nullptr, _1443 ? _1443->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1438,_1439,_1441,_1440,nullptr,::mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(_1443));
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = _1439;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = _1442;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = _1440;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = _1441;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = _1443;
  }
}void mosek::fusion::p_LinearPSDVariable::flushNames(){
}
std::string mosek::fusion::LinearPSDVariable :: toString() { return mosek::fusion::p_LinearPSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearPSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1444 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1444->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1444->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1444->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7291 = (int)1;
  int _7292 = (int)((shape)->size(0));
  for (int _1445 = _7291; _1445 < _7292; ++_1445)
  {
    {
      _1444->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1445)));
    }
  }
  _1444->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1444->toString();
}
void mosek::fusion::LinearPSDVariable :: make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1446) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_continuous(_1446); }void mosek::fusion::p_LinearPSDVariable::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1446){
  _checked_ptr_1<long long> _ptr__1446(_1446 ? _1446->raw() : nullptr, _1446 ? _1446->size(0) : 0);
}
void mosek::fusion::LinearPSDVariable :: make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1447) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_integer(_1447); }void mosek::fusion::p_LinearPSDVariable::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1447){
  _checked_ptr_1<long long> _ptr__1447(_1447 ? _1447->raw() : nullptr, _1447 ? _1447->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Cannot make PSDVariable elements integer"));
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearPSDVariable::__mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1448){
  return (::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::LinearPSDVariable::t(_pubthis),_1448)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1449){
  _checked_ptr_1<long long> _ptr__1449(_1449 ? _1449->raw() : nullptr, _1449 ? _1449->size(0) : 0);
  std::vector<long long> _7293;
  for (int _1450 = (int)0, _7294 = (int)((_1449)->size(0)); _1450 < _7294 ; ++_1450)
  {
    _7293.push_back((-safe_add( _ptr__1449[_1450],(int)1 )));
  }
  auto _7295 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7293.size()),_7293.begin(),_7293.end()));
  return _7295;
}
void mosek::fusion::p_LinearPSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDVariable::destroy() { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->destroy(); }mosek::fusion::PSDVariable::PSDVariable(mosek::fusion::p_PSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "PSDVariable()" << this << std::endl; */ }mosek::fusion::PSDVariable::~PSDVariable() {  /* std::cout << "~PSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDVariable::p_PSDVariable  (::mosek::fusion::PSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1451,    monty::rc_ptr< ::mosek::fusion::Model > _1452){ return new mosek::fusion::PSDVariable(_1451,_1452); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1451,    monty::rc_ptr< ::mosek::fusion::Model > _1452) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1451,_1452); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1451,    monty::rc_ptr< ::mosek::fusion::Model > _1452){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1451,_1452);
    varid = mosek::fusion::p_PSDVariable::_get_impl(_1451)->varid;
    nativeidxs = mosek::fusion::p_PSDVariable::_get_impl(_1451)->nativeidxs;
    name = mosek::fusion::p_PSDVariable::_get_impl(_1451)->name;
    shape = mosek::fusion::p_PSDVariable::_get_impl(_1451)->shape;
    conedim1 = mosek::fusion::p_PSDVariable::_get_impl(_1451)->conedim1;
    conedim2 = mosek::fusion::p_PSDVariable::_get_impl(_1451)->conedim2;
  }
}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1453,    const std::string &  _1454,    int _1455,    std::shared_ptr< monty::ndarray< int,1 > > _1456,    int _1457,    int _1458,    std::shared_ptr< monty::ndarray< long long,1 > > _1459){ return new mosek::fusion::PSDVariable(_1453,_1454,_1455,_1456,_1457,_1458,_1459); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1453,    const std::string &  _1454,    int _1455,    std::shared_ptr< monty::ndarray< int,1 > > _1456,    int _1457,    int _1458,    std::shared_ptr< monty::ndarray< long long,1 > > _1459) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1453,_1454,_1455,_1456,_1457,_1458,_1459); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1453,    const std::string &  _1454,    int _1455,    std::shared_ptr< monty::ndarray< int,1 > > _1456,    int _1457,    int _1458,    std::shared_ptr< monty::ndarray< long long,1 > > _1459){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1456(_1456 ? _1456->raw() : nullptr, _1456 ? _1456->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1459(_1459 ? _1459->raw() : nullptr, _1459 ? _1459->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1453,_1454,_1456,_1455,nullptr,::mosek::fusion::p_PSDVariable::fullnativeidxs(_1456,_1457,_1458,_1459));
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->varid = _1455;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->nativeidxs = _1459;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->name = _1454;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->shape = _1456;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim1 = _1457;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim2 = _1458;
  }
}void mosek::fusion::p_PSDVariable::flushNames(){
}
std::string mosek::fusion::PSDVariable :: toString() { return mosek::fusion::p_PSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1460 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1460->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1460->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1460->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7296 = (int)1;
  int _7297 = (int)((shape)->size(0));
  for (int _1461 = _7296; _1461 < _7297; ++_1461)
  {
    {
      _1460->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1461)));
    }
  }
  _1460->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1460->toString();
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable :: __mosek_2fusion_2PSDVariable__elementDesc(long long _1462,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1463) { return mosek::fusion::p_PSDVariable::_get_impl(this)->__mosek_2fusion_2PSDVariable__elementDesc(_1462,_1463); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable::elementDesc(long long _1462,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1463) { return __mosek_2fusion_2PSDVariable__elementDesc(_1462,_1463); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__elementDesc(long long _1462,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1463){
  _pubthis->elementName(_1462,_1463);
  _1463->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element in positive semidefinite cone"));
  return _1463;
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1464){
  return (::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::PSDVariable::t(_pubthis),_1464)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_PSDVariable::fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1465,int _1466,int _1467,std::shared_ptr< monty::ndarray< long long,1 > > _1468){
  _checked_ptr_1<int> _ptr__1465(_1465 ? _1465->raw() : nullptr, _1465 ? _1465->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1468(_1468 ? _1468->raw() : nullptr, _1468 ? _1468->size(0) : 0);
  int _1469 = (int)((_1465)->size(0));
  bool _1470 = (_1466 < _1467);
  int _7298;
  bool _7299 = _1470;
  if (_7299)
  {
    _7298 = _1466;
  }
  else
  {
    _7298 = _1467;
  }
  int _1471 = _7298;
  int _7300;
  bool _7301 = (!_1470);
  if (_7301)
  {
    _7300 = _1466;
  }
  else
  {
    _7300 = _1467;
  }
  int _1472 = _7300;
  int _1473 = (int)1;
  int _7302 = (int)0;
  int _7303 = _1471;
  for (int _1474 = _7302; _1474 < _7303; ++_1474)
  {
    {
      _1473 *= _ptr__1465[_1474];
    }
  }
  int _1475 = _ptr__1465[_1471];
  int _1476 = (int)1;
  int _7304 = safe_add( _1471,(int)1 );
  int _7305 = _1472;
  for (int _1477 = _7304; _1477 < _7305; ++_1477)
  {
    {
      _1476 *= _ptr__1465[_1477];
    }
  }
  int _1478 = _ptr__1465[_1472];
  int _1479 = (int)1;
  int _7306 = safe_add( _1472,(int)1 );
  int _7307 = _1469;
  for (int _1480 = _7306; _1480 < _7307; ++_1480)
  {
    {
      _1479 *= _ptr__1465[_1480];
    }
  }
  int _1481 = safe_mul( safe_mul( safe_mul( safe_mul( _1473,_1475 ),_1476 ),_1478 ),_1479 );
  std::shared_ptr< monty::ndarray< long long,1 > > _1482 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1481)));
  _checked_ptr_1<long long> _ptr__1482(_1482 ? _1482->raw() : nullptr,_1482 ? _1482->size(0) : 0);
  int _1483 = _1479;
  int _1484 = safe_mul( _1483,_1478 );
  int _1485 = safe_mul( _1484,_1476 );
  int _1486 = safe_mul( _1485,_1485 );
  {
    int _1487 = (int)0;
    int _7308 = (int)0;
    int _7309 = _1473;
    for (int _1488 = _7308; _1488 < _7309; ++_1488)
    {
      {
        int _7310 = (int)0;
        int _7311 = _1478;
        for (int _1489 = _7310; _1489 < _7311; ++_1489)
        {
          {
            int _7312 = (int)0;
            int _7313 = _1476;
            for (int _1490 = _7312; _1490 < _7313; ++_1490)
            {
              {
                int _7314 = _1489;
                int _7315 = _1475;
                for (int _1491 = _7314; _1491 < _7315; ++_1491)
                {
                  {
                    int _7316 = (int)0;
                    int _7317 = _1479;
                    for (int _1492 = _7316; _1492 < _7317; ++_1492)
                    {
                      {
                        _ptr__1482[safe_add( safe_add( safe_add( safe_add( safe_mul( _1488,_1486 ),safe_mul( _1491,_1485 ) ),safe_mul( _1490,_1484 ) ),safe_mul( _1489,_1483 ) ),_1492 )] = (-safe_add( _ptr__1468[_1487],(int)1 ));
                        _ptr__1482[safe_add( safe_add( safe_add( safe_add( safe_mul( _1488,_1486 ),safe_mul( _1489,_1485 ) ),safe_mul( _1490,_1484 ) ),safe_mul( _1491,_1483 ) ),_1492 )] = (-safe_add( _ptr__1468[_1487],(int)1 ));
                        ++ _1487;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _1482;
}
void mosek::fusion::p_PSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::PSDVariable::destroy() { mosek::fusion::p_PSDVariable::_get_impl(this)->destroy(); }mosek::fusion::SymLinearVariable::SymLinearVariable(mosek::fusion::p_SymLinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymLinearVariable()" << this << std::endl; */ }mosek::fusion::SymLinearVariable::~SymLinearVariable() {  /* std::cout << "~SymLinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymLinearVariable::p_SymLinearVariable  (::mosek::fusion::SymLinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1493,    monty::rc_ptr< ::mosek::fusion::Model > _1494){ return new mosek::fusion::SymLinearVariable(_1493,_1494); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1493,    monty::rc_ptr< ::mosek::fusion::Model > _1494) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1493,_1494); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1493,    monty::rc_ptr< ::mosek::fusion::Model > _1494){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1493,_1494);
    names_flushed = mosek::fusion::p_SymLinearVariable::_get_impl(_1493)->names_flushed;
    name = mosek::fusion::p_SymLinearVariable::_get_impl(_1493)->name;
    sparsity = mosek::fusion::p_SymLinearVariable::_get_impl(_1493)->sparsity;
    nativeidxs = mosek::fusion::p_SymLinearVariable::_get_impl(_1493)->nativeidxs;
    dim = mosek::fusion::p_SymLinearVariable::_get_impl(_1493)->dim;
  }
}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1495,    const std::string &  _1496,    long long _1497,    int _1498,    std::shared_ptr< monty::ndarray< long long,1 > > _1499,    std::shared_ptr< monty::ndarray< int,1 > > _1500){ return new mosek::fusion::SymLinearVariable(_1495,_1496,_1497,_1498,_1499,_1500); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1495,    const std::string &  _1496,    long long _1497,    int _1498,    std::shared_ptr< monty::ndarray< long long,1 > > _1499,    std::shared_ptr< monty::ndarray< int,1 > > _1500) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1495,_1496,_1497,_1498,_1499,_1500); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1495,    const std::string &  _1496,    long long _1497,    int _1498,    std::shared_ptr< monty::ndarray< long long,1 > > _1499,    std::shared_ptr< monty::ndarray< int,1 > > _1500){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1499(_1499 ? _1499->raw() : nullptr, _1499 ? _1499->size(0) : 0);
    _checked_ptr_1<int> _ptr__1500(_1500 ? _1500->raw() : nullptr, _1500 ? _1500->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1495,_1496,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1498),(int)(_1498)}),_1497,::mosek::fusion::p_SymLinearVariable::mirror_sp(_1498,_1499),::mosek::fusion::p_SymLinearVariable::mirror_idxs(_1498,_1499,_1500));
    names_flushed = false;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->name = _1496;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->nativeidxs = _1500;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->sparsity = _1499;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->dim = _1498;
  }
}void mosek::fusion::p_SymLinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1501 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7318 = (int)0;
          int _7319 = (int)((nativeidxs)->size(0));
          for (int _1502 = _7318; _1502 < _7319; ++_1502)
          {
            {
              std::string _7320;
              bool _7321 = ((int)((name).size()) == (int)0);
              if (_7321)
              {
                _7320 = std::string ("");
              }
              else
              {
                _7320 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1502 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1502 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1501.get())->varname(((*nativeidxs)(_1502)),_7320);
            }
          }
        }
      }
      else
      {
        {
          int _7322 = (int)0;
          int _7323 = (int)((sparsity)->size(0));
          for (int _1503 = _7322; _1503 < _7323; ++_1503)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1501.get())->varname(((*nativeidxs)(_1503)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1503)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1503)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymLinearVariable::__mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1504){
  return (::mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable(::mosek::fusion::SymLinearVariable::t(_pubthis),_1504)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_idxs(int _1505,std::shared_ptr< monty::ndarray< long long,1 > > _1506,std::shared_ptr< monty::ndarray< int,1 > > _1507){
  _checked_ptr_1<long long> _ptr__1506(_1506 ? _1506->raw() : nullptr, _1506 ? _1506->size(0) : 0);
  _checked_ptr_1<int> _ptr__1507(_1507 ? _1507->raw() : nullptr, _1507 ? _1507->size(0) : 0);
  if ((NULL == _1506.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1508 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1505,_1505 ))));
      _checked_ptr_1<long long> _ptr__1508(_1508 ? _1508->raw() : nullptr,_1508 ? _1508->size(0) : 0);
      int _1509 = (int)0;
      {
        int _7324 = (int)0;
        int _7325 = _1505;
        for (int _1510 = _7324; _1510 < _7325; ++_1510)
        {
          {
            _ptr__1508[safe_add( safe_mul( _1510,_1505 ),_1510 )] = safe_add( _ptr__1507[_1509],(int)1 );
            ++ _1509;
            int _7326 = safe_add( _1510,(int)1 );
            int _7327 = _1505;
            for (int _1511 = _7326; _1511 < _7327; ++_1511)
            {
              {
                _ptr__1508[safe_add( safe_mul( _1510,_1505 ),_1511 )] = safe_add( _ptr__1507[_1509],(int)1 );
                _ptr__1508[safe_add( safe_mul( _1511,_1505 ),_1510 )] = safe_add( _ptr__1507[_1509],(int)1 );
                ++ _1509;
              }
            }
          }
        }
      }
      return _1508;
    }
  }
  else
  {
    {
      int _1512 = (int)0;
      {
        int _7328 = (int)0;
        int _7329 = (int)((_1506)->size(0));
        for (int _1513 = _7328; _1513 < _7329; ++_1513)
        {
          {
            int _7330;
            bool _7331 = ((_ptr__1506[_1513] % safe_add( _1505,(int)1 )) == (int)0);
            if (_7331)
            {
              _7330 = (int)1;
            }
            else
            {
              _7330 = (int)2;
            }
            _1512 += _7330;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1514 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1512)));
      _checked_ptr_1<long long> _ptr__1514(_1514 ? _1514->raw() : nullptr,_1514 ? _1514->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1515 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1512)));
      _checked_ptr_1<long long> _ptr__1515(_1515 ? _1515->raw() : nullptr,_1515 ? _1515->size(0) : 0);
      {
        int _1516 = (int)0;
        int _7332 = (int)0;
        int _7333 = (int)((_1506)->size(0));
        for (int _1517 = _7332; _1517 < _7333; ++_1517)
        {
          {
            long long _1518 = (_ptr__1506[_1517] / _1505);
            long long _1519 = (_ptr__1506[_1517] % _1505);
            _ptr__1514[_1516] = _ptr__1506[_1517];
            _ptr__1515[_1516] = safe_add( _ptr__1507[_1517],(int)1 );
            ++ _1516;
            if ((_1518 != _1519))
            {
              {
                _ptr__1514[_1516] = safe_add( safe_mul( _1519,_1505 ),_1518 );
                _ptr__1515[_1516] = safe_add( _ptr__1507[_1517],(int)1 );
                ++ _1516;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7334;
      for (int _1521 = (int)0, _7335 = _1512; _1521 < _7335 ; ++_1521)
      {
        _7334.push_back(_1521);
      }
      auto _7336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7334.size()),_7334.begin(),_7334.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1520 = _7336;
      _checked_ptr_1<long long> _ptr__1520(_1520 ? _1520->raw() : nullptr,_1520 ? _1520->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1520,_1514,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1512));
      std::vector<long long> _7337;
      for (int _1522 = (int)0, _7338 = _1512; _1522 < _7338 ; ++_1522)
      {
        _7337.push_back(_ptr__1515[_ptr__1520[_1522]]);
      }
      auto _7339 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7337.size()),_7337.begin(),_7337.end()));
      return _7339;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_sp(int _1523,std::shared_ptr< monty::ndarray< long long,1 > > _1524){
  _checked_ptr_1<long long> _ptr__1524(_1524 ? _1524->raw() : nullptr, _1524 ? _1524->size(0) : 0);
  if ((NULL == _1524.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1525 = (int)0;
      {
        int _7340 = (int)0;
        int _7341 = (int)((_1524)->size(0));
        for (int _1526 = _7340; _1526 < _7341; ++_1526)
        {
          {
            int _7342;
            bool _7343 = ((_ptr__1524[_1526] % safe_add( _1523,(int)1 )) == (int)0);
            if (_7343)
            {
              _7342 = (int)1;
            }
            else
            {
              _7342 = (int)2;
            }
            _1525 += _7342;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1527 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1525)));
      _checked_ptr_1<long long> _ptr__1527(_1527 ? _1527->raw() : nullptr,_1527 ? _1527->size(0) : 0);
      {
        int _1528 = (int)0;
        int _7344 = (int)0;
        int _7345 = (int)((_1524)->size(0));
        for (int _1529 = _7344; _1529 < _7345; ++_1529)
        {
          {
            long long _1530 = (_ptr__1524[_1529] / _1523);
            long long _1531 = (_ptr__1524[_1529] % _1523);
            _ptr__1527[_1528] = _ptr__1524[_1529];
            ++ _1528;
            if ((_1530 != _1531))
            {
              {
                _ptr__1527[_1528] = safe_add( safe_mul( _1531,_1523 ),_1530 );
                ++ _1528;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7346;
      for (int _1533 = (int)0, _7347 = _1525; _1533 < _7347 ; ++_1533)
      {
        _7346.push_back(_1533);
      }
      auto _7348 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7346.size()),_7346.begin(),_7346.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1532 = _7348;
      _checked_ptr_1<long long> _ptr__1532(_1532 ? _1532->raw() : nullptr,_1532 ? _1532->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1532,_1527,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1525));
      std::vector<long long> _7349;
      for (int _1534 = (int)0, _7350 = _1525; _1534 < _7350 ; ++_1534)
      {
        _7349.push_back(_ptr__1527[_ptr__1532[_1534]]);
      }
      auto _7351 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7349.size()),_7349.begin(),_7349.end()));
      return _7351;
    }
  }
}
void mosek::fusion::p_SymLinearVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymLinearVariable::destroy() { mosek::fusion::p_SymLinearVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearVariable::LinearVariable(mosek::fusion::p_LinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearVariable()" << this << std::endl; */ }mosek::fusion::LinearVariable::~LinearVariable() {  /* std::cout << "~LinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearVariable::p_LinearVariable  (::mosek::fusion::LinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1535,    monty::rc_ptr< ::mosek::fusion::Model > _1536){ return new mosek::fusion::LinearVariable(_1535,_1536); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1535,    monty::rc_ptr< ::mosek::fusion::Model > _1536) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1535,_1536); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1535,    monty::rc_ptr< ::mosek::fusion::Model > _1536){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1535,_1536);
    names_flushed = mosek::fusion::p_LinearVariable::_get_impl(_1535)->names_flushed;
    nativeidxs = mosek::fusion::p_LinearVariable::_get_impl(_1535)->nativeidxs;
    sparsity = mosek::fusion::p_LinearVariable::_get_impl(_1535)->sparsity;
    shape = mosek::fusion::p_LinearVariable::_get_impl(_1535)->shape;
    name = mosek::fusion::p_LinearVariable::_get_impl(_1535)->name;
  }
}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1537,    const std::string &  _1538,    long long _1539,    std::shared_ptr< monty::ndarray< int,1 > > _1540,    std::shared_ptr< monty::ndarray< long long,1 > > _1541,    std::shared_ptr< monty::ndarray< int,1 > > _1542){ return new mosek::fusion::LinearVariable(_1537,_1538,_1539,_1540,_1541,_1542); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1537,    const std::string &  _1538,    long long _1539,    std::shared_ptr< monty::ndarray< int,1 > > _1540,    std::shared_ptr< monty::ndarray< long long,1 > > _1541,    std::shared_ptr< monty::ndarray< int,1 > > _1542) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1537,_1538,_1539,_1540,_1541,_1542); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1537,    const std::string &  _1538,    long long _1539,    std::shared_ptr< monty::ndarray< int,1 > > _1540,    std::shared_ptr< monty::ndarray< long long,1 > > _1541,    std::shared_ptr< monty::ndarray< int,1 > > _1542){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1540(_1540 ? _1540->raw() : nullptr, _1540 ? _1540->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1541(_1541 ? _1541->raw() : nullptr, _1541 ? _1541->size(0) : 0);
    _checked_ptr_1<int> _ptr__1542(_1542 ? _1542->raw() : nullptr, _1542 ? _1542->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1537,_1538,_1540,_1539,_1541,::mosek::fusion::p_LinearVariable::globalNativeIndexes(_1542));
    names_flushed = false;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->name = _1538;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->nativeidxs = _1542;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->sparsity = _1541;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->shape = _1540;
  }
}std::string mosek::fusion::LinearVariable :: toString() { return mosek::fusion::p_LinearVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1543 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1543->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearVariable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1543->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7352 = (int)1;
      int _7353 = (int)((shape)->size(0));
      for (int _1544 = _7352; _1544 < _7353; ++_1544)
      {
        {
          _1543->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1544)));
        }
      }
    }
  }
  {}
  _1543->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1543->toString();
}
void mosek::fusion::p_LinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1545 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1546 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1546->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1546->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7354 = (int)1;
          int _7355 = _pubthis->getND();
          for (int _1547 = _7354; _1547 < _7355; ++_1547)
          {
            {
              _1546->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1547);
            }
          }
        }
      }
      {}
      _1546->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7356;
      bool _7357 = (_pubthis->getND() > (int)0);
      if (_7357)
      {
        _7356 = _pubthis->getShape();
      }
      else
      {
        _7356 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
      }
      mosek::fusion::p_Model::_get_impl(_1545.get())->varnames(nativeidxs,_1546->toString(),_7356,sparsity);
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearVariable::__mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1548){
  return (::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::LinearVariable::t(_pubthis),_1548)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1549){
  _checked_ptr_1<int> _ptr__1549(_1549 ? _1549->raw() : nullptr, _1549 ? _1549->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1550 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1549)->size(0)))));
  _checked_ptr_1<long long> _ptr__1550(_1550 ? _1550->raw() : nullptr,_1550 ? _1550->size(0) : 0);
  int _7358 = (int)0;
  int _7359 = (int)((_1549)->size(0));
  for (int _1551 = _7358; _1551 < _7359; ++_1551)
  {
    {
      _ptr__1550[_1551] = safe_add( _ptr__1549[_1551],(int)1 );
    }
  }
  return _1550;
}
void mosek::fusion::p_LinearVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::LinearVariable::destroy() { mosek::fusion::p_LinearVariable::_get_impl(this)->destroy(); }mosek::fusion::ConicVariable::ConicVariable(mosek::fusion::p_ConicVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "ConicVariable()" << this << std::endl; */ }mosek::fusion::ConicVariable::~ConicVariable() {  /* std::cout << "~ConicVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicVariable::p_ConicVariable  (::mosek::fusion::ConicVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1552,    monty::rc_ptr< ::mosek::fusion::Model > _1553){ return new mosek::fusion::ConicVariable(_1552,_1553); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1552,    monty::rc_ptr< ::mosek::fusion::Model > _1553) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1552,_1553); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1552,    monty::rc_ptr< ::mosek::fusion::Model > _1553){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1552,_1553);
    names_flushed = mosek::fusion::p_ConicVariable::_get_impl(_1552)->names_flushed;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1552)->shape;
    nativeidxs = mosek::fusion::p_ConicVariable::_get_impl(_1552)->nativeidxs;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1552)->shape;
    varid = mosek::fusion::p_ConicVariable::_get_impl(_1552)->varid;
    name = mosek::fusion::p_ConicVariable::_get_impl(_1552)->name;
  }
}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1554,    const std::string &  _1555,    int _1556,    std::shared_ptr< monty::ndarray< int,1 > > _1557,    std::shared_ptr< monty::ndarray< int,1 > > _1558){ return new mosek::fusion::ConicVariable(_1554,_1555,_1556,_1557,_1558); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1554,    const std::string &  _1555,    int _1556,    std::shared_ptr< monty::ndarray< int,1 > > _1557,    std::shared_ptr< monty::ndarray< int,1 > > _1558) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1554,_1555,_1556,_1557,_1558); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1554,    const std::string &  _1555,    int _1556,    std::shared_ptr< monty::ndarray< int,1 > > _1557,    std::shared_ptr< monty::ndarray< int,1 > > _1558){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1557(_1557 ? _1557->raw() : nullptr, _1557 ? _1557->size(0) : 0);
    _checked_ptr_1<int> _ptr__1558(_1558 ? _1558->raw() : nullptr, _1558 ? _1558->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1554,_1555,_1557,_1556,nullptr,::mosek::fusion::p_ConicVariable::globalNativeIndexes(_1558));
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->name = _1555;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->varid = _1556;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->shape = _1557;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->nativeidxs = _1558;
  }
}std::string mosek::fusion::ConicVariable :: toString() { return mosek::fusion::p_ConicVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1559 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicVariable( "));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("));
  _1559->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7360 = (int)1;
  int _7361 = (int)((shape)->size(0));
  for (int _1560 = _7360; _1560 < _7361; ++_1560)
  {
    {
      _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1560)));
    }
  }
  _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _1559->toString();
}
void mosek::fusion::p_ConicVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1561 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1562 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1562->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      _1562->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
      int _7362 = (int)1;
      int _7363 = _pubthis->getND();
      for (int _1563 = _7362; _1563 < _7363; ++_1563)
      {
        {
          _1562->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1563);
        }
      }
      _1562->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7364;
      bool _7365 = (_pubthis->getND() > (int)0);
      if (_7365)
      {
        _7364 = _pubthis->getShape();
      }
      else
      {
        _7364 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      }
      mosek::fusion::p_Model::_get_impl(_1561.get())->varnames(nativeidxs,_1562->toString(),_7364,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_ConicVariable::__mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1564){
  return (::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::ConicVariable::t(_pubthis),_1564)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ConicVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1565){
  _checked_ptr_1<int> _ptr__1565(_1565 ? _1565->raw() : nullptr, _1565 ? _1565->size(0) : 0);
  std::vector<long long> _7366;
  for (int _1566 = (int)0, _7367 = (int)((_1565)->size(0)); _1566 < _7367 ; ++_1566)
  {
    _7366.push_back(safe_add( _ptr__1565[_1566],(int)1 ));
  }
  auto _7368 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7366.size()),_7366.begin(),_7366.end()));
  return _7368;
}
void mosek::fusion::p_ConicVariable::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::ConicVariable::destroy() { mosek::fusion::p_ConicVariable::_get_impl(this)->destroy(); }mosek::fusion::ModelVariable::ModelVariable(mosek::fusion::p_ModelVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "ModelVariable()" << this << std::endl; */ }mosek::fusion::ModelVariable::~ModelVariable() {  /* std::cout << "~ModelVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelVariable::p_ModelVariable  (::mosek::fusion::ModelVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelVariable > _1567,    monty::rc_ptr< ::mosek::fusion::Model > _1568){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1567,_1568);
    name = mosek::fusion::p_ModelVariable::_get_impl(_1567)->name;
    varid = mosek::fusion::p_ModelVariable::_get_impl(_1567)->varid;
    nativeidxs = mosek::fusion::p_ModelVariable::_get_impl(_1567)->nativeidxs;
    shape = mosek::fusion::p_ModelVariable::_get_impl(_1567)->shape;
    sparsity = mosek::fusion::p_ModelVariable::_get_impl(_1567)->sparsity;
  }
}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1569,    const std::string &  _1570,    std::shared_ptr< monty::ndarray< int,1 > > _1571,    long long _1572,    std::shared_ptr< monty::ndarray< long long,1 > > _1573,    std::shared_ptr< monty::ndarray< long long,1 > > _1574){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1571(_1571 ? _1571->raw() : nullptr, _1571 ? _1571->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1573(_1573 ? _1573->raw() : nullptr, _1573 ? _1573->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1574(_1574 ? _1574->raw() : nullptr, _1574 ? _1574->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1569,_1571,_1573,_1574);
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->name = _1570;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->varid = _1572;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->shape = _1571;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->sparsity = _1573;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->nativeidxs = _1574;
  }
}void mosek::fusion::ModelVariable :: elementName(long long _1575,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1576) { mosek::fusion::p_ModelVariable::_get_impl(this)->elementName(_1575,_1576); }void mosek::fusion::p_ModelVariable::elementName(long long _1575,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1576){
  std::string _7369;
  bool _7370 = ((int)((name).size()) == (int)0);
  if (_7370)
  {
    _7369 = std::string ("_");
  }
  else
  {
    _7369 = name;
  }
  _1576->__mosek_2fusion_2Utils_2StringBuffer__a(_7369)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,_1575))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
}
void mosek::fusion::p_ModelVariable::destroy(){sparsity.reset();shape.reset();nativeidxs.reset();}void mosek::fusion::ModelVariable::destroy() { mosek::fusion::p_ModelVariable::_get_impl(this)->destroy(); }mosek::fusion::NilVariable::NilVariable(mosek::fusion::p_NilVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "NilVariable()" << this << std::endl; */ }mosek::fusion::NilVariable::~NilVariable() {  /* std::cout << "~NilVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_NilVariable::p_NilVariable  (::mosek::fusion::NilVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1578){ return new mosek::fusion::NilVariable(_1578); }mosek::fusion::NilVariable::NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1578) :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(_1578); }void mosek::fusion::p_NilVariable::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _1578){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1578(_1578 ? _1578->raw() : nullptr, _1578 ? _1578->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(nullptr,::mosek::fusion::Utils::Tools::arraycopy(_1578),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))));
    std::vector<int> _7371;
    for (int _1579 = (int)0, _7372 = (int)((_1578)->size(0)); _1579 < _7372 ; ++_1579)
    {
      _7371.push_back(_ptr__1578[_1579]);
    }
    auto _7373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7371.size()),_7371.begin(),_7371.end()));
    mosek::fusion::p_NilVariable::_get_impl(::mosek::fusion::NilVariable::t(_pubthis))->shape = _7373;
  }
}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (){ return new mosek::fusion::NilVariable(); }mosek::fusion::NilVariable::NilVariable  () :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(); }void mosek::fusion::p_NilVariable::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_NilVariable::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)}));
  }
}void mosek::fusion::p_NilVariable::flushNames(){
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__elementDesc(long long _1580,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1581) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__elementDesc(_1580,_1581); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable::elementDesc(long long _1580,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1581) { return __mosek_2fusion_2NilVariable__elementDesc(_1580,_1581); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__elementDesc(long long _1580,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1581){
  return _1581;
}
void mosek::fusion::NilVariable :: elementName(long long _1582,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1583) { mosek::fusion::p_NilVariable::_get_impl(this)->elementName(_1582,_1583); }void mosek::fusion::p_NilVariable::elementName(long long _1582,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1583){
}
int mosek::fusion::NilVariable :: numInst() { return mosek::fusion::p_NilVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_NilVariable::numInst(){
  return (int)0;
}
int mosek::fusion::NilVariable :: inst(int _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585,std::shared_ptr< monty::ndarray< long long,1 > > _1586) { return mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1584,_1585,_1586); }int mosek::fusion::p_NilVariable::inst(int _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585,std::shared_ptr< monty::ndarray< long long,1 > > _1586){
  _checked_ptr_1<long long> _ptr__1585(_1585 ? _1585->raw() : nullptr, _1585 ? _1585->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1586(_1586 ? _1586->raw() : nullptr, _1586 ? _1586->size(0) : 0);
  return (int)0;
}
void mosek::fusion::NilVariable :: inst(int _1587,std::shared_ptr< monty::ndarray< long long,1 > > _1588) { mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1587,_1588); }void mosek::fusion::p_NilVariable::inst(int _1587,std::shared_ptr< monty::ndarray< long long,1 > > _1588){
  _checked_ptr_1<long long> _ptr__1588(_1588 ? _1588->raw() : nullptr, _1588 ? _1588->size(0) : 0);
}
void mosek::fusion::NilVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1589,bool _1590) { mosek::fusion::p_NilVariable::_get_impl(this)->set_values(_1589,_1590); }void mosek::fusion::p_NilVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1589,bool _1590){
  _checked_ptr_1<double> _ptr__1589(_1589 ? _1589->raw() : nullptr, _1589 ? _1589->size(0) : 0);
}
void mosek::fusion::NilVariable :: values(int _1591,std::shared_ptr< monty::ndarray< double,1 > > _1592,bool _1593) { mosek::fusion::p_NilVariable::_get_impl(this)->values(_1591,_1592,_1593); }void mosek::fusion::p_NilVariable::values(int _1591,std::shared_ptr< monty::ndarray< double,1 > > _1592,bool _1593){
  _checked_ptr_1<double> _ptr__1592(_1592 ? _1592->raw() : nullptr, _1592 ? _1592->size(0) : 0);
}
void mosek::fusion::NilVariable :: make_continuous() { mosek::fusion::p_NilVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_NilVariable::make_continuous(){
}
void mosek::fusion::NilVariable :: make_integer() { mosek::fusion::p_NilVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_NilVariable::make_integer(){
}
std::string mosek::fusion::NilVariable :: toString() { return mosek::fusion::p_NilVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_NilVariable::toString(){
  return std::string ("NilVariable");
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1594) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1594); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1594) { return __mosek_2fusion_2NilVariable__index(_1594); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1594) { return __mosek_2fusion_2NilVariable__index(_1594); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1594) { return __mosek_2fusion_2NilVariable__index(_1594); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1594){
  _checked_ptr_1<int> _ptr__1594(_1594 ? _1594->raw() : nullptr, _1594 ? _1594->size(0) : 0);
  std::vector<int> _7374;
  for (int _1595 = (int)0, _7375 = (int)((shape)->size(0)); _1595 < _7375 ; ++_1595)
  {
    _7374.push_back((int)1);
  }
  auto _7376 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7374.size()),_7374.begin(),_7374.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7376)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(int _1596) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1596); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(int _1596) { return __mosek_2fusion_2NilVariable__index(_1596); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(int _1596) { return __mosek_2fusion_2NilVariable__index(_1596); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(int _1596) { return __mosek_2fusion_2NilVariable__index(_1596); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(int _1596){
  std::vector<int> _7377;
  for (int _1597 = (int)0, _7378 = (int)((shape)->size(0)); _1597 < _7378 ; ++_1597)
  {
    _7377.push_back((int)1);
  }
  auto _7379 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7377.size()),_7377.begin(),_7377.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7379)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1598,_1599); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__slice(_1598,_1599); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__slice(_1598,_1599); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__slice(_1598,_1599); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599){
  _checked_ptr_1<int> _ptr__1598(_1598 ? _1598->raw() : nullptr, _1598 ? _1598->size(0) : 0);
  _checked_ptr_1<int> _ptr__1599(_1599 ? _1599->raw() : nullptr, _1599 ? _1599->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)((_1598)->size(0))) || ((int)((shape)->size(0)) != (int)((_1599)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  {}
  int _7380 = (int)0;
  int _7381 = (int)((_1598)->size(0));
  for (int _1600 = _7380; _1600 < _7381; ++_1600)
  {
    {
      if (((_ptr__1599[_1600] > _ptr__1598[_1600]) || ((_ptr__1598[_1600] < (int)0) || (_ptr__1599[_1600] >= ((*shape)(_1600))))))
      {
        {
          throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _7382;
  for (int _1601 = (int)0, _7383 = (int)((shape)->size(0)); _1601 < _7383 ; ++_1601)
  {
    _7382.push_back((_ptr__1599[_1601] - _ptr__1598[_1601]));
  }
  auto _7384 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7382.size()),_7382.begin(),_7382.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7384)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(int _1602,int _1603) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1602,_1603); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(int _1602,int _1603) { return __mosek_2fusion_2NilVariable__slice(_1602,_1603); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(int _1602,int _1603) { return __mosek_2fusion_2NilVariable__slice(_1602,_1603); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(int _1602,int _1603) { return __mosek_2fusion_2NilVariable__slice(_1602,_1603); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(int _1602,int _1603){
  if (((_1603 > _1602) || ((_1602 < (int)0) || (_1603 > ((*shape)((int)0))))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_1603 - _1602))}))).as<::mosek::fusion::Variable>();
    }
  }
}
void mosek::fusion::p_NilVariable::destroy(){shape.reset();}void mosek::fusion::NilVariable::destroy() { mosek::fusion::p_NilVariable::_get_impl(this)->destroy(); }mosek::fusion::BaseVariable::BaseVariable(mosek::fusion::p_BaseVariable *_impl) : _impl(_impl) { /*std::cout << "BaseVariable() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseVariable::~BaseVariable() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseVariable::p_BaseVariable  (::mosek::fusion::BaseVariable * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::BaseVariable > _1604,    monty::rc_ptr< ::mosek::fusion::Model > _1605){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _1605;
    shape = mosek::fusion::p_BaseVariable::_get_impl(_1604)->shape;
    sparsity = mosek::fusion::p_BaseVariable::_get_impl(_1604)->sparsity;
    nativeidxs = mosek::fusion::p_BaseVariable::_get_impl(_1604)->nativeidxs;
  }
}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1606,    std::shared_ptr< monty::ndarray< int,1 > > _1607,    std::shared_ptr< monty::ndarray< long long,1 > > _1608,    std::shared_ptr< monty::ndarray< long long,1 > > _1609){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1607(_1607 ? _1607->raw() : nullptr, _1607 ? _1607->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1608(_1608 ? _1608->raw() : nullptr, _1608 ? _1608->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1609(_1609 ? _1609->raw() : nullptr, _1609 ? _1609->size(0) : 0);
    model = _1606;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->shape = _1607;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity = _1608;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs = _1609;
  }
}std::string mosek::fusion::BaseVariable :: toString() { return mosek::fusion::p_BaseVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1610 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1610->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1610->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7385 = (int)1;
      int _7386 = (int)((shape)->size(0));
      for (int _1611 = _7385; _1611 < _7386; ++_1611)
      {
        {
          _1610->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1611)));
        }
      }
    }
  }
  {}
  _1610->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1610->toString();
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__eval() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::eval() { return __mosek_2fusion_2BaseVariable__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__eval(){
  return _pubthis->__mosek_2fusion_2BaseVariable__asExpr()->__mosek_2fusion_2Expression__eval();
}
void mosek::fusion::BaseVariable :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1612,monty::rc_ptr< ::mosek::fusion::WorkStack > _1613,monty::rc_ptr< ::mosek::fusion::WorkStack > _1614) { mosek::fusion::p_BaseVariable::_get_impl(this)->eval(_1612,_1613,_1614); }void mosek::fusion::p_BaseVariable::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1612,monty::rc_ptr< ::mosek::fusion::WorkStack > _1613,monty::rc_ptr< ::mosek::fusion::WorkStack > _1614){
  int _1615 = (int)((nativeidxs)->size(0));
  int _1616 = _1615;
  int _1617 = (int)((shape)->size(0));
  bool _1618 = (NULL != sparsity.get());
  _1612->alloc_expr(_1617,_1616,_1615,_1618);
  int _1619 = mosek::fusion::p_WorkStack::_get_impl(_1612)->ptr_base;
  int _1620 = mosek::fusion::p_WorkStack::_get_impl(_1612)->nidxs_base;
  int _1621 = mosek::fusion::p_WorkStack::_get_impl(_1612)->sp_base;
  int _1622 = mosek::fusion::p_WorkStack::_get_impl(_1612)->cof_base;
  int _1623 = mosek::fusion::p_WorkStack::_get_impl(_1612)->bfix_base;
  int _1624 = mosek::fusion::p_WorkStack::_get_impl(_1612)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _1625 = mosek::fusion::p_WorkStack::_get_impl(_1612)->i32;
  _checked_ptr_1<int> _ptr__1625(_1625 ? _1625->raw() : nullptr,_1625 ? _1625->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1626 = mosek::fusion::p_WorkStack::_get_impl(_1612)->i64;
  _checked_ptr_1<long long> _ptr__1626(_1626 ? _1626->raw() : nullptr,_1626 ? _1626->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1627 = mosek::fusion::p_WorkStack::_get_impl(_1612)->f64;
  _checked_ptr_1<double> _ptr__1627(_1627 ? _1627->raw() : nullptr,_1627 ? _1627->size(0) : 0);
  int _7387 = (int)0;
  int _7388 = _1617;
  for (int _1628 = _7387; _1628 < _7388; ++_1628)
  {
    {
      _ptr__1625[safe_add( _1624,_1628 )] = ((*shape)(_1628));
    }
  }
  {
    int _7389 = (int)0;
    int _7390 = safe_add( _1615,(int)1 );
    for (int _1629 = _7389; _1629 < _7390; ++_1629)
    {
      {
        _ptr__1625[safe_add( _1619,_1629 )] = _1629;
      }
    }
    int _7391 = (int)0;
    int _7392 = _1615;
    for (int _1630 = _7391; _1630 < _7392; ++_1630)
    {
      {
        _ptr__1626[safe_add( _1620,_1630 )] = ((*nativeidxs)(_1630));
      }
    }
    if (_1618)
    {
      {
        int _7393 = (int)0;
        int _7394 = _1615;
        for (int _1631 = _7393; _1631 < _7394; ++_1631)
        {
          {
            _ptr__1626[safe_add( _1621,_1631 )] = ((*sparsity)(_1631));
          }
        }
      }
    }
    {}
    int _7395 = (int)0;
    int _7396 = _1615;
    for (int _1632 = _7395; _1632 < _7396; ++_1632)
    {
      {
        _ptr__1627[safe_add( _1622,_1632 )] = 1.0;
      }
    }
    int _7397 = (int)0;
    int _7398 = _1615;
    for (int _1633 = _7397; _1633 < _7398; ++_1633)
    {
      {
        _ptr__1627[safe_add( _1623,_1633 )] = 0.0;
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1634) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1634); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1634) { return __mosek_2fusion_2BaseVariable__reshape(_1634); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1634) { return __mosek_2fusion_2BaseVariable__reshape(_1634); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1634){
  _checked_ptr_1<int> _ptr__1634(_1634 ? _1634->raw() : nullptr, _1634 ? _1634->size(0) : 0);
  long long _1635 = (int)1;
  int _7399 = (int)0;
  int _7400 = (int)((_1634)->size(0));
  for (int _1636 = _7399; _1636 < _7400; ++_1636)
  {
    {
      if ((_ptr__1634[_1636] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
      _1635 *= _ptr__1634[_1636];
    }
  }
  if ((_1635 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Shape size does not match variable size"));
    }
  }
  {}
  std::vector<int> _7401;
  for (int _1637 = (int)0, _7402 = (int)((_1634)->size(0)); _1637 < _7402 ; ++_1637)
  {
    _7401.push_back(_ptr__1634[_1637]);
  }
  auto _7403 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7401.size()),_7401.begin(),_7401.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_7403,sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
}
void mosek::fusion::BaseVariable :: setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1638) { mosek::fusion::p_BaseVariable::_get_impl(this)->setLevel(_1638); }void mosek::fusion::p_BaseVariable::setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1638){
  _checked_ptr_1<double> _ptr__1638(_1638 ? _1638->raw() : nullptr, _1638 ? _1638->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      if (((int)((_1638)->size(0)) != (int)((nativeidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      model->setVariableValues(true,nativeidxs,_1638);
    }
  }
  else
  {
    {
      if (((int)((_1638)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      std::vector<double> _7404;
      for (int _1640 = (int)0, _7405 = (int)((nativeidxs)->size(0)); _1640 < _7405 ; ++_1640)
      {
        _7404.push_back(_ptr__1638[((*sparsity)(_1640))]);
      }
      auto _7406 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7404.size()),_7404.begin(),_7404.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _1639 = _7406;
      _checked_ptr_1<double> _ptr__1639(_1639 ? _1639->raw() : nullptr,_1639 ? _1639->size(0) : 0);
      model->setVariableValues(true,nativeidxs,_1639);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__getModel() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__getModel(){
  return model;
}
int mosek::fusion::BaseVariable :: getND() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getND(); }int mosek::fusion::p_BaseVariable::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseVariable :: getDim(int _1641) { return mosek::fusion::p_BaseVariable::_get_impl(this)->getDim(_1641); }int mosek::fusion::p_BaseVariable::getDim(int _1641){
  return ((*shape)(_1641));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseVariable :: getShape() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseVariable::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
long long mosek::fusion::BaseVariable :: getSize() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseVariable::getSize(){
  long long _1642 = (long long)1;
  int _7407 = (int)0;
  int _7408 = (int)((shape)->size(0));
  for (int _1643 = _7407; _1643 < _7408; ++_1643)
  {
    {
      _1642 *= ((*shape)(_1643));
    }
  }
  return _1642;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: dual() { return mosek::fusion::p_BaseVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _1644 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1644(_1644 ? _1644->raw() : nullptr,_1644 ? _1644->size(0) : 0);
  model->getVariableValues(false,nativeidxs,_1644,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1645 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1645(_1645 ? _1645->raw() : nullptr,_1645 ? _1645->size(0) : 0);
      int _7409 = (int)0;
      int _7410 = (int)((nativeidxs)->size(0));
      for (int _1646 = _7409; _1646 < _7410; ++_1646)
      {
        {
          _ptr__1645[((*sparsity)(_1646))] = _ptr__1644[_1646];
        }
      }
      _1644 = _1645;
      _ptr__1644.update(_1644 ? _1644->raw() : nullptr, _1644 ? _1644->size(0) : 0);
    }
  }
  {}
  return _1644;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: level() { return mosek::fusion::p_BaseVariable::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _1647 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1647(_1647 ? _1647->raw() : nullptr,_1647 ? _1647->size(0) : 0);
  model->getVariableValues(true,nativeidxs,_1647,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1648 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1648(_1648 ? _1648->raw() : nullptr,_1648 ? _1648->size(0) : 0);
      int _7411 = (int)0;
      int _7412 = (int)((nativeidxs)->size(0));
      for (int _1649 = _7411; _1649 < _7412; ++_1649)
      {
        {
          _ptr__1648[((*sparsity)(_1649))] = _ptr__1647[_1649];
        }
      }
      _1647 = _1648;
      _ptr__1647.update(_1647 ? _1647->raw() : nullptr, _1647 ? _1647->size(0) : 0);
    }
  }
  {}
  return _1647;
}
void mosek::fusion::BaseVariable :: makeContinuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeContinuous(); }void mosek::fusion::p_BaseVariable::makeContinuous(){
  _pubthis->make_continuous();
}
void mosek::fusion::BaseVariable :: makeInteger() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeInteger(); }void mosek::fusion::p_BaseVariable::makeInteger(){
  _pubthis->make_integer();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__transpose() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose(){
  if (((int)((shape)->size(0)) == (int)1))
  {
    {
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(((*shape)((int)0)))}),sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((shape)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1650 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      _checked_ptr_1<long long> _ptr__1650(_1650 ? _1650->raw() : nullptr,_1650 ? _1650->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _7413;
      bool _7414 = (NULL == sparsity.get());
      if (_7414)
      {
        _7413 = nullptr;
      }
      else
      {
        _7413 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1651 = _7413;
      _checked_ptr_1<long long> _ptr__1651(_1651 ? _1651->raw() : nullptr,_1651 ? _1651->size(0) : 0);
      if ((NULL == sparsity.get()))
      {
        {
          int _1652 = (int)0;
          int _7415 = (int)0;
          int _7416 = ((*shape)((int)1));
          for (int _1653 = _7415; _1653 < _7416; ++_1653)
          {
            {
              int _7417 = (int)0;
              int _7418 = ((*shape)((int)0));
              for (int _1654 = _7417; _1654 < _7418; ++_1654)
              {
                {
                  _ptr__1650[_1652] = ((*nativeidxs)(safe_add( safe_mul( _1654,((*shape)((int)1)) ),_1653 )));
                  ++ _1652;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1655 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( ((*shape)((int)1)),(int)1 ))));
          _checked_ptr_1<int> _ptr__1655(_1655 ? _1655->raw() : nullptr,_1655 ? _1655->size(0) : 0);
          int _1656 = ((*shape)((int)0));
          int _1657 = ((*shape)((int)1));
          int _7419 = (int)0;
          int _7420 = (int)((sparsity)->size(0));
          for (int _1658 = _7419; _1658 < _7420; ++_1658)
          {
            {
              ++ _ptr__1655[safe_add( (((*sparsity)(_1658)) % _1657),(int)1 )];
            }
          }
          int _7421 = (int)0;
          int _7422 = _1657;
          for (int _1659 = _7421; _1659 < _7422; ++_1659)
          {
            {
              _ptr__1655[safe_add( _1659,(int)1 )] += _ptr__1655[_1659];
            }
          }
          int _7423 = (int)0;
          int _7424 = (int)((sparsity)->size(0));
          for (int _1660 = _7423; _1660 < _7424; ++_1660)
          {
            {
              long long _1661 = (((*sparsity)(_1660)) % _1657);
              _ptr__1650[_ptr__1655[_1661]] = ((*nativeidxs)(_1660));
              _ptr__1651[_ptr__1655[_1661]] = safe_add( (((*sparsity)(_1660)) / _1657),safe_mul( (((*sparsity)(_1660)) % _1657),_1656 ) );
              ++ _ptr__1655[_1661];
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*shape)((int)1))),(int)(((*shape)((int)0)))}),_1651,_1650)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1662,int _1663,int _1664) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1662,_1663,_1664); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1662,int _1663,int _1664) { return __mosek_2fusion_2BaseVariable__index(_1662,_1663,_1664); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1662,int _1663,int _1664) { return __mosek_2fusion_2BaseVariable__index(_1662,_1663,_1664); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1662,int _1663,int _1664){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1662),(int)(_1663),(int)(_1664)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1665,int _1666) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1665,_1666); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1665,int _1666) { return __mosek_2fusion_2BaseVariable__index(_1665,_1666); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1665,int _1666) { return __mosek_2fusion_2BaseVariable__index(_1665,_1666); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1665,int _1666){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1665),(int)(_1666)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1667) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1667); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1667) { return __mosek_2fusion_2BaseVariable__index(_1667); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1667) { return __mosek_2fusion_2BaseVariable__index(_1667); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1667){
  _checked_ptr_1<int> _ptr__1667(_1667 ? _1667->raw() : nullptr, _1667 ? _1667->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1668 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_1667)->size(0)))));
  int _7425 = (int)0;
  int _7426 = (int)((_1667)->size(0));
  for (int _1669 = _7425; _1669 < _7426; ++_1669)
  {
    {
      ((*_1668)((int)0,_1669)) = _ptr__1667[_1669];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1668)->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1670) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1670); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1670) { return __mosek_2fusion_2BaseVariable__index(_1670); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1670) { return __mosek_2fusion_2BaseVariable__index(_1670); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1670){
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1670)}))->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1671,std::shared_ptr< monty::ndarray< int,1 > > _1672,std::shared_ptr< monty::ndarray< int,1 > > _1673) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1671,_1672,_1673); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1671,std::shared_ptr< monty::ndarray< int,1 > > _1672,std::shared_ptr< monty::ndarray< int,1 > > _1673) { return __mosek_2fusion_2BaseVariable__pick(_1671,_1672,_1673); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1671,std::shared_ptr< monty::ndarray< int,1 > > _1672,std::shared_ptr< monty::ndarray< int,1 > > _1673) { return __mosek_2fusion_2BaseVariable__pick(_1671,_1672,_1673); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1671,std::shared_ptr< monty::ndarray< int,1 > > _1672,std::shared_ptr< monty::ndarray< int,1 > > _1673){
  _checked_ptr_1<int> _ptr__1671(_1671 ? _1671->raw() : nullptr, _1671 ? _1671->size(0) : 0);
  _checked_ptr_1<int> _ptr__1672(_1672 ? _1672->raw() : nullptr, _1672 ? _1672->size(0) : 0);
  _checked_ptr_1<int> _ptr__1673(_1673 ? _1673->raw() : nullptr, _1673 ? _1673->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)3))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((((int)((_1671)->size(0)) != (int)((_1672)->size(0))) || ((int)((_1671)->size(0)) != (int)((_1673)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching argument lengths"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1674 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1671)->size(0)),(int)3)));
  int _7427 = (int)0;
  int _7428 = (int)((_1671)->size(0));
  for (int _1675 = _7427; _1675 < _7428; ++_1675)
  {
    {
      ((*_1674)(_1675,(int)0)) = _ptr__1671[_1675];
      ((*_1674)(_1675,(int)1)) = _ptr__1672[_1675];
      ((*_1674)(_1675,(int)2)) = _ptr__1673[_1675];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1674);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1676,std::shared_ptr< monty::ndarray< int,1 > > _1677) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1676,_1677); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1676,std::shared_ptr< monty::ndarray< int,1 > > _1677) { return __mosek_2fusion_2BaseVariable__pick(_1676,_1677); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1676,std::shared_ptr< monty::ndarray< int,1 > > _1677) { return __mosek_2fusion_2BaseVariable__pick(_1676,_1677); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1676,std::shared_ptr< monty::ndarray< int,1 > > _1677){
  _checked_ptr_1<int> _ptr__1676(_1676 ? _1676->raw() : nullptr, _1676 ? _1676->size(0) : 0);
  _checked_ptr_1<int> _ptr__1677(_1677 ? _1677->raw() : nullptr, _1677 ? _1677->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)2) || ((int)((_1676)->size(0)) != (int)((_1677)->size(0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1678 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1676)->size(0)),(int)2)));
  int _7429 = (int)0;
  int _7430 = (int)((_1676)->size(0));
  for (int _1679 = _7429; _1679 < _7430; ++_1679)
  {
    {
      ((*_1678)(_1679,(int)0)) = _ptr__1676[_1679];
      ((*_1678)(_1679,(int)1)) = _ptr__1677[_1679];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1678);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1680) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1680); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1680) { return __mosek_2fusion_2BaseVariable__pick(_1680); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1680) { return __mosek_2fusion_2BaseVariable__pick(_1680); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1680){
  if (((int)((shape)->size(0)) != (int)((_1680)->size(1))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7431 = (int)0;
  int _7432 = (int)((_1680)->size(0));
  for (int _1681 = _7431; _1681 < _7432; ++_1681)
  {
    {
      int _7433 = (int)0;
      int _7434 = (int)((_1680)->size(1));
      for (int _1682 = _7433; _1682 < _7434; ++_1682)
      {
        {
          if (((((*_1680)(_1681,_1682)) < (int)0) || (((*_1680)(_1681,_1682)) >= ((*shape)(_1682)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
            }
          }
          {}
        }
      }
    }
  }
  int _1683 = (int)((shape)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1684 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1683)));
  _checked_ptr_1<long long> _ptr__1684(_1684 ? _1684->raw() : nullptr,_1684 ? _1684->size(0) : 0);
  _ptr__1684[(_1683 - (int)1)] = (int)1;
  int _7435 = (int)1;
  int _7436 = _1683;
  for (int _1685 = _7435; _1685 < _7436; ++_1685)
  {
    {
      _ptr__1684[((_1683 - _1685) - (int)1)] = safe_mul( _ptr__1684[(_1683 - _1685)],((*shape)((_1683 - _1685))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1686 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1680)->size(0)))});
  _checked_ptr_1<int> _ptr__1686(_1686 ? _1686->raw() : nullptr,_1686 ? _1686->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1687;
  _checked_ptr_1<long long> _ptr__1687(_1687 ? _1687->raw() : nullptr,_1687 ? _1687->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1688 = nullptr;
  _checked_ptr_1<long long> _ptr__1688(_1688 ? _1688->raw() : nullptr,_1688 ? _1688->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _1687 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1680)->size(0)))));
      _ptr__1687.update(_1687 ? _1687->raw() : nullptr, _1687 ? _1687->size(0) : 0);
      {
        int _7437 = (int)0;
        int _7438 = (int)((_1680)->size(0));
        for (int _1689 = _7437; _1689 < _7438; ++_1689)
        {
          {
            long long _1690 = (long long)0;
            int _7439 = (int)0;
            int _7440 = _1683;
            for (int _1691 = _7439; _1691 < _7440; ++_1691)
            {
              {
                _1690 += safe_mul( _ptr__1684[_1691],((*_1680)(_1689,_1691)) );
              }
            }
            _ptr__1687[_1689] = ((*nativeidxs)(_1690));
          }
        }
      }
    }
  }
  else
  {
    {
      int _1692 = (int)0;
      int _7441 = (int)0;
      int _7442 = (int)((_1680)->size(0));
      for (int _1693 = _7441; _1693 < _7442; ++_1693)
      {
        {
          long long _1694 = (long long)0;
          int _7443 = (int)0;
          int _7444 = _1683;
          for (int _1695 = _7443; _1695 < _7444; ++_1695)
          {
            {
              _1694 += safe_mul( _ptr__1684[_1695],((*_1680)(_1693,_1695)) );
            }
          }
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1694) >= (int)0))
          {
            {
              ++ _1692;
            }
          }
          {}
        }
      }
      _1687 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1692)));
      _ptr__1687.update(_1687 ? _1687->raw() : nullptr, _1687 ? _1687->size(0) : 0);
      _1688 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1692)));
      _ptr__1688.update(_1688 ? _1688->raw() : nullptr, _1688 ? _1688->size(0) : 0);
      {
        int _1696 = (int)0;
        int _7445 = (int)0;
        int _7446 = (int)((_1680)->size(0));
        for (int _1697 = _7445; _1697 < _7446; ++_1697)
        {
          {
            long long _1698 = (long long)0;
            int _7447 = (int)0;
            int _7448 = _1683;
            for (int _1699 = _7447; _1699 < _7448; ++_1699)
            {
              {
                _1698 += safe_mul( _ptr__1684[_1699],((*_1680)(_1697,_1699)) );
              }
            }
            int _1700 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1698);
            if ((_1700 >= (int)0))
            {
              {
                _ptr__1687[_1696] = ((*nativeidxs)(_1700));
                _ptr__1688[_1696] = _1697;
                ++ _1696;
              }
            }
            {}
          }
        }
      }
      if ((_1692 == (int)((_1680)->size(0))))
      {
        {
          _1688 = nullptr;
          _ptr__1688.update(_1688 ? _1688->raw() : nullptr, _1688 ? _1688->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1686,_1688,_1687)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1701) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1701); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1701) { return __mosek_2fusion_2BaseVariable__pick(_1701); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1701) { return __mosek_2fusion_2BaseVariable__pick(_1701); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1701){
  _checked_ptr_1<int> _ptr__1701(_1701 ? _1701->raw() : nullptr, _1701 ? _1701->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7449 = (int)0;
  int _7450 = (int)((_1701)->size(0));
  for (int _1702 = _7449; _1702 < _7450; ++_1702)
  {
    {
      if (((_ptr__1701[_1702] < (int)0) || (_ptr__1701[_1702] >= ((*shape)((int)0)))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1703;
  _checked_ptr_1<long long> _ptr__1703(_1703 ? _1703->raw() : nullptr,_1703 ? _1703->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1704 = nullptr;
  _checked_ptr_1<long long> _ptr__1704(_1704 ? _1704->raw() : nullptr,_1704 ? _1704->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      std::vector<long long> _7451;
      for (int _1705 = (int)0, _7452 = (int)((_1701)->size(0)); _1705 < _7452 ; ++_1705)
      {
        _7451.push_back(((*nativeidxs)(_ptr__1701[_1705])));
      }
      auto _7453 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7451.size()),_7451.begin(),_7451.end()));
      _1703 = _7453;
      _ptr__1703.update(_1703 ? _1703->raw() : nullptr, _1703 ? _1703->size(0) : 0);
    }
  }
  else
  {
    {
      int _1706 = (int)0;
      int _7454 = (int)0;
      int _7455 = (int)((_1701)->size(0));
      for (int _1707 = _7454; _1707 < _7455; ++_1707)
      {
        {
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1701[_1707])) >= (int)0))
          {
            {
              ++ _1706;
            }
          }
          {}
        }
      }
      _1703 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1706)));
      _ptr__1703.update(_1703 ? _1703->raw() : nullptr, _1703 ? _1703->size(0) : 0);
      _1704 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1706)));
      _ptr__1704.update(_1704 ? _1704->raw() : nullptr, _1704 ? _1704->size(0) : 0);
      int _1708 = (int)0;
      int _7456 = (int)0;
      int _7457 = (int)((_1701)->size(0));
      for (int _1709 = _7456; _1709 < _7457; ++_1709)
      {
        {
          int _1710 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1701[_1709]));
          if ((_1710 >= (int)0))
          {
            {
              _ptr__1704[_1708] = _1709;
              _ptr__1703[_1708] = ((*nativeidxs)(_1710));
              ++ _1708;
            }
          }
          {}
        }
      }
      if ((_1706 == (int)((_1701)->size(0))))
      {
        {
          _1704 = nullptr;
          _ptr__1704.update(_1704 ? _1704->raw() : nullptr, _1704 ? _1704->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1701)->size(0)))}),_1704,_1703)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag(int _1711) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(_1711); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag(int _1711) { return __mosek_2fusion_2BaseVariable__antidiag(_1711); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag(int _1711) { return __mosek_2fusion_2BaseVariable__antidiag(_1711); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(int _1711){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  else if(((_1711 >= ((*shape)((int)1))) || ((-_1711) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1711 >= (int)0))
  {
    {
      int _7458;
      bool _7459 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1711));
      if (_7459)
      {
        _7458 = ((*shape)((int)0));
      }
      else
      {
        _7458 = (((*shape)((int)1)) - _1711);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(((((*shape)((int)1)) - (int)1) - _1711))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7458);
    }
  }
  else
  {
    {
      int _7460;
      bool _7461 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1711 ));
      if (_7461)
      {
        _7460 = ((*shape)((int)1));
      }
      else
      {
        _7460 = safe_add( ((*shape)((int)0)),_1711 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1711)),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7460);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7462;
  bool _7463 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7463)
  {
    _7462 = ((*shape)((int)0));
  }
  else
  {
    _7462 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7462);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag(int _1712) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(_1712); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag(int _1712) { return __mosek_2fusion_2BaseVariable__diag(_1712); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag(int _1712) { return __mosek_2fusion_2BaseVariable__diag(_1712); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(int _1712){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  else if(((_1712 >= ((*shape)((int)1))) || ((-_1712) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1712 >= (int)0))
  {
    {
      int _7464;
      bool _7465 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1712));
      if (_7465)
      {
        _7464 = ((*shape)((int)0));
      }
      else
      {
        _7464 = (((*shape)((int)1)) - _1712);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(_1712)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7464);
    }
  }
  else
  {
    {
      int _7466;
      bool _7467 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1712 ));
      if (_7467)
      {
        _7466 = ((*shape)((int)1));
      }
      else
      {
        _7466 = safe_add( ((*shape)((int)0)),_1712 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1712)),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7466);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag() { return __mosek_2fusion_2BaseVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7468;
  bool _7469 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7469)
  {
    _7468 = ((*shape)((int)0));
  }
  else
  {
    _7468 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7468);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714,int _1715){
  _checked_ptr_1<int> _ptr__1713(_1713 ? _1713->raw() : nullptr, _1713 ? _1713->size(0) : 0);
  _checked_ptr_1<int> _ptr__1714(_1714 ? _1714->raw() : nullptr, _1714 ? _1714->size(0) : 0);
  int _1716 = (int)((shape)->size(0));
  if (((_1716 != (int)((_1713)->size(0))) || (_1716 != (int)((_1714)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid start or step definition"));
    }
  }
  {}
  int _7470 = (int)0;
  int _7471 = _1716;
  for (int _1717 = _7470; _1717 < _7471; ++_1717)
  {
    {
      if (((_ptr__1713[_1717] < (int)0) || (_ptr__1713[_1717] >= ((*shape)(_1717)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Start element is out of bounds"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1718 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1716)));
  _checked_ptr_1<long long> _ptr__1718(_1718 ? _1718->raw() : nullptr,_1718 ? _1718->size(0) : 0);
  _ptr__1718[(_1716 - (int)1)] = (int)1;
  int _7472 = (int)1;
  int _7473 = _1716;
  for (int _1719 = _7472; _1719 < _7473; ++_1719)
  {
    {
      _ptr__1718[((_1716 - _1719) - (int)1)] = safe_mul( _ptr__1718[(_1716 - _1719)],((*shape)((_1716 - _1719))) );
    }
  }
  long long _1720 = (long long)0;
  int _7474 = (int)0;
  int _7475 = (int)((_1714)->size(0));
  for (int _1721 = _7474; _1721 < _7475; ++_1721)
  {
    {
      _1720 += safe_mul( _ptr__1713[_1721],_ptr__1718[_1721] );
    }
  }
  long long _1722 = (long long)0;
  int _7476 = (int)0;
  int _7477 = (int)((_1714)->size(0));
  for (int _1723 = _7476; _1723 < _7477; ++_1723)
  {
    {
      _1722 += safe_mul( _ptr__1714[_1723],_ptr__1718[_1723] );
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1724 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1715)));
      _checked_ptr_1<long long> _ptr__1724(_1724 ? _1724->raw() : nullptr,_1724 ? _1724->size(0) : 0);
      int _7478 = (int)0;
      int _7479 = _1715;
      for (int _1725 = _7478; _1725 < _7479; ++_1725)
      {
        {
          _ptr__1724[_1725] = ((*nativeidxs)(safe_add( _1720,safe_mul( _1722,_1725 ) )));
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1715)}),nullptr,_1724)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1726 = (int)0;
      int _7480 = (int)0;
      int _7481 = _1715;
      for (int _1727 = _7480; _1727 < _7481; ++_1727)
      {
        {
          long long _1728 = safe_add( _1720,safe_mul( _1722,_1727 ) );
          int _1729 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1728);
          if ((_1729 >= (int)0))
          {
            {
              ++ _1726;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1730 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1726)));
      _checked_ptr_1<long long> _ptr__1730(_1730 ? _1730->raw() : nullptr,_1730 ? _1730->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1731 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1726)));
      _checked_ptr_1<long long> _ptr__1731(_1731 ? _1731->raw() : nullptr,_1731 ? _1731->size(0) : 0);
      int _1732 = (int)0;
      int _7482 = (int)0;
      int _7483 = _1715;
      for (int _1733 = _7482; _1733 < _7483; ++_1733)
      {
        {
          _ptr__1730[_1733] = ((*nativeidxs)(safe_add( _1720,safe_mul( _1722,_1733 ) )));
          long long _1734 = safe_add( _1720,safe_mul( _1722,_1733 ) );
          int _1735 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1734);
          if ((_1735 >= (int)0))
          {
            {
              _ptr__1731[_1732] = _1733;
              _ptr__1730[_1732] = ((*nativeidxs)(_1735));
              ++ _1732;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1715)}),_1731,_1730)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1736,std::shared_ptr< monty::ndarray< int,1 > > _1737) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1736,_1737); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1736,std::shared_ptr< monty::ndarray< int,1 > > _1737) { return __mosek_2fusion_2BaseVariable__slice(_1736,_1737); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1736,std::shared_ptr< monty::ndarray< int,1 > > _1737) { return __mosek_2fusion_2BaseVariable__slice(_1736,_1737); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1736,std::shared_ptr< monty::ndarray< int,1 > > _1737){
  _checked_ptr_1<int> _ptr__1736(_1736 ? _1736->raw() : nullptr, _1736 ? _1736->size(0) : 0);
  _checked_ptr_1<int> _ptr__1737(_1737 ? _1737->raw() : nullptr, _1737 ? _1737->size(0) : 0);
  if (((int)((_1736)->size(0)) != (int)((_1737)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if(((int)((_1736)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7484 = (int)0;
      int _7485 = (int)((shape)->size(0));
      for (int _1738 = _7484; _1738 < _7485; ++_1738)
      {
        {
          if (((_ptr__1736[_1738] < (int)0) || (_ptr__1737[_1738] > ((*shape)(_1738)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
            }
          }
          else if((_ptr__1736[_1738] > _ptr__1737[_1738]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
            }
          }
          {}
        }
      }
      int _1739 = (int)((shape)->size(0));
      std::vector<int> _7486;
      for (int _1741 = (int)0, _7487 = _1739; _1741 < _7487 ; ++_1741)
      {
        _7486.push_back((_ptr__1737[_1741] - _ptr__1736[_1741]));
      }
      auto _7488 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7486.size()),_7486.begin(),_7486.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1740 = _7488;
      _checked_ptr_1<int> _ptr__1740(_1740 ? _1740->raw() : nullptr,_1740 ? _1740->size(0) : 0);
      int _1742 = (int)1;
      int _7489 = (int)0;
      int _7490 = _1739;
      for (int _1743 = _7489; _1743 < _7490; ++_1743)
      {
        {
          _1742 *= (_ptr__1737[_1743] - _ptr__1736[_1743]);
        }
      }
      if ((_1742 == (int)0))
      {
        {
          return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
        }
      }
      else if((NULL != sparsity.get()))
      {
        {
          int _1744 = (int)0;
          std::shared_ptr< monty::ndarray< int,1 > > _1745 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1739)));
          _checked_ptr_1<int> _ptr__1745(_1745 ? _1745->raw() : nullptr,_1745 ? _1745->size(0) : 0);
          int _7491 = (int)0;
          int _7492 = (int)((sparsity)->size(0));
          for (int _1746 = _7491; _1746 < _7492; ++_1746)
          {
            {
              long long _1747 = ((*sparsity)(_1746));
              int _7493 = (int)1;
              int _7494 = _1739;
              for (int _1748 = _7493; _1748 < _7494; ++_1748)
              {
                {
                  _ptr__1745[(_1739 - _1748)] = (int)(_1747 % ((*shape)((_1739 - _1748))));
                  _1747 /= ((*shape)((_1739 - _1748)));
                }
              }
              _ptr__1745[(int)0] = (int)_1747;
              int _1749 = (int)0;
              while ( ((_ptr__1745[_1749] >= _ptr__1736[_1749]) && (_ptr__1745[_1749] < _ptr__1737[_1749])) )
              {
                {
                  ++ _1749;
                }
              }
              if ((_1749 == _1739))
              {
                {
                  ++ _1744;
                }
              }
              {}
            }
          }
          int _1750 = (int)0;
          std::shared_ptr< monty::ndarray< long long,1 > > _1751 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1744)));
          _checked_ptr_1<long long> _ptr__1751(_1751 ? _1751->raw() : nullptr,_1751 ? _1751->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1752 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1744)));
          _checked_ptr_1<long long> _ptr__1752(_1752 ? _1752->raw() : nullptr,_1752 ? _1752->size(0) : 0);
          int _7495 = (int)0;
          int _7496 = (int)((sparsity)->size(0));
          for (int _1753 = _7495; _1753 < _7496; ++_1753)
          {
            {
              long long _1754 = ((*sparsity)(_1753));
              int _7497 = (int)1;
              int _7498 = _1739;
              for (int _1755 = _7497; _1755 < _7498; ++_1755)
              {
                {
                  _ptr__1745[(_1739 - _1755)] = (int)(_1754 % ((*shape)((_1739 - _1755))));
                  _1754 /= ((*shape)((_1739 - _1755)));
                }
              }
              _ptr__1745[(int)0] = (int)_1754;
              int _1756 = (int)0;
              while ( ((_ptr__1745[_1756] >= _ptr__1736[_1756]) && (_ptr__1745[_1756] < _ptr__1737[_1756])) )
              {
                {
                  ++ _1756;
                }
              }
              if ((_1756 == _1739))
              {
                {
                  _ptr__1751[_1750] = ((*nativeidxs)(_1753));
                  int _1757 = (int)0;
                  int _7499 = (int)0;
                  int _7500 = _1739;
                  for (int _1758 = _7499; _1758 < _7500; ++_1758)
                  {
                    {
                      _1757 = safe_add( safe_mul( _1757,_ptr__1740[_1758] ),(_ptr__1745[_1758] - _ptr__1736[_1758]) );
                    }
                  }
                  _ptr__1752[_1750] = _1757;
                  ++ _1750;
                }
              }
              {}
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1740,_1752,_1751)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1759 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1742)));
          _checked_ptr_1<long long> _ptr__1759(_1759 ? _1759->raw() : nullptr,_1759 ? _1759->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _1760 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1739)));
            _checked_ptr_1<int> _ptr__1760(_1760 ? _1760->raw() : nullptr,_1760 ? _1760->size(0) : 0);
            _ptr__1760[(_1739 - (int)1)] = (int)1;
            int _7501 = (int)1;
            int _7502 = _1739;
            for (int _1761 = _7501; _1761 < _7502; ++_1761)
            {
              {
                _ptr__1760[((_1739 - _1761) - (int)1)] = safe_mul( _ptr__1760[(_1739 - _1761)],((*shape)((_1739 - _1761))) );
              }
            }
            int _1762 = (int)0;
            int _7503 = (int)0;
            int _7504 = _1739;
            for (int _1763 = _7503; _1763 < _7504; ++_1763)
            {
              {
                _1762 += safe_mul( _ptr__1736[_1763],_ptr__1760[_1763] );
              }
            }
            std::vector<int> _7505;
            for (int _1765 = (int)0, _7506 = _1739; _1765 < _7506 ; ++_1765)
            {
              _7505.push_back(_1762);
            }
            auto _7507 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7505.size()),_7505.begin(),_7505.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1764 = _7507;
            _checked_ptr_1<int> _ptr__1764(_1764 ? _1764->raw() : nullptr,_1764 ? _1764->size(0) : 0);
            std::vector<int> _7508;
            for (int _1767 = (int)0, _7509 = _1739; _1767 < _7509 ; ++_1767)
            {
              _7508.push_back(_ptr__1736[_1767]);
            }
            auto _7510 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7508.size()),_7508.begin(),_7508.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1766 = _7510;
            _checked_ptr_1<int> _ptr__1766(_1766 ? _1766->raw() : nullptr,_1766 ? _1766->size(0) : 0);
            int _7511 = (int)0;
            int _7512 = _1742;
            for (int _1768 = _7511; _1768 < _7512; ++_1768)
            {
              {
                _ptr__1759[_1768] = ((*nativeidxs)(_ptr__1764[(_1739 - (int)1)]));
                _ptr__1766[(_1739 - (int)1)] += (int)1;
                _ptr__1764[(_1739 - (int)1)] += _ptr__1760[(_1739 - (int)1)];
                if ((_ptr__1766[(_1739 - (int)1)] >= _ptr__1737[(_1739 - (int)1)]))
                {
                  {
                    int _1769 = (_1739 - (int)1);
                    while ( ((_1769 > (int)0) && (_ptr__1766[_1769] >= _ptr__1737[_1769])) )
                    {
                      {
                        _ptr__1766[_1769] = _ptr__1736[_1769];
                        _ptr__1766[(_1769 - (int)1)] += (int)1;
                        _ptr__1764[(_1769 - (int)1)] += _ptr__1760[(_1769 - (int)1)];
                        -- _1769;
                      }
                    }
                    int _7513 = safe_add( _1769,(int)1 );
                    int _7514 = _1739;
                    for (int _1770 = _7513; _1770 < _7514; ++_1770)
                    {
                      {
                        _ptr__1764[_1770] = _ptr__1764[_1769];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1740,nullptr,_1759)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(int _1771,int _1772) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1771,_1772); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(int _1771,int _1772) { return __mosek_2fusion_2BaseVariable__slice(_1771,_1772); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(int _1771,int _1772) { return __mosek_2fusion_2BaseVariable__slice(_1771,_1772); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(int _1771,int _1772){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_1771 == (int)0) && (_1772 == ((*shape)((int)0)))))
  {
    {
      return (::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((_1771 < (int)0) || (_1772 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_1771 > _1772))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if((_1771 == _1772))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((NULL != sparsity.get()))
  {
    {
      int _1773 = (_1772 - _1771);
      int _1774 = (int)0;
      int _1775 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1771));
      int _1776 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1772));
      std::vector<long long> _7515;
      for (int _1777 = _1775, _7516 = _1776; _1777 < _7516 ; ++_1777)
      {
        _7515.push_back((((*sparsity)(_1777)) - _1771));
      }
      auto _7517 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7515.size()),_7515.begin(),_7515.end()));
      std::vector<long long> _7518;
      for (int _1778 = _1775, _7519 = _1776; _1778 < _7519 ; ++_1778)
      {
        _7518.push_back(((*nativeidxs)(_1778)));
      }
      auto _7520 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7518.size()),_7518.begin(),_7518.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1773)}),_7517,_7520)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1779 = (_1772 - _1771);
      std::shared_ptr< monty::ndarray< long long,1 > > _1780 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1779)));
      _checked_ptr_1<long long> _ptr__1780(_1780 ? _1780->raw() : nullptr,_1780 ? _1780->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(nativeidxs,_1771,_1780,(int)0,_1779);
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1779)}),nullptr,_1780)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__asExpr() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__asExpr(){
  return (::mosek::fusion::p_ExprFromVar::_new_ExprFromVar((::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>())).as<::mosek::fusion::Expression>();
}
int mosek::fusion::BaseVariable :: inst(int _1781,std::shared_ptr< monty::ndarray< long long,1 > > _1782,int _1783,std::shared_ptr< monty::ndarray< long long,1 > > _1784) { return mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1781,_1782,_1783,_1784); }int mosek::fusion::p_BaseVariable::inst(int _1781,std::shared_ptr< monty::ndarray< long long,1 > > _1782,int _1783,std::shared_ptr< monty::ndarray< long long,1 > > _1784){
  _checked_ptr_1<long long> _ptr__1782(_1782 ? _1782->raw() : nullptr, _1782 ? _1782->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1784(_1784 ? _1784->raw() : nullptr, _1784 ? _1784->size(0) : 0);
  if ((NULL == mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity.get()))
  {
    {
      int _7521 = (int)0;
      int _7522 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
      for (int _1785 = _7521; _1785 < _7522; ++_1785)
      {
        {
          _ptr__1782[safe_add( _1785,_1781 )] = _1785;
          _ptr__1784[safe_add( _1785,_1783 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1785));
        }
      }
    }
  }
  else
  {
    {
      int _7523 = (int)0;
      int _7524 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)->size(0));
      for (int _1786 = _7523; _1786 < _7524; ++_1786)
      {
        {
          _ptr__1782[safe_add( _1781,_1786 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)(_1786));
          _ptr__1784[safe_add( _1786,_1783 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1786));
        }
      }
    }
  }
  return (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
}
int mosek::fusion::BaseVariable :: numInst() { return mosek::fusion::p_BaseVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_BaseVariable::numInst(){
  return (int)((nativeidxs)->size(0));
}
void mosek::fusion::BaseVariable :: inst(int _1787,std::shared_ptr< monty::ndarray< long long,1 > > _1788) { mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1787,_1788); }void mosek::fusion::p_BaseVariable::inst(int _1787,std::shared_ptr< monty::ndarray< long long,1 > > _1788){
  _checked_ptr_1<long long> _ptr__1788(_1788 ? _1788->raw() : nullptr, _1788 ? _1788->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      int _7525 = (int)0;
      int _7526 = (int)((nativeidxs)->size(0));
      for (int _1789 = _7525; _1789 < _7526; ++_1789)
      {
        {
          _ptr__1788[safe_add( _1787,_1789 )] = ((*nativeidxs)(_1789));
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1790 = _pubthis->getShape();
      _checked_ptr_1<int> _ptr__1790(_1790 ? _1790->raw() : nullptr,_1790 ? _1790->size(0) : 0);
      int _1791 = (int)1;
      int _7527 = (int)0;
      int _7528 = (int)((_1790)->size(0));
      for (int _1792 = _7527; _1792 < _7528; ++_1792)
      {
        {
          _1791 *= _ptr__1790[_1792];
        }
      }
      int _7529 = (int)0;
      int _7530 = _1791;
      for (int _1793 = _7529; _1793 < _7530; ++_1793)
      {
        {
          _ptr__1788[safe_add( _1787,_1793 )] = (int)0;
        }
      }
      int _7531 = (int)0;
      int _7532 = (int)((sparsity)->size(0));
      for (int _1794 = _7531; _1794 < _7532; ++_1794)
      {
        {
          _ptr__1788[safe_add( _1787,((*sparsity)(_1794)) )] = ((*nativeidxs)(_1794));
        }
      }
    }
  }
}
void mosek::fusion::BaseVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1795,bool _1796) { mosek::fusion::p_BaseVariable::_get_impl(this)->set_values(_1795,_1796); }void mosek::fusion::p_BaseVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1795,bool _1796){
  _checked_ptr_1<double> _ptr__1795(_1795 ? _1795->raw() : nullptr, _1795 ? _1795->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1796,nativeidxs,_1795);
    }
  }
  else
  {
    {
      int _1797 = (int)1;
      int _7533 = (int)0;
      int _7534 = (int)((shape)->size(0));
      for (int _1798 = _7533; _1798 < _7534; ++_1798)
      {
        {
          _1797 *= ((*shape)(_1798));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1799 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1797)));
      _checked_ptr_1<long long> _ptr__1799(_1799 ? _1799->raw() : nullptr,_1799 ? _1799->size(0) : 0);
      int _7535 = (int)0;
      int _7536 = (int)((nativeidxs)->size(0));
      for (int _1800 = _7535; _1800 < _7536; ++_1800)
      {
        {
          _ptr__1799[((*sparsity)(_1800))] = ((*nativeidxs)(_1800));
        }
      }
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1796,_1799,_1795);
    }
  }
}
void mosek::fusion::p_BaseVariable::dual_lu(int _1801,std::shared_ptr< monty::ndarray< double,1 > > _1802,bool _1803){
  _checked_ptr_1<double> _ptr__1802(_1802 ? _1802->raw() : nullptr, _1802 ? _1802->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableDuals(_1803,nativeidxs,_1802,_1801);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1804 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1804(_1804 ? _1804->raw() : nullptr,_1804 ? _1804->size(0) : 0);
      int _7537 = (int)0;
      int _7538 = (int)((sparsity)->size(0));
      for (int _1805 = _7537; _1805 < _7538; ++_1805)
      {
        {
          _ptr__1804[((*sparsity)(_1805))] = ((*nativeidxs)(_1805));
        }
      }
      model->getVariableDuals(_1803,_1804,_1802,_1801);
    }
  }
}
void mosek::fusion::BaseVariable :: values(int _1806,std::shared_ptr< monty::ndarray< double,1 > > _1807,bool _1808) { mosek::fusion::p_BaseVariable::_get_impl(this)->values(_1806,_1807,_1808); }void mosek::fusion::p_BaseVariable::values(int _1806,std::shared_ptr< monty::ndarray< double,1 > > _1807,bool _1808){
  _checked_ptr_1<double> _ptr__1807(_1807 ? _1807->raw() : nullptr, _1807 ? _1807->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableValues(_1808,nativeidxs,_1807,_1806);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1809 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1809(_1809 ? _1809->raw() : nullptr,_1809 ? _1809->size(0) : 0);
      int _7539 = (int)0;
      int _7540 = (int)((sparsity)->size(0));
      for (int _1810 = _7539; _1810 < _7540; ++_1810)
      {
        {
          _ptr__1809[((*sparsity)(_1810))] = ((*nativeidxs)(_1810));
        }
      }
      model->getVariableValues(_1808,_1809,_1807,_1806);
    }
  }
}
void mosek::fusion::BaseVariable :: make_continuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_BaseVariable::make_continuous(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_continuous(nativeidxs);
}
void mosek::fusion::BaseVariable :: make_integer() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_BaseVariable::make_integer(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_integer(nativeidxs);
}
void mosek::fusion::p_BaseVariable::destroy(){sparsity.reset();nativeidxs.reset();model.reset();shape.reset();}void mosek::fusion::BaseVariable::destroy() { mosek::fusion::p_BaseVariable::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Variable::getModel() { return __mosek_2fusion_2Variable__getModel(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1818) { return __mosek_2fusion_2Variable__reshape(_1818); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::transpose() { return __mosek_2fusion_2Variable__transpose(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1824,std::shared_ptr< monty::ndarray< int,1 > > _1825,std::shared_ptr< monty::ndarray< int,1 > > _1826) { return __mosek_2fusion_2Variable__pick(_1824,_1825,_1826); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1827,std::shared_ptr< monty::ndarray< int,1 > > _1828) { return __mosek_2fusion_2Variable__pick(_1827,_1828); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _1829) { return __mosek_2fusion_2Variable__pick(_1829); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1829) { return __mosek_2fusion_2Variable__pick(_1829); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _1830) { return __mosek_2fusion_2Variable__pick(_1830); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1830) { return __mosek_2fusion_2Variable__pick(_1830); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag() { return __mosek_2fusion_2Variable__antidiag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag(int _1831) { return __mosek_2fusion_2Variable__antidiag(_1831); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag() { return __mosek_2fusion_2Variable__diag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag(int _1832) { return __mosek_2fusion_2Variable__diag(_1832); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _1833) { return __mosek_2fusion_2Variable__index(_1833); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(std::shared_ptr< monty::ndarray< int,1 > > _1833) { return __mosek_2fusion_2Variable__index(_1833); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1834,int _1835,int _1836) { return __mosek_2fusion_2Variable__index(_1834,_1835,_1836); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1837,int _1838) { return __mosek_2fusion_2Variable__index(_1837,_1838); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(int _1839) { return __mosek_2fusion_2Variable__index(_1839); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1839) { return __mosek_2fusion_2Variable__index(_1839); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _1840,std::shared_ptr< monty::ndarray< int,1 > > _1841) { return __mosek_2fusion_2Variable__slice(_1840,_1841); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1840,std::shared_ptr< monty::ndarray< int,1 > > _1841) { return __mosek_2fusion_2Variable__slice(_1840,_1841); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(int _1842,int _1843) { return __mosek_2fusion_2Variable__slice(_1842,_1843); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(int _1842,int _1843) { return __mosek_2fusion_2Variable__slice(_1842,_1843); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::asExpr() { return __mosek_2fusion_2Variable__asExpr(); }
mosek::fusion::Var::Var(mosek::fusion::p_Var *_impl) : _impl(_impl) { /*std::cout << "Var() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Var::~Var() { delete _impl; _impl = nullptr; }mosek::fusion::p_Var::p_Var  (::mosek::fusion::Var * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::empty  ( std::shared_ptr< monty::ndarray< int,1 > > _1844) { return mosek::fusion::p_Var::empty(_1844); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::empty(std::shared_ptr< monty::ndarray< int,1 > > _1844){
  _checked_ptr_1<int> _ptr__1844(_1844 ? _1844->raw() : nullptr, _1844 ? _1844->size(0) : 0);
  int _7541 = (int)0;
  int _7542 = (int)((_1844)->size(0));
  for (int _1845 = _7541; _1845 < _7542; ++_1845)
  {
    {
      if ((_ptr__1844[_1845] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_1844)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::compress  ( monty::rc_ptr< ::mosek::fusion::Variable > _1846) { return mosek::fusion::p_Var::compress(_1846); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::compress(monty::rc_ptr< ::mosek::fusion::Variable > _1846){
  std::shared_ptr< monty::ndarray< int,1 > > _1847 = _1846->getShape();
  _checked_ptr_1<int> _ptr__1847(_1847 ? _1847->raw() : nullptr,_1847 ? _1847->size(0) : 0);
  int _1848 = (int)((_1847)->size(0));
  int _1849 = (int)0;
  int _7543 = (int)0;
  int _7544 = _1848;
  for (int _1850 = _7543; _1850 < _7544; ++_1850)
  {
    {
      if ((_ptr__1847[_1850] != (int)1))
      {
        {
          ++ _1849;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1851 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1849)));
  _checked_ptr_1<int> _ptr__1851(_1851 ? _1851->raw() : nullptr,_1851 ? _1851->size(0) : 0);
  {
    int _1852 = (int)0;
    int _7545 = (int)0;
    int _7546 = _1848;
    for (int _1853 = _7545; _1853 < _7546; ++_1853)
    {
      {
        if ((_ptr__1847[_1853] != (int)1))
        {
          {
            _ptr__1851[_1852] = _ptr__1847[_1853];
            ++ _1852;
          }
        }
        {}
      }
    }
  }
  return ::mosek::fusion::p_Var::reshape(_1846,_1851);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1854,    int _1855) { return mosek::fusion::p_Var::reshape(_1854,_1855); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1854,int _1855){
  return ::mosek::fusion::p_Var::reshape(_1854,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1855)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1856,    int _1857,    int _1858) { return mosek::fusion::p_Var::reshape(_1856,_1857,_1858); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1856,int _1857,int _1858){
  return ::mosek::fusion::p_Var::reshape(_1856,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1857),(int)(_1858)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::flatten  ( monty::rc_ptr< ::mosek::fusion::Variable > _1859) { return mosek::fusion::p_Var::flatten(_1859); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1859){
  return ::mosek::fusion::p_Var::reshape(_1859,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)::mosek::fusion::p_Set::size(_1859->getShape()))}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1860,    std::shared_ptr< monty::ndarray< int,1 > > _1861) { return mosek::fusion::p_Var::reshape(_1860,_1861); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1860,std::shared_ptr< monty::ndarray< int,1 > > _1861){
  _checked_ptr_1<int> _ptr__1861(_1861 ? _1861->raw() : nullptr, _1861 ? _1861->size(0) : 0);
  return _1860->__mosek_2fusion_2Variable__reshape(_1861);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1862,std::shared_ptr< monty::ndarray< int,1 > > _1863){
  _checked_ptr_1<int> _ptr__1863(_1863 ? _1863->raw() : nullptr, _1863 ? _1863->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1864;
  _checked_ptr_1<long long> _ptr__1864(_1864 ? _1864->raw() : nullptr,_1864 ? _1864->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1865;
  _checked_ptr_1<long long> _ptr__1865(_1865 ? _1865->raw() : nullptr,_1865 ? _1865->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1866 = _1862->getShape();
  _checked_ptr_1<int> _ptr__1866(_1866 ? _1866->raw() : nullptr,_1866 ? _1866->size(0) : 0);
  int _1867 = (int)((_1866)->size(0));
  int _1868 = (int)1;
  int _7547 = (int)0;
  int _7548 = _1867;
  for (int _1869 = _7547; _1869 < _7548; ++_1869)
  {
    {
      _1868 *= _ptr__1866[_1869];
    }
  }
  int _1870 = _1862->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _1871 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1867)));
  _checked_ptr_1<long long> _ptr__1871(_1871 ? _1871->raw() : nullptr,_1871 ? _1871->size(0) : 0);
  _ptr__1871[(_1867 - (int)1)] = (int)1;
  int _7549 = (int)1;
  int _7550 = _1867;
  for (int _1872 = _7549; _1872 < _7550; ++_1872)
  {
    {
      _ptr__1871[((_1867 - _1872) - (int)1)] = safe_mul( _ptr__1871[(_1867 - _1872)],_ptr__1866[_ptr__1863[(_1867 - _1872)]] );
    }
  }
  if ((_1870 < _1868))
  {
    {
      _1864 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1870)));
      _ptr__1864.update(_1864 ? _1864->raw() : nullptr, _1864 ? _1864->size(0) : 0);
      _1865 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1870)));
      _ptr__1865.update(_1865 ? _1865->raw() : nullptr, _1865 ? _1865->size(0) : 0);
      _1862->inst((int)0,_1864,(int)0,_1865);
    }
  }
  else
  {
    {
      _1864 = nullptr;
      _ptr__1864.update(_1864 ? _1864->raw() : nullptr, _1864 ? _1864->size(0) : 0);
      _1865 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1870)));
      _ptr__1865.update(_1865 ? _1865->raw() : nullptr, _1865 ? _1865->size(0) : 0);
      _1862->inst((int)0,_1865);
    }
  }
  if ((NULL == _1864.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1873 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1870)));
      _checked_ptr_1<long long> _ptr__1873(_1873 ? _1873->raw() : nullptr,_1873 ? _1873->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1874 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1867)));
        _checked_ptr_1<int> _ptr__1874(_1874 ? _1874->raw() : nullptr,_1874 ? _1874->size(0) : 0);
        int _7551 = (int)0;
        int _7552 = _1870;
        for (int _1875 = _7551; _1875 < _7552; ++_1875)
        {
          {
            int _1876 = _1875;
            int _7553 = (int)0;
            int _7554 = _1867;
            for (int _1877 = _7553; _1877 < _7554; ++_1877)
            {
              {
                _ptr__1874[((_1867 - _1875) - (int)1)] = (_1876 % _ptr__1866[((_1867 - _1875) - (int)1)]);
                _1876 /= _ptr__1866[((_1867 - _1875) - (int)1)];
              }
            }
            int _1878 = (int)0;
            int _7555 = (int)0;
            int _7556 = _1867;
            for (int _1879 = _7555; _1879 < _7556; ++_1879)
            {
              {
                _1878 += (int)safe_mul( _ptr__1874[_ptr__1863[_1879]],_ptr__1871[_1879] );
              }
            }
            _ptr__1873[_1878] = _ptr__1865[_1875];
          }
        }
      }
      _1865 = _1873;
      _ptr__1865.update(_1865 ? _1865->raw() : nullptr, _1865 ? _1865->size(0) : 0);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1880 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1870)));
      _checked_ptr_1<long long> _ptr__1880(_1880 ? _1880->raw() : nullptr,_1880 ? _1880->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1881 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1867)));
        _checked_ptr_1<int> _ptr__1881(_1881 ? _1881->raw() : nullptr,_1881 ? _1881->size(0) : 0);
        int _7557 = (int)0;
        int _7558 = _1870;
        for (int _1882 = _7557; _1882 < _7558; ++_1882)
        {
          {
            int _1883 = _1882;
            int _7559 = (int)0;
            int _7560 = _1867;
            for (int _1884 = _7559; _1884 < _7560; ++_1884)
            {
              {
                _ptr__1881[((_1867 - _1882) - (int)1)] = (_1883 % _ptr__1866[((_1867 - _1882) - (int)1)]);
                _1883 /= _ptr__1866[((_1867 - _1882) - (int)1)];
              }
            }
            int _1885 = (int)0;
            int _7561 = (int)0;
            int _7562 = _1867;
            for (int _1886 = _7561; _1886 < _7562; ++_1886)
            {
              {
                _1885 += (int)safe_mul( _ptr__1881[_ptr__1863[_1886]],_ptr__1871[_1886] );
              }
            }
            _ptr__1880[_1882] = _1885;
          }
        }
      }
      std::vector<long long> _7563;
      for (int _1888 = (int)0, _7564 = _1870; _1888 < _7564 ; ++_1888)
      {
        _7563.push_back(_1888);
      }
      auto _7565 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7563.size()),_7563.begin(),_7563.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1887 = _7565;
      _checked_ptr_1<long long> _ptr__1887(_1887 ? _1887->raw() : nullptr,_1887 ? _1887->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1887,_1880,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1870));
      std::vector<long long> _7566;
      for (int _1889 = (int)0, _7567 = _1870; _1889 < _7567 ; ++_1889)
      {
        _7566.push_back(_ptr__1864[_ptr__1887[_1889]]);
      }
      auto _7568 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7566.size()),_7566.begin(),_7566.end()));
      _1864 = _7568;
      _ptr__1864.update(_1864 ? _1864->raw() : nullptr, _1864 ? _1864->size(0) : 0);
      std::vector<long long> _7569;
      for (int _1890 = (int)0, _7570 = _1870; _1890 < _7570 ; ++_1890)
      {
        _7569.push_back(_ptr__1865[_ptr__1887[_1890]]);
      }
      auto _7571 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7569.size()),_7569.begin(),_7569.end()));
      _1865 = _7571;
      _ptr__1865.update(_1865 ? _1865->raw() : nullptr, _1865 ? _1865->size(0) : 0);
    }
  }
  std::vector<int> _7572;
  for (int _1891 = (int)0, _7573 = _1867; _1891 < _7573 ; ++_1891)
  {
    _7572.push_back(_ptr__1866[_ptr__1863[_1891]]);
  }
  auto _7574 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7572.size()),_7572.begin(),_7572.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1862->__mosek_2fusion_2Variable__getModel(),_7574,_1864,_1865)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1892,    int _1893) { return mosek::fusion::p_Var::hrepeat(_1892,_1893); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1892,int _1893){
  return ::mosek::fusion::p_Var::drepeat(_1892,(int)1,_1893);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1894,    int _1895) { return mosek::fusion::p_Var::vrepeat(_1894,_1895); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1894,int _1895){
  return ::mosek::fusion::p_Var::drepeat(_1894,(int)0,_1895);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1896,    int _1897) { return mosek::fusion::p_Var::repeat(_1896,_1897); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1896,int _1897){
  return ::mosek::fusion::p_Var::drepeat(_1896,(int)0,_1897);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1898,    int _1899,    int _1900) { return mosek::fusion::p_Var::repeat(_1898,_1899,_1900); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1898,int _1899,int _1900){
  return ::mosek::fusion::p_Var::drepeat(_1898,_1899,_1900);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1901,int _1902,int _1903){
  if ((_1903 < (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot repeat less than 0 times"));
    }
  }
  else if((_1903 == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((_1903 == (int)1))
  {
    {
      return _1901;
    }
  }
  else
  {
    {
      monty::rc_ptr< ::mosek::fusion::Model > _1904 = _1901->__mosek_2fusion_2Variable__getModel();
      std::shared_ptr< monty::ndarray< int,1 > > _1905 = _1901->getShape();
      _checked_ptr_1<int> _ptr__1905(_1905 ? _1905->raw() : nullptr,_1905 ? _1905->size(0) : 0);
      int _1906 = (int)((_1905)->size(0));
      if (((_1902 < (int)0) || (_1902 > _1906)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      long long _1907 = ::mosek::fusion::p_Set::size(_1905);
      int _1908 = _1901->numInst();
      int _1909 = safe_mul( _1908,_1903 );
      int _1910 = (int)1;
      int _7575 = (int)0;
      int _7576 = _1902;
      for (int _1911 = _7575; _1911 < _7576; ++_1911)
      {
        {
          _1910 *= _ptr__1905[_1911];
        }
      }
      int _7577;
      bool _7578 = (_1902 < _1906);
      if (_7578)
      {
        _7577 = _ptr__1905[_1902];
      }
      else
      {
        _7577 = (int)1;
      }
      int _1912 = _7577;
      int _1913 = safe_mul( _1912,_1903 );
      int _1914 = (int)1;
      int _7579 = safe_add( _1902,(int)1 );
      int _7580 = _1906;
      for (int _1915 = _7579; _1915 < _7580; ++_1915)
      {
        {
          _1914 *= _ptr__1905[_1915];
        }
      }
      int _7581;
      bool _7582 = (_1902 < _1906);
      if (_7582)
      {
        _7581 = _1906;
      }
      else
      {
        _7581 = safe_add( _1902,(int)1 );
      }
      int _1916 = _7581;
      std::shared_ptr< monty::ndarray< int,1 > > _1917 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1916)));
      _checked_ptr_1<int> _ptr__1917(_1917 ? _1917->raw() : nullptr,_1917 ? _1917->size(0) : 0);
      int _7583 = (int)0;
      int _7584 = _1906;
      for (int _1918 = _7583; _1918 < _7584; ++_1918)
      {
        {
          _ptr__1917[_1918] = _ptr__1905[_1918];
        }
      }
      int _7585 = _1906;
      int _7586 = _1916;
      for (int _1919 = _7585; _1919 < _7586; ++_1919)
      {
        {
          _ptr__1917[_1919] = (int)1;
        }
      }
      _ptr__1917[_1902] = _1913;
      if ((_1908 < _1907))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1920 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1908)));
          _checked_ptr_1<long long> _ptr__1920(_1920 ? _1920->raw() : nullptr,_1920 ? _1920->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1921 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1908)));
          _checked_ptr_1<long long> _ptr__1921(_1921 ? _1921->raw() : nullptr,_1921 ? _1921->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1922 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1909)));
          _checked_ptr_1<long long> _ptr__1922(_1922 ? _1922->raw() : nullptr,_1922 ? _1922->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1923 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1909)));
          _checked_ptr_1<long long> _ptr__1923(_1923 ? _1923->raw() : nullptr,_1923 ? _1923->size(0) : 0);
          _1901->inst((int)0,_1921,(int)0,_1920);
          {
            int _1924 = safe_mul( _1913,_1914 );
            int _1925 = safe_mul( _1912,_1914 );
            int _1926 = _1914;
            if ((_1902 == (int)0))
            {
              {
                int _1927 = (int)0;
                int _7587 = (int)0;
                int _7588 = _1903;
                for (int _1928 = _7587; _1928 < _7588; ++_1928)
                {
                  {
                    int _7589 = (int)0;
                    int _7590 = _1908;
                    for (int _1929 = _7589; _1929 < _7590; ++_1929)
                    {
                      {
                        _ptr__1923[_1927] = safe_add( _ptr__1921[_1929],safe_mul( _1928,_1907 ) );
                        _ptr__1922[_1927] = _ptr__1920[_1929];
                        ++ _1927;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1904,_1917,_1923,_1922)).as<::mosek::fusion::Variable>();
              }
            }
            else if((_1902 >= _1906))
            {
              {
                int _1930 = (int)0;
                int _7591 = (int)0;
                int _7592 = _1908;
                for (int _1931 = _7591; _1931 < _7592; ++_1931)
                {
                  {
                    int _7593 = (int)0;
                    int _7594 = _1903;
                    for (int _1932 = _7593; _1932 < _7594; ++_1932)
                    {
                      {
                        _ptr__1923[_1930] = safe_add( safe_mul( _ptr__1921[_1931],_1903 ),_1932 );
                        _ptr__1922[_1930] = _ptr__1920[_1931];
                        ++ _1930;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1904,_1917,_1923,_1922)).as<::mosek::fusion::Variable>();
              }
            }
            else
            {
              {
                int _1933 = (int)0;
                int _7595 = (int)0;
                int _7596 = _1908;
                for (int _1934 = _7595; _1934 < _7596; ++_1934)
                {
                  {
                    long long _1935 = (_ptr__1921[_1934] / _1925);
                    long long _1936 = ((_ptr__1921[_1934] / _1926) % _1912);
                    long long _1937 = (_ptr__1921[_1934] % _1914);
                    int _7597 = (int)0;
                    int _7598 = _1903;
                    for (int _1938 = _7597; _1938 < _7598; ++_1938)
                    {
                      {
                        _ptr__1923[_1933] = safe_add( safe_add( safe_mul( _1935,_1924 ),safe_mul( safe_add( _1936,safe_mul( _1912,_1938 ) ),_1914 ) ),_1937 );
                        _ptr__1922[_1933] = _ptr__1920[_1934];
                        ++ _1933;
                      }
                    }
                  }
                }
                int _1939 = (int)1;
                int _7599 = (int)0;
                int _7600 = _1916;
                for (int _1940 = _7599; _1940 < _7600; ++_1940)
                {
                  {
                    if ((_1939 < _ptr__1917[_1940]))
                    {
                      {
                        _1939 = _ptr__1917[_1940];
                      }
                    }
                    {}
                  }
                }
                std::shared_ptr< monty::ndarray< int,1 > > _1941 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1909)));
                _checked_ptr_1<int> _ptr__1941(_1941 ? _1941->raw() : nullptr,_1941 ? _1941->size(0) : 0);
                std::shared_ptr< monty::ndarray< int,1 > > _1942 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1909)));
                _checked_ptr_1<int> _ptr__1942(_1942 ? _1942->raw() : nullptr,_1942 ? _1942->size(0) : 0);
                {
                  std::shared_ptr< monty::ndarray< int,1 > > _1943 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _1939,(int)1 ))));
                  _checked_ptr_1<int> _ptr__1943(_1943 ? _1943->raw() : nullptr,_1943 ? _1943->size(0) : 0);
                  std::shared_ptr< monty::ndarray< long long,1 > > _1944 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1916)));
                  _checked_ptr_1<long long> _ptr__1944(_1944 ? _1944->raw() : nullptr,_1944 ? _1944->size(0) : 0);
                  _ptr__1944[(_1916 - (int)1)] = (int)1;
                  int _7601 = (int)1;
                  int _7602 = _1916;
                  for (int _1945 = _7601; _1945 < _7602; ++_1945)
                  {
                    {
                      _ptr__1944[((_1916 - _1945) - (int)1)] = safe_mul( _ptr__1944[(_1916 - _1945)],_ptr__1917[(_1916 - _1945)] );
                    }
                  }
                  int _7603 = (int)0;
                  int _7604 = _1909;
                  for (int _1946 = _7603; _1946 < _7604; ++_1946)
                  {
                    {
                      _ptr__1941[_1946] = _1946;
                    }
                  }
                  int _7605 = (int)0;
                  int _7606 = _1916;
                  for (int _1947 = _7605; _1947 < _7606; ++_1947)
                  {
                    {
                      int _1948 = ((_1916 - _1947) - (int)1);
                      int _7607 = (int)0;
                      int _7608 = safe_add( _ptr__1917[_1948],(int)1 );
                      for (int _1949 = _7607; _1949 < _7608; ++_1949)
                      {
                        {
                          _ptr__1943[_1949] = (int)0;
                        }
                      }
                      int _7609 = (int)0;
                      int _7610 = _1909;
                      for (int _1950 = _7609; _1950 < _7610; ++_1950)
                      {
                        {
                          ++ _ptr__1943[safe_add( ((_ptr__1923[_1950] / _ptr__1944[_1948]) % _ptr__1917[_1948]),(int)1 )];
                        }
                      }
                      int _7611 = (int)0;
                      int _7612 = _ptr__1917[_1948];
                      for (int _1951 = _7611; _1951 < _7612; ++_1951)
                      {
                        {
                          _ptr__1943[safe_add( _1951,(int)1 )] += _ptr__1943[_1951];
                        }
                      }
                      int _7613 = (int)0;
                      int _7614 = _1909;
                      for (int _1952 = _7613; _1952 < _7614; ++_1952)
                      {
                        {
                          int _1953 = _ptr__1941[_1952];
                          long long _1954 = ((_ptr__1923[_1953] / _ptr__1944[_1948]) % _ptr__1917[_1948]);
                          _ptr__1942[_ptr__1943[_1954]] = _1953;
                          ++ _ptr__1943[_1954];
                        }
                      }
                      std::shared_ptr< monty::ndarray< int,1 > > _1955 = _1941;
                      _checked_ptr_1<int> _ptr__1955(_1955 ? _1955->raw() : nullptr,_1955 ? _1955->size(0) : 0);
                      _1941 = _1942;
                      _ptr__1941.update(_1941 ? _1941->raw() : nullptr, _1941 ? _1941->size(0) : 0);
                      _1942 = _1955;
                      _ptr__1942.update(_1942 ? _1942->raw() : nullptr, _1942 ? _1942->size(0) : 0);
                    }
                  }
                }
                std::vector<long long> _7615;
                for (int _1956 = (int)0, _7616 = _1909; _1956 < _7616 ; ++_1956)
                {
                  _7615.push_back(_ptr__1923[_ptr__1941[_1956]]);
                }
                auto _7617 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7615.size()),_7615.begin(),_7615.end()));
                std::vector<long long> _7618;
                for (int _1957 = (int)0, _7619 = _1909; _1957 < _7619 ; ++_1957)
                {
                  _7618.push_back(_ptr__1922[_ptr__1941[_1957]]);
                }
                auto _7620 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7618.size()),_7618.begin(),_7618.end()));
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1904,_1917,_7617,_7620)).as<::mosek::fusion::Variable>();
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1958 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1908)));
          _checked_ptr_1<long long> _ptr__1958(_1958 ? _1958->raw() : nullptr,_1958 ? _1958->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1959 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1908,_1903 ))));
          _checked_ptr_1<long long> _ptr__1959(_1959 ? _1959->raw() : nullptr,_1959 ? _1959->size(0) : 0);
          _1901->inst((int)0,_1958);
          int _1960 = safe_mul( _1913,_1914 );
          int _1961 = _1914;
          int _1962 = (int)0;
          int _7621 = (int)0;
          int _7622 = _1910;
          for (int _1963 = _7621; _1963 < _7622; ++_1963)
          {
            {
              int _7623 = (int)0;
              int _7624 = _1912;
              for (int _1964 = _7623; _1964 < _7624; ++_1964)
              {
                {
                  int _7625 = (int)0;
                  int _7626 = _1914;
                  for (int _1965 = _7625; _1965 < _7626; ++_1965)
                  {
                    {
                      int _7627 = (int)0;
                      int _7628 = _1903;
                      for (int _1966 = _7627; _1966 < _7628; ++_1966)
                      {
                        {
                          _ptr__1959[safe_add( safe_add( safe_mul( _1963,_1960 ),safe_mul( safe_add( _1964,safe_mul( _1966,_1912 ) ),_1961 ) ),_1965 )] = _ptr__1958[_1962];
                        }
                      }
                      ++ _1962;
                    }
                  }
                }
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1904,_1917,nullptr,_1959)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1967) { return mosek::fusion::p_Var::stack(_1967); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1967){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _7629;
  for (int _1968 = (int)0, _7630 = (int)((_1967)->size(0)); _1968 < _7630 ; ++_1968)
  {
    _7629.push_back(::mosek::fusion::p_Var::dstack(((*_1967)(_1968)),(int)1));
  }
  auto _7631 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_7629.size()),_7629.begin(),_7629.end()));
  return ::mosek::fusion::p_Var::dstack(_7631,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1969,    monty::rc_ptr< ::mosek::fusion::Variable > _1970,    monty::rc_ptr< ::mosek::fusion::Variable > _1971) { return mosek::fusion::p_Var::vstack(_1969,_1970,_1971); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1969,monty::rc_ptr< ::mosek::fusion::Variable > _1970,monty::rc_ptr< ::mosek::fusion::Variable > _1971){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1969.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1970.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1971.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1972,    monty::rc_ptr< ::mosek::fusion::Variable > _1973) { return mosek::fusion::p_Var::vstack(_1972,_1973); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1972,monty::rc_ptr< ::mosek::fusion::Variable > _1973){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1972.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1973.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1974) { return mosek::fusion::p_Var::vstack(_1974); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1974){
  return ::mosek::fusion::p_Var::dstack(_1974,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1975,    monty::rc_ptr< ::mosek::fusion::Variable > _1976,    monty::rc_ptr< ::mosek::fusion::Variable > _1977) { return mosek::fusion::p_Var::hstack(_1975,_1976,_1977); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1975,monty::rc_ptr< ::mosek::fusion::Variable > _1976,monty::rc_ptr< ::mosek::fusion::Variable > _1977){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1975.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1976.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1977.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1978,    monty::rc_ptr< ::mosek::fusion::Variable > _1979) { return mosek::fusion::p_Var::hstack(_1978,_1979); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1978,monty::rc_ptr< ::mosek::fusion::Variable > _1979){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1978.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1979.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1980) { return mosek::fusion::p_Var::hstack(_1980); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1980){
  return ::mosek::fusion::p_Var::dstack(_1980,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1981,    monty::rc_ptr< ::mosek::fusion::Variable > _1982,    monty::rc_ptr< ::mosek::fusion::Variable > _1983,    int _1984) { return mosek::fusion::p_Var::stack(_1981,_1982,_1983,_1984); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1981,monty::rc_ptr< ::mosek::fusion::Variable > _1982,monty::rc_ptr< ::mosek::fusion::Variable > _1983,int _1984){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1981.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1982.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1983.get())}),_1984);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1985,    monty::rc_ptr< ::mosek::fusion::Variable > _1986,    int _1987) { return mosek::fusion::p_Var::stack(_1985,_1986,_1987); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1985,monty::rc_ptr< ::mosek::fusion::Variable > _1986,int _1987){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1985.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1986.get())}),_1987);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1988,    int _1989) { return mosek::fusion::p_Var::stack(_1988,_1989); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1988,int _1989){
  int _1990 = _1989;
  int _7632 = (int)0;
  int _7633 = (int)((_1988)->size(0));
  for (int _1991 = _7632; _1991 < _7633; ++_1991)
  {
    {
      if ((_1990 < ((*_1988)(_1991))->getND()))
      {
        {
          _1990 = ((*_1988)(_1991))->getND();
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Var::dstack(_1988,_1989);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::promote  ( monty::rc_ptr< ::mosek::fusion::Variable > _1992,    int _1993) { return mosek::fusion::p_Var::promote(_1992,_1993); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::promote(monty::rc_ptr< ::mosek::fusion::Variable > _1992,int _1993){
  if ((_1993 > _1992->getND()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1994 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1993)));
      _checked_ptr_1<int> _ptr__1994(_1994 ? _1994->raw() : nullptr,_1994 ? _1994->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1995 = _1992->getShape();
      _checked_ptr_1<int> _ptr__1995(_1995 ? _1995->raw() : nullptr,_1995 ? _1995->size(0) : 0);
      int _7634 = (int)0;
      int _7635 = (int)((_1995)->size(0));
      for (int _1996 = _7634; _1996 < _7635; ++_1996)
      {
        {
          _ptr__1994[_1996] = _ptr__1995[_1996];
        }
      }
      int _7636 = (int)((_1995)->size(0));
      int _7637 = _1993;
      for (int _1997 = _7636; _1997 < _7637; ++_1997)
      {
        {
          _ptr__1994[_1997] = (int)1;
        }
      }
      return _1992->__mosek_2fusion_2Variable__reshape(_1994);
    }
  }
  else
  {
    {
      return _1992;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1998,int _1999){
  if ((_1999 < (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Model > _2000 = nullptr;
  {
    int _7638 = (int)0;
    int _7639 = (int)((_1998)->size(0));
    for (int _2001 = _7638; _2001 < _7639; ++_2001)
    {
      {
        if ((NULL == _2000.get()))
        {
          {
            _2000 = ((*_1998)(_2001))->__mosek_2fusion_2Variable__getModel();
          }
        }
        else if(((NULL != ((*_1998)(_2001))->__mosek_2fusion_2Variable__getModel().get()) && (((*_1998)(_2001))->__mosek_2fusion_2Variable__getModel() != _2000)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2002 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7640;
            bool _7641 = ((int)((mosek::fusion::p_Model::_get_impl(_2000.get())->getName()).size()) > (int)0);
            if (_7641)
            {
              _7640 = mosek::fusion::p_Model::_get_impl(_2000.get())->getName();
            }
            else
            {
              _7640 = std::string ("?");
            }
            std::string _2003 = _7640;
            std::string _7642;
            bool _7643 = ((int)((mosek::fusion::p_Model::_get_impl(((*_1998)(_2001))->__mosek_2fusion_2Variable__getModel().get())->getName()).size()) > (int)0);
            if (_7643)
            {
              _7642 = mosek::fusion::p_Model::_get_impl(((*_1998)(_2001))->__mosek_2fusion_2Variable__getModel().get())->getName();
            }
            else
            {
              _7642 = std::string ("?");
            }
            std::string _2004 = _7642;
            _2002->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variables belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2003)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2004)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2002->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_1998)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((_1998)->size(0)) == (int)1))
  {
    {
      return ((*_1998)((int)1));
    }
  }
  else
  {
    {
      int _2005 = (int)((_1998)->size(0));
      std::vector<int> _7644;
      for (int _2007 = (int)0, _7645 = _2005; _2007 < _7645 ; ++_2007)
      {
        _7644.push_back(((*_1998)(_2007))->numInst());
      }
      auto _7646 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7644.size()),_7644.begin(),_7644.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2006 = _7646;
      _checked_ptr_1<int> _ptr__2006(_2006 ? _2006->raw() : nullptr,_2006 ? _2006->size(0) : 0);
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7647;
      for (int _2009 = (int)0, _7648 = _2005; _2009 < _7648 ; ++_2009)
      {
        _7647.push_back(((*_1998)(_2009))->getShape());
      }
      auto _7649 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7647.size()),_7647.begin(),_7647.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2008 = _7649;
      std::vector<int> _7650;
      for (int _2011 = (int)0, _7651 = _2005; _2011 < _7651 ; ++_2011)
      {
        _7650.push_back((int)((((*_2008)(_2011)))->size(0)));
      }
      auto _7652 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7650.size()),_7650.begin(),_7650.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2010 = _7652;
      _checked_ptr_1<int> _ptr__2010(_2010 ? _2010->raw() : nullptr,_2010 ? _2010->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2012 = ((*_2008)((int)0));
      _checked_ptr_1<int> _ptr__2012(_2012 ? _2012->raw() : nullptr,_2012 ? _2012->size(0) : 0);
      int _2013 = _ptr__2010[(int)0];
      int _2014 = (int)0;
      int _7653 = (int)0;
      int _7654 = _2005;
      for (int _2015 = _7653; _2015 < _7654; ++_2015)
      {
        {
          _2014 += _ptr__2006[_2015];
        }
      }
      int _2016 = safe_add( _1999,(int)1 );
      int _7655 = (int)0;
      int _7656 = _2005;
      for (int _2017 = _7655; _2017 < _7656; ++_2017)
      {
        {
          if ((_2016 < _ptr__2010[_2017]))
          {
            {
              _2016 = _ptr__2010[_2017];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2018 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2016)));
      _checked_ptr_1<int> _ptr__2018(_2018 ? _2018->raw() : nullptr,_2018 ? _2018->size(0) : 0);
      int _7657 = (int)0;
      int _7658 = _2013;
      for (int _2019 = _7657; _2019 < _7658; ++_2019)
      {
        {
          _ptr__2018[_2019] = _ptr__2012[_2019];
        }
      }
      int _7659 = _2013;
      int _7660 = _2016;
      for (int _2020 = _7659; _2020 < _7660; ++_2020)
      {
        {
          _ptr__2018[_2020] = (int)1;
        }
      }
      _ptr__2018[_1999] = (int)0;
      int _7661 = (int)0;
      int _7662 = _2005;
      for (int _2021 = _7661; _2021 < _7662; ++_2021)
      {
        {
          int _7663;
          bool _7664 = ((int)((((*_2008)(_2021)))->size(0)) > _1999);
          if (_7664)
          {
            _7663 = ((*((*_2008)(_2021)))(_1999));
          }
          else
          {
            _7663 = (int)1;
          }
          _ptr__2018[_1999] += _7663;
        }
      }
      int _7665 = (int)0;
      int _7666 = _2005;
      for (int _2022 = _7665; _2022 < _7666; ++_2022)
      {
        {
          int _7667 = (int)0;
          int _7668 = (int)((((*_2008)(_2022)))->size(0));
          for (int _2023 = _7667; _2023 < _7668; ++_2023)
          {
            {
              if (((_2023 != _1999) && (((*((*_2008)(_2022)))(_2023)) != _ptr__2018[_2023])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
          int _7669 = (int)((((*_2008)(_2022)))->size(0));
          int _7670 = _2016;
          for (int _2024 = _7669; _2024 < _7670; ++_2024)
          {
            {
              if (((_2024 != _1999) && ((int)1 != _ptr__2018[_2024])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2025 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2014)));
      _checked_ptr_1<long long> _ptr__2025(_2025 ? _2025->raw() : nullptr,_2025 ? _2025->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2026 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2014)));
      _checked_ptr_1<long long> _ptr__2026(_2026 ? _2026->raw() : nullptr,_2026 ? _2026->size(0) : 0);
      std::vector<int> _7671;
      for (int _2028 = (int)0, _7672 = (int)((_1998)->size(0)); _2028 < _7672 ; ++_2028)
      {
        int _7673;
        bool _7674 = (_1999 < (int)((((*_2008)(_2028)))->size(0)));
        if (_7674)
        {
          _7673 = ((*((*_2008)(_2028)))(_1999));
        }
        else
        {
          _7673 = (int)1;
        }
        _7671.push_back(_7673);
      }
      auto _7675 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7671.size()),_7671.begin(),_7671.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2027 = _7675;
      _checked_ptr_1<int> _ptr__2027(_2027 ? _2027->raw() : nullptr,_2027 ? _2027->size(0) : 0);
      int _2029 = (int)1;
      int _7676 = (int)0;
      int _7677 = _1999;
      for (int _2030 = _7676; _2030 < _7677; ++_2030)
      {
        {
          int _7678;
          bool _7679 = (_2030 < (int)((_2012)->size(0)));
          if (_7679)
          {
            _7678 = _ptr__2012[_2030];
          }
          else
          {
            _7678 = (int)1;
          }
          _2029 *= _7678;
        }
      }
      int _2031 = (int)0;
      int _7680 = (int)0;
      int _7681 = _2005;
      for (int _2032 = _7680; _2032 < _7681; ++_2032)
      {
        {
          _2031 += _ptr__2027[_2032];
        }
      }
      int _2033 = (int)1;
      int _7682 = safe_add( _1999,(int)1 );
      int _7683 = (int)((_2012)->size(0));
      for (int _2034 = _7682; _2034 < _7683; ++_2034)
      {
        {
          _2033 *= _ptr__2012[_2034];
        }
      }
      if ((_2029 == (int)1))
      {
        {
          int _2035 = (int)0;
          long long _2036 = (int)0;
          int _7684 = (int)0;
          int _7685 = _2005;
          for (int _2037 = _7684; _2037 < _7685; ++_2037)
          {
            {
              ((*_1998)(_2037))->inst(_2035,_2026,_2035,_2025);
              int _7686 = (int)0;
              int _7687 = _ptr__2006[_2037];
              for (int _2038 = _7686; _2038 < _7687; ++_2038)
              {
                {
                  _ptr__2026[_2035] += _2036;
                  ++ _2035;
                }
              }
              _2036 += ::mosek::fusion::p_Set::size(((*_2008)(_2037)));
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7688;
          bool _7689 = (_2014 < safe_mul( safe_mul( _2029,_2031 ),_2033 ));
          if (_7689)
          {
            _7688 = _2026;
          }
          else
          {
            _7688 = nullptr;
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2000,_2018,_7688,_2025)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          int _2039 = (int)0;
          int _7690 = (int)0;
          int _7691 = _2005;
          for (int _2040 = _7690; _2040 < _7691; ++_2040)
          {
            {
              _2039 += ((*_1998)(_2040))->inst(_2039,_2026,_2039,_2025);
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2041 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2014)));
          _checked_ptr_1<int> _ptr__2041(_2041 ? _2041->raw() : nullptr,_2041 ? _2041->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2042 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2014)));
          _checked_ptr_1<int> _ptr__2042(_2042 ? _2042->raw() : nullptr,_2042 ? _2042->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2043 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2005)));
          _checked_ptr_1<int> _ptr__2043(_2043 ? _2043->raw() : nullptr,_2043 ? _2043->size(0) : 0);
          int _7692 = (int)0;
          int _7693 = (_2005 - (int)1);
          for (int _2044 = _7692; _2044 < _7693; ++_2044)
          {
            {
              _ptr__2043[safe_add( _2044,(int)1 )] = safe_add( _ptr__2043[_2044],_ptr__2027[_2044] );
            }
          }
          int _7694 = (int)0;
          int _7695 = _2014;
          for (int _2045 = _7694; _2045 < _7695; ++_2045)
          {
            {
              _ptr__2041[_2045] = _2045;
            }
          }
          int _2046 = (int)0;
          int _7696 = (int)0;
          int _7697 = _2005;
          for (int _2047 = _7696; _2047 < _7697; ++_2047)
          {
            {
              int _7698 = (int)0;
              int _7699 = _ptr__2006[_2047];
              for (int _2048 = _7698; _2048 < _7699; ++_2048)
              {
                {
                  long long _2049 = (_ptr__2026[_2046] / safe_mul( _ptr__2027[_2047],_2033 ));
                  long long _2050 = ((_ptr__2026[_2046] / _2033) % _ptr__2027[_2047]);
                  long long _2051 = (_ptr__2026[_2046] % _2033);
                  _ptr__2026[_2046] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _2049,_2031 ),_2050 ),_ptr__2043[_2047] ),_2033 ),_2051 );
                  ++ _2046;
                }
              }
            }
          }
          int _2052 = (int)1;
          int _7700 = (int)0;
          int _7701 = _2016;
          for (int _2053 = _7700; _2053 < _7701; ++_2053)
          {
            {
              int _7702;
              bool _7703 = (_2052 < _ptr__2018[_2053]);
              if (_7703)
              {
                _7702 = _ptr__2018[_2053];
              }
              else
              {
                _7702 = _2052;
              }
              _2052 = _7702;
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _2054 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2016)));
          _checked_ptr_1<long long> _ptr__2054(_2054 ? _2054->raw() : nullptr,_2054 ? _2054->size(0) : 0);
          _ptr__2054[(_2016 - (int)1)] = (int)1;
          int _7704 = (int)1;
          int _7705 = _2016;
          for (int _2055 = _7704; _2055 < _7705; ++_2055)
          {
            {
              _ptr__2054[((_2016 - _2055) - (int)1)] = safe_mul( _ptr__2054[(_2016 - _2055)],_ptr__2018[(_2016 - _2055)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2056 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2052,(int)1 ))));
          _checked_ptr_1<int> _ptr__2056(_2056 ? _2056->raw() : nullptr,_2056 ? _2056->size(0) : 0);
          int _7706 = (int)0;
          int _7707 = _2016;
          for (int _2057 = _7706; _2057 < _7707; ++_2057)
          {
            {
              int _2058 = ((_2016 - _2057) - (int)1);
              int _7708 = (int)0;
              int _7709 = safe_add( _ptr__2018[_2058],(int)1 );
              for (int _2059 = _7708; _2059 < _7709; ++_2059)
              {
                {
                  _ptr__2056[_2059] = (int)0;
                }
              }
              int _7710 = (int)0;
              int _7711 = _2014;
              for (int _2060 = _7710; _2060 < _7711; ++_2060)
              {
                {
                  ++ _ptr__2056[safe_add( ((_ptr__2026[_2060] / _ptr__2054[_2058]) % _ptr__2018[_2058]),(int)1 )];
                }
              }
              int _7712 = (int)0;
              int _7713 = _ptr__2018[_2058];
              for (int _2061 = _7712; _2061 < _7713; ++_2061)
              {
                {
                  _ptr__2056[safe_add( _2061,(int)1 )] += _ptr__2056[_2061];
                }
              }
              int _7714 = (int)0;
              int _7715 = _2014;
              for (int _2062 = _7714; _2062 < _7715; ++_2062)
              {
                {
                  int _2063 = _ptr__2041[_2062];
                  long long _2064 = ((_ptr__2026[_2063] / _ptr__2054[_2058]) % _ptr__2018[_2058]);
                  _ptr__2042[_ptr__2056[_2064]] = _2063;
                  ++ _ptr__2056[_2064];
                }
              }
              std::shared_ptr< monty::ndarray< int,1 > > _2065 = _2041;
              _checked_ptr_1<int> _ptr__2065(_2065 ? _2065->raw() : nullptr,_2065 ? _2065->size(0) : 0);
              _2041 = _2042;
              _ptr__2041.update(_2041 ? _2041->raw() : nullptr, _2041 ? _2041->size(0) : 0);
              _2042 = _2065;
              _ptr__2042.update(_2042 ? _2042->raw() : nullptr, _2042 ? _2042->size(0) : 0);
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7716;
          bool _7717 = (_2014 < safe_mul( safe_mul( _2029,_2031 ),_2033 ));
          if (_7717)
          {
            std::vector<long long> _7718;
            for (int _2066 = (int)0, _7719 = _2014; _2066 < _7719 ; ++_2066)
            {
              _7718.push_back(_ptr__2026[_ptr__2041[_2066]]);
            }
            auto _7720 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7718.size()),_7718.begin(),_7718.end()));
            _7716 = _7720;
          }
          else
          {
            _7716 = nullptr;
          }
          std::vector<long long> _7721;
          for (int _2067 = (int)0, _7722 = _2014; _2067 < _7722 ; ++_2067)
          {
            _7721.push_back(_ptr__2025[_ptr__2041[_2067]]);
          }
          auto _7723 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7721.size()),_7721.begin(),_7721.end()));
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2000,_2018,_7716,_7723)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
void mosek::fusion::p_Var::destroy(){}void mosek::fusion::Var::destroy() { mosek::fusion::p_Var::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint(mosek::fusion::p_LinearPSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearPSDConstraint()" << this << std::endl; */ }mosek::fusion::LinearPSDConstraint::~LinearPSDConstraint() {  /* std::cout << "~LinearPSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDConstraint::p_LinearPSDConstraint  (::mosek::fusion::LinearPSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2068,    monty::rc_ptr< ::mosek::fusion::Model > _2069){ return new mosek::fusion::LinearPSDConstraint(_2068,_2069); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2068,    monty::rc_ptr< ::mosek::fusion::Model > _2069) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2068,_2069); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2068,    monty::rc_ptr< ::mosek::fusion::Model > _2069){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2068,_2069);
    conid = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2068)->conid;
    slackidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2068)->slackidxs;
    nativeidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2068)->nativeidxs;
    conedim = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2068)->conedim;
    shape = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2068)->shape;
  }
}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2070,    const std::string &  _2071,    int _2072,    std::shared_ptr< monty::ndarray< int,1 > > _2073,    int _2074,    std::shared_ptr< monty::ndarray< int,1 > > _2075,    std::shared_ptr< monty::ndarray< long long,1 > > _2076){ return new mosek::fusion::LinearPSDConstraint(_2070,_2071,_2072,_2073,_2074,_2075,_2076); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2070,    const std::string &  _2071,    int _2072,    std::shared_ptr< monty::ndarray< int,1 > > _2073,    int _2074,    std::shared_ptr< monty::ndarray< int,1 > > _2075,    std::shared_ptr< monty::ndarray< long long,1 > > _2076) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2070,_2071,_2072,_2073,_2074,_2075,_2076); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2070,    const std::string &  _2071,    int _2072,    std::shared_ptr< monty::ndarray< int,1 > > _2073,    int _2074,    std::shared_ptr< monty::ndarray< int,1 > > _2075,    std::shared_ptr< monty::ndarray< long long,1 > > _2076){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2073(_2073 ? _2073->raw() : nullptr, _2073 ? _2073->size(0) : 0);
    _checked_ptr_1<int> _ptr__2075(_2075 ? _2075->raw() : nullptr, _2075 ? _2075->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2076(_2076 ? _2076->raw() : nullptr, _2076 ? _2076->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2070,_2071,_2073,_2075);
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conid = _2072;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->slackidxs = _2076;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->nativeidxs = _2075;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conedim = _2074;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->shape = _2073;
  }
}void mosek::fusion::p_LinearPSDConstraint::domainToString(long long _2077,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2078){
  std::shared_ptr< monty::ndarray< int,1 > > _2079 = ::mosek::fusion::p_Set::idxtokey(shape,_2077);
  _checked_ptr_1<int> _ptr__2079(_2079 ? _2079->raw() : nullptr,_2079 ? _2079->size(0) : 0);
  _2078->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2079[(int)0]);
  int _7724 = (int)1;
  int _7725 = (int)((_2079)->size(0));
  for (int _2080 = _7724; _2080 < _7725; ++_2080)
  {
    {
      _2078->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2079[_2080]);
    }
  }
  _2078->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") in a positive semi-definite cone of size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7726 = (int)1;
  int _7727 = (int)((_2079)->size(0));
  for (int _2081 = _7726; _2081 < _7727; ++_2081)
  {
    {
      _2078->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_2081)));
    }
  }
  _2078->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearPSDConstraint::__mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2082){
  return (::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::LinearPSDConstraint::t(_pubthis),_2082)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearPSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDConstraint::destroy() { mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::PSDConstraint::PSDConstraint(mosek::fusion::p_PSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "PSDConstraint()" << this << std::endl; */ }mosek::fusion::PSDConstraint::~PSDConstraint() {  /* std::cout << "~PSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDConstraint::p_PSDConstraint  (::mosek::fusion::PSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2083,    monty::rc_ptr< ::mosek::fusion::Model > _2084){ return new mosek::fusion::PSDConstraint(_2083,_2084); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2083,    monty::rc_ptr< ::mosek::fusion::Model > _2084) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2083,_2084); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2083,    monty::rc_ptr< ::mosek::fusion::Model > _2084){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2083,_2084);
    conid = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->conid;
    name = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->name;
    shape = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->shape;
    slackidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->slackidxs;
    nativeidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->nativeidxs;
    names_flushed = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->names_flushed;
    conedim0 = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->conedim0;
    conedim1 = mosek::fusion::p_PSDConstraint::_get_impl(_2083)->conedim1;
  }
}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2085,    const std::string &  _2086,    int _2087,    std::shared_ptr< monty::ndarray< int,1 > > _2088,    int _2089,    int _2090,    std::shared_ptr< monty::ndarray< long long,1 > > _2091,    std::shared_ptr< monty::ndarray< int,1 > > _2092){ return new mosek::fusion::PSDConstraint(_2085,_2086,_2087,_2088,_2089,_2090,_2091,_2092); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2085,    const std::string &  _2086,    int _2087,    std::shared_ptr< monty::ndarray< int,1 > > _2088,    int _2089,    int _2090,    std::shared_ptr< monty::ndarray< long long,1 > > _2091,    std::shared_ptr< monty::ndarray< int,1 > > _2092) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2085,_2086,_2087,_2088,_2089,_2090,_2091,_2092); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2085,    const std::string &  _2086,    int _2087,    std::shared_ptr< monty::ndarray< int,1 > > _2088,    int _2089,    int _2090,    std::shared_ptr< monty::ndarray< long long,1 > > _2091,    std::shared_ptr< monty::ndarray< int,1 > > _2092){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2088(_2088 ? _2088->raw() : nullptr, _2088 ? _2088->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2091(_2091 ? _2091->raw() : nullptr, _2091 ? _2091->size(0) : 0);
    _checked_ptr_1<int> _ptr__2092(_2092 ? _2092->raw() : nullptr, _2092 ? _2092->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2085,_2086,_2088,::mosek::fusion::p_PSDConstraint::computenidxs(_2088,_2089,_2090,_2092));
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conid = _2087;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->nativeidxs = _2092;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->slackidxs = _2091;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->name = _2086;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->shape = _2088;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim0 = _2089;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim1 = _2090;
    names_flushed = false;
  }
}std::string mosek::fusion::PSDConstraint :: toString() { return mosek::fusion::p_PSDConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDConstraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("PSDConstraint.toString not implemented"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_PSDConstraint::__mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2093){
  return (::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::PSDConstraint::t(_pubthis),_2093)).as<::mosek::fusion::ModelConstraint>();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_PSDConstraint::computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2094,int _2095,int _2096,std::shared_ptr< monty::ndarray< int,1 > > _2097){
  _checked_ptr_1<int> _ptr__2094(_2094 ? _2094->raw() : nullptr, _2094 ? _2094->size(0) : 0);
  _checked_ptr_1<int> _ptr__2097(_2097 ? _2097->raw() : nullptr, _2097 ? _2097->size(0) : 0);
  int _2098 = (int)((_2094)->size(0));
  bool _2099 = (_2095 < _2096);
  int _7728;
  bool _7729 = _2099;
  if (_7729)
  {
    _7728 = _2095;
  }
  else
  {
    _7728 = _2096;
  }
  int _2100 = _7728;
  int _7730;
  bool _7731 = _2099;
  if (_7731)
  {
    _7730 = _2096;
  }
  else
  {
    _7730 = _2095;
  }
  int _2101 = _7730;
  std::shared_ptr< monty::ndarray< int,1 > > _2102 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__2102(_2102 ? _2102->raw() : nullptr,_2102 ? _2102->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2103 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__2103(_2103 ? _2103->raw() : nullptr,_2103 ? _2103->size(0) : 0);
  int _2104 = (int)1;
  int _7732 = (int)0;
  int _7733 = (int)((_2094)->size(0));
  for (int _2105 = _7732; _2105 < _7733; ++_2105)
  {
    {
      _2104 *= _ptr__2094[_2105];
    }
  }
  int _7734 = (int)0;
  int _7735 = _2100;
  for (int _2106 = _7734; _2106 < _7735; ++_2106)
  {
    {
      _ptr__2102[(int)0] *= _ptr__2094[_2106];
    }
  }
  _ptr__2102[(int)1] = _ptr__2094[_2100];
  int _7736 = safe_add( _2100,(int)1 );
  int _7737 = _2101;
  for (int _2107 = _7736; _2107 < _7737; ++_2107)
  {
    {
      _ptr__2102[(int)2] *= _ptr__2094[_2107];
    }
  }
  _ptr__2102[(int)3] = _ptr__2094[_2101];
  int _7738 = safe_add( _2101,(int)1 );
  int _7739 = _2098;
  for (int _2108 = _7738; _2108 < _7739; ++_2108)
  {
    {
      _ptr__2102[(int)4] *= _ptr__2094[_2108];
    }
  }
  _ptr__2103[(int)4] = (int)1;
  int _7740 = (int)1;
  int _7741 = (int)5;
  for (int _2109 = _7740; _2109 < _7741; ++_2109)
  {
    {
      _ptr__2103[(((int)5 - _2109) - (int)1)] = safe_mul( _ptr__2103[((int)5 - _2109)],_ptr__2102[((int)5 - _2109)] );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2110 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2104)));
  _checked_ptr_1<int> _ptr__2110(_2110 ? _2110->raw() : nullptr,_2110 ? _2110->size(0) : 0);
  int _2111 = (int)0;
  if (_2099)
  {
    {
      int _7742 = (int)0;
      int _7743 = _ptr__2102[(int)0];
      for (int _2112 = _7742; _2112 < _7743; ++_2112)
      {
        {
          int _7744 = (int)0;
          int _7745 = _ptr__2102[(int)1];
          for (int _2113 = _7744; _2113 < _7745; ++_2113)
          {
            {
              int _7746 = (int)0;
              int _7747 = _ptr__2102[(int)2];
              for (int _2114 = _7746; _2114 < _7747; ++_2114)
              {
                {
                  int _7748 = _2113;
                  int _7749 = _ptr__2102[(int)1];
                  for (int _2115 = _7748; _2115 < _7749; ++_2115)
                  {
                    {
                      int _7750 = (int)0;
                      int _7751 = _ptr__2102[(int)4];
                      for (int _2116 = _7750; _2116 < _7751; ++_2116)
                      {
                        {
                          _ptr__2110[safe_add( safe_add( safe_add( safe_add( safe_mul( _2112,_ptr__2103[(int)0] ),safe_mul( _2113,_ptr__2103[(int)1] ) ),safe_mul( _2114,_ptr__2103[(int)2] ) ),safe_mul( _2115,_ptr__2103[(int)3] ) ),safe_mul( _2116,_ptr__2103[(int)4] ) )] = _ptr__2097[_2111];
                          _ptr__2110[safe_add( safe_add( safe_add( safe_add( safe_mul( _2112,_ptr__2103[(int)0] ),safe_mul( _2115,_ptr__2103[(int)1] ) ),safe_mul( _2114,_ptr__2103[(int)2] ) ),safe_mul( _2113,_ptr__2103[(int)3] ) ),safe_mul( _2116,_ptr__2103[(int)4] ) )] = _ptr__2097[_2111];
                          ++ _2111;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _7752 = (int)0;
      int _7753 = _ptr__2102[(int)0];
      for (int _2117 = _7752; _2117 < _7753; ++_2117)
      {
        {
          int _7754 = (int)0;
          int _7755 = _ptr__2102[(int)1];
          for (int _2118 = _7754; _2118 < _7755; ++_2118)
          {
            {
              int _7756 = (int)0;
              int _7757 = _ptr__2102[(int)2];
              for (int _2119 = _7756; _2119 < _7757; ++_2119)
              {
                {
                  int _7758 = (int)0;
                  int _7759 = safe_add( _2118,(int)1 );
                  for (int _2120 = _7758; _2120 < _7759; ++_2120)
                  {
                    {
                      int _7760 = (int)0;
                      int _7761 = _ptr__2102[(int)4];
                      for (int _2121 = _7760; _2121 < _7761; ++_2121)
                      {
                        {
                          _ptr__2110[safe_add( safe_add( safe_add( safe_add( safe_mul( _2117,_ptr__2103[(int)0] ),safe_mul( _2118,_ptr__2103[(int)1] ) ),safe_mul( _2119,_ptr__2103[(int)2] ) ),safe_mul( _2120,_ptr__2103[(int)3] ) ),safe_mul( _2121,_ptr__2103[(int)4] ) )] = _ptr__2097[_2111];
                          _ptr__2110[safe_add( safe_add( safe_add( safe_add( safe_mul( _2117,_ptr__2103[(int)0] ),safe_mul( _2120,_ptr__2103[(int)1] ) ),safe_mul( _2119,_ptr__2103[(int)2] ) ),safe_mul( _2118,_ptr__2103[(int)3] ) ),safe_mul( _2121,_ptr__2103[(int)4] ) )] = _ptr__2097[_2111];
                          ++ _2111;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _2110;
}
void mosek::fusion::p_PSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::PSDConstraint::destroy() { mosek::fusion::p_PSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConstraintCache::ConstraintCache(mosek::fusion::p_ConstraintCache *_impl) : _impl(_impl) { /*std::cout << "ConstraintCache() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConstraintCache::~ConstraintCache() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConstraintCache::p_ConstraintCache  (::mosek::fusion::ConstraintCache * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barmatidx() { return _impl->barmatidx; }
void mosek::fusion::ConstraintCache::set_barmatidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmatidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConstraintCache::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConstraintCache::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
long long mosek::fusion::ConstraintCache::get_nbarnz() { return _impl->nbarnz; }
void mosek::fusion::ConstraintCache::set_nbarnz(long long _val) { _impl->nbarnz = _val; }
long long mosek::fusion::ConstraintCache::get_nunordered() { return _impl->nunordered; }
void mosek::fusion::ConstraintCache::set_nunordered(long long _val) { _impl->nunordered = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subi() { return _impl->buffer_subi; }
void mosek::fusion::ConstraintCache::set_buffer_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subj() { return _impl->buffer_subj; }
void mosek::fusion::ConstraintCache::set_buffer_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subj = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_buffer_cof() { return _impl->buffer_cof; }
void mosek::fusion::ConstraintCache::set_buffer_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->buffer_cof = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConstraintCache::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_cof() { return _impl->cof; }
void mosek::fusion::ConstraintCache::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subi() { return _impl->subi; }
void mosek::fusion::ConstraintCache::set_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subj() { return _impl->subj; }
void mosek::fusion::ConstraintCache::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
long long mosek::fusion::ConstraintCache::get_nnz() { return _impl->nnz; }
void mosek::fusion::ConstraintCache::set_nnz(long long _val) { _impl->nnz = _val; }
int mosek::fusion::ConstraintCache::get_nrows() { return _impl->nrows; }
void mosek::fusion::ConstraintCache::set_nrows(int _val) { _impl->nrows = _val; }
mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2122){ return new mosek::fusion::ConstraintCache(_2122); }mosek::fusion::ConstraintCache::ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2122) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2122); }void mosek::fusion::p_ConstraintCache::_initialize  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2122){monty::rc_reserve __reserve_this(_pubthis);   {
    nrows = mosek::fusion::p_ConstraintCache::_get_impl(_2122)->nrows;
    nnz = mosek::fusion::p_ConstraintCache::_get_impl(_2122)->nnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7762;
    bool _7763 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->subj.get());
    if (_7763)
    {
      _7762 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->subj);
    }
    else
    {
      _7762 = nullptr;
    }
    subj = _7762;
    std::shared_ptr< monty::ndarray< int,1 > > _7764;
    bool _7765 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->subi.get());
    if (_7765)
    {
      _7764 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->subi);
    }
    else
    {
      _7764 = nullptr;
    }
    subi = _7764;
    std::shared_ptr< monty::ndarray< double,1 > > _7766;
    bool _7767 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->cof.get());
    if (_7767)
    {
      _7766 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->cof);
    }
    else
    {
      _7766 = nullptr;
    }
    cof = _7766;
    std::shared_ptr< monty::ndarray< double,1 > > _7768;
    bool _7769 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->bfix.get());
    if (_7769)
    {
      _7768 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->bfix);
    }
    else
    {
      _7768 = nullptr;
    }
    bfix = _7768;
    std::shared_ptr< monty::ndarray< double,1 > > _7770;
    bool _7771 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->buffer_cof.get());
    if (_7771)
    {
      _7770 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->buffer_cof);
    }
    else
    {
      _7770 = nullptr;
    }
    buffer_cof = _7770;
    std::shared_ptr< monty::ndarray< int,1 > > _7772;
    bool _7773 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->buffer_subj.get());
    if (_7773)
    {
      _7772 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->buffer_subj);
    }
    else
    {
      _7772 = nullptr;
    }
    buffer_subj = _7772;
    std::shared_ptr< monty::ndarray< int,1 > > _7774;
    bool _7775 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->buffer_subi.get());
    if (_7775)
    {
      _7774 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->buffer_subi);
    }
    else
    {
      _7774 = nullptr;
    }
    buffer_subi = _7774;
    nunordered = mosek::fusion::p_ConstraintCache::_get_impl(_2122)->nunordered;
    nbarnz = mosek::fusion::p_ConstraintCache::_get_impl(_2122)->nbarnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7776;
    bool _7777 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->barsubi.get());
    if (_7777)
    {
      _7776 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->barsubi);
    }
    else
    {
      _7776 = nullptr;
    }
    barsubi = _7776;
    std::shared_ptr< monty::ndarray< int,1 > > _7778;
    bool _7779 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->barsubj.get());
    if (_7779)
    {
      _7778 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->barsubj);
    }
    else
    {
      _7778 = nullptr;
    }
    barsubj = _7778;
    std::shared_ptr< monty::ndarray< int,1 > > _7780;
    bool _7781 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2122)->barmatidx.get());
    if (_7781)
    {
      _7780 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2122)->barmatidx);
    }
    else
    {
      _7780 = nullptr;
    }
    barmatidx = _7780;
  }
}mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2123,    std::shared_ptr< monty::ndarray< double,1 > > _2124,    std::shared_ptr< monty::ndarray< int,1 > > _2125,    std::shared_ptr< monty::ndarray< double,1 > > _2126,    std::shared_ptr< monty::ndarray< int,1 > > _2127,    std::shared_ptr< monty::ndarray< int,1 > > _2128,    std::shared_ptr< monty::ndarray< int,1 > > _2129){ return new mosek::fusion::ConstraintCache(_2123,_2124,_2125,_2126,_2127,_2128,_2129); }mosek::fusion::ConstraintCache::ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2123,    std::shared_ptr< monty::ndarray< double,1 > > _2124,    std::shared_ptr< monty::ndarray< int,1 > > _2125,    std::shared_ptr< monty::ndarray< double,1 > > _2126,    std::shared_ptr< monty::ndarray< int,1 > > _2127,    std::shared_ptr< monty::ndarray< int,1 > > _2128,    std::shared_ptr< monty::ndarray< int,1 > > _2129) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2123,_2124,_2125,_2126,_2127,_2128,_2129); }void mosek::fusion::p_ConstraintCache::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _2123,    std::shared_ptr< monty::ndarray< double,1 > > _2124,    std::shared_ptr< monty::ndarray< int,1 > > _2125,    std::shared_ptr< monty::ndarray< double,1 > > _2126,    std::shared_ptr< monty::ndarray< int,1 > > _2127,    std::shared_ptr< monty::ndarray< int,1 > > _2128,    std::shared_ptr< monty::ndarray< int,1 > > _2129){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2123(_2123 ? _2123->raw() : nullptr, _2123 ? _2123->size(0) : 0);
    _checked_ptr_1<double> _ptr__2124(_2124 ? _2124->raw() : nullptr, _2124 ? _2124->size(0) : 0);
    _checked_ptr_1<int> _ptr__2125(_2125 ? _2125->raw() : nullptr, _2125 ? _2125->size(0) : 0);
    _checked_ptr_1<double> _ptr__2126(_2126 ? _2126->raw() : nullptr, _2126 ? _2126->size(0) : 0);
    _checked_ptr_1<int> _ptr__2127(_2127 ? _2127->raw() : nullptr, _2127 ? _2127->size(0) : 0);
    _checked_ptr_1<int> _ptr__2128(_2128 ? _2128->raw() : nullptr, _2128 ? _2128->size(0) : 0);
    _checked_ptr_1<int> _ptr__2129(_2129 ? _2129->raw() : nullptr, _2129 ? _2129->size(0) : 0);
    nrows = ((int)((_2123)->size(0)) - (int)1);
    nnz = _ptr__2123[((int)((_2123)->size(0)) - (int)1)];
    subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nnz)));
    if ((NULL != _2126.get()))
    {
      {
        bfix = _2126;
      }
    }
    else
    {
      {
        bfix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nrows)));
      }
    }
    if (((NULL != _2127.get()) && ((NULL != _2128.get()) && (NULL != _2129.get()))))
    {
      {
        nbarnz = (int)((_2127)->size(0));
        if ((nbarnz > (int)((_2128)->size(0))))
        {
          {
            nbarnz = (int)((_2128)->size(0));
          }
        }
        {}
        if ((nbarnz > (int)((_2129)->size(0))))
        {
          {
            nbarnz = (int)((_2129)->size(0));
          }
        }
        {}
        barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        ::mosek::fusion::Utils::Tools::arraycopy(_2127,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2128,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2129,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
      }
    }
    else
    {
      {
        nbarnz = (int)0;
        barsubi = nullptr;
        barsubj = nullptr;
        barmatidx = nullptr;
      }
    }
    ::mosek::fusion::Utils::Tools::arraycopy(_2125,(long long)0,subj,(long long)0,nnz);
    ::mosek::fusion::Utils::Tools::arraycopy(_2124,(long long)0,cof,(long long)0,nnz);
    int _7782 = (int)0;
    int _7783 = nrows;
    for (int _2130 = _7782; _2130 < _7783; ++_2130)
    {
      {
        long long _7784 = _ptr__2123[_2130];
        long long _7785 = _ptr__2123[safe_add( _2130,(int)1 )];
        for (long long _2131 = _7784; _2131 < _7785; ++_2131)
        {
          {
            ((*subi)(_2131)) = _2130;
          }
        }
      }
    }
    buffer_cof = nullptr;
    buffer_subj = nullptr;
    buffer_subi = nullptr;
    nunordered = (long long)0;
  }
}void mosek::fusion::p_ConstraintCache::unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2132){
  _checked_ptr_1<double> _ptr__2132(_2132 ? _2132->raw() : nullptr, _2132 ? _2132->size(0) : 0);
  int _7786 = (int)0;
  int _7787 = nrows;
  for (int _2133 = _7786; _2133 < _7787; ++_2133)
  {
    {
      ((*bfix)(_2133)) = (((*bfix)(_2133)) + _ptr__2132[_2133]);
    }
  }
}
long long mosek::fusion::p_ConstraintCache::order_barentries(){
  std::vector<long long> _7788;
  for (long long _2135 = (long long)0, _7789 = nbarnz; _2135 < _7789 ; ++_2135)
  {
    _7788.push_back(_2135);
  }
  auto _7790 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7788.size()),_7788.begin(),_7788.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _2134 = _7790;
  _checked_ptr_1<long long> _ptr__2134(_2134 ? _2134->raw() : nullptr,_2134 ? _2134->size(0) : 0);
  if ((!::mosek::fusion::p_Sort::issorted(_2134,barsubi,barsubj,(long long)((int)0),nbarnz,false)))
  {
    {
      ::mosek::fusion::p_Sort::argsort(_2134,barsubi,barsubj,(long long)((int)0),nbarnz,false);
      std::shared_ptr< monty::ndarray< int,1 > > _2136 = barsubi;
      _checked_ptr_1<int> _ptr__2136(_2136 ? _2136->raw() : nullptr,_2136 ? _2136->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2137 = barsubj;
      _checked_ptr_1<int> _ptr__2137(_2137 ? _2137->raw() : nullptr,_2137 ? _2137->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2138 = barmatidx;
      _checked_ptr_1<int> _ptr__2138(_2138 ? _2138->raw() : nullptr,_2138 ? _2138->size(0) : 0);
      std::vector<int> _7791;
      for (long long _2139 = (int)0, _7792 = nbarnz; _2139 < _7792 ; ++_2139)
      {
        _7791.push_back(_ptr__2136[_ptr__2134[_2139]]);
      }
      auto _7793 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7791.size()),_7791.begin(),_7791.end()));
      barsubi = _7793;
      std::vector<int> _7794;
      for (long long _2140 = (int)0, _7795 = nbarnz; _2140 < _7795 ; ++_2140)
      {
        _7794.push_back(_ptr__2137[_ptr__2134[_2140]]);
      }
      auto _7796 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7794.size()),_7794.begin(),_7794.end()));
      barsubj = _7796;
      std::vector<int> _7797;
      for (long long _2141 = (int)0, _7798 = nbarnz; _2141 < _7798 ; ++_2141)
      {
        _7797.push_back(_ptr__2138[_ptr__2134[_2141]]);
      }
      auto _7799 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7797.size()),_7797.begin(),_7797.end()));
      barmatidx = _7799;
    }
  }
  {}
  return nbarnz;
}
void mosek::fusion::p_ConstraintCache::add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2142,std::shared_ptr< monty::ndarray< int,1 > > _2143,std::shared_ptr< monty::ndarray< int,1 > > _2144){
  _checked_ptr_1<int> _ptr__2142(_2142 ? _2142->raw() : nullptr, _2142 ? _2142->size(0) : 0);
  _checked_ptr_1<int> _ptr__2143(_2143 ? _2143->raw() : nullptr, _2143 ? _2143->size(0) : 0);
  _checked_ptr_1<int> _ptr__2144(_2144 ? _2144->raw() : nullptr, _2144 ? _2144->size(0) : 0);
  if ((NULL != _2142.get()))
  {
    {
      int _2145 = (int)((_2142)->size(0));
      if (((int)((_2142)->size(0)) <= safe_add( nbarnz,_2145 )))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2146 = barsubi;
          _checked_ptr_1<int> _ptr__2146(_2146 ? _2146->raw() : nullptr,_2146 ? _2146->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2147 = barsubj;
          _checked_ptr_1<int> _ptr__2147(_2147 ? _2147->raw() : nullptr,_2147 ? _2147->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2148 = barmatidx;
          _checked_ptr_1<int> _ptr__2148(_2148 ? _2148->raw() : nullptr,_2148 ? _2148->size(0) : 0);
          long long _7800;
          bool _7801 = (safe_mul( (int)2,nbarnz ) > safe_add( nbarnz,_2145 ));
          if (_7801)
          {
            _7800 = safe_mul( (int)2,nbarnz );
          }
          else
          {
            _7800 = safe_add( nbarnz,safe_mul( _2145,(int)2 ) );
          }
          long long _2149 = _7800;
          barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2149)));
          barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2149)));
          barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2149)));
          if ((nbarnz > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_2146,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2147,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2148,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
            }
          }
          {}
        }
      }
      {}
      ::mosek::fusion::Utils::Tools::arraycopy(_2142,(long long)((int)0),barsubi,nbarnz,(long long)(_2145));
      ::mosek::fusion::Utils::Tools::arraycopy(_2143,(long long)((int)0),barsubj,nbarnz,(long long)(_2145));
      ::mosek::fusion::Utils::Tools::arraycopy(_2144,(long long)((int)0),barmatidx,nbarnz,(long long)(_2145));
      nbarnz += _2145;
    }
  }
  {}
}
void mosek::fusion::p_ConstraintCache::unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2150,std::shared_ptr< monty::ndarray< int,1 > > _2151,std::shared_ptr< monty::ndarray< double,1 > > _2152,std::shared_ptr< monty::ndarray< double,1 > > _2153){
  _checked_ptr_1<long long> _ptr__2150(_2150 ? _2150->raw() : nullptr, _2150 ? _2150->size(0) : 0);
  _checked_ptr_1<int> _ptr__2151(_2151 ? _2151->raw() : nullptr, _2151 ? _2151->size(0) : 0);
  _checked_ptr_1<double> _ptr__2152(_2152 ? _2152->raw() : nullptr, _2152 ? _2152->size(0) : 0);
  _checked_ptr_1<double> _ptr__2153(_2153 ? _2153->raw() : nullptr, _2153 ? _2153->size(0) : 0);
  long long _2154 = safe_add( nunordered,_ptr__2150[nrows] );
  long long _2155 = _ptr__2150[nrows];
  std::shared_ptr< monty::ndarray< int,1 > > _2156;
  _checked_ptr_1<int> _ptr__2156(_2156 ? _2156->raw() : nullptr,_2156 ? _2156->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2157;
  _checked_ptr_1<int> _ptr__2157(_2157 ? _2157->raw() : nullptr,_2157 ? _2157->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2158;
  _checked_ptr_1<double> _ptr__2158(_2158 ? _2158->raw() : nullptr,_2158 ? _2158->size(0) : 0);
  if (((NULL == buffer_cof.get()) || ((int)((buffer_cof)->size(0)) < _2154)))
  {
    {
      _2156 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2154)));
      _ptr__2156.update(_2156 ? _2156->raw() : nullptr, _2156 ? _2156->size(0) : 0);
      _2157 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2154)));
      _ptr__2157.update(_2157 ? _2157->raw() : nullptr, _2157 ? _2157->size(0) : 0);
      _2158 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2154)));
      _ptr__2158.update(_2158 ? _2158->raw() : nullptr, _2158 ? _2158->size(0) : 0);
      if ((NULL != buffer_cof.get()))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subi,(long long)0,_2156,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subj,(long long)0,_2157,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_cof,(long long)0,_2158,(long long)0,nunordered);
        }
      }
      {}
    }
  }
  else
  {
    {
      _2156 = buffer_subi;
      _ptr__2156.update(_2156 ? _2156->raw() : nullptr, _2156 ? _2156->size(0) : 0);
      _2157 = buffer_subj;
      _ptr__2157.update(_2157 ? _2157->raw() : nullptr, _2157 ? _2157->size(0) : 0);
      _2158 = buffer_cof;
      _ptr__2158.update(_2158 ? _2158->raw() : nullptr, _2158 ? _2158->size(0) : 0);
    }
  }
  int _7802 = (int)0;
  int _7803 = nrows;
  for (int _2159 = _7802; _2159 < _7803; ++_2159)
  {
    {
      long long _7804 = _ptr__2150[_2159];
      long long _7805 = _ptr__2150[safe_add( _2159,(int)1 )];
      for (long long _2160 = _7804; _2160 < _7805; ++_2160)
      {
        {
          _ptr__2156[safe_add( nunordered,_2160 )] = _2159;
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(_2151,(long long)0,_2157,nunordered,_2155);
  ::mosek::fusion::Utils::Tools::arraycopy(_2152,(long long)0,_2158,nunordered,_2155);
  buffer_subi = _2156;
  buffer_subj = _2157;
  buffer_cof = _2158;
  if ((NULL != _2153.get()))
  {
    {
      int _7806 = (int)0;
      int _7807 = nrows;
      for (int _2161 = _7806; _2161 < _7807; ++_2161)
      {
        {
          ((*bfix)(_2161)) = (((*bfix)(_2161)) + _ptr__2153[_2161]);
        }
      }
    }
  }
  {}
  nunordered = _2154;
}
void mosek::fusion::ConstraintCache :: add(std::shared_ptr< monty::ndarray< long long,1 > > _2162,std::shared_ptr< monty::ndarray< int,1 > > _2163,std::shared_ptr< monty::ndarray< double,1 > > _2164,std::shared_ptr< monty::ndarray< double,1 > > _2165) { mosek::fusion::p_ConstraintCache::_get_impl(this)->add(_2162,_2163,_2164,_2165); }void mosek::fusion::p_ConstraintCache::add(std::shared_ptr< monty::ndarray< long long,1 > > _2162,std::shared_ptr< monty::ndarray< int,1 > > _2163,std::shared_ptr< monty::ndarray< double,1 > > _2164,std::shared_ptr< monty::ndarray< double,1 > > _2165){
  _checked_ptr_1<long long> _ptr__2162(_2162 ? _2162->raw() : nullptr, _2162 ? _2162->size(0) : 0);
  _checked_ptr_1<int> _ptr__2163(_2163 ? _2163->raw() : nullptr, _2163 ? _2163->size(0) : 0);
  _checked_ptr_1<double> _ptr__2164(_2164 ? _2164->raw() : nullptr, _2164 ? _2164->size(0) : 0);
  _checked_ptr_1<double> _ptr__2165(_2165 ? _2165->raw() : nullptr, _2165 ? _2165->size(0) : 0);
  if ((((int)((_2162)->size(0)) != safe_add( nrows,(int)1 )) || ((NULL != _2165.get()) && ((int)((_2165)->size(0)) != nrows))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching expression lengths"));
    }
  }
  {}
  unchecked_add_l(_2162,_2163,_2164,_2165);
}
long long mosek::fusion::ConstraintCache :: flush(std::shared_ptr< monty::ndarray< int,1 > > _2166,std::shared_ptr< monty::ndarray< int,1 > > _2167,std::shared_ptr< monty::ndarray< double,1 > > _2168,std::shared_ptr< monty::ndarray< double,1 > > _2169) { return mosek::fusion::p_ConstraintCache::_get_impl(this)->flush(_2166,_2167,_2168,_2169); }long long mosek::fusion::p_ConstraintCache::flush(std::shared_ptr< monty::ndarray< int,1 > > _2166,std::shared_ptr< monty::ndarray< int,1 > > _2167,std::shared_ptr< monty::ndarray< double,1 > > _2168,std::shared_ptr< monty::ndarray< double,1 > > _2169){
  _checked_ptr_1<int> _ptr__2166(_2166 ? _2166->raw() : nullptr, _2166 ? _2166->size(0) : 0);
  _checked_ptr_1<int> _ptr__2167(_2167 ? _2167->raw() : nullptr, _2167 ? _2167->size(0) : 0);
  _checked_ptr_1<double> _ptr__2168(_2168 ? _2168->raw() : nullptr, _2168 ? _2168->size(0) : 0);
  _checked_ptr_1<double> _ptr__2169(_2169 ? _2169->raw() : nullptr, _2169 ? _2169->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2170 = nullptr;
  _checked_ptr_1<long long> _ptr__2170(_2170 ? _2170->raw() : nullptr,_2170 ? _2170->size(0) : 0);
  if (((NULL != bfix.get()) && (NULL != _2169.get())))
  {
    {
      int _7808 = (int)0;
      int _7809 = nrows;
      for (int _2171 = _7808; _2171 < _7809; ++_2171)
      {
        {
          _ptr__2169[_2171] = ((*bfix)(_2171));
        }
      }
    }
  }
  {}
  if ((nunordered == (long long)0))
  {
    {
      return (long long)0;
    }
  }
  {}
  bool _2172 = false;
  {
    int _2173 = (int)1;
    while ( ((_2173 < nunordered) && ((((*buffer_subi)((_2173 - (int)1))) < ((*buffer_subi)(_2173))) || ((((*buffer_subi)((_2173 - (int)1))) == ((*buffer_subi)(_2173))) && (((*buffer_subj)((_2173 - (int)1))) <= ((*buffer_subj)(_2173)))))) )
    {
      {
        ++ _2173;
      }
    }
    _2172 = (_2173 == nunordered);
  }
  if ((!_2172))
  {
    {
      std::vector<long long> _7810;
      for (long long _2174 = (int)0, _7811 = nunordered; _2174 < _7811 ; ++_2174)
      {
        _7810.push_back(_2174);
      }
      auto _7812 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7810.size()),_7810.begin(),_7810.end()));
      _2170 = _7812;
      _ptr__2170.update(_2170 ? _2170->raw() : nullptr, _2170 ? _2170->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2170,buffer_subi,buffer_subj,(long long)0,nunordered);
    }
  }
  {}
  long long _2175 = nnz;
  std::shared_ptr< monty::ndarray< int,1 > > _2176 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2175 ))));
  _checked_ptr_1<int> _ptr__2176(_2176 ? _2176->raw() : nullptr,_2176 ? _2176->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2177 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2175 ))));
  _checked_ptr_1<int> _ptr__2177(_2177 ? _2177->raw() : nullptr,_2177 ? _2177->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2178 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( nunordered,_2175 ))));
  _checked_ptr_1<double> _ptr__2178(_2178 ? _2178->raw() : nullptr,_2178 ? _2178->size(0) : 0);
  long long _2179 = (long long)0;
  if (_2172)
  {
    {
      long long _2180 = (long long)0;
      int _2181 = (int)0;
      long long _2182 = nunordered;
      long long _2183 = _2175;
      int _2184 = (int)0;
      int _2185 = (int)0;
      while ( ((_2185 < _2183) && (_2184 < _2182)) )
      {
        {
          if (((((*subi)(_2185)) < ((*buffer_subi)(_2184))) || ((((*subi)(_2185)) == ((*buffer_subi)(_2184))) && (((*subj)(_2185)) < ((*buffer_subj)(_2184))))))
          {
            {
              _ptr__2176[_2181] = ((*subi)(_2185));
              _ptr__2177[_2181] = ((*subj)(_2185));
              _ptr__2178[_2181] = ((*cof)(_2185));
              ++ _2185;
              ++ _2181;
            }
          }
          else if(((((*subi)(_2185)) > ((*buffer_subi)(_2184))) || ((((*subi)(_2185)) == ((*buffer_subi)(_2184))) && (((*subj)(_2185)) > ((*buffer_subj)(_2184))))))
          {
            {
              _ptr__2176[_2181] = ((*buffer_subi)(_2184));
              _ptr__2177[_2181] = ((*buffer_subj)(_2184));
              _ptr__2178[_2181] = ((*buffer_cof)(_2184));
              _ptr__2166[_2179] = _ptr__2176[_2181];
              _ptr__2167[_2179] = _ptr__2177[_2181];
              _ptr__2168[_2179] = _ptr__2178[_2181];
              ++ _2179;
              ++ _2184;
              ++ _2181;
            }
          }
          else
          {
            {
              _ptr__2176[_2181] = ((*subi)(_2185));
              _ptr__2177[_2181] = ((*subj)(_2185));
              _ptr__2178[_2181] = ((*cof)(_2185));
              while ( ((_2185 < (int)((subi)->size(0))) && ((_2184 < (int)((buffer_subi)->size(0))) && ((((*subi)(_2185)) == ((*buffer_subi)(_2184))) && (((*subj)(_2185)) == ((*buffer_subj)(_2184)))))) )
              {
                {
                  _ptr__2178[_2181] = (_ptr__2178[_2181] + ((*buffer_cof)(_2184)));
                  ++ _2184;
                }
              }
              _ptr__2166[_2179] = _ptr__2176[_2181];
              _ptr__2167[_2179] = _ptr__2177[_2181];
              _ptr__2168[_2179] = _ptr__2178[_2181];
              ++ _2179;
              ++ _2185;
              ++ _2181;
            }
          }
        }
      }
      while ( (_2185 < _2183) )
      {
        {
          _ptr__2176[_2181] = ((*subi)(_2185));
          _ptr__2177[_2181] = ((*subj)(_2185));
          _ptr__2178[_2181] = ((*cof)(_2185));
          ++ _2185;
          ++ _2181;
        }
      }
      while ( (_2184 < _2182) )
      {
        {
          _ptr__2176[_2181] = ((*buffer_subi)(_2184));
          _ptr__2177[_2181] = ((*buffer_subj)(_2184));
          _ptr__2178[_2181] = ((*buffer_cof)(_2184));
          _ptr__2166[_2179] = _ptr__2176[_2181];
          _ptr__2167[_2179] = _ptr__2177[_2181];
          _ptr__2168[_2179] = _ptr__2178[_2181];
          ++ _2179;
          ++ _2184;
          ++ _2181;
        }
      }
      nnz = _2181;
    }
  }
  else
  {
    {
      long long _2186 = (long long)0;
      int _2187 = (int)0;
      long long _2188 = nunordered;
      long long _2189 = _2175;
      int _2190 = (int)0;
      int _2191 = (int)0;
      while ( ((_2191 < _2189) && (_2190 < _2188)) )
      {
        {
          if (((((*subi)(_2191)) < ((*buffer_subi)(_ptr__2170[_2190]))) || ((((*subi)(_2191)) == ((*buffer_subi)(_ptr__2170[_2190]))) && (((*subj)(_2191)) < ((*buffer_subj)(_ptr__2170[_2190]))))))
          {
            {
              _ptr__2176[_2187] = ((*subi)(_2191));
              _ptr__2177[_2187] = ((*subj)(_2191));
              _ptr__2178[_2187] = ((*cof)(_2191));
              ++ _2191;
              ++ _2187;
            }
          }
          else if(((((*subi)(_2191)) > ((*buffer_subi)(_ptr__2170[_2190]))) || ((((*subi)(_2191)) == ((*buffer_subi)(_ptr__2170[_2190]))) && (((*subj)(_2191)) > ((*buffer_subj)(_ptr__2170[_2190]))))))
          {
            {
              _ptr__2176[_2187] = ((*buffer_subi)(_ptr__2170[_2190]));
              _ptr__2177[_2187] = ((*buffer_subj)(_ptr__2170[_2190]));
              _ptr__2178[_2187] = ((*buffer_cof)(_ptr__2170[_2190]));
              _ptr__2166[_2179] = _ptr__2176[_2187];
              _ptr__2167[_2179] = _ptr__2177[_2187];
              _ptr__2168[_2179] = _ptr__2178[_2187];
              ++ _2179;
              ++ _2190;
              ++ _2187;
            }
          }
          else
          {
            {
              _ptr__2176[_2187] = ((*subi)(_2191));
              _ptr__2177[_2187] = ((*subj)(_2191));
              _ptr__2178[_2187] = ((*cof)(_2191));
              while ( ((((*subi)(_2191)) == ((*buffer_subi)(_ptr__2170[_2190]))) && (((*subj)(_2191)) == ((*buffer_subj)(_ptr__2170[_2190])))) )
              {
                {
                  _ptr__2178[_2187] = (_ptr__2178[_2187] + ((*buffer_cof)(_ptr__2170[_2190])));
                  ++ _2190;
                }
              }
              _ptr__2166[_2179] = _ptr__2176[_2187];
              _ptr__2167[_2179] = _ptr__2177[_2187];
              _ptr__2168[_2179] = _ptr__2178[_2187];
              ++ _2179;
              ++ _2191;
              ++ _2187;
            }
          }
        }
      }
      nnz = _2187;
    }
  }
  subi = _2176;
  subj = _2177;
  cof = _2178;
  nunordered = (long long)0;
  return _2179;
}
long long mosek::fusion::ConstraintCache :: numUnsorted() { return mosek::fusion::p_ConstraintCache::_get_impl(this)->numUnsorted(); }long long mosek::fusion::p_ConstraintCache::numUnsorted(){
  return nunordered;
}
monty::rc_ptr< ::mosek::fusion::ConstraintCache > mosek::fusion::p_ConstraintCache::__mosek_2fusion_2ConstraintCache__clone(){
  return ::mosek::fusion::p_ConstraintCache::_new_ConstraintCache(::mosek::fusion::ConstraintCache::t(_pubthis));
}
void mosek::fusion::p_ConstraintCache::destroy(){barmatidx.reset();barsubj.reset();barsubi.reset();buffer_subi.reset();buffer_subj.reset();buffer_cof.reset();bfix.reset();cof.reset();subi.reset();subj.reset();}void mosek::fusion::ConstraintCache::destroy() { mosek::fusion::p_ConstraintCache::_get_impl(this)->destroy(); }mosek::fusion::SliceConstraint::SliceConstraint(mosek::fusion::p_SliceConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "SliceConstraint()" << this << std::endl; */ }mosek::fusion::SliceConstraint::~SliceConstraint() {  /* std::cout << "~SliceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceConstraint::p_SliceConstraint  (::mosek::fusion::SliceConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2192,    std::shared_ptr< monty::ndarray< int,1 > > _2193,    std::shared_ptr< monty::ndarray< int,1 > > _2194){ return new mosek::fusion::SliceConstraint(_2192,_2193,_2194); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2192,    std::shared_ptr< monty::ndarray< int,1 > > _2193,    std::shared_ptr< monty::ndarray< int,1 > > _2194) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2192,_2193,_2194); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2192,    std::shared_ptr< monty::ndarray< int,1 > > _2193,    std::shared_ptr< monty::ndarray< int,1 > > _2194){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2193(_2193 ? _2193->raw() : nullptr, _2193 ? _2193->size(0) : 0);
    _checked_ptr_1<int> _ptr__2194(_2194 ? _2194->raw() : nullptr, _2194 ? _2194->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2192,_2193,_2194);
  }
}std::string mosek::fusion::SliceConstraint :: toString() { return mosek::fusion::p_SliceConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_SliceConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2195 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2195->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SliceConstraint()"));
  return _2195->toString();
}
void mosek::fusion::p_SliceConstraint::destroy(){}void mosek::fusion::SliceConstraint::destroy() { mosek::fusion::p_SliceConstraint::_get_impl(this)->destroy(); }mosek::fusion::RangedConstraint::RangedConstraint(mosek::fusion::p_RangedConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "RangedConstraint()" << this << std::endl; */ }mosek::fusion::RangedConstraint::~RangedConstraint() {  /* std::cout << "~RangedConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedConstraint::p_RangedConstraint  (::mosek::fusion::RangedConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2196,    monty::rc_ptr< ::mosek::fusion::Model > _2197){ return new mosek::fusion::RangedConstraint(_2196,_2197); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2196,    monty::rc_ptr< ::mosek::fusion::Model > _2197) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2196,_2197); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2196,    monty::rc_ptr< ::mosek::fusion::Model > _2197){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2196,_2197);
    shape = mosek::fusion::p_RangedConstraint::_get_impl(_2196)->shape;
    nativeidxs = mosek::fusion::p_RangedConstraint::_get_impl(_2196)->nativeidxs;
  }
}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2198,    const std::string &  _2199,    std::shared_ptr< monty::ndarray< int,1 > > _2200,    std::shared_ptr< monty::ndarray< int,1 > > _2201){ return new mosek::fusion::RangedConstraint(_2198,_2199,_2200,_2201); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2198,    const std::string &  _2199,    std::shared_ptr< monty::ndarray< int,1 > > _2200,    std::shared_ptr< monty::ndarray< int,1 > > _2201) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2198,_2199,_2200,_2201); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2198,    const std::string &  _2199,    std::shared_ptr< monty::ndarray< int,1 > > _2200,    std::shared_ptr< monty::ndarray< int,1 > > _2201){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2200(_2200 ? _2200->raw() : nullptr, _2200 ? _2200->size(0) : 0);
    _checked_ptr_1<int> _ptr__2201(_2201 ? _2201->raw() : nullptr, _2201 ? _2201->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2198,_2199,_2200,_2201);
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->shape = _2200;
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->nativeidxs = _2201;
  }
}monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2202){
  return (::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::RangedConstraint::t(_pubthis),_2202)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_RangedConstraint::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::RangedConstraint::destroy() { mosek::fusion::p_RangedConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConicConstraint::ConicConstraint(mosek::fusion::p_ConicConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "ConicConstraint()" << this << std::endl; */ }mosek::fusion::ConicConstraint::~ConicConstraint() {  /* std::cout << "~ConicConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicConstraint::p_ConicConstraint  (::mosek::fusion::ConicConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2203,    monty::rc_ptr< ::mosek::fusion::Model > _2204){ return new mosek::fusion::ConicConstraint(_2203,_2204); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2203,    monty::rc_ptr< ::mosek::fusion::Model > _2204) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2203,_2204); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2203,    monty::rc_ptr< ::mosek::fusion::Model > _2204){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2203,_2204);
    dom = mosek::fusion::p_ConicConstraint::_get_impl(_2203)->dom;
    conid = mosek::fusion::p_ConicConstraint::_get_impl(_2203)->conid;
    shape = mosek::fusion::p_ConicConstraint::_get_impl(_2203)->shape;
    name = mosek::fusion::p_ConicConstraint::_get_impl(_2203)->name;
    nativeidxs = mosek::fusion::p_ConicConstraint::_get_impl(_2203)->nativeidxs;
    nativeslack = mosek::fusion::p_ConicConstraint::_get_impl(_2203)->nativeslack;
    names_flushed = mosek::fusion::p_ConicConstraint::_get_impl(_2203)->names_flushed;
  }
}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2205,    const std::string &  _2206,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2207,    std::shared_ptr< monty::ndarray< int,1 > > _2208,    int _2209,    std::shared_ptr< monty::ndarray< int,1 > > _2210,    std::shared_ptr< monty::ndarray< int,1 > > _2211){ return new mosek::fusion::ConicConstraint(_2205,_2206,_2207,_2208,_2209,_2210,_2211); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2205,    const std::string &  _2206,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2207,    std::shared_ptr< monty::ndarray< int,1 > > _2208,    int _2209,    std::shared_ptr< monty::ndarray< int,1 > > _2210,    std::shared_ptr< monty::ndarray< int,1 > > _2211) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2205,_2206,_2207,_2208,_2209,_2210,_2211); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2205,    const std::string &  _2206,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2207,    std::shared_ptr< monty::ndarray< int,1 > > _2208,    int _2209,    std::shared_ptr< monty::ndarray< int,1 > > _2210,    std::shared_ptr< monty::ndarray< int,1 > > _2211){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2208(_2208 ? _2208->raw() : nullptr, _2208 ? _2208->size(0) : 0);
    _checked_ptr_1<int> _ptr__2210(_2210 ? _2210->raw() : nullptr, _2210 ? _2210->size(0) : 0);
    _checked_ptr_1<int> _ptr__2211(_2211 ? _2211->raw() : nullptr, _2211 ? _2211->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2205,_2206,_2208,_2210);
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->dom = _2207;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->shape = _2208;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->name = _2206;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeidxs = _2210;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeslack = _2211;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->conid = _2209;
    names_flushed = false;
  }
}void mosek::fusion::p_ConicConstraint::flushNames(){
  ::mosek::fusion::p_ModelConstraint::flushNames();
  int _2212 = (int)((nativeslack)->size(0));
  monty::rc_ptr< ::mosek::fusion::Model > _2213 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          int _7813 = (int)0;
          int _7814 = _2212;
          for (int _2214 = _7813; _2214 < _7814; ++_2214)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2213.get())->task_var_name(((*nativeslack)(_2214)),std::string (""));
            }
          }
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2215 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          int _7815 = (int)0;
          int _7816 = _2212;
          for (int _2216 = _7815; _2216 < _7816; ++_2216)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2213.get())->task_var_name(((*nativeslack)(_2216)),_2215->__mosek_2fusion_2Utils_2StringBuffer__clear()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,(long long)(_2216)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("].coneslack"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
std::string mosek::fusion::ConicConstraint :: toString() { return mosek::fusion::p_ConicConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2217 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2217->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2217->toString();
}
void mosek::fusion::p_ConicConstraint::domainToString(long long _2218,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2219){
  throw ::mosek::fusion::UnimplementedError(std::string ("ConicConstraint.domainToString"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_ConicConstraint::__mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2220){
  return (::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::ConicConstraint::t(_pubthis),_2220)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_ConicConstraint::destroy(){nativeslack.reset();nativeidxs.reset();shape.reset();dom.reset();}void mosek::fusion::ConicConstraint::destroy() { mosek::fusion::p_ConicConstraint::_get_impl(this)->destroy(); }mosek::fusion::LinearConstraint::LinearConstraint(mosek::fusion::p_LinearConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearConstraint()" << this << std::endl; */ }mosek::fusion::LinearConstraint::~LinearConstraint() {  /* std::cout << "~LinearConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearConstraint::p_LinearConstraint  (::mosek::fusion::LinearConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2221,    monty::rc_ptr< ::mosek::fusion::Model > _2222){ return new mosek::fusion::LinearConstraint(_2221,_2222); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2221,    monty::rc_ptr< ::mosek::fusion::Model > _2222) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2221,_2222); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2221,    monty::rc_ptr< ::mosek::fusion::Model > _2222){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2221,_2222);
    conid = mosek::fusion::p_LinearConstraint::_get_impl(_2221)->conid;
    name = mosek::fusion::p_LinearConstraint::_get_impl(_2221)->name;
  }
}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2223,    const std::string &  _2224,    int _2225,    std::shared_ptr< monty::ndarray< int,1 > > _2226,    std::shared_ptr< monty::ndarray< int,1 > > _2227){ return new mosek::fusion::LinearConstraint(_2223,_2224,_2225,_2226,_2227); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2223,    const std::string &  _2224,    int _2225,    std::shared_ptr< monty::ndarray< int,1 > > _2226,    std::shared_ptr< monty::ndarray< int,1 > > _2227) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2223,_2224,_2225,_2226,_2227); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2223,    const std::string &  _2224,    int _2225,    std::shared_ptr< monty::ndarray< int,1 > > _2226,    std::shared_ptr< monty::ndarray< int,1 > > _2227){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2226(_2226 ? _2226->raw() : nullptr, _2226 ? _2226->size(0) : 0);
    _checked_ptr_1<int> _ptr__2227(_2227 ? _2227->raw() : nullptr, _2227 ? _2227->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2223,_2224,_2226,_2227);
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->conid = _2225;
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->name = _2224;
  }
}std::string mosek::fusion::LinearConstraint :: toString() { return mosek::fusion::p_LinearConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2228 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2228->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2228->toString();
}
void mosek::fusion::p_LinearConstraint::domainToString(long long _2229,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2230){
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearConstraint::__mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2231){
  return (::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::LinearConstraint::t(_pubthis),_2231)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearConstraint::destroy(){}void mosek::fusion::LinearConstraint::destroy() { mosek::fusion::p_LinearConstraint::_get_impl(this)->destroy(); }mosek::fusion::ModelConstraint::ModelConstraint(mosek::fusion::p_ModelConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "ModelConstraint()" << this << std::endl; */ }mosek::fusion::ModelConstraint::~ModelConstraint() {  /* std::cout << "~ModelConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelConstraint::p_ModelConstraint  (::mosek::fusion::ModelConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2232,    monty::rc_ptr< ::mosek::fusion::Model > _2233){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2232,_2233);
    name = mosek::fusion::p_ModelConstraint::_get_impl(_2232)->name;
    names_flushed = mosek::fusion::p_ModelConstraint::_get_impl(_2232)->names_flushed;
    nativeidxs = mosek::fusion::p_ModelConstraint::_get_impl(_2232)->nativeidxs;
    shape = mosek::fusion::p_ModelConstraint::_get_impl(_2232)->shape;
  }
}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2234,    const std::string &  _2235,    std::shared_ptr< monty::ndarray< int,1 > > _2236,    std::shared_ptr< monty::ndarray< int,1 > > _2237){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2236(_2236 ? _2236->raw() : nullptr, _2236 ? _2236->size(0) : 0);
    _checked_ptr_1<int> _ptr__2237(_2237 ? _2237->raw() : nullptr, _2237 ? _2237->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2234,_2236,_2237);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->name = _2235;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->nativeidxs = _2237;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->shape = _2236;
  }
}std::string mosek::fusion::ModelConstraint :: toString() { return mosek::fusion::p_ModelConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ModelConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2238 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2238->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2238->toString();
}
void mosek::fusion::p_ModelConstraint::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _2239 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if ((!names_flushed))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          mosek::fusion::p_Model::_get_impl(_2239.get())->connames(nativeidxs,std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_pubthis->getSize())}),std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2240 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          _2240->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
          if ((_pubthis->getND() > (int)0))
          {
            {
              _2240->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
              int _7817 = (int)1;
              int _7818 = _pubthis->getND();
              for (int _2241 = _7817; _2241 < _7818; ++_2241)
              {
                {
                  _2240->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2241);
                }
              }
            }
          }
          {}
          _2240->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
          std::shared_ptr< monty::ndarray< int,1 > > _7819;
          bool _7820 = (_pubthis->getND() > (int)0);
          if (_7820)
          {
            _7819 = _pubthis->getShape();
          }
          else
          {
            _7819 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
          }
          mosek::fusion::p_Model::_get_impl(_2239.get())->connames(nativeidxs,_2240->toString(),_7819,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
          names_flushed = true;
        }
      }
    }
  }
  {}
}
void mosek::fusion::p_ModelConstraint::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::ModelConstraint::destroy() { mosek::fusion::p_ModelConstraint::_get_impl(this)->destroy(); }mosek::fusion::Constraint::Constraint(mosek::fusion::p_Constraint *_impl) : _impl(_impl) { /*std::cout << "Constraint() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Constraint::~Constraint() { delete _impl; _impl = nullptr; }mosek::fusion::p_Constraint::p_Constraint  (::mosek::fusion::Constraint * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Constraint > _2243,    monty::rc_ptr< ::mosek::fusion::Model > _2244){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _2244;
    shape = mosek::fusion::p_Constraint::_get_impl(_2243)->shape;
    nativeidxs = mosek::fusion::p_Constraint::_get_impl(_2243)->nativeidxs;
  }
}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2245,    std::shared_ptr< monty::ndarray< int,1 > > _2246,    std::shared_ptr< monty::ndarray< int,1 > > _2247){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2246(_2246 ? _2246->raw() : nullptr, _2246 ? _2246->size(0) : 0);
    _checked_ptr_1<int> _ptr__2247(_2247 ? _2247->raw() : nullptr, _2247 ? _2247->size(0) : 0);
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->model = _2245;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->shape = _2246;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->nativeidxs = _2247;
  }
}std::string mosek::fusion::Constraint :: toString() { return mosek::fusion::p_Constraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_Constraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("Constraint.toString"));
}
void mosek::fusion::p_Constraint::toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2248,long long _2249,std::shared_ptr< monty::ndarray< std::string,1 > > _2250){
  _checked_ptr_1<long long> _ptr__2248(_2248 ? _2248->raw() : nullptr, _2248 ? _2248->size(0) : 0);
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: dual() { return mosek::fusion::p_Constraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2251 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2251(_2251 ? _2251->raw() : nullptr,_2251 ? _2251->size(0) : 0);
  values(false,(int)0,_2251);
  return _2251;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: level() { return mosek::fusion::p_Constraint::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2252 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2252(_2252 ? _2252->raw() : nullptr,_2252 ? _2252->size(0) : 0);
  values(true,(int)0,_2252);
  return _2252;
}
void mosek::fusion::p_Constraint::values(bool _2253,int _2254,std::shared_ptr< monty::ndarray< double,1 > > _2255){
  _checked_ptr_1<double> _ptr__2255(_2255 ? _2255->raw() : nullptr, _2255 ? _2255->size(0) : 0);
  model->getConstraintValues(_2253,nativeidxs,_2255,_2254);
}
void mosek::fusion::Constraint :: update(std::shared_ptr< monty::ndarray< double,1 > > _2256) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2256); }void mosek::fusion::p_Constraint::update(std::shared_ptr< monty::ndarray< double,1 > > _2256){
  _checked_ptr_1<double> _ptr__2256(_2256 ? _2256->raw() : nullptr, _2256 ? _2256->size(0) : 0);
  mosek::fusion::p_Model::_get_impl(model.get())->update_bfix(nativeidxs,_2256);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2257) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2257); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2257){
  std::shared_ptr< monty::ndarray< int,1 > > _2258 = _2257->getShape();
  _checked_ptr_1<int> _ptr__2258(_2258 ? _2258->raw() : nullptr,_2258 ? _2258->size(0) : 0);
  if (((int)((shape)->size(0)) < (int)((_2258)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7821 = (int)0;
  int _7822 = (int)((_2258)->size(0));
  for (int _2259 = _7821; _2259 < _7822; ++_2259)
  {
    {
      if ((_ptr__2258[_2259] != ((*shape)(_2259))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7823 = (int)((_2258)->size(0));
  int _7824 = (int)((shape)->size(0));
  for (int _2260 = _7823; _2260 < _7824; ++_2260)
  {
    {
      if ((((*shape)(_2260)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2257);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2261,monty::rc_ptr< ::mosek::fusion::Variable > _2262,bool _2263) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2261,_2262,_2263); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2261,monty::rc_ptr< ::mosek::fusion::Variable > _2262,bool _2263){
  int _2264 = _pubthis->getND();
  std::shared_ptr< monty::ndarray< int,1 > > _2265 = _2261->getShape();
  _checked_ptr_1<int> _ptr__2265(_2265 ? _2265->raw() : nullptr,_2265 ? _2265->size(0) : 0);
  if ((_2264 < (int)((_2265)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7825 = (int)0;
  int _7826 = (int)((_2265)->size(0));
  for (int _2266 = _7825; _2266 < _7826; ++_2266)
  {
    {
      if ((_ptr__2265[_2266] != ((*shape)(_2266))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7827 = (int)((_2265)->size(0));
  int _7828 = (int)((shape)->size(0));
  for (int _2267 = _7827; _2267 < _7828; ++_2267)
  {
    {
      if ((((*shape)(_2267)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _2268 = _2262->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2269 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2268)));
  _checked_ptr_1<long long> _ptr__2269(_2269 ? _2269->raw() : nullptr,_2269 ? _2269->size(0) : 0);
  if ((_2268 < _2262->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2270 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2268)));
      _checked_ptr_1<long long> _ptr__2270(_2270 ? _2270->raw() : nullptr,_2270 ? _2270->size(0) : 0);
      _2262->inst((int)0,_2270,(int)0,_2269);
    }
  }
  else
  {
    {
      _2262->inst((int)0,_2269);
    }
  }
  int _7829 = (int)0;
  int _7830 = _2268;
  for (int _2271 = _7829; _2271 < _7830; ++_2271)
  {
    {
      if ((_ptr__2269[_2271] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2272;
  _checked_ptr_1<int> _ptr__2272(_2272 ? _2272->raw() : nullptr,_2272 ? _2272->size(0) : 0);
  {
    bool _2273 = true;
    int _7831 = (int)0;
    int _7832 = (_2268 - (int)1);
    for (int _2274 = _7831; _2274 < _7832; ++_2274)
    {
      {
        _2273 = (_2273 && (_ptr__2269[_2274] < _ptr__2269[safe_add( _2274,(int)1 )]));
      }
    }
    if (_2273)
    {
      {
        std::vector<int> _7833;
        for (int _2275 = (int)0, _7834 = _2268; _2275 < _7834 ; ++_2275)
        {
          _7833.push_back((int)(_ptr__2269[_2275] - (int)1));
        }
        auto _7835 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7833.size()),_7833.begin(),_7833.end()));
        _2272 = _7835;
        _ptr__2272.update(_2272 ? _2272->raw() : nullptr, _2272 ? _2272->size(0) : 0);
      }
    }
    else
    {
      {
        std::vector<long long> _7836;
        for (int _2277 = (int)0, _7837 = _2268; _2277 < _7837 ; ++_2277)
        {
          _7836.push_back(_2277);
        }
        auto _7838 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7836.size()),_7836.begin(),_7836.end()));
        std::shared_ptr< monty::ndarray< long long,1 > > _2276 = _7838;
        _checked_ptr_1<long long> _ptr__2276(_2276 ? _2276->raw() : nullptr,_2276 ? _2276->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_2276,_2269,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2268));
        int _2278 = (int)1;
        int _7839 = (int)1;
        int _7840 = _2268;
        for (int _2279 = _7839; _2279 < _7840; ++_2279)
        {
          {
            if ((_ptr__2269[_ptr__2276[(_2279 - (int)1)]] < _ptr__2269[_ptr__2276[_2279]]))
            {
              {
                ++ _2278;
              }
            }
            {}
          }
        }
        _2272 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2278)));
        _ptr__2272.update(_2272 ? _2272->raw() : nullptr, _2272 ? _2272->size(0) : 0);
        int _2280 = (int)0;
        _ptr__2272[(int)0] = (int)(_ptr__2269[_ptr__2276[(int)0]] - (int)1);
        int _7841 = (int)1;
        int _7842 = _2268;
        for (int _2281 = _7841; _2281 < _7842; ++_2281)
        {
          {
            if ((_ptr__2269[(_2281 - (int)1)] < _ptr__2269[_2281]))
            {
              {
                _ptr__2272[_2280] = (int)(_ptr__2269[_ptr__2276[_2281]] - (int)1);
                ++ _2280;
              }
            }
            {}
          }
        }
      }
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2261,_2272,_2263);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2282,monty::rc_ptr< ::mosek::fusion::Variable > _2283) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2282,_2283); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2282,monty::rc_ptr< ::mosek::fusion::Variable > _2283){
  _pubthis->update(_2282,_2283,false);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__get_model() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__get_model(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::get_model() { return __mosek_2fusion_2Constraint__get_model(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__get_model(){
  return model;
}
int mosek::fusion::Constraint :: get_nd() { return mosek::fusion::p_Constraint::_get_impl(this)->get_nd(); }int mosek::fusion::p_Constraint::get_nd(){
  return (int)((shape)->size(0));
}
long long mosek::fusion::Constraint :: size() { return mosek::fusion::p_Constraint::_get_impl(this)->size(); }long long mosek::fusion::p_Constraint::size(){
  long long _2284 = (int)1;
  int _7843 = (int)0;
  int _7844 = (int)((shape)->size(0));
  for (int _2285 = _7843; _2285 < _7844; ++_2285)
  {
    {
      _2284 *= ((*shape)(_2285));
    }
  }
  return _2284;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2286,    int _2287) { return mosek::fusion::p_Constraint::stack(_2286,_2287); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2286,int _2287){
  return ::mosek::fusion::p_Constraint::dstack(_2286,_2287);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2288,    monty::rc_ptr< ::mosek::fusion::Constraint > _2289,    monty::rc_ptr< ::mosek::fusion::Constraint > _2290,    int _2291) { return mosek::fusion::p_Constraint::stack(_2288,_2289,_2290,_2291); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2288,monty::rc_ptr< ::mosek::fusion::Constraint > _2289,monty::rc_ptr< ::mosek::fusion::Constraint > _2290,int _2291){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2288.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2289.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2290.get())}),_2291);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2292,    monty::rc_ptr< ::mosek::fusion::Constraint > _2293,    int _2294) { return mosek::fusion::p_Constraint::stack(_2292,_2293,_2294); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2292,monty::rc_ptr< ::mosek::fusion::Constraint > _2293,int _2294){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2292.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2293.get())}),_2294);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2295) { return mosek::fusion::p_Constraint::hstack(_2295); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2295){
  return ::mosek::fusion::p_Constraint::dstack(_2295,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2296) { return mosek::fusion::p_Constraint::vstack(_2296); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2296){
  return ::mosek::fusion::p_Constraint::dstack(_2296,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2297,    monty::rc_ptr< ::mosek::fusion::Constraint > _2298,    monty::rc_ptr< ::mosek::fusion::Constraint > _2299) { return mosek::fusion::p_Constraint::hstack(_2297,_2298,_2299); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2297,monty::rc_ptr< ::mosek::fusion::Constraint > _2298,monty::rc_ptr< ::mosek::fusion::Constraint > _2299){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2297.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2298.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2299.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2300,    monty::rc_ptr< ::mosek::fusion::Constraint > _2301,    monty::rc_ptr< ::mosek::fusion::Constraint > _2302) { return mosek::fusion::p_Constraint::vstack(_2300,_2301,_2302); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2300,monty::rc_ptr< ::mosek::fusion::Constraint > _2301,monty::rc_ptr< ::mosek::fusion::Constraint > _2302){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2300.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2301.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2302.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2303,    monty::rc_ptr< ::mosek::fusion::Constraint > _2304) { return mosek::fusion::p_Constraint::hstack(_2303,_2304); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2303,monty::rc_ptr< ::mosek::fusion::Constraint > _2304){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2303.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2304.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2305,    monty::rc_ptr< ::mosek::fusion::Constraint > _2306) { return mosek::fusion::p_Constraint::vstack(_2305,_2306); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2305,monty::rc_ptr< ::mosek::fusion::Constraint > _2306){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2305.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2306.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2307,int _2308){
  monty::rc_ptr< ::mosek::fusion::Model > _2309 = nullptr;
  {
    int _7845 = (int)0;
    int _7846 = (int)((_2307)->size(0));
    for (int _2310 = _7845; _2310 < _7846; ++_2310)
    {
      {
        if ((NULL == _2309.get()))
        {
          {
            _2309 = ((*_2307)(_2310))->__mosek_2fusion_2Constraint__getModel();
          }
        }
        else if(((NULL != mosek::fusion::p_Constraint::_get_impl(((*_2307)(_2310)))->model.get()) && (mosek::fusion::p_Constraint::_get_impl(((*_2307)(_2310)))->model != _2309)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2311 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7847;
            bool _7848 = ((int)((mosek::fusion::p_Model::_get_impl(_2309.get())->getName()).size()) > (int)0);
            if (_7848)
            {
              _7847 = mosek::fusion::p_Model::_get_impl(_2309.get())->getName();
            }
            else
            {
              _7847 = std::string ("?");
            }
            std::string _2312 = _7847;
            std::string _7849;
            bool _7850 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2307)(_2310))->__mosek_2fusion_2Constraint__getModel().get())->getName()).size()) > (int)0);
            if (_7850)
            {
              _7849 = mosek::fusion::p_Model::_get_impl(((*_2307)(_2310))->__mosek_2fusion_2Constraint__getModel().get())->getName();
            }
            else
            {
              _7849 = std::string ("?");
            }
            std::string _2313 = _7849;
            _2311->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraints belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2312)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2313)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2311->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2307)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
    }
  }
  else if(((int)((_2307)->size(0)) == (int)1))
  {
    {
      return ((*_2307)((int)1));
    }
  }
  else
  {
    {
      int _2314 = (int)((_2307)->size(0));
      int _2315 = (int)1;
      int _7851 = (int)0;
      int _7852 = _2314;
      for (int _2316 = _7851; _2316 < _7852; ++_2316)
      {
        {
          int _7853;
          bool _7854 = (((*_2307)(_2316))->getND() > _2315);
          if (_7854)
          {
            _7853 = ((*_2307)(_2316))->getND();
          }
          else
          {
            _7853 = _2315;
          }
          _2315 = _7853;
        }
      }
      if ((_2308 == _2315))
      {
        {
          ++ _2315;
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,2 > > _2317 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2314,_2315)));
      int _7855 = (int)0;
      int _7856 = _2314;
      for (int _2318 = _7855; _2318 < _7856; ++_2318)
      {
        {
          int _7857 = (int)0;
          int _7858 = _2315;
          for (int _2319 = _7857; _2319 < _7858; ++_2319)
          {
            {
              ((*_2317)(_2318,_2319)) = (int)1;
            }
          }
        }
      }
      std::vector<int> _7859;
      for (int _2321 = (int)0, _7860 = _2314; _2321 < _7860 ; ++_2321)
      {
        _7859.push_back(((*_2307)(_2321))->getSize());
      }
      auto _7861 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7859.size()),_7859.begin(),_7859.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2320 = _7861;
      _checked_ptr_1<int> _ptr__2320(_2320 ? _2320->raw() : nullptr,_2320 ? _2320->size(0) : 0);
      int _2322 = (int)0;
      int _7862 = (int)0;
      int _7863 = _2314;
      for (int _2323 = _7862; _2323 < _7863; ++_2323)
      {
        {
          _2322 += _ptr__2320[_2323];
        }
      }
      int _7864 = (int)0;
      int _7865 = _2314;
      for (int _2324 = _7864; _2324 < _7865; ++_2324)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2325 = ((*_2307)(_2324))->getShape();
          _checked_ptr_1<int> _ptr__2325(_2325 ? _2325->raw() : nullptr,_2325 ? _2325->size(0) : 0);
          int _7866 = (int)0;
          int _7867 = (int)((_2325)->size(0));
          for (int _2326 = _7866; _2326 < _7867; ++_2326)
          {
            {
              ((*_2317)(_2324,_2326)) = _ptr__2325[_2326];
            }
          }
        }
      }
      if (((_2308 < (int)0) || (_2308 > _2315)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      int _7868 = (int)0;
      int _7869 = _2308;
      for (int _2327 = _7868; _2327 < _7869; ++_2327)
      {
        {
          int _7870 = (int)1;
          int _7871 = _2314;
          for (int _2328 = _7870; _2328 < _7871; ++_2328)
          {
            {
              if ((((*_2317)((int)0,_2327)) != ((*_2317)(_2328,_2327))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      int _7872 = safe_add( _2308,(int)1 );
      int _7873 = _2315;
      for (int _2329 = _7872; _2329 < _7873; ++_2329)
      {
        {
          int _7874 = (int)1;
          int _7875 = _2314;
          for (int _2330 = _7874; _2330 < _7875; ++_2330)
          {
            {
              if ((((*_2317)((int)0,_2329)) != ((*_2317)(_2330,_2329))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2331 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2322)));
      _checked_ptr_1<int> _ptr__2331(_2331 ? _2331->raw() : nullptr,_2331 ? _2331->size(0) : 0);
      std::vector<int> _7876;
      for (int _2333 = (int)0, _7877 = _2315; _2333 < _7877 ; ++_2333)
      {
        _7876.push_back(((*_2317)((int)0,_2333)));
      }
      auto _7878 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7876.size()),_7876.begin(),_7876.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2332 = _7878;
      _checked_ptr_1<int> _ptr__2332(_2332 ? _2332->raw() : nullptr,_2332 ? _2332->size(0) : 0);
      int _7879 = (int)0;
      int _7880 = _2315;
      for (int _2334 = _7879; _2334 < _7880; ++_2334)
      {
        {
          _ptr__2332[_2308] += ((*_2317)(_2334,_2308));
        }
      }
      {
        int _2335 = (int)((_2332)->size(0));
        std::shared_ptr< monty::ndarray< long long,1 > > _2336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( (int)((_2307)->size(0)),(int)1 ))));
        _checked_ptr_1<long long> _ptr__2336(_2336 ? _2336->raw() : nullptr,_2336 ? _2336->size(0) : 0);
        int _7881 = (int)0;
        int _7882 = (int)((_2307)->size(0));
        for (int _2337 = _7881; _2337 < _7882; ++_2337)
        {
          {
            _ptr__2336[safe_add( _2337,(int)1 )] = safe_add( _ptr__2336[_2337],((*_2317)(_2337,_2308)) );
          }
        }
        if ((_2308 == (int)0))
        {
          {
            int _2338 = (int)0;
            int _7883 = (int)0;
            int _7884 = _2314;
            for (int _2339 = _7883; _2339 < _7884; ++_2339)
            {
              {
                int _2340 = (int)((mosek::fusion::p_Constraint::_get_impl(((*_2307)(_2339)))->nativeidxs)->size(0));
                ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Constraint::_get_impl(((*_2307)(_2339)))->nativeidxs,(int)0,_2331,_2338,_2340);
                _2338 += _2340;
              }
            }
          }
        }
        else
        {
          {
            std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7885;
            for (int _2342 = (int)0, _7886 = _2314; _2342 < _7886 ; ++_2342)
            {
              _7885.push_back(mosek::fusion::p_Constraint::_get_impl(((*_2307)(_2342)))->nativeidxs);
            }
            auto _7887 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7885.size()),_7885.begin(),_7885.end()));
            std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2341 = _7887;
            if ((_2308 < _2315))
            {
              {
                int _2343 = (int)1;
                int _7888 = (int)0;
                int _7889 = _2308;
                for (int _2344 = _7888; _2344 < _7889; ++_2344)
                {
                  {
                    _2343 *= _ptr__2332[_2344];
                  }
                }
                int _2345 = (int)1;
                int _7890 = safe_add( _2308,(int)1 );
                int _7891 = _2315;
                for (int _2346 = _7890; _2346 < _7891; ++_2346)
                {
                  {
                    _2345 *= _ptr__2332[_2346];
                  }
                }
                int _2347 = (int)0;
                int _7892 = (int)0;
                int _7893 = _2343;
                for (int _2348 = _7892; _2348 < _7893; ++_2348)
                {
                  {
                    int _7894 = (int)0;
                    int _7895 = _2314;
                    for (int _2349 = _7894; _2349 < _7895; ++_2349)
                    {
                      {
                        int _2350 = (int)0;
                        int _2351 = ((*_2317)(_2349,_2308));
                        int _7896 = (int)0;
                        int _7897 = _2351;
                        for (int _2352 = _7896; _2352 < _7897; ++_2352)
                        {
                          {
                            int _7898 = (int)0;
                            int _7899 = _2345;
                            for (int _2353 = _7898; _2353 < _7899; ++_2353)
                            {
                              {
                                _ptr__2331[_2347] = ((*mosek::fusion::p_Constraint::_get_impl(((*_2307)(_2314)))->nativeidxs)(safe_add( safe_mul( safe_mul( _2348,_2345 ),_2351 ),_2350 )));
                                ++ _2347;
                                ++ _2350;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            else
            {
              {
                int _2354 = (int)1;
                int _7900 = (int)0;
                int _7901 = _2315;
                for (int _2355 = _7900; _2355 < _7901; ++_2355)
                {
                  {
                    _2354 *= _ptr__2332[_2355];
                  }
                }
                int _2356 = (int)0;
                int _7902 = (int)0;
                int _7903 = _2354;
                for (int _2357 = _7902; _2357 < _7903; ++_2357)
                {
                  {
                    int _7904 = (int)0;
                    int _7905 = _2314;
                    for (int _2358 = _7904; _2358 < _7905; ++_2358)
                    {
                      {
                        _ptr__2331[_2356] = ((*((*_2341)(_2358)))(_2357));
                        ++ _2356;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_2309,_2332,_2331)).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2359) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2359); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2359) { return __mosek_2fusion_2Constraint__index(_2359); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2359){
  _checked_ptr_1<int> _ptr__2359(_2359 ? _2359->raw() : nullptr, _2359 ? _2359->size(0) : 0);
  if (((int)((_2359)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7906 = (int)0;
      int _7907 = (int)((shape)->size(0));
      for (int _2360 = _7906; _2360 < _7907; ++_2360)
      {
        {
          if (((_ptr__2359[_2360] < (int)0) || (_ptr__2359[_2360] > ((*shape)(_2360)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("index is out of bounds"));
            }
          }
          {}
        }
      }
      int _2361 = (int)((shape)->size(0));
      std::shared_ptr< monty::ndarray< long long,1 > > _2362 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2361)));
      _checked_ptr_1<long long> _ptr__2362(_2362 ? _2362->raw() : nullptr,_2362 ? _2362->size(0) : 0);
      _ptr__2362[(_2361 - (int)1)] = (int)1;
      int _7908 = (int)1;
      int _7909 = _2361;
      for (int _2363 = _7908; _2363 < _7909; ++_2363)
      {
        {
          _ptr__2362[((_2361 - _2363) - (int)1)] = safe_mul( _ptr__2362[(_2361 - _2363)],((*shape)(_2363)) );
        }
      }
      int _2364 = (int)0;
      int _7910 = (int)0;
      int _7911 = _2361;
      for (int _2365 = _7910; _2365 < _7911; ++_2365)
      {
        {
          _2364 += (int)safe_mul( _ptr__2362[_2365],_ptr__2359[_2365] );
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2364)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(int _2366) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2366); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(int _2366) { return __mosek_2fusion_2Constraint__index(_2366); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(int _2366){
  if ((((int)((shape)->size(0)) == (int)0) && (_2366 == (int)0)))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else if(((_2366 < (int)0) || (_2366 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index is out of bounds"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2366)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2367,std::shared_ptr< monty::ndarray< int,1 > > _2368) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2367,_2368); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2367,std::shared_ptr< monty::ndarray< int,1 > > _2368) { return __mosek_2fusion_2Constraint__slice(_2367,_2368); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2367,std::shared_ptr< monty::ndarray< int,1 > > _2368){
  _checked_ptr_1<int> _ptr__2367(_2367 ? _2367->raw() : nullptr, _2367 ? _2367->size(0) : 0);
  _checked_ptr_1<int> _ptr__2368(_2368 ? _2368->raw() : nullptr, _2368 ? _2368->size(0) : 0);
  if (((int)((_2367)->size(0)) != (int)((_2368)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
    }
  }
  else if(((int)((_2367)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7912 = (int)0;
      int _7913 = (int)((shape)->size(0));
      for (int _2369 = _7912; _2369 < _7913; ++_2369)
      {
        {
          if (((_ptr__2367[_2369] < (int)0) || (_ptr__2368[_2369] > ((*shape)(_2369)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("slice is out of bounds"));
            }
          }
          else if((_ptr__2367[_2369] > _ptr__2368[_2369]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
            }
          }
          {}
        }
      }
      int _2370 = (int)((shape)->size(0));
      std::vector<int> _7914;
      for (int _2372 = (int)0, _7915 = _2370; _2372 < _7915 ; ++_2372)
      {
        _7914.push_back((_ptr__2368[_2372] - _ptr__2367[_2372]));
      }
      auto _7916 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7914.size()),_7914.begin(),_7914.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2371 = _7916;
      _checked_ptr_1<int> _ptr__2371(_2371 ? _2371->raw() : nullptr,_2371 ? _2371->size(0) : 0);
      int _2373 = (int)1;
      int _7917 = (int)0;
      int _7918 = _2370;
      for (int _2374 = _7917; _2374 < _7918; ++_2374)
      {
        {
          _2373 *= (_ptr__2368[_2374] - _ptr__2367[_2374]);
        }
      }
      if ((_2373 == (int)0))
      {
        {
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,_2371,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2375 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2373)));
          _checked_ptr_1<int> _ptr__2375(_2375 ? _2375->raw() : nullptr,_2375 ? _2375->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2376 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2370)));
            _checked_ptr_1<int> _ptr__2376(_2376 ? _2376->raw() : nullptr,_2376 ? _2376->size(0) : 0);
            _ptr__2376[(_2370 - (int)1)] = (int)1;
            int _7919 = (int)1;
            int _7920 = _2370;
            for (int _2377 = _7919; _2377 < _7920; ++_2377)
            {
              {
                _ptr__2376[((_2370 - _2377) - (int)1)] = safe_mul( _ptr__2376[(_2370 - _2377)],((*shape)((_2370 - _2377))) );
              }
            }
            int _2378 = (int)0;
            int _7921 = (int)0;
            int _7922 = _2370;
            for (int _2379 = _7921; _2379 < _7922; ++_2379)
            {
              {
                _2378 += safe_mul( _ptr__2367[_2379],_ptr__2376[_2379] );
              }
            }
            std::vector<int> _7923;
            for (int _2381 = (int)0, _7924 = _2370; _2381 < _7924 ; ++_2381)
            {
              _7923.push_back(_2378);
            }
            auto _7925 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7923.size()),_7923.begin(),_7923.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2380 = _7925;
            _checked_ptr_1<int> _ptr__2380(_2380 ? _2380->raw() : nullptr,_2380 ? _2380->size(0) : 0);
            std::vector<int> _7926;
            for (int _2383 = (int)0, _7927 = _2370; _2383 < _7927 ; ++_2383)
            {
              _7926.push_back(_ptr__2367[_2383]);
            }
            auto _7928 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7926.size()),_7926.begin(),_7926.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2382 = _7928;
            _checked_ptr_1<int> _ptr__2382(_2382 ? _2382->raw() : nullptr,_2382 ? _2382->size(0) : 0);
            int _7929 = (int)0;
            int _7930 = _2373;
            for (int _2384 = _7929; _2384 < _7930; ++_2384)
            {
              {
                _ptr__2375[_2384] = ((*nativeidxs)(_ptr__2380[(_2370 - (int)1)]));
                _ptr__2382[(_2370 - (int)1)] += (int)1;
                _ptr__2380[(_2370 - (int)1)] += _ptr__2376[(_2370 - (int)1)];
                if ((_ptr__2382[(_2370 - (int)1)] >= _ptr__2368[(_2370 - (int)1)]))
                {
                  {
                    int _2385 = (_2370 - (int)1);
                    while ( ((_2385 > (int)0) && (_ptr__2382[_2385] >= _ptr__2368[_2385])) )
                    {
                      {
                        _ptr__2382[_2385] = _ptr__2367[_2385];
                        _ptr__2382[(_2385 - (int)1)] += (int)1;
                        _ptr__2380[(_2385 - (int)1)] += _ptr__2376[(_2385 - (int)1)];
                        -- _2385;
                      }
                    }
                    int _7931 = safe_add( _2385,(int)1 );
                    int _7932 = _2370;
                    for (int _2386 = _7931; _2386 < _7932; ++_2386)
                    {
                      {
                        _ptr__2380[_2386] = _ptr__2380[_2385];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),_2371,_2375)).as<::mosek::fusion::Constraint>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(int _2387,int _2388) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2387,_2388); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(int _2387,int _2388) { return __mosek_2fusion_2Constraint__slice(_2387,_2388); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(int _2387,int _2388){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2387 == (int)0) && (_2388 == ((*shape)((int)0)))))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((_2387 < (int)0) || (_2388 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2387 > _2388))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else
  {
    {
      std::vector<int> _7933;
      for (int _2389 = _2387, _7934 = _2388; _2389 < _7934 ; ++_2389)
      {
        _7933.push_back(((*nativeidxs)(_2389)));
      }
      auto _7935 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7933.size()),_7933.begin(),_7933.end()));
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_2388 - _2387))}),_7935)).as<::mosek::fusion::Constraint>();
    }
  }
}
int mosek::fusion::Constraint :: getND() { return mosek::fusion::p_Constraint::_get_impl(this)->getND(); }int mosek::fusion::p_Constraint::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::Constraint :: getSize() { return mosek::fusion::p_Constraint::_get_impl(this)->getSize(); }int mosek::fusion::p_Constraint::getSize(){
  int _2390 = (int)1;
  int _7936 = (int)0;
  int _7937 = (int)((shape)->size(0));
  for (int _2391 = _7936; _2391 < _7937; ++_2391)
  {
    {
      _2390 *= ((*shape)(_2391));
    }
  }
  return _2390;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__getModel() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::getModel() { return __mosek_2fusion_2Constraint__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__getModel(){
  return model;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Constraint :: getShape() { return mosek::fusion::p_Constraint::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getShape(){
  std::vector<int> _7938;
  for (int _2392 = (int)0, _7939 = (int)((shape)->size(0)); _2392 < _7939 ; ++_2392)
  {
    _7938.push_back(((*shape)(_2392)));
  }
  auto _7940 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7938.size()),_7938.begin(),_7938.end()));
  return _7940;
}
void mosek::fusion::p_Constraint::destroy(){nativeidxs.reset();shape.reset();model.reset();}void mosek::fusion::Constraint::destroy() { mosek::fusion::p_Constraint::_get_impl(this)->destroy(); }mosek::fusion::Set::Set(mosek::fusion::p_Set *_impl) : _impl(_impl) { /*std::cout << "Set() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Set::~Set() { delete _impl; _impl = nullptr; }mosek::fusion::p_Set::p_Set  (::mosek::fusion::Set * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::Set::size  ( std::shared_ptr< monty::ndarray< int,1 > > _2393) { return mosek::fusion::p_Set::size(_2393); }long long mosek::fusion::p_Set::size(std::shared_ptr< monty::ndarray< int,1 > > _2393){
  _checked_ptr_1<int> _ptr__2393(_2393 ? _2393->raw() : nullptr, _2393 ? _2393->size(0) : 0);
  long long _2394 = (long long)1;
  int _7941 = (int)0;
  int _7942 = (int)((_2393)->size(0));
  for (int _2395 = _7941; _2395 < _7942; ++_2395)
  {
    {
      _2394 *= _ptr__2393[_2395];
    }
  }
  return _2394;
}
bool mosek::fusion::Set::match  ( std::shared_ptr< monty::ndarray< int,1 > > _2396,    std::shared_ptr< monty::ndarray< int,1 > > _2397) { return mosek::fusion::p_Set::match(_2396,_2397); }bool mosek::fusion::p_Set::match(std::shared_ptr< monty::ndarray< int,1 > > _2396,std::shared_ptr< monty::ndarray< int,1 > > _2397){
  _checked_ptr_1<int> _ptr__2396(_2396 ? _2396->raw() : nullptr, _2396 ? _2396->size(0) : 0);
  _checked_ptr_1<int> _ptr__2397(_2397 ? _2397->raw() : nullptr, _2397 ? _2397->size(0) : 0);
  if (((int)((_2396)->size(0)) != (int)((_2397)->size(0))))
  {
    {
      return false;
    }
  }
  {}
  int _7943 = (int)0;
  int _7944 = (int)((_2396)->size(0));
  for (int _2398 = _7943; _2398 < _7944; ++_2398)
  {
    {
      if ((_ptr__2396[_2398] != _ptr__2397[_2398]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
long long mosek::fusion::Set::linearidx  ( std::shared_ptr< monty::ndarray< int,1 > > _2399,    std::shared_ptr< monty::ndarray< int,1 > > _2400) { return mosek::fusion::p_Set::linearidx(_2399,_2400); }long long mosek::fusion::p_Set::linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2399,std::shared_ptr< monty::ndarray< int,1 > > _2400){
  _checked_ptr_1<int> _ptr__2399(_2399 ? _2399->raw() : nullptr, _2399 ? _2399->size(0) : 0);
  _checked_ptr_1<int> _ptr__2400(_2400 ? _2400->raw() : nullptr, _2400 ? _2400->size(0) : 0);
  long long _2401 = _ptr__2400[(int)0];
  int _7945 = (int)1;
  int _7946 = (int)((_2400)->size(0));
  for (int _2402 = _7945; _2402 < _7946; ++_2402)
  {
    {
      _2401 = safe_add( safe_mul( _2401,_ptr__2399[_2402] ),_ptr__2400[_2402] );
    }
  }
  return _2401;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2403,    long long _2404) { return mosek::fusion::p_Set::idxtokey(_2403,_2404); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2403,long long _2404){
  _checked_ptr_1<int> _ptr__2403(_2403 ? _2403->raw() : nullptr, _2403 ? _2403->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2405 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_2403)->size(0)))));
  _checked_ptr_1<int> _ptr__2405(_2405 ? _2405->raw() : nullptr,_2405 ? _2405->size(0) : 0);
  ::mosek::fusion::p_Set::idxtokey(_2403,_2404,_2405);
  return _2405;
}
void mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2406,    long long _2407,    std::shared_ptr< monty::ndarray< int,1 > > _2408) { mosek::fusion::p_Set::idxtokey(_2406,_2407,_2408); }void mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2406,long long _2407,std::shared_ptr< monty::ndarray< int,1 > > _2408){
  _checked_ptr_1<int> _ptr__2406(_2406 ? _2406->raw() : nullptr, _2406 ? _2406->size(0) : 0);
  _checked_ptr_1<int> _ptr__2408(_2408 ? _2408->raw() : nullptr, _2408 ? _2408->size(0) : 0);
  int _2409 = (int)((_2406)->size(0));
  if ((_2409 > (int)0))
  {
    {
      long long _2410 = _2407;
      int _7947 = (int)0;
      int _7948 = (_2409 - (int)1);
      for (int _2411 = _7947; _2411 < _7948; ++_2411)
      {
        {
          _ptr__2408[((_2409 - _2411) - (int)1)] = (int)(_2410 % _ptr__2406[((_2409 - _2411) - (int)1)]);
          _2410 /= _ptr__2406[((_2409 - _2411) - (int)1)];
        }
      }
      _ptr__2408[(int)0] = (int)_2410;
    }
  }
  {}
}
std::string mosek::fusion::Set::indexToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2412,    long long _2413) { return mosek::fusion::p_Set::indexToString(_2412,_2413); }std::string mosek::fusion::p_Set::indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2412,long long _2413){
  _checked_ptr_1<int> _ptr__2412(_2412 ? _2412->raw() : nullptr, _2412 ? _2412->size(0) : 0);
  int _2414 = (int)((_2412)->size(0));
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2415 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  if ((_2414 == (int)0))
  {
    {
      return std::string ("0");
    }
  }
  else if((_2414 == (int)1))
  {
    {
      return _2415->__mosek_2fusion_2Utils_2StringBuffer__a(_2413)->toString();
    }
  }
  else
  {
    {
      long long _2416 = _2413;
      std::shared_ptr< monty::ndarray< int,1 > > _2417 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2414)));
      _checked_ptr_1<int> _ptr__2417(_2417 ? _2417->raw() : nullptr,_2417 ? _2417->size(0) : 0);
      int _7949 = (int)1;
      int _7950 = _2414;
      for (int _2418 = _7949; _2418 < _7950; ++_2418)
      {
        {
          _ptr__2417[(_2414 - _2418)] = (int)(_2416 % _ptr__2412[(_2414 - _2418)]);
          _2416 /= _ptr__2412[(_2414 - _2418)];
        }
      }
      _ptr__2417[(int)0] = (int)_2416;
      _2415->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2417[(int)0]);
      int _7951 = (int)1;
      int _7952 = _2414;
      for (int _2419 = _7951; _2419 < _7952; ++_2419)
      {
        {
          _2415->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2417[_2419]);
        }
      }
      return _2415->toString();
    }
  }
}
std::string mosek::fusion::Set::keyToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2420) { return mosek::fusion::p_Set::keyToString(_2420); }std::string mosek::fusion::p_Set::keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2420){
  _checked_ptr_1<int> _ptr__2420(_2420 ? _2420->raw() : nullptr, _2420 ? _2420->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2421 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2421->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2420[(int)0]);
  int _7953 = (int)1;
  int _7954 = (int)((_2420)->size(0));
  for (int _2422 = _7953; _2422 < _7954; ++_2422)
  {
    {
      _2421->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2420[_2422]);
    }
  }
  return _2421->toString();
}
void mosek::fusion::Set::indexToKey  ( std::shared_ptr< monty::ndarray< int,1 > > _2423,    long long _2424,    std::shared_ptr< monty::ndarray< int,1 > > _2425) { mosek::fusion::p_Set::indexToKey(_2423,_2424,_2425); }void mosek::fusion::p_Set::indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2423,long long _2424,std::shared_ptr< monty::ndarray< int,1 > > _2425){
  _checked_ptr_1<int> _ptr__2423(_2423 ? _2423->raw() : nullptr, _2423 ? _2423->size(0) : 0);
  _checked_ptr_1<int> _ptr__2425(_2425 ? _2425->raw() : nullptr, _2425 ? _2425->size(0) : 0);
  int _2426 = (int)((_2423)->size(0));
  if ((_2426 == (int)1))
  {
    {
      _ptr__2425[(int)0] = (int)_2424;
    }
  }
  else
  {
    {
      long long _2427 = _2424;
      int _7955 = (int)1;
      int _7956 = _2426;
      for (int _2428 = _7955; _2428 < _7956; ++_2428)
      {
        {
          _ptr__2425[(_2426 - _2428)] = (int)(_2427 % _ptr__2423[(_2426 - _2428)]);
          _2427 /= _ptr__2423[(_2426 - _2428)];
        }
      }
      _ptr__2425[(int)0] = (int)_2427;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::Set::strides  ( std::shared_ptr< monty::ndarray< int,1 > > _2429) { return mosek::fusion::p_Set::strides(_2429); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_Set::strides(std::shared_ptr< monty::ndarray< int,1 > > _2429){
  _checked_ptr_1<int> _ptr__2429(_2429 ? _2429->raw() : nullptr, _2429 ? _2429->size(0) : 0);
  int _2430 = (int)((_2429)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2431 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2430)));
  _checked_ptr_1<long long> _ptr__2431(_2431 ? _2431->raw() : nullptr,_2431 ? _2431->size(0) : 0);
  _ptr__2431[(_2430 - (int)1)] = (int)1;
  int _7957 = (int)1;
  int _7958 = _2430;
  for (int _2432 = _7957; _2432 < _7958; ++_2432)
  {
    {
      _ptr__2431[((_2430 - _2432) - (int)1)] = safe_mul( _ptr__2431[(_2430 - _2432)],_ptr__2429[(_2430 - _2432)] );
    }
  }
  return _2431;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2433,    std::shared_ptr< monty::ndarray< int,1 > > _2434) { return mosek::fusion::p_Set::make(_2433,_2434); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2433,std::shared_ptr< monty::ndarray< int,1 > > _2434){
  _checked_ptr_1<int> _ptr__2433(_2433 ? _2433->raw() : nullptr, _2433 ? _2433->size(0) : 0);
  _checked_ptr_1<int> _ptr__2434(_2434 ? _2434->raw() : nullptr, _2434 ? _2434->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2435 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((_2433)->size(0)),(int)((_2434)->size(0)) ))));
  _checked_ptr_1<int> _ptr__2435(_2435 ? _2435->raw() : nullptr,_2435 ? _2435->size(0) : 0);
  int _7959 = (int)0;
  int _7960 = (int)((_2433)->size(0));
  for (int _2436 = _7959; _2436 < _7960; ++_2436)
  {
    {
      _ptr__2435[_2436] = _ptr__2433[_2436];
    }
  }
  int _7961 = (int)0;
  int _7962 = (int)((_2434)->size(0));
  for (int _2437 = _7961; _2437 < _7962; ++_2437)
  {
    {
      _ptr__2435[safe_add( (int)((_2433)->size(0)),_2437 )] = _ptr__2434[_2437];
    }
  }
  return _2435;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2438) { return mosek::fusion::p_Set::make(_2438); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2438){
  _checked_ptr_1<int> _ptr__2438(_2438 ? _2438->raw() : nullptr, _2438 ? _2438->size(0) : 0);
  std::vector<int> _7963;
  for (int _2439 = (int)0, _7964 = (int)((_2438)->size(0)); _2439 < _7964 ; ++_2439)
  {
    _7963.push_back(_ptr__2438[_2439]);
  }
  auto _7965 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7963.size()),_7963.begin(),_7963.end()));
  return _7965;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2440,    int _2441,    int _2442) { return mosek::fusion::p_Set::make(_2440,_2441,_2442); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2440,int _2441,int _2442){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2440),(int)(_2441),(int)(_2442)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2443,    int _2444) { return mosek::fusion::p_Set::make(_2443,_2444); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2443,int _2444){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2443),(int)(_2444)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2445) { return mosek::fusion::p_Set::make(_2445); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2445){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2445)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::scalar  ( ) { return mosek::fusion::p_Set::scalar(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::scalar(){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< std::string,1 > > _2446) { return mosek::fusion::p_Set::make(_2446); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< std::string,1 > > _2446){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2446)->size(0)))});
}
void mosek::fusion::p_Set::destroy(){}void mosek::fusion::Set::destroy() { mosek::fusion::p_Set::_get_impl(this)->destroy(); }mosek::fusion::ConeDomain::ConeDomain(mosek::fusion::p_ConeDomain *_impl) : _impl(_impl) { /*std::cout << "ConeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConeDomain::~ConeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConeDomain::p_ConeDomain  (::mosek::fusion::ConeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2447,    double _2448,    std::shared_ptr< monty::ndarray< int,1 > > _2449){ return new mosek::fusion::ConeDomain(_2447,_2448,_2449); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2447,    double _2448,    std::shared_ptr< monty::ndarray< int,1 > > _2449) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2447,_2448,_2449); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2447,    double _2448,    std::shared_ptr< monty::ndarray< int,1 > > _2449){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2449(_2449 ? _2449->raw() : nullptr, _2449 ? _2449->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _7966;
    bool _7967 = (NULL != _2449.get());
    if (_7967)
    {
      _7966 = ::mosek::fusion::p_Set::make(_2449);
    }
    else
    {
      _7966 = nullptr;
    }
    shape = _7966;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2448;
    key = _2447;
    axisidx = (int)0;
    axisset = false;
    int_flag = false;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2448;
  }
}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2450,    std::shared_ptr< monty::ndarray< int,1 > > _2451){ return new mosek::fusion::ConeDomain(_2450,_2451); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2450,    std::shared_ptr< monty::ndarray< int,1 > > _2451) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2450,_2451); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2450,    std::shared_ptr< monty::ndarray< int,1 > > _2451){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2451(_2451 ? _2451->raw() : nullptr, _2451 ? _2451->size(0) : 0);
    mosek::fusion::p_ConeDomain::_initialize(_2450,1.0,_2451);
  }
}bool mosek::fusion::p_ConeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2452){
  _checked_ptr_1<int> _ptr__2452(_2452 ? _2452->raw() : nullptr, _2452 ? _2452->size(0) : 0);
  return ((NULL == shape.get()) || ::mosek::fusion::p_Set::match(_2452,shape));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__integral() { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::integral() { return __mosek_2fusion_2ConeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__integral(){
  int_flag = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
bool mosek::fusion::ConeDomain :: axisIsSet() { return mosek::fusion::p_ConeDomain::_get_impl(this)->axisIsSet(); }bool mosek::fusion::p_ConeDomain::axisIsSet(){
  return axisset;
}
int mosek::fusion::ConeDomain :: getAxis() { return mosek::fusion::p_ConeDomain::_get_impl(this)->getAxis(); }int mosek::fusion::p_ConeDomain::getAxis(){
  return axisidx;
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__axis(int _2453) { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__axis(_2453); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::axis(int _2453) { return __mosek_2fusion_2ConeDomain__axis(_2453); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__axis(int _2453){
  axisidx = _2453;
  axisset = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
void mosek::fusion::p_ConeDomain::destroy(){shape.reset();}void mosek::fusion::ConeDomain::destroy() { mosek::fusion::p_ConeDomain::_get_impl(this)->destroy(); }mosek::fusion::LinPSDDomain::LinPSDDomain(mosek::fusion::p_LinPSDDomain *_impl) : _impl(_impl) { /*std::cout << "LinPSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinPSDDomain::~LinPSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinPSDDomain::p_LinPSDDomain  (::mosek::fusion::LinPSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2454,    int _2455){ return new mosek::fusion::LinPSDDomain(_2454,_2455); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2454,    int _2455) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2454,_2455); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2454,    int _2455){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2454(_2454 ? _2454->raw() : nullptr, _2454 ? _2454->size(0) : 0);
    mosek::fusion::p_LinPSDDomain::_get_impl(::mosek::fusion::LinPSDDomain::t(_pubthis))->conedim = _2455;
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2454);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2456){ return new mosek::fusion::LinPSDDomain(_2456); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2456) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2456); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2456){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2456(_2456 ? _2456->raw() : nullptr, _2456 ? _2456->size(0) : 0);
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2456);
    conedim = ((int)((shape)->size(0)) - (int)1);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (){ return new mosek::fusion::LinPSDDomain(); }mosek::fusion::LinPSDDomain::LinPSDDomain  () :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinPSDDomain::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    conedim = (int)0;
    shape = nullptr;
  }
}void mosek::fusion::p_LinPSDDomain::destroy(){shape.reset();}void mosek::fusion::LinPSDDomain::destroy() { mosek::fusion::p_LinPSDDomain::_get_impl(this)->destroy(); }mosek::fusion::PSDDomain::PSDDomain(mosek::fusion::p_PSDDomain *_impl) : _impl(_impl) { /*std::cout << "PSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::PSDDomain::~PSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_PSDDomain::p_PSDDomain  (::mosek::fusion::PSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2457,    std::shared_ptr< monty::ndarray< int,1 > > _2458,    int _2459,    int _2460){ return new mosek::fusion::PSDDomain(_2457,_2458,_2459,_2460); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2457,    std::shared_ptr< monty::ndarray< int,1 > > _2458,    int _2459,    int _2460) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2457,_2458,_2459,_2460); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2457,    std::shared_ptr< monty::ndarray< int,1 > > _2458,    int _2459,    int _2460){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2458(_2458 ? _2458->raw() : nullptr, _2458 ? _2458->size(0) : 0);
    axisIsSet = true;
    shape = _2458;
    key = _2457;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2459;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2460;
    int _2461 = (int)((shape)->size(0));
    if (((!(((int)((shape)->size(0)) > _2459) && (((int)((shape)->size(0)) > _2460) && ((_2459 >= (int)0) && ((_2460 >= (int)0) && (_2459 != _2460)))))) && (((*shape)(_2459)) == ((*shape)(_2460)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
      }
    }
    {}
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2462,    std::shared_ptr< monty::ndarray< int,1 > > _2463){ return new mosek::fusion::PSDDomain(_2462,_2463); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2462,    std::shared_ptr< monty::ndarray< int,1 > > _2463) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2462,_2463); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2462,    std::shared_ptr< monty::ndarray< int,1 > > _2463){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2463(_2463 ? _2463->raw() : nullptr, _2463 ? _2463->size(0) : 0);
    mosek::fusion::p_PSDDomain::_initialize(_2462,_2463,((int)((_2463)->size(0)) - (int)2),((int)((_2463)->size(0)) - (int)1));
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2464){ return new mosek::fusion::PSDDomain(_2464); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2464) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2464); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2464){monty::rc_reserve __reserve_this(_pubthis);   {
    shape = nullptr;
    key = _2464;
    conedim1 = (int)0;
    conedim2 = (int)0;
    axisIsSet = false;
  }
}monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain :: __mosek_2fusion_2PSDDomain__axis(int _2465,int _2466) { return mosek::fusion::p_PSDDomain::_get_impl(this)->__mosek_2fusion_2PSDDomain__axis(_2465,_2466); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain::axis(int _2465,int _2466) { return __mosek_2fusion_2PSDDomain__axis(_2465,_2466); }
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_PSDDomain::__mosek_2fusion_2PSDDomain__axis(int _2465,int _2466){
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2465;
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2466;
  axisIsSet = true;
  if (((NULL == shape.get()) && (!((_2465 >= (int)0) && ((_2466 >= (int)0) && (_2465 != _2466))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  else if(((NULL != shape.get()) && ((!(((int)((shape)->size(0)) > _2465) && (((int)((shape)->size(0)) > _2466) && ((_2465 >= (int)0) && ((_2466 >= (int)0) && (_2465 != _2466)))))) && (((*shape)(_2465)) == ((*shape)(_2466))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  {}
  return ::mosek::fusion::PSDDomain::t(_pubthis);
}
void mosek::fusion::p_PSDDomain::destroy(){shape.reset();}void mosek::fusion::PSDDomain::destroy() { mosek::fusion::p_PSDDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain(mosek::fusion::p_SymmetricRangeDomain *_impl) : mosek::fusion::RangeDomain(_impl) { /*std::cout << "SymmetricRangeDomain()" << this << std::endl; */ }mosek::fusion::SymmetricRangeDomain::~SymmetricRangeDomain() {  /* std::cout << "~SymmetricRangeDomain()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymmetricRangeDomain::p_SymmetricRangeDomain  (::mosek::fusion::SymmetricRangeDomain * _pubthis) :     mosek::fusion::p_RangeDomain(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymmetricRangeDomain::t mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2467){ return new mosek::fusion::SymmetricRangeDomain(_2467); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2467) :    SymmetricRangeDomain(new mosek::fusion::p_SymmetricRangeDomain(this)){ mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->_initialize(_2467); }void mosek::fusion::p_SymmetricRangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2467){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_RangeDomain::_initialize(_2467);
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7968;
    bool _7969 = (NULL == shape.get());
    if (_7969)
    {
      _7968 = (int)0;
    }
    else
    {
      _7968 = ((*shape)((int)0));
    }
    dim = _7968;
  }
}void mosek::fusion::p_SymmetricRangeDomain::destroy(){}void mosek::fusion::SymmetricRangeDomain::destroy() { mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->destroy(); }mosek::fusion::RangeDomain::RangeDomain(mosek::fusion::p_RangeDomain *_impl) : _impl(_impl) { /*std::cout << "RangeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::RangeDomain::~RangeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_RangeDomain::p_RangeDomain  (::mosek::fusion::RangeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2468,    std::shared_ptr< monty::ndarray< double,1 > > _2469,    std::shared_ptr< monty::ndarray< double,1 > > _2470,    std::shared_ptr< monty::ndarray< int,1 > > _2471){ return new mosek::fusion::RangeDomain(_2468,_2469,_2470,_2471); }mosek::fusion::RangeDomain::RangeDomain  (bool _2468,    std::shared_ptr< monty::ndarray< double,1 > > _2469,    std::shared_ptr< monty::ndarray< double,1 > > _2470,    std::shared_ptr< monty::ndarray< int,1 > > _2471) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2468,_2469,_2470,_2471); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2468,    std::shared_ptr< monty::ndarray< double,1 > > _2469,    std::shared_ptr< monty::ndarray< double,1 > > _2470,    std::shared_ptr< monty::ndarray< int,1 > > _2471){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2469(_2469 ? _2469->raw() : nullptr, _2469 ? _2469->size(0) : 0);
    _checked_ptr_1<double> _ptr__2470(_2470 ? _2470->raw() : nullptr, _2470 ? _2470->size(0) : 0);
    _checked_ptr_1<int> _ptr__2471(_2471 ? _2471->raw() : nullptr, _2471 ? _2471->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2468,_2469,_2470,_2471,nullptr,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2472,    std::shared_ptr< monty::ndarray< double,1 > > _2473,    std::shared_ptr< monty::ndarray< double,1 > > _2474,    std::shared_ptr< monty::ndarray< int,1 > > _2475,    std::shared_ptr< monty::ndarray< int,2 > > _2476){ return new mosek::fusion::RangeDomain(_2472,_2473,_2474,_2475,_2476); }mosek::fusion::RangeDomain::RangeDomain  (bool _2472,    std::shared_ptr< monty::ndarray< double,1 > > _2473,    std::shared_ptr< monty::ndarray< double,1 > > _2474,    std::shared_ptr< monty::ndarray< int,1 > > _2475,    std::shared_ptr< monty::ndarray< int,2 > > _2476) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2472,_2473,_2474,_2475,_2476); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2472,    std::shared_ptr< monty::ndarray< double,1 > > _2473,    std::shared_ptr< monty::ndarray< double,1 > > _2474,    std::shared_ptr< monty::ndarray< int,1 > > _2475,    std::shared_ptr< monty::ndarray< int,2 > > _2476){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2473(_2473 ? _2473->raw() : nullptr, _2473 ? _2473->size(0) : 0);
    _checked_ptr_1<double> _ptr__2474(_2474 ? _2474->raw() : nullptr, _2474 ? _2474->size(0) : 0);
    _checked_ptr_1<int> _ptr__2475(_2475 ? _2475->raw() : nullptr, _2475 ? _2475->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2472,_2473,_2474,_2475,_2476,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2477,    std::shared_ptr< monty::ndarray< double,1 > > _2478,    std::shared_ptr< monty::ndarray< double,1 > > _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    std::shared_ptr< monty::ndarray< int,2 > > _2481,    int _2482){ return new mosek::fusion::RangeDomain(_2477,_2478,_2479,_2480,_2481,_2482); }mosek::fusion::RangeDomain::RangeDomain  (bool _2477,    std::shared_ptr< monty::ndarray< double,1 > > _2478,    std::shared_ptr< monty::ndarray< double,1 > > _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    std::shared_ptr< monty::ndarray< int,2 > > _2481,    int _2482) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2477,_2478,_2479,_2480,_2481,_2482); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2477,    std::shared_ptr< monty::ndarray< double,1 > > _2478,    std::shared_ptr< monty::ndarray< double,1 > > _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    std::shared_ptr< monty::ndarray< int,2 > > _2481,    int _2482){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2478(_2478 ? _2478->raw() : nullptr, _2478 ? _2478->size(0) : 0);
    _checked_ptr_1<double> _ptr__2479(_2479 ? _2479->raw() : nullptr, _2479 ? _2479->size(0) : 0);
    _checked_ptr_1<int> _ptr__2480(_2480 ? _2480->raw() : nullptr, _2480 ? _2480->size(0) : 0);
    cardinal_flag = false;
    shape = _2480;
    sparsity = nullptr;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->scalable = _2477;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->ub = _2479;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->lb = _2478;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = _2481;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2483){ return new mosek::fusion::RangeDomain(_2483); }mosek::fusion::RangeDomain::RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2483) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2483); }void mosek::fusion::p_RangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2483){monty::rc_reserve __reserve_this(_pubthis);   {
    cardinal_flag = mosek::fusion::p_RangeDomain::_get_impl(_2483)->cardinal_flag;
    sparsity = mosek::fusion::p_RangeDomain::_get_impl(_2483)->sparsity;
    scalable = mosek::fusion::p_RangeDomain::_get_impl(_2483)->scalable;
    shape = mosek::fusion::p_RangeDomain::_get_impl(_2483)->shape;
    ub = mosek::fusion::p_RangeDomain::_get_impl(_2483)->ub;
    lb = mosek::fusion::p_RangeDomain::_get_impl(_2483)->lb;
    empty = mosek::fusion::p_RangeDomain::_get_impl(_2483)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__symmetric() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain::symmetric() { return __mosek_2fusion_2RangeDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain(::mosek::fusion::RangeDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2484); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484) { return __mosek_2fusion_2RangeDomain__sparse(_2484); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2484)->size(0)),(int)((_2484)->size(1)))));
  {
    int _2485 = (int)0;
    for(;(_2485 < (int)((_2484)->size(0)));++ _2485)
    {
      {
        {
          int _2486 = (int)0;
          for(;(_2486 < (int)((_2484)->size(1)));++ _2486)
          {
            {
              ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2485,_2486)) = ((*_2484)(_2485,_2486));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2487); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487) { return __mosek_2fusion_2RangeDomain__sparse(_2487); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487){
  _checked_ptr_1<int> _ptr__2487(_2487 ? _2487->raw() : nullptr, _2487 ? _2487->size(0) : 0);
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2487)->size(0)),(int)1)));
  int _7970 = (int)0;
  int _7971 = (int)((_2487)->size(0));
  for (int _2488 = _7970; _2488 < _7971; ++_2488)
  {
    {
      ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2488,(int)0)) = _ptr__2487[_2488];
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse() { return __mosek_2fusion_2RangeDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__integral() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::integral() { return __mosek_2fusion_2RangeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2489); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489) { return __mosek_2fusion_2RangeDomain__withShape(_2489); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489){
  _checked_ptr_1<int> _ptr__2489(_2489 ? _2489->raw() : nullptr, _2489 ? _2489->size(0) : 0);
  shape = _2489;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
bool mosek::fusion::p_RangeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2490){
  _checked_ptr_1<int> _ptr__2490(_2490 ? _2490->raw() : nullptr, _2490 ? _2490->size(0) : 0);
  if (scalable)
  {
    {
      return true;
    }
  }
  else if(((int)((shape)->size(0)) != (int)((_2490)->size(0))))
  {
    {
      return false;
    }
  }
  else
  {
    {
      int _7972 = (int)0;
      int _7973 = (int)((shape)->size(0));
      for (int _2491 = _7972; _2491 < _7973; ++_2491)
      {
        {
          if ((((*shape)(_2491)) != _ptr__2490[_2491]))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  return true;
}
void mosek::fusion::p_RangeDomain::destroy(){ub.reset();lb.reset();sparsity.reset();shape.reset();}void mosek::fusion::RangeDomain::destroy() { mosek::fusion::p_RangeDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain(mosek::fusion::p_SymmetricLinearDomain *_impl) : _impl(_impl) { /*std::cout << "SymmetricLinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricLinearDomain::~SymmetricLinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricLinearDomain::p_SymmetricLinearDomain  (::mosek::fusion::SymmetricLinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricLinearDomain::t mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2492){ return new mosek::fusion::SymmetricLinearDomain(_2492); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2492) :    SymmetricLinearDomain(new mosek::fusion::p_SymmetricLinearDomain(this)){ mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->_initialize(_2492); }void mosek::fusion::p_SymmetricLinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2492){monty::rc_reserve __reserve_this(_pubthis);   {
    dom = _2492;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2492)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2492)->key;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2492)->cardinal_flag;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2492)->sparsity;
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7974;
    bool _7975 = (NULL == shape.get());
    if (_7975)
    {
      _7974 = (int)0;
    }
    else
    {
      _7974 = ((*shape)((int)0));
    }
    dim = _7974;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2493) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2493); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2493) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2493); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2493){
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2493)->size(0)),(int)((_2493)->size(1)))));
  {
    int _2494 = (int)0;
    for(;(_2494 < (int)((_2493)->size(0)));++ _2494)
    {
      {
        {
          int _2495 = (int)0;
          for(;(_2495 < (int)((_2493)->size(1)));++ _2495)
          {
            {
              ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2494,_2495)) = ((*_2493)(_2494,_2495));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2496) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2496); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2496) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2496); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2496){
  _checked_ptr_1<int> _ptr__2496(_2496 ? _2496->raw() : nullptr, _2496 ? _2496->size(0) : 0);
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2496)->size(0)),(int)1)));
  int _7976 = (int)0;
  int _7977 = (int)((_2496)->size(0));
  for (int _2497 = _7976; _2497 < _7977; ++_2497)
  {
    {
      ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2497,(int)0)) = _ptr__2496[_2497];
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__integral() { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::integral() { return __mosek_2fusion_2SymmetricLinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
bool mosek::fusion::p_SymmetricLinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2498){
  _checked_ptr_1<int> _ptr__2498(_2498 ? _2498->raw() : nullptr, _2498 ? _2498->size(0) : 0);
  int _7978 = (int)0;
  int _7979 = (int)((_2498)->size(0));
  for (int _2499 = _7978; _2499 < _7979; ++_2499)
  {
    {
      if ((_ptr__2498[_2499] == ((*shape)(_2499))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_SymmetricLinearDomain::destroy(){sparsity.reset();shape.reset();dom.reset();}void mosek::fusion::SymmetricLinearDomain::destroy() { mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->destroy(); }mosek::fusion::LinearDomain::LinearDomain(mosek::fusion::p_LinearDomain *_impl) : _impl(_impl) { /*std::cout << "LinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinearDomain::~LinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinearDomain::p_LinearDomain  (::mosek::fusion::LinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2500,    bool _2501,    std::shared_ptr< monty::ndarray< double,1 > > _2502,    std::shared_ptr< monty::ndarray< int,1 > > _2503){ return new mosek::fusion::LinearDomain(_2500,_2501,_2502,_2503); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2500,    bool _2501,    std::shared_ptr< monty::ndarray< double,1 > > _2502,    std::shared_ptr< monty::ndarray< int,1 > > _2503) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2500,_2501,_2502,_2503); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2500,    bool _2501,    std::shared_ptr< monty::ndarray< double,1 > > _2502,    std::shared_ptr< monty::ndarray< int,1 > > _2503){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2502(_2502 ? _2502->raw() : nullptr, _2502 ? _2502->size(0) : 0);
    _checked_ptr_1<int> _ptr__2503(_2503 ? _2503->raw() : nullptr, _2503 ? _2503->size(0) : 0);
    mosek::fusion::p_LinearDomain::_initialize(_2500,_2501,_2502,_2503,nullptr,(int)1);
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2504,    bool _2505,    std::shared_ptr< monty::ndarray< double,1 > > _2506,    std::shared_ptr< monty::ndarray< int,1 > > _2507,    std::shared_ptr< monty::ndarray< int,2 > > _2508,    int _2509){ return new mosek::fusion::LinearDomain(_2504,_2505,_2506,_2507,_2508,_2509); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2504,    bool _2505,    std::shared_ptr< monty::ndarray< double,1 > > _2506,    std::shared_ptr< monty::ndarray< int,1 > > _2507,    std::shared_ptr< monty::ndarray< int,2 > > _2508,    int _2509) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2504,_2505,_2506,_2507,_2508,_2509); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2504,    bool _2505,    std::shared_ptr< monty::ndarray< double,1 > > _2506,    std::shared_ptr< monty::ndarray< int,1 > > _2507,    std::shared_ptr< monty::ndarray< int,2 > > _2508,    int _2509){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2506(_2506 ? _2506->raw() : nullptr, _2506 ? _2506->size(0) : 0);
    _checked_ptr_1<int> _ptr__2507(_2507 ? _2507->raw() : nullptr, _2507 ? _2507->size(0) : 0);
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->scalable = _2505;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->shape = _2507;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->key = _2504;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->bnd = _2506;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = _2508;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->cardinal_flag = false;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2510){ return new mosek::fusion::LinearDomain(_2510); }mosek::fusion::LinearDomain::LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2510) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2510); }void mosek::fusion::p_LinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2510){monty::rc_reserve __reserve_this(_pubthis);   {
    scalable = mosek::fusion::p_LinearDomain::_get_impl(_2510)->scalable;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2510)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2510)->key;
    bnd = mosek::fusion::p_LinearDomain::_get_impl(_2510)->bnd;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2510)->sparsity;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2510)->cardinal_flag;
    empty = mosek::fusion::p_LinearDomain::_get_impl(_2510)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__symmetric() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain::symmetric() { return __mosek_2fusion_2LinearDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain(::mosek::fusion::LinearDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2511) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2511); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2511) { return __mosek_2fusion_2LinearDomain__sparse(_2511); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2511){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2511)->size(0)),(int)((_2511)->size(1)))));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  {
    int _2512 = (int)0;
    for(;(_2512 < (int)((_2511)->size(0)));++ _2512)
    {
      {
        {
          int _2513 = (int)0;
          for(;(_2513 < (int)((_2511)->size(1)));++ _2513)
          {
            {
              ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2512,_2513)) = ((*_2511)(_2512,_2513));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2514) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2514); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2514) { return __mosek_2fusion_2LinearDomain__sparse(_2514); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2514){
  _checked_ptr_1<int> _ptr__2514(_2514 ? _2514->raw() : nullptr, _2514 ? _2514->size(0) : 0);
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2514)->size(0)),(int)1)));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  int _7980 = (int)0;
  int _7981 = (int)((_2514)->size(0));
  for (int _2515 = _7980; _2515 < _7981; ++_2515)
  {
    {
      ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2515,(int)0)) = _ptr__2514[_2515];
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse() { return __mosek_2fusion_2LinearDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__integral() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::integral() { return __mosek_2fusion_2LinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2516) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2516); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2516) { return __mosek_2fusion_2LinearDomain__withShape(_2516); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2516){
  _checked_ptr_1<int> _ptr__2516(_2516 ? _2516->raw() : nullptr, _2516 ? _2516->size(0) : 0);
  shape = _2516;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
bool mosek::fusion::p_LinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2517){
  _checked_ptr_1<int> _ptr__2517(_2517 ? _2517->raw() : nullptr, _2517 ? _2517->size(0) : 0);
  if ((!scalable))
  {
    {
      int _7982 = (int)0;
      int _7983 = (int)((_2517)->size(0));
      for (int _2518 = _7982; _2518 < _7983; ++_2518)
      {
        {
          if ((_ptr__2517[_2518] == ((*shape)(_2518))))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinearDomain::destroy(){sparsity.reset();bnd.reset();shape.reset();}void mosek::fusion::LinearDomain::destroy() { mosek::fusion::p_LinearDomain::_get_impl(this)->destroy(); }mosek::fusion::Domain::Domain(mosek::fusion::p_Domain *_impl) : _impl(_impl) { /*std::cout << "Domain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Domain::~Domain() { delete _impl; _impl = nullptr; }mosek::fusion::p_Domain::p_Domain  (::mosek::fusion::Domain * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::p_Domain::dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2519){
  _checked_ptr_1<int> _ptr__2519(_2519 ? _2519->raw() : nullptr, _2519 ? _2519->size(0) : 0);
  long long _2520 = (long long)1;
  int _7984 = (int)0;
  int _7985 = (int)((_2519)->size(0));
  for (int _2521 = _7984; _2521 < _7985; ++_2521)
  {
    {
      _2520 *= _ptr__2519[_2521];
    }
  }
  return _2520;
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::mkLinearDomain(mosek::fusion::RelationKey _2522,monty::rc_ptr< ::mosek::fusion::Matrix > _2523){
  if (_2523->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2524 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2523->numNonzeros())));
      _checked_ptr_1<int> _ptr__2524(_2524 ? _2524->raw() : nullptr,_2524 ? _2524->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2525 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2523->numNonzeros())));
      _checked_ptr_1<int> _ptr__2525(_2525 ? _2525->raw() : nullptr,_2525 ? _2525->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2526 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2523->numNonzeros())));
      _checked_ptr_1<double> _ptr__2526(_2526 ? _2526->raw() : nullptr,_2526 ? _2526->size(0) : 0);
      _2523->getDataAsTriplets(_2524,_2525,_2526);
      std::shared_ptr< monty::ndarray< int,2 > > _2527 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2524)->size(0)),(int)2)));
      int _7986 = (int)0;
      int _7987 = (int)((_2524)->size(0));
      for (int _2528 = _7986; _2528 < _7987; ++_2528)
      {
        {
          ((*_2527)(_2528,(int)0)) = _ptr__2524[_2528];
          ((*_2527)(_2528,(int)1)) = _ptr__2525[_2528];
        }
      }
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2522,false,_2526,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2523)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2523)->dimj)}),_2527,(int)1);
    }
  }
  else
  {
    {
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2522,false,_2523->getDataAsArray(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2523)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2523)->dimj)}),nullptr,(int)1);
    }
  }
}
long long mosek::fusion::p_Domain::prod(std::shared_ptr< monty::ndarray< int,1 > > _2529){
  _checked_ptr_1<int> _ptr__2529(_2529 ? _2529->raw() : nullptr, _2529 ? _2529->size(0) : 0);
  long long _2530 = (int)1;
  int _7988 = (int)0;
  int _7989 = (int)((_2529)->size(0));
  for (int _2531 = _7988; _2531 < _7989; ++_2531)
  {
    {
      _2530 *= _ptr__2529[_2531];
    }
  }
  return _2530;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(bool _2532,std::shared_ptr< monty::ndarray< double,1 > > _2533,std::shared_ptr< monty::ndarray< double,1 > > _2534,std::shared_ptr< monty::ndarray< int,2 > > _2535,std::shared_ptr< monty::ndarray< int,1 > > _2536){
  _checked_ptr_1<double> _ptr__2533(_2533 ? _2533->raw() : nullptr, _2533 ? _2533->size(0) : 0);
  _checked_ptr_1<double> _ptr__2534(_2534 ? _2534->raw() : nullptr, _2534 ? _2534->size(0) : 0);
  _checked_ptr_1<int> _ptr__2536(_2536 ? _2536->raw() : nullptr, _2536 ? _2536->size(0) : 0);
  if (((!_2532) && ((int)((_2533)->size(0)) != (int)((_2534)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper and lower bounds."));
    }
  }
  {}
  if (((NULL != _2535.get()) && ((int)((_2535)->size(0)) != (int)((_2533)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper/lower bounds and sparsity."));
    }
  }
  {}
  int _7990 = (int)0;
  int _7991 = (int)((_2534)->size(0));
  for (int _2537 = _7990; _2537 < _7991; ++_2537)
  {
    {
      if ((_ptr__2533[_2537] > _ptr__2534[_2537]))
      {
        {
          throw ::mosek::fusion::DomainError(std::string ("Invalid range specified"));
        }
      }
      {}
    }
  }
  if (((NULL != _2536.get()) && (::mosek::fusion::p_Domain::dimsize(_2536) != (int)((_2533)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching dimensions."));
    }
  }
  {}
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(_2532,_2533,_2534,_2536)->__mosek_2fusion_2RangeDomain__sparse(_2535);
}
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2538) { return mosek::fusion::p_Domain::symmetric(_2538); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2538){
  return _2538->__mosek_2fusion_2RangeDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2539) { return mosek::fusion::p_Domain::symmetric(_2539); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2539){
  return _2539->__mosek_2fusion_2LinearDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2540,    std::shared_ptr< monty::ndarray< int,2 > > _2541) { return mosek::fusion::p_Domain::sparse(_2540,_2541); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2540,std::shared_ptr< monty::ndarray< int,2 > > _2541){
  return _2540->__mosek_2fusion_2RangeDomain__sparse(_2541);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2542,    std::shared_ptr< monty::ndarray< int,1 > > _2543) { return mosek::fusion::p_Domain::sparse(_2542,_2543); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2542,std::shared_ptr< monty::ndarray< int,1 > > _2543){
  _checked_ptr_1<int> _ptr__2543(_2543 ? _2543->raw() : nullptr, _2543 ? _2543->size(0) : 0);
  return _2542->__mosek_2fusion_2RangeDomain__sparse(_2543);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2544,    std::shared_ptr< monty::ndarray< int,2 > > _2545) { return mosek::fusion::p_Domain::sparse(_2544,_2545); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2544,std::shared_ptr< monty::ndarray< int,2 > > _2545){
  return _2544->__mosek_2fusion_2LinearDomain__sparse(_2545);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2546,    std::shared_ptr< monty::ndarray< int,1 > > _2547) { return mosek::fusion::p_Domain::sparse(_2546,_2547); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2546,std::shared_ptr< monty::ndarray< int,1 > > _2547){
  _checked_ptr_1<int> _ptr__2547(_2547 ? _2547->raw() : nullptr, _2547 ? _2547->size(0) : 0);
  return _2546->__mosek_2fusion_2LinearDomain__sparse(_2547);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2548) { return mosek::fusion::p_Domain::integral(_2548); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2548){
  return _2548->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2549) { return mosek::fusion::p_Domain::integral(_2549); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2549){
  return _2549->__mosek_2fusion_2LinearDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2550) { return mosek::fusion::p_Domain::integral(_2550); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2550){
  return _2550->__mosek_2fusion_2ConeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::axis  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2551,    int _2552) { return mosek::fusion::p_Domain::axis(_2551,_2552); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2551,int _2552){
  return _2551->__mosek_2fusion_2ConeDomain__axis(_2552);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2553,    std::shared_ptr< monty::ndarray< int,1 > > _2554) { return mosek::fusion::p_Domain::inDPowerCone(_2553,_2554); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2553,std::shared_ptr< monty::ndarray< int,1 > > _2554){
  _checked_ptr_1<int> _ptr__2554(_2554 ? _2554->raw() : nullptr, _2554 ? _2554->size(0) : 0);
  std::vector<int> _7992;
  for (int _2555 = (int)0, _7993 = (int)((_2554)->size(0)); _2555 < _7993 ; ++_2555)
  {
    _7992.push_back(_ptr__2554[_2555]);
  }
  auto _7994 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7992.size()),_7992.begin(),_7992.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2553,_7994);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2556,    int _2557) { return mosek::fusion::p_Domain::inDPowerCone(_2556,_2557); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2556,int _2557){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2556,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2557),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2558) { return mosek::fusion::p_Domain::inDPowerCone(_2558); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2558){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2558,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2559,    std::shared_ptr< monty::ndarray< int,1 > > _2560) { return mosek::fusion::p_Domain::inPPowerCone(_2559,_2560); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2559,std::shared_ptr< monty::ndarray< int,1 > > _2560){
  _checked_ptr_1<int> _ptr__2560(_2560 ? _2560->raw() : nullptr, _2560 ? _2560->size(0) : 0);
  std::vector<int> _7995;
  for (int _2561 = (int)0, _7996 = (int)((_2560)->size(0)); _2561 < _7996 ; ++_2561)
  {
    _7995.push_back(_ptr__2560[_2561]);
  }
  auto _7997 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7995.size()),_7995.begin(),_7995.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2559,_7997);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2562,    int _2563) { return mosek::fusion::p_Domain::inPPowerCone(_2562,_2563); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2562,int _2563){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2562,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2563),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2564) { return mosek::fusion::p_Domain::inPPowerCone(_2564); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2564){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2564,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2565) { return mosek::fusion::p_Domain::inDExpCone(_2565); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2565){
  _checked_ptr_1<int> _ptr__2565(_2565 ? _2565->raw() : nullptr, _2565 ? _2565->size(0) : 0);
  std::vector<int> _7998;
  for (int _2566 = (int)0, _7999 = (int)((_2565)->size(0)); _2566 < _7999 ; ++_2566)
  {
    _7998.push_back(_ptr__2565[_2566]);
  }
  auto _8000 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7998.size()),_7998.begin(),_7998.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,_8000);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( int _2567) { return mosek::fusion::p_Domain::inDExpCone(_2567); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(int _2567){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2567),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( ) { return mosek::fusion::p_Domain::inDExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2568) { return mosek::fusion::p_Domain::inPExpCone(_2568); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2568){
  _checked_ptr_1<int> _ptr__2568(_2568 ? _2568->raw() : nullptr, _2568 ? _2568->size(0) : 0);
  std::vector<int> _8001;
  for (int _2569 = (int)0, _8002 = (int)((_2568)->size(0)); _2569 < _8002 ; ++_2569)
  {
    _8001.push_back(_ptr__2568[_2569]);
  }
  auto _8003 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8001.size()),_8001.begin(),_8001.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,_8003);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( int _2570) { return mosek::fusion::p_Domain::inPExpCone(_2570); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(int _2570){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2570),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( ) { return mosek::fusion::p_Domain::inPExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2571) { return mosek::fusion::p_Domain::inRotatedQCone(_2571); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2571){
  _checked_ptr_1<int> _ptr__2571(_2571 ? _2571->raw() : nullptr, _2571 ? _2571->size(0) : 0);
  std::vector<int> _8004;
  for (int _2572 = (int)0, _8005 = (int)((_2571)->size(0)); _2572 < _8005 ; ++_2572)
  {
    _8004.push_back(_ptr__2571[_2572]);
  }
  auto _8006 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8004.size()),_8004.begin(),_8004.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,_8006);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2573,    int _2574) { return mosek::fusion::p_Domain::inRotatedQCone(_2573,_2574); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2573,int _2574){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2573),(int)(_2574)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2575) { return mosek::fusion::p_Domain::inRotatedQCone(_2575); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2575){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2575)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( ) { return mosek::fusion::p_Domain::inRotatedQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2576) { return mosek::fusion::p_Domain::inQCone(_2576); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2576){
  _checked_ptr_1<int> _ptr__2576(_2576 ? _2576->raw() : nullptr, _2576 ? _2576->size(0) : 0);
  std::vector<int> _8007;
  for (int _2577 = (int)0, _8008 = (int)((_2576)->size(0)); _2577 < _8008 ; ++_2577)
  {
    _8007.push_back(_ptr__2576[_2577]);
  }
  auto _8009 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8007.size()),_8007.begin(),_8007.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,_8009);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2578,    int _2579) { return mosek::fusion::p_Domain::inQCone(_2578,_2579); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2578,int _2579){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2578),(int)(_2579)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2580) { return mosek::fusion::p_Domain::inQCone(_2580); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2580){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2580)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( ) { return mosek::fusion::p_Domain::inQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2581,    int _2582) { return mosek::fusion::p_Domain::isLinPSD(_2581,_2582); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2581,int _2582){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2581,safe_add( _2581,(int)1 ) ) / (int)2),_2582));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2583) { return mosek::fusion::p_Domain::isLinPSD(_2583); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2583){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2583,safe_add( _2583,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( ) { return mosek::fusion::p_Domain::isLinPSD(); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain();
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2584,    int _2585) { return mosek::fusion::p_Domain::isTrilPSD(_2584,_2585); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2584,int _2585){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2585),(int)(_2584),(int)(_2584)}),(int)1,(int)2);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2586) { return mosek::fusion::p_Domain::isTrilPSD(_2586); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2586){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2586),(int)(_2586)}),(int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( ) { return mosek::fusion::p_Domain::isTrilPSD(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2587,    int _2588) { return mosek::fusion::p_Domain::inPSDCone(_2587,_2588); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2587,int _2588){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2588),(int)(_2587),(int)(_2587)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2589) { return mosek::fusion::p_Domain::inPSDCone(_2589); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2589){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2589),(int)(_2589)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( ) { return mosek::fusion::p_Domain::inPSDCone(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( ) { return mosek::fusion::p_Domain::binary(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),nullptr)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( std::shared_ptr< monty::ndarray< int,1 > > _2590) { return mosek::fusion::p_Domain::binary(_2590); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(std::shared_ptr< monty::ndarray< int,1 > > _2590){
  _checked_ptr_1<int> _ptr__2590(_2590 ? _2590->raw() : nullptr, _2590 ? _2590->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),_2590)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2591,    int _2592) { return mosek::fusion::p_Domain::binary(_2591,_2592); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2591,int _2592){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2591),(int)(_2592)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2593) { return mosek::fusion::p_Domain::binary(_2593); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2593){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2593)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2594,    std::shared_ptr< monty::ndarray< double,1 > > _2595,    std::shared_ptr< monty::ndarray< int,1 > > _2596) { return mosek::fusion::p_Domain::inRange(_2594,_2595,_2596); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2594,std::shared_ptr< monty::ndarray< double,1 > > _2595,std::shared_ptr< monty::ndarray< int,1 > > _2596){
  _checked_ptr_1<double> _ptr__2594(_2594 ? _2594->raw() : nullptr, _2594 ? _2594->size(0) : 0);
  _checked_ptr_1<double> _ptr__2595(_2595 ? _2595->raw() : nullptr, _2595 ? _2595->size(0) : 0);
  _checked_ptr_1<int> _ptr__2596(_2596 ? _2596->raw() : nullptr, _2596 ? _2596->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2594,_2595,_2596);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2597,    double _2598,    std::shared_ptr< monty::ndarray< int,1 > > _2599) { return mosek::fusion::p_Domain::inRange(_2597,_2598,_2599); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2597,double _2598,std::shared_ptr< monty::ndarray< int,1 > > _2599){
  _checked_ptr_1<double> _ptr__2597(_2597 ? _2597->raw() : nullptr, _2597 ? _2597->size(0) : 0);
  _checked_ptr_1<int> _ptr__2599(_2599 ? _2599->raw() : nullptr, _2599 ? _2599->size(0) : 0);
  std::vector<double> _8010;
  for (int _2600 = (int)0, _8011 = (int)((_2597)->size(0)); _2600 < _8011 ; ++_2600)
  {
    _8010.push_back(_2598);
  }
  auto _8012 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8010.size()),_8010.begin(),_8010.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2597,_8012,_2599);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2601,    std::shared_ptr< monty::ndarray< double,1 > > _2602,    std::shared_ptr< monty::ndarray< int,1 > > _2603) { return mosek::fusion::p_Domain::inRange(_2601,_2602,_2603); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2601,std::shared_ptr< monty::ndarray< double,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603){
  _checked_ptr_1<double> _ptr__2602(_2602 ? _2602->raw() : nullptr, _2602 ? _2602->size(0) : 0);
  _checked_ptr_1<int> _ptr__2603(_2603 ? _2603->raw() : nullptr, _2603 ? _2603->size(0) : 0);
  std::vector<double> _8013;
  for (int _2604 = (int)0, _8014 = (int)((_2602)->size(0)); _2604 < _8014 ; ++_2604)
  {
    _8013.push_back(_2601);
  }
  auto _8015 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8013.size()),_8013.begin(),_8013.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8015,_2602,_2603);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2605,    double _2606,    std::shared_ptr< monty::ndarray< int,1 > > _2607) { return mosek::fusion::p_Domain::inRange(_2605,_2606,_2607); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2605,double _2606,std::shared_ptr< monty::ndarray< int,1 > > _2607){
  _checked_ptr_1<int> _ptr__2607(_2607 ? _2607->raw() : nullptr, _2607 ? _2607->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2605)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2606)}),_2607);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2608,    std::shared_ptr< monty::ndarray< double,1 > > _2609) { return mosek::fusion::p_Domain::inRange(_2608,_2609); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2608,std::shared_ptr< monty::ndarray< double,1 > > _2609){
  _checked_ptr_1<double> _ptr__2608(_2608 ? _2608->raw() : nullptr, _2608 ? _2608->size(0) : 0);
  _checked_ptr_1<double> _ptr__2609(_2609 ? _2609->raw() : nullptr, _2609 ? _2609->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2608,_2609,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2608)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2610,    double _2611) { return mosek::fusion::p_Domain::inRange(_2610,_2611); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2610,double _2611){
  _checked_ptr_1<double> _ptr__2610(_2610 ? _2610->raw() : nullptr, _2610 ? _2610->size(0) : 0);
  std::vector<double> _8016;
  for (int _2612 = (int)0, _8017 = (int)((_2610)->size(0)); _2612 < _8017 ; ++_2612)
  {
    _8016.push_back(_2611);
  }
  auto _8018 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8016.size()),_8016.begin(),_8016.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2610,_8018,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2610)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2613,    std::shared_ptr< monty::ndarray< double,1 > > _2614) { return mosek::fusion::p_Domain::inRange(_2613,_2614); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2613,std::shared_ptr< monty::ndarray< double,1 > > _2614){
  _checked_ptr_1<double> _ptr__2614(_2614 ? _2614->raw() : nullptr, _2614 ? _2614->size(0) : 0);
  std::vector<double> _8019;
  for (int _2615 = (int)0, _8020 = (int)((_2614)->size(0)); _2615 < _8020 ; ++_2615)
  {
    _8019.push_back(_2613);
  }
  auto _8021 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8019.size()),_8019.begin(),_8019.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8021,_2614,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2614)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2616,    double _2617) { return mosek::fusion::p_Domain::inRange(_2616,_2617); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2616,double _2617){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2616)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2617)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2618) { return mosek::fusion::p_Domain::greaterThan(_2618); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2618){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::GreaterThan,_2618);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2619,    std::shared_ptr< monty::ndarray< int,1 > > _2620) { return mosek::fusion::p_Domain::greaterThan(_2619,_2620); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2619,std::shared_ptr< monty::ndarray< int,1 > > _2620){
  _checked_ptr_1<double> _ptr__2619(_2619 ? _2619->raw() : nullptr, _2619 ? _2619->size(0) : 0);
  _checked_ptr_1<int> _ptr__2620(_2620 ? _2620->raw() : nullptr, _2620 ? _2620->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2619),_2620);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2621) { return mosek::fusion::p_Domain::greaterThan(_2621); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2621){
  std::vector<double> _8022;
  for (int _2622 = (int)0, _8023 = (int)((_2621)->size(0)); _2622 < _8023 ; ++_2622)
  {
    for (int _2623 = (int)0, _8024 = (int)((_2621)->size(1)); _2623 < _8024 ; ++_2623)
    {
      _8022.push_back(((*_2621)(_2622,_2623)));
    }
  }
  auto _8025 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8022.size()),_8022.begin(),_8022.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,_8025,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2621)->size(0))),(int)((int)((_2621)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2624) { return mosek::fusion::p_Domain::greaterThan(_2624); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2624){
  _checked_ptr_1<double> _ptr__2624(_2624 ? _2624->raw() : nullptr, _2624 ? _2624->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2624),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2624)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2625,    std::shared_ptr< monty::ndarray< int,1 > > _2626) { return mosek::fusion::p_Domain::greaterThan(_2625,_2626); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2625,std::shared_ptr< monty::ndarray< int,1 > > _2626){
  _checked_ptr_1<int> _ptr__2626(_2626 ? _2626->raw() : nullptr, _2626 ? _2626->size(0) : 0);
  std::vector<double> _8026;
  for (long long _2627 = (int)0, _8027 = ::mosek::fusion::p_Domain::prod(_2626); _2627 < _8027 ; ++_2627)
  {
    _8026.push_back(_2625);
  }
  auto _8028 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8026.size()),_8026.begin(),_8026.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8028,_2626);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2628,    int _2629,    int _2630) { return mosek::fusion::p_Domain::greaterThan(_2628,_2629,_2630); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2628,int _2629,int _2630){
  std::vector<double> _8029;
  for (int _2631 = (int)0, _8030 = safe_mul( _2630,_2629 ); _2631 < _8030 ; ++_2631)
  {
    _8029.push_back(_2628);
  }
  auto _8031 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8029.size()),_8029.begin(),_8029.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8031,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2629),(int)(_2630)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2632,    int _2633) { return mosek::fusion::p_Domain::greaterThan(_2632,_2633); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2632,int _2633){
  std::vector<double> _8032;
  for (int _2634 = (int)0, _8033 = _2633; _2634 < _8033 ; ++_2634)
  {
    _8032.push_back(_2632);
  }
  auto _8034 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8032.size()),_8032.begin(),_8032.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8034,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2633)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2635) { return mosek::fusion::p_Domain::greaterThan(_2635); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2635){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2635)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2636) { return mosek::fusion::p_Domain::lessThan(_2636); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2636){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::LessThan,_2636);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2637,    std::shared_ptr< monty::ndarray< int,1 > > _2638) { return mosek::fusion::p_Domain::lessThan(_2637,_2638); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2637,std::shared_ptr< monty::ndarray< int,1 > > _2638){
  _checked_ptr_1<double> _ptr__2637(_2637 ? _2637->raw() : nullptr, _2637 ? _2637->size(0) : 0);
  _checked_ptr_1<int> _ptr__2638(_2638 ? _2638->raw() : nullptr, _2638 ? _2638->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2637),_2638);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2639) { return mosek::fusion::p_Domain::lessThan(_2639); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2639){
  std::vector<double> _8035;
  for (int _2640 = (int)0, _8036 = (int)((_2639)->size(0)); _2640 < _8036 ; ++_2640)
  {
    for (int _2641 = (int)0, _8037 = (int)((_2639)->size(1)); _2641 < _8037 ; ++_2641)
    {
      _8035.push_back(((*_2639)(_2640,_2641)));
    }
  }
  auto _8038 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8035.size()),_8035.begin(),_8035.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,_8038,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2639)->size(0))),(int)((int)((_2639)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2642) { return mosek::fusion::p_Domain::lessThan(_2642); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2642){
  _checked_ptr_1<double> _ptr__2642(_2642 ? _2642->raw() : nullptr, _2642 ? _2642->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2642),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2642)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2643,    std::shared_ptr< monty::ndarray< int,1 > > _2644) { return mosek::fusion::p_Domain::lessThan(_2643,_2644); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2643,std::shared_ptr< monty::ndarray< int,1 > > _2644){
  _checked_ptr_1<int> _ptr__2644(_2644 ? _2644->raw() : nullptr, _2644 ? _2644->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2643)}),_2644);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2645,    int _2646,    int _2647) { return mosek::fusion::p_Domain::lessThan(_2645,_2646,_2647); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2645,int _2646,int _2647){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2645)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2646),(int)(_2647)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2648,    int _2649) { return mosek::fusion::p_Domain::lessThan(_2648,_2649); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2648,int _2649){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2648)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2649)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2650) { return mosek::fusion::p_Domain::lessThan(_2650); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2650){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2650)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2651) { return mosek::fusion::p_Domain::equalsTo(_2651); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2651){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::EqualsTo,_2651);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2652,    std::shared_ptr< monty::ndarray< int,1 > > _2653) { return mosek::fusion::p_Domain::equalsTo(_2652,_2653); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2652,std::shared_ptr< monty::ndarray< int,1 > > _2653){
  _checked_ptr_1<double> _ptr__2652(_2652 ? _2652->raw() : nullptr, _2652 ? _2652->size(0) : 0);
  _checked_ptr_1<int> _ptr__2653(_2653 ? _2653->raw() : nullptr, _2653 ? _2653->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2652),_2653);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,2 > > _2654) { return mosek::fusion::p_Domain::equalsTo(_2654); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2654){
  std::vector<double> _8039;
  for (int _2655 = (int)0, _8040 = (int)((_2654)->size(0)); _2655 < _8040 ; ++_2655)
  {
    for (int _2656 = (int)0, _8041 = (int)((_2654)->size(1)); _2656 < _8041 ; ++_2656)
    {
      _8039.push_back(((*_2654)(_2655,_2656)));
    }
  }
  auto _8042 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8039.size()),_8039.begin(),_8039.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,_8042,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2654)->size(0))),(int)((int)((_2654)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2657) { return mosek::fusion::p_Domain::equalsTo(_2657); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2657){
  _checked_ptr_1<double> _ptr__2657(_2657 ? _2657->raw() : nullptr, _2657 ? _2657->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2657),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2657)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2658,    std::shared_ptr< monty::ndarray< int,1 > > _2659) { return mosek::fusion::p_Domain::equalsTo(_2658,_2659); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2658,std::shared_ptr< monty::ndarray< int,1 > > _2659){
  _checked_ptr_1<int> _ptr__2659(_2659 ? _2659->raw() : nullptr, _2659 ? _2659->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2658)}),_2659);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2660,    int _2661,    int _2662) { return mosek::fusion::p_Domain::equalsTo(_2660,_2661,_2662); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2660,int _2661,int _2662){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2660)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2661),(int)(_2662)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2663,    int _2664) { return mosek::fusion::p_Domain::equalsTo(_2663,_2664); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2663,int _2664){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2663)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2664)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2665) { return mosek::fusion::p_Domain::equalsTo(_2665); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2665){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2665)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( std::shared_ptr< monty::ndarray< int,1 > > _2666) { return mosek::fusion::p_Domain::unbounded(_2666); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2666){
  _checked_ptr_1<int> _ptr__2666(_2666 ? _2666->raw() : nullptr, _2666 ? _2666->size(0) : 0);
  std::vector<int> _8043;
  for (int _2667 = (int)0, _8044 = (int)((_2666)->size(0)); _2667 < _8044 ; ++_2667)
  {
    _8043.push_back(_ptr__2666[_2667]);
  }
  auto _8045 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8043.size()),_8043.begin(),_8043.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,_8045);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2668,    int _2669) { return mosek::fusion::p_Domain::unbounded(_2668,_2669); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2668,int _2669){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2668),(int)(_2669)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2670) { return mosek::fusion::p_Domain::unbounded(_2670); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2670){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2670)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( ) { return mosek::fusion::p_Domain::unbounded(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,true,nullptr,nullptr);
}
void mosek::fusion::p_Domain::destroy(){}void mosek::fusion::Domain::destroy() { mosek::fusion::p_Domain::_get_impl(this)->destroy(); }mosek::fusion::ExprConst::ExprConst(mosek::fusion::p_ExprConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprConst()" << this << std::endl; */ }mosek::fusion::ExprConst::~ExprConst() {  /* std::cout << "~ExprConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprConst::p_ExprConst  (::mosek::fusion::ExprConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2671,    std::shared_ptr< monty::ndarray< long long,1 > > _2672,    std::shared_ptr< monty::ndarray< double,1 > > _2673){ return new mosek::fusion::ExprConst(_2671,_2672,_2673); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2671,    std::shared_ptr< monty::ndarray< long long,1 > > _2672,    std::shared_ptr< monty::ndarray< double,1 > > _2673) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2671,_2672,_2673); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2671,    std::shared_ptr< monty::ndarray< long long,1 > > _2672,    std::shared_ptr< monty::ndarray< double,1 > > _2673){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2671(_2671 ? _2671->raw() : nullptr, _2671 ? _2671->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2672(_2672 ? _2672->raw() : nullptr, _2672 ? _2672->size(0) : 0);
    _checked_ptr_1<double> _ptr__2673(_2673 ? _2673->raw() : nullptr, _2673 ? _2673->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2671);
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = ::mosek::fusion::Utils::Tools::arraycopy(_2673);
    std::shared_ptr< monty::ndarray< long long,1 > > _8046;
    bool _8047 = (NULL != _2672.get());
    if (_8047)
    {
      _8046 = ::mosek::fusion::Utils::Tools::arraycopy(_2672);
    }
    else
    {
      _8046 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8046;
    ::mosek::fusion::p_ExprConst::validate(_2671,_2673,_2672);
  }
}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2674,    std::shared_ptr< monty::ndarray< long long,1 > > _2675,    double _2676){ return new mosek::fusion::ExprConst(_2674,_2675,_2676); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2674,    std::shared_ptr< monty::ndarray< long long,1 > > _2675,    double _2676) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2674,_2675,_2676); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2674,    std::shared_ptr< monty::ndarray< long long,1 > > _2675,    double _2676){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2674(_2674 ? _2674->raw() : nullptr, _2674 ? _2674->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2675(_2675 ? _2675->raw() : nullptr, _2675 ? _2675->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2674);
    long long _8048;
    bool _8049 = (NULL == _2675.get());
    if (_8049)
    {
      _8048 = ::mosek::fusion::p_Set::size(_2674);
    }
    else
    {
      _8048 = (int)((_2675)->size(0));
    }
    long long _2677 = _8048;
    std::vector<double> _8050;
    for (long long _2678 = (int)0, _8051 = _2677; _2678 < _8051 ; ++_2678)
    {
      _8050.push_back(_2676);
    }
    auto _8052 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8050.size()),_8050.begin(),_8050.end()));
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = _8052;
    std::shared_ptr< monty::ndarray< long long,1 > > _8053;
    bool _8054 = (NULL != _2675.get());
    if (_8054)
    {
      _8053 = ::mosek::fusion::Utils::Tools::arraycopy(_2675);
    }
    else
    {
      _8053 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8053;
    ::mosek::fusion::p_ExprConst::validate(_2674,mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix,_2675);
  }
}void mosek::fusion::ExprConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2679,monty::rc_ptr< ::mosek::fusion::WorkStack > _2680,monty::rc_ptr< ::mosek::fusion::WorkStack > _2681) { mosek::fusion::p_ExprConst::_get_impl(this)->eval(_2679,_2680,_2681); }void mosek::fusion::p_ExprConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2679,monty::rc_ptr< ::mosek::fusion::WorkStack > _2680,monty::rc_ptr< ::mosek::fusion::WorkStack > _2681){
  std::shared_ptr< monty::ndarray< int,1 > > _2682 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__2682(_2682 ? _2682->raw() : nullptr,_2682 ? _2682->size(0) : 0);
  int _2683 = (int)((bfix)->size(0));
  bool _2684 = ((NULL != sparsity.get()) && ((int)((sparsity)->size(0)) < ::mosek::fusion::p_Set::size(_2682)));
  int _2685 = _2679->alloci32(safe_add( _2683,(int)1 ));
  int _8055;
  bool _8056 = _2684;
  if (_8056)
  {
    _8055 = (int)1;
  }
  else
  {
    _8055 = (int)0;
  }
  _2679->pushi32(_8055);
  _2679->pushi32((int)0);
  _2679->pushi32(_2683);
  int _8057 = (int)0;
  int _8058 = (int)((_2682)->size(0));
  for (int _2686 = _8057; _2686 < _8058; ++_2686)
  {
    {
      _2679->pushi32(_ptr__2682[_2686]);
    }
  }
  _2679->pushi32((int)((_2682)->size(0)));
  if ((NULL != sparsity.get()))
  {
    {
      int _2687 = _2679->alloci64((int)((sparsity)->size(0)));
      std::shared_ptr< monty::ndarray< long long,1 > > _2688 = mosek::fusion::p_WorkStack::_get_impl(_2679)->i64;
      _checked_ptr_1<long long> _ptr__2688(_2688 ? _2688->raw() : nullptr,_2688 ? _2688->size(0) : 0);
      int _8059 = (int)0;
      int _8060 = (int)((sparsity)->size(0));
      for (int _2689 = _8059; _2689 < _8060; ++_2689)
      {
        {
          _ptr__2688[safe_add( _2687,_2689 )] = ((*sparsity)(_2689));
        }
      }
    }
  }
  {}
  int _2690 = _2679->allocf64((int)((bfix)->size(0)));
  std::shared_ptr< monty::ndarray< double,1 > > _2691 = mosek::fusion::p_WorkStack::_get_impl(_2679)->f64;
  _checked_ptr_1<double> _ptr__2691(_2691 ? _2691->raw() : nullptr,_2691 ? _2691->size(0) : 0);
  int _8061 = (int)0;
  int _8062 = (int)((bfix)->size(0));
  for (int _2692 = _8061; _2692 < _8062; ++_2692)
  {
    {
      _ptr__2691[safe_add( _2690,_2692 )] = ((*bfix)(_2692));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2693 = mosek::fusion::p_WorkStack::_get_impl(_2679)->i32;
  _checked_ptr_1<int> _ptr__2693(_2693 ? _2693->raw() : nullptr,_2693 ? _2693->size(0) : 0);
  int _8063 = (int)0;
  int _8064 = safe_add( _2683,(int)1 );
  for (int _2694 = _8063; _2694 < _8064; ++_2694)
  {
    {
      _ptr__2693[safe_add( _2685,_2694 )] = (int)0;
    }
  }
}
void mosek::fusion::p_ExprConst::validate(std::shared_ptr< monty::ndarray< int,1 > > _2695,std::shared_ptr< monty::ndarray< double,1 > > _2696,std::shared_ptr< monty::ndarray< long long,1 > > _2697){
  _checked_ptr_1<int> _ptr__2695(_2695 ? _2695->raw() : nullptr, _2695 ? _2695->size(0) : 0);
  _checked_ptr_1<double> _ptr__2696(_2696 ? _2696->raw() : nullptr, _2696 ? _2696->size(0) : 0);
  _checked_ptr_1<long long> _ptr__2697(_2697 ? _2697->raw() : nullptr, _2697 ? _2697->size(0) : 0);
  long long _2698 = ::mosek::fusion::p_Set::size(_2695);
  if ((NULL != _2697.get()))
  {
    {
      if (((int)((_2697)->size(0)) != (int)((_2696)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data lengths"));
        }
      }
      {}
      int _8065 = (int)0;
      int _8066 = (int)((_2697)->size(0));
      for (int _2699 = _8065; _2699 < _8066; ++_2699)
      {
        {
          if (((_ptr__2697[_2699] < (int)0) || (_ptr__2697[_2699] >= _2698)))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid sparsity index"));
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_2696)->size(0)) != _2698))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data length"));
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprConst :: toString() { return mosek::fusion::p_ExprConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprConst::toString(){
  return std::string ("ExprConst()");
}
void mosek::fusion::p_ExprConst::destroy(){sparsity.reset();bfix.reset();}void mosek::fusion::ExprConst::destroy() { mosek::fusion::p_ExprConst::_get_impl(this)->destroy(); }mosek::fusion::ExprPick::ExprPick(mosek::fusion::p_ExprPick *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPick()" << this << std::endl; */ }mosek::fusion::ExprPick::~ExprPick() {  /* std::cout << "~ExprPick()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPick::p_ExprPick  (::mosek::fusion::ExprPick * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2700,    std::shared_ptr< monty::ndarray< int,2 > > _2701){ return new mosek::fusion::ExprPick(_2700,_2701); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2700,    std::shared_ptr< monty::ndarray< int,2 > > _2701) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2700,_2701); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2700,    std::shared_ptr< monty::ndarray< int,2 > > _2701){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2701)->size(0)))}));
    std::shared_ptr< monty::ndarray< int,1 > > _2702 = _2700->getShape();
    _checked_ptr_1<int> _ptr__2702(_2702 ? _2702->raw() : nullptr,_2702 ? _2702->size(0) : 0);
    int _2703 = (int)((_2702)->size(0));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2700;
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_2701)->size(0)))));
    std::shared_ptr< monty::ndarray< long long,1 > > _2704 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
    _checked_ptr_1<long long> _ptr__2704(_2704 ? _2704->raw() : nullptr,_2704 ? _2704->size(0) : 0);
    if (((int)((_2701)->size(1)) != _2703))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and index dimensions"));
      }
    }
    {}
    int _8067 = (int)0;
    int _8068 = (int)((_2701)->size(0));
    for (int _2705 = _8067; _2705 < _8068; ++_2705)
    {
      {
        int _8069 = (int)0;
        int _8070 = _2703;
        for (int _2706 = _8069; _2706 < _8070; ++_2706)
        {
          {
            if (((((*_2701)(_2705,_2706)) < (int)0) || (((*_2701)(_2705,_2706)) >= _ptr__2702[_2706])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2707 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2703)));
      _checked_ptr_1<long long> _ptr__2707(_2707 ? _2707->raw() : nullptr,_2707 ? _2707->size(0) : 0);
      _ptr__2707[(_2703 - (int)1)] = (int)1;
      int _8071 = (int)1;
      int _8072 = _2703;
      for (int _2708 = _8071; _2708 < _8072; ++_2708)
      {
        {
          _ptr__2707[((_2703 - _2708) - (int)1)] = safe_mul( _ptr__2707[(_2703 - _2708)],_ptr__2702[(_2703 - _2708)] );
        }
      }
      int _8073 = (int)0;
      int _8074 = (int)((_2701)->size(0));
      for (int _2709 = _8073; _2709 < _8074; ++_2709)
      {
        {
          long long _2710 = (long long)0;
          int _8075 = (int)0;
          int _8076 = _2703;
          for (int _2711 = _8075; _2711 < _8076; ++_2711)
          {
            {
              _2710 += safe_mul( _ptr__2707[_2711],((*_2701)(_2709,_2711)) );
            }
          }
          _ptr__2704[_2709] = _2710;
        }
      }
    }
  }
}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2712,    std::shared_ptr< monty::ndarray< long long,1 > > _2713){ return new mosek::fusion::ExprPick(_2712,_2713); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2712,    std::shared_ptr< monty::ndarray< long long,1 > > _2713) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2712,_2713); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2712,    std::shared_ptr< monty::ndarray< long long,1 > > _2713){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2713(_2713 ? _2713->raw() : nullptr, _2713 ? _2713->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2713)->size(0)))}));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2712;
    std::shared_ptr< monty::ndarray< int,1 > > _2714 = _2712->getShape();
    _checked_ptr_1<int> _ptr__2714(_2714 ? _2714->raw() : nullptr,_2714 ? _2714->size(0) : 0);
    long long _2715 = ::mosek::fusion::p_Set::size(_2714);
    int _8077 = (int)0;
    int _8078 = (int)((_2713)->size(0));
    for (int _2716 = _8077; _2716 < _8078; ++_2716)
    {
      {
        if (((_ptr__2713[_2716] < (int)0) || (_ptr__2713[_2716] >= _2715)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
          }
        }
        {}
      }
    }
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = ::mosek::fusion::Utils::Tools::arraycopy(_2713);
  }
}void mosek::fusion::ExprPick :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2717,monty::rc_ptr< ::mosek::fusion::WorkStack > _2718,monty::rc_ptr< ::mosek::fusion::WorkStack > _2719) { mosek::fusion::p_ExprPick::_get_impl(this)->eval(_2717,_2718,_2719); }void mosek::fusion::p_ExprPick::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2717,monty::rc_ptr< ::mosek::fusion::WorkStack > _2718,monty::rc_ptr< ::mosek::fusion::WorkStack > _2719){
  expr->eval(_2718,_2717,_2719);
  _2718->pop_expr();
  int _2720 = mosek::fusion::p_WorkStack::_get_impl(_2718)->nd;
  int _2721 = mosek::fusion::p_WorkStack::_get_impl(_2718)->shape_base;
  int _2722 = mosek::fusion::p_WorkStack::_get_impl(_2718)->nelem;
  int _2723 = mosek::fusion::p_WorkStack::_get_impl(_2718)->nnz;
  bool _2724 = mosek::fusion::p_WorkStack::_get_impl(_2718)->hassp;
  int _2725 = mosek::fusion::p_WorkStack::_get_impl(_2718)->ptr_base;
  int _2726 = mosek::fusion::p_WorkStack::_get_impl(_2718)->sp_base;
  int _2727 = mosek::fusion::p_WorkStack::_get_impl(_2718)->nidxs_base;
  int _2728 = mosek::fusion::p_WorkStack::_get_impl(_2718)->bfix_base;
  int _2729 = mosek::fusion::p_WorkStack::_get_impl(_2718)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _2730 = mosek::fusion::p_WorkStack::_get_impl(_2718)->i32;
  _checked_ptr_1<int> _ptr__2730(_2730 ? _2730->raw() : nullptr,_2730 ? _2730->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2731 = mosek::fusion::p_WorkStack::_get_impl(_2718)->i64;
  _checked_ptr_1<long long> _ptr__2731(_2731 ? _2731->raw() : nullptr,_2731 ? _2731->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2732 = mosek::fusion::p_WorkStack::_get_impl(_2718)->f64;
  _checked_ptr_1<double> _ptr__2732(_2732 ? _2732->raw() : nullptr,_2732 ? _2732->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2733 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
  _checked_ptr_1<long long> _ptr__2733(_2733 ? _2733->raw() : nullptr,_2733 ? _2733->size(0) : 0);
  if ((!_2724))
  {
    {
      int _2734 = (int)((_2733)->size(0));
      int _2735 = (int)1;
      int _2736 = (int)0;
      int _8079 = (int)0;
      int _8080 = (int)((_2733)->size(0));
      for (int _2737 = _8079; _2737 < _8080; ++_2737)
      {
        {
          _2736 += (_ptr__2730[safe_add( safe_add( _2725,_ptr__2733[_2737] ),(int)1 )] - _ptr__2730[safe_add( _2725,_ptr__2733[_2737] )]);
        }
      }
      _2717->alloc_expr(_2735,_2734,_2736,false);
      int _2738 = mosek::fusion::p_WorkStack::_get_impl(_2717)->cof_base;
      int _2739 = mosek::fusion::p_WorkStack::_get_impl(_2717)->bfix_base;
      int _2740 = mosek::fusion::p_WorkStack::_get_impl(_2717)->nidxs_base;
      int _2741 = mosek::fusion::p_WorkStack::_get_impl(_2717)->ptr_base;
      int _2742 = mosek::fusion::p_WorkStack::_get_impl(_2717)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2743 = mosek::fusion::p_WorkStack::_get_impl(_2717)->i32;
      _checked_ptr_1<int> _ptr__2743(_2743 ? _2743->raw() : nullptr,_2743 ? _2743->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2744 = mosek::fusion::p_WorkStack::_get_impl(_2717)->i64;
      _checked_ptr_1<long long> _ptr__2744(_2744 ? _2744->raw() : nullptr,_2744 ? _2744->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2745 = mosek::fusion::p_WorkStack::_get_impl(_2717)->f64;
      _checked_ptr_1<double> _ptr__2745(_2745 ? _2745->raw() : nullptr,_2745 ? _2745->size(0) : 0);
      _ptr__2743[_2742] = (int)((_2733)->size(0));
      int _2746 = (int)0;
      _ptr__2743[_2741] = (int)0;
      int _8081 = (int)0;
      int _8082 = (int)((_2733)->size(0));
      for (int _2747 = _8081; _2747 < _8082; ++_2747)
      {
        {
          int _8083 = _ptr__2730[safe_add( _2725,_ptr__2733[_2747] )];
          int _8084 = _ptr__2730[safe_add( safe_add( _2725,_ptr__2733[_2747] ),(int)1 )];
          for (int _2748 = _8083; _2748 < _8084; ++_2748)
          {
            {
              _ptr__2744[safe_add( _2740,_2746 )] = _ptr__2731[safe_add( _2727,_2748 )];
              _ptr__2745[safe_add( _2738,_2746 )] = _ptr__2732[safe_add( _2729,_2748 )];
              ++ _2746;
            }
          }
          _ptr__2745[safe_add( _2739,_2747 )] = _ptr__2732[safe_add( _2728,_ptr__2733[_2747] )];
          _ptr__2743[safe_add( safe_add( _2741,_2747 ),(int)1 )] = _2746;
        }
      }
    }
  }
  else
  {
    {
      int _2749 = (int)1;
      int _2750 = (int)((_2733)->size(0));
      int _2751 = (int)0;
      std::shared_ptr< monty::ndarray< long long,1 > > _2752 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
      _checked_ptr_1<long long> _ptr__2752(_2752 ? _2752->raw() : nullptr,_2752 ? _2752->size(0) : 0);
      int _2753 = _2719->alloci32((int)((_2752)->size(0)));
      std::shared_ptr< monty::ndarray< int,1 > > _2754 = mosek::fusion::p_WorkStack::_get_impl(_2719)->i32;
      _checked_ptr_1<int> _ptr__2754(_2754 ? _2754->raw() : nullptr,_2754 ? _2754->size(0) : 0);
      int _8085 = (int)0;
      int _8086 = (int)((_2752)->size(0));
      for (int _2755 = _8085; _2755 < _8086; ++_2755)
      {
        {
          int _2756 = _2722;
          int _2757 = (int)0;
          while ( (_2757 < (_2756 - (int)1)) )
          {
            {
              int _2758 = (safe_add( safe_add( _2756,_2757 ),(int)1 ) / (int)2);
              if ((_ptr__2731[safe_add( _2726,_2758 )] >= _ptr__2752[_2755]))
              {
                {
                  _2756 = _2758;
                }
              }
              else
              {
                {
                  _2757 = _2758;
                }
              }
            }
          }
          ++ _2757;
          if (((_2757 < _2722) && (_ptr__2731[safe_add( _2726,_2757 )] == _ptr__2752[_2755])))
          {
            {
              _ptr__2754[safe_add( _2753,_2755 )] = _2757;
              _2751 += (_ptr__2730[safe_add( safe_add( _2725,_2757 ),(int)1 )] - _ptr__2730[safe_add( _2725,_2757 )]);
            }
          }
          else
          {
            {
              _ptr__2754[safe_add( _2753,_2755 )] = (-(int)1);
            }
          }
        }
      }
      _2717->alloc_expr(_2749,_2750,_2751,false);
      int _2759 = mosek::fusion::p_WorkStack::_get_impl(_2717)->ptr_base;
      int _2760 = mosek::fusion::p_WorkStack::_get_impl(_2717)->nidxs_base;
      int _2761 = mosek::fusion::p_WorkStack::_get_impl(_2717)->cof_base;
      int _2762 = mosek::fusion::p_WorkStack::_get_impl(_2717)->bfix_base;
      int _2763 = mosek::fusion::p_WorkStack::_get_impl(_2717)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2764 = mosek::fusion::p_WorkStack::_get_impl(_2717)->i32;
      _checked_ptr_1<int> _ptr__2764(_2764 ? _2764->raw() : nullptr,_2764 ? _2764->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2765 = mosek::fusion::p_WorkStack::_get_impl(_2717)->i64;
      _checked_ptr_1<long long> _ptr__2765(_2765 ? _2765->raw() : nullptr,_2765 ? _2765->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2766 = mosek::fusion::p_WorkStack::_get_impl(_2717)->f64;
      _checked_ptr_1<double> _ptr__2766(_2766 ? _2766->raw() : nullptr,_2766 ? _2766->size(0) : 0);
      _ptr__2764[_2763] = (int)((_2752)->size(0));
      _ptr__2764[_2759] = (int)0;
      int _2767 = (int)0;
      int _8087 = (int)0;
      int _8088 = (int)((_2752)->size(0));
      for (int _2768 = _8087; _2768 < _8088; ++_2768)
      {
        {
          if ((_ptr__2754[safe_add( _2753,_2768 )] >= (int)0))
          {
            {
              int _2769 = _ptr__2754[safe_add( _2753,_2768 )];
              int _8089 = _ptr__2730[safe_add( _2725,_2769 )];
              int _8090 = _ptr__2730[safe_add( safe_add( _2725,_2769 ),(int)1 )];
              for (int _2770 = _8089; _2770 < _8090; ++_2770)
              {
                {
                  _ptr__2765[safe_add( _2760,_2767 )] = _ptr__2731[safe_add( _2727,_2770 )];
                  _ptr__2766[safe_add( _2761,_2767 )] = _ptr__2732[safe_add( _2729,_2770 )];
                  ++ _2767;
                }
              }
              _ptr__2766[safe_add( _2762,_2768 )] = _ptr__2732[safe_add( _2728,_2769 )];
            }
          }
          else
          {
            {
              _ptr__2766[safe_add( _2762,_2768 )] = 0.0;
            }
          }
          _ptr__2764[safe_add( safe_add( _2759,_2768 ),(int)1 )] = _2767;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprPick :: toString() { return mosek::fusion::p_ExprPick::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprPick::toString(){
  return std::string ("ExprPick()");
}
void mosek::fusion::p_ExprPick::destroy(){idxs.reset();expr.reset();}void mosek::fusion::ExprPick::destroy() { mosek::fusion::p_ExprPick::_get_impl(this)->destroy(); }mosek::fusion::ExprSlice::ExprSlice(mosek::fusion::p_ExprSlice *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSlice()" << this << std::endl; */ }mosek::fusion::ExprSlice::~ExprSlice() {  /* std::cout << "~ExprSlice()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSlice::p_ExprSlice  (::mosek::fusion::ExprSlice * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSlice::t mosek::fusion::p_ExprSlice::_new_ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2771,    std::shared_ptr< monty::ndarray< int,1 > > _2772,    std::shared_ptr< monty::ndarray< int,1 > > _2773){ return new mosek::fusion::ExprSlice(_2771,_2772,_2773); }mosek::fusion::ExprSlice::ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2771,    std::shared_ptr< monty::ndarray< int,1 > > _2772,    std::shared_ptr< monty::ndarray< int,1 > > _2773) :    ExprSlice(new mosek::fusion::p_ExprSlice(this)){ mosek::fusion::p_ExprSlice::_get_impl(this)->_initialize(_2771,_2772,_2773); }void mosek::fusion::p_ExprSlice::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2771,    std::shared_ptr< monty::ndarray< int,1 > > _2772,    std::shared_ptr< monty::ndarray< int,1 > > _2773){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2772(_2772 ? _2772->raw() : nullptr, _2772 ? _2772->size(0) : 0);
    _checked_ptr_1<int> _ptr__2773(_2773 ? _2773->raw() : nullptr, _2773 ? _2773->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSlice::makeShape(_2771->getShape(),_2772,_2773));
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->expr = _2771;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->first = _2772;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->last = _2773;
  }
}void mosek::fusion::ExprSlice :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2774,monty::rc_ptr< ::mosek::fusion::WorkStack > _2775,monty::rc_ptr< ::mosek::fusion::WorkStack > _2776) { mosek::fusion::p_ExprSlice::_get_impl(this)->eval(_2774,_2775,_2776); }void mosek::fusion::p_ExprSlice::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2774,monty::rc_ptr< ::mosek::fusion::WorkStack > _2775,monty::rc_ptr< ::mosek::fusion::WorkStack > _2776){
  expr->eval(_2775,_2774,_2776);
  int _2777 = _2775->popi32();
  int _2778 = _2775->popi32(_2777);
  int _2779 = _2775->popi32();
  int _2780 = _2775->popi32();
  bool _2781 = (_2775->popi32() != (int)0);
  int _2782 = _2775->popi32(safe_add( _2779,(int)1 ));
  int _8091;
  bool _8092 = _2781;
  if (_8092)
  {
    _8091 = _2775->popi64(_2779);
  }
  else
  {
    _8091 = (-(int)1);
  }
  int _2783 = _8091;
  int _2784 = _2775->popi64(_2780);
  int _2785 = _2775->popf64(_2779);
  int _2786 = _2775->popf64(_2780);
  std::shared_ptr< monty::ndarray< int,1 > > _2787 = mosek::fusion::p_WorkStack::_get_impl(_2775)->i32;
  _checked_ptr_1<int> _ptr__2787(_2787 ? _2787->raw() : nullptr,_2787 ? _2787->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2788 = mosek::fusion::p_WorkStack::_get_impl(_2775)->i64;
  _checked_ptr_1<long long> _ptr__2788(_2788 ? _2788->raw() : nullptr,_2788 ? _2788->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2789 = mosek::fusion::p_WorkStack::_get_impl(_2775)->f64;
  _checked_ptr_1<double> _ptr__2789(_2789 ? _2789->raw() : nullptr,_2789 ? _2789->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2790 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2777)));
  _checked_ptr_1<long long> _ptr__2790(_2790 ? _2790->raw() : nullptr,_2790 ? _2790->size(0) : 0);
  _ptr__2790[(_2777 - (int)1)] = (int)1;
  int _8093 = (int)1;
  int _8094 = _2777;
  for (int _2791 = _8093; _2791 < _8094; ++_2791)
  {
    {
      _ptr__2790[((_2777 - _2791) - (int)1)] = safe_mul( _ptr__2790[(_2777 - _2791)],_ptr__2787[(safe_add( _2778,_2777 ) - _2791)] );
    }
  }
  int _2792 = (int)0;
  int _2793 = (int)0;
  if (_2781)
  {
    {
      int _8095 = (int)0;
      int _8096 = _2779;
      for (int _2794 = _8095; _2794 < _8096; ++_2794)
      {
        {
          bool _2795 = true;
          int _8097 = (int)0;
          int _8098 = _2777;
          for (int _2796 = _8097; _2796 < _8098; ++_2796)
          {
            {
              long long _2797 = ((_ptr__2788[safe_add( _2783,_2794 )] / _ptr__2790[_2796]) % _ptr__2787[safe_add( _2778,_2796 )]);
              _2795 = (_2795 && ((_2797 >= ((*first)(_2796))) && (_2797 < ((*last)(_2796)))));
            }
          }
          if (_2795)
          {
            {
              _2793 += (_ptr__2787[safe_add( safe_add( _2782,_2794 ),(int)1 )] - _ptr__2787[safe_add( _2782,_2794 )]);
              ++ _2792;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      _2792 = (int)1;
      int _8099 = (int)0;
      int _8100 = _2777;
      for (int _2798 = _8099; _2798 < _8100; ++_2798)
      {
        {
          _2792 *= (((*last)(_2798)) - ((*first)(_2798)));
        }
      }
      int _8101 = (int)0;
      int _8102 = _2779;
      for (int _2799 = _8101; _2799 < _8102; ++_2799)
      {
        {
          bool _2800 = true;
          int _8103 = (int)0;
          int _8104 = _2777;
          for (int _2801 = _8103; _2801 < _8104; ++_2801)
          {
            {
              long long _2802 = ((_2799 / _ptr__2790[_2801]) % _ptr__2787[safe_add( _2778,_2801 )]);
              _2800 = (_2800 && ((_2802 >= ((*first)(_2801))) && (_2802 < ((*last)(_2801)))));
            }
          }
          if (_2800)
          {
            {
              _2793 += (_ptr__2787[safe_add( safe_add( _2782,_2799 ),(int)1 )] - _ptr__2787[safe_add( _2782,_2799 )]);
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _8105;
  for (int _2804 = (int)0, _8106 = _2777; _2804 < _8106 ; ++_2804)
  {
    _8105.push_back((((*last)(_2804)) - ((*first)(_2804))));
  }
  auto _8107 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8105.size()),_8105.begin(),_8105.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _2803 = _8107;
  _checked_ptr_1<int> _ptr__2803(_2803 ? _2803->raw() : nullptr,_2803 ? _2803->size(0) : 0);
  int _2805 = _2774->allocf64(_2793);
  int _2806 = _2774->allocf64(_2792);
  int _2807 = _2774->alloci64(_2793);
  int _8108;
  bool _8109 = _2781;
  if (_8109)
  {
    _8108 = _2774->alloci64(_2792);
  }
  else
  {
    _8108 = (-(int)1);
  }
  int _2808 = _8108;
  int _2809 = _2774->alloci32(safe_add( _2792,(int)1 ));
  int _8110;
  bool _8111 = _2781;
  if (_8111)
  {
    _8110 = (int)1;
  }
  else
  {
    _8110 = (int)0;
  }
  _2774->pushi32(_8110);
  _2774->pushi32(_2793);
  _2774->pushi32(_2792);
  int _8112 = (int)0;
  int _8113 = _2777;
  for (int _2810 = _8112; _2810 < _8113; ++_2810)
  {
    {
      _2774->pushi32(_ptr__2803[_2810]);
    }
  }
  _2774->pushi32(_2777);
  std::shared_ptr< monty::ndarray< int,1 > > _2811 = mosek::fusion::p_WorkStack::_get_impl(_2774)->i32;
  _checked_ptr_1<int> _ptr__2811(_2811 ? _2811->raw() : nullptr,_2811 ? _2811->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2812 = mosek::fusion::p_WorkStack::_get_impl(_2774)->i64;
  _checked_ptr_1<long long> _ptr__2812(_2812 ? _2812->raw() : nullptr,_2812 ? _2812->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2813 = mosek::fusion::p_WorkStack::_get_impl(_2774)->f64;
  _checked_ptr_1<double> _ptr__2813(_2813 ? _2813->raw() : nullptr,_2813 ? _2813->size(0) : 0);
  _ptr__2811[_2809] = (int)0;
  std::shared_ptr< monty::ndarray< long long,1 > > _2814 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2777)));
  _checked_ptr_1<long long> _ptr__2814(_2814 ? _2814->raw() : nullptr,_2814 ? _2814->size(0) : 0);
  _ptr__2814[(_2777 - (int)1)] = (int)1;
  int _8114 = (int)1;
  int _8115 = _2777;
  for (int _2815 = _8114; _2815 < _8115; ++_2815)
  {
    {
      _ptr__2814[((_2777 - _2815) - (int)1)] = safe_mul( _ptr__2814[(_2777 - _2815)],_ptr__2803[(_2777 - _2815)] );
    }
  }
  int _2816 = (int)0;
  int _2817 = (int)0;
  if (_2781)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2818 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2777)));
      _checked_ptr_1<int> _ptr__2818(_2818 ? _2818->raw() : nullptr,_2818 ? _2818->size(0) : 0);
      int _8116 = (int)0;
      int _8117 = _2779;
      for (int _2819 = _8116; _2819 < _8117; ++_2819)
      {
        {
          bool _2820 = true;
          int _8118 = (int)0;
          int _8119 = _2777;
          for (int _2821 = _8118; _2821 < _8119; ++_2821)
          {
            {
              _ptr__2818[_2821] = (int)((_ptr__2788[safe_add( _2783,_2819 )] / _ptr__2790[_2821]) % _ptr__2787[safe_add( _2778,_2821 )]);
              _2820 = (_2820 && ((_ptr__2818[_2821] >= ((*first)(_2821))) && (_ptr__2818[_2821] < ((*last)(_2821)))));
            }
          }
          if (_2820)
          {
            {
              int _8120 = _ptr__2787[safe_add( _2782,_2819 )];
              int _8121 = _ptr__2787[safe_add( safe_add( _2782,_2819 ),(int)1 )];
              for (int _2822 = _8120; _2822 < _8121; ++_2822)
              {
                {
                  _ptr__2812[safe_add( _2807,_2817 )] = _ptr__2788[safe_add( _2784,_2822 )];
                  _ptr__2813[safe_add( _2805,_2817 )] = _ptr__2789[safe_add( _2786,_2822 )];
                  ++ _2817;
                }
              }
              long long _2823 = (long long)0;
              int _8122 = (int)0;
              int _8123 = _2777;
              for (int _2824 = _8122; _2824 < _8123; ++_2824)
              {
                {
                  _2823 += safe_mul( _ptr__2814[_2824],(_ptr__2818[_2824] - ((*first)(_2824))) );
                }
              }
              _ptr__2812[safe_add( _2808,_2816 )] = _2823;
              _ptr__2813[safe_add( _2806,_2816 )] = _ptr__2789[safe_add( _2785,_2819 )];
              _ptr__2811[safe_add( safe_add( _2809,_2816 ),(int)1 )] = _2817;
              ++ _2816;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _8124 = (int)0;
      int _8125 = _2779;
      for (int _2825 = _8124; _2825 < _8125; ++_2825)
      {
        {
          bool _2826 = true;
          int _8126 = (int)0;
          int _8127 = _2777;
          for (int _2827 = _8126; _2827 < _8127; ++_2827)
          {
            {
              long long _2828 = ((_2825 / _ptr__2790[_2827]) % _ptr__2787[safe_add( _2778,_2827 )]);
              _2826 = (_2826 && ((_2828 >= ((*first)(_2827))) && (_2828 < ((*last)(_2827)))));
            }
          }
          if (_2826)
          {
            {
              int _8128 = _ptr__2787[safe_add( _2782,_2825 )];
              int _8129 = _ptr__2787[safe_add( safe_add( _2782,_2825 ),(int)1 )];
              for (int _2829 = _8128; _2829 < _8129; ++_2829)
              {
                {
                  _ptr__2812[safe_add( _2807,_2817 )] = _ptr__2788[safe_add( _2784,_2829 )];
                  _ptr__2813[safe_add( _2805,_2817 )] = _ptr__2789[safe_add( _2786,_2829 )];
                  ++ _2817;
                }
              }
              _ptr__2813[safe_add( _2806,_2816 )] = _ptr__2789[safe_add( _2785,_2825 )];
              _ptr__2811[safe_add( safe_add( _2809,_2816 ),(int)1 )] = _2817;
              ++ _2816;
            }
          }
          {}
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSlice::makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2830,std::shared_ptr< monty::ndarray< int,1 > > _2831,std::shared_ptr< monty::ndarray< int,1 > > _2832){
  _checked_ptr_1<int> _ptr__2830(_2830 ? _2830->raw() : nullptr, _2830 ? _2830->size(0) : 0);
  _checked_ptr_1<int> _ptr__2831(_2831 ? _2831->raw() : nullptr, _2831 ? _2831->size(0) : 0);
  _checked_ptr_1<int> _ptr__2832(_2832 ? _2832->raw() : nullptr, _2832 ? _2832->size(0) : 0);
  if ((((int)((_2830)->size(0)) != (int)((_2831)->size(0))) || ((int)((_2830)->size(0)) != (int)((_2832)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid or mismatching index lengths"));
    }
  }
  {}
  int _8130 = (int)0;
  int _8131 = (int)((_2830)->size(0));
  for (int _2833 = _8130; _2833 < _8131; ++_2833)
  {
    {
      if (((_ptr__2831[_2833] < (int)0) || ((_ptr__2832[_2833] < _ptr__2831[_2833]) || (_ptr__2832[_2833] > _ptr__2830[_2833]))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _8132;
  for (int _2834 = (int)0, _8133 = (int)((_2830)->size(0)); _2834 < _8133 ; ++_2834)
  {
    _8132.push_back((_ptr__2832[_2834] - _ptr__2831[_2834]));
  }
  auto _8134 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8132.size()),_8132.begin(),_8132.end()));
  return _8134;
}
std::string mosek::fusion::ExprSlice :: toString() { return mosek::fusion::p_ExprSlice::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSlice::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2835 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSlice(["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)((int)0)));
  int _8135 = (int)1;
  int _8136 = (int)((first)->size(0));
  for (int _2836 = _8135; _2836 < _8136; ++_2836)
  {
    {
      _2835->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)(_2836)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)(_2836)));
    }
  }
  _2835->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("],"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _2835->toString();
}
void mosek::fusion::p_ExprSlice::destroy(){last.reset();first.reset();expr.reset();}void mosek::fusion::ExprSlice::destroy() { mosek::fusion::p_ExprSlice::_get_impl(this)->destroy(); }mosek::fusion::ExprPermuteDims::ExprPermuteDims(mosek::fusion::p_ExprPermuteDims *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPermuteDims()" << this << std::endl; */ }mosek::fusion::ExprPermuteDims::~ExprPermuteDims() {  /* std::cout << "~ExprPermuteDims()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPermuteDims::p_ExprPermuteDims  (::mosek::fusion::ExprPermuteDims * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2837,    monty::rc_ptr< ::mosek::fusion::Expression > _2838){ return new mosek::fusion::ExprPermuteDims(_2837,_2838); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2837,    monty::rc_ptr< ::mosek::fusion::Expression > _2838) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2837,_2838); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2837,    monty::rc_ptr< ::mosek::fusion::Expression > _2838){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2837(_2837 ? _2837->raw() : nullptr, _2837 ? _2837->size(0) : 0);
    mosek::fusion::p_ExprPermuteDims::_initialize(_2837,_2838,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _2839 = _2838->getShape();
    _checked_ptr_1<int> _ptr__2839(_2839 ? _2839->raw() : nullptr,_2839 ? _2839->size(0) : 0);
    if (((int)((_2837)->size(0)) != (int)((_2839)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
      }
    }
    {}
    std::vector<int> _8137;
    for (int _2841 = (int)0, _8138 = (int)((_2837)->size(0)); _2841 < _8138 ; ++_2841)
    {
      _8137.push_back((int)0);
    }
    auto _8139 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8137.size()),_8137.begin(),_8137.end()));
    std::shared_ptr< monty::ndarray< int,1 > > _2840 = _8139;
    _checked_ptr_1<int> _ptr__2840(_2840 ? _2840->raw() : nullptr,_2840 ? _2840->size(0) : 0);
    int _8140 = (int)0;
    int _8141 = (int)((_2840)->size(0));
    for (int _2842 = _8140; _2842 < _8141; ++_2842)
    {
      {
        if (((_ptr__2837[_2842] < (int)0) || (_ptr__2837[_2842] > (int)((_2839)->size(0)))))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
        ++ _ptr__2840[_ptr__2837[_2842]];
      }
    }
    int _8142 = (int)0;
    int _8143 = (int)((_2840)->size(0));
    for (int _2843 = _8142; _2843 < _8143; ++_2843)
    {
      {
        if (((_ptr__2840[_2843] < (int)1) || (_ptr__2840[_2843] > (int)1)))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2844,    monty::rc_ptr< ::mosek::fusion::Expression > _2845,    int _2846){ return new mosek::fusion::ExprPermuteDims(_2844,_2845,_2846); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2844,    monty::rc_ptr< ::mosek::fusion::Expression > _2845,    int _2846) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2844,_2845,_2846); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2844,    monty::rc_ptr< ::mosek::fusion::Expression > _2845,    int _2846){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2844(_2844 ? _2844->raw() : nullptr, _2844 ? _2844->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprPermuteDims::computeshape(_2844,_2845->getShape()));
    mosek::fusion::p_ExprPermuteDims::_get_impl(::mosek::fusion::ExprPermuteDims::t(_pubthis))->expr = _2845;
    dperm = ::mosek::fusion::Utils::Tools::arraycopy(_2844);
  }
}void mosek::fusion::ExprPermuteDims :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2847,monty::rc_ptr< ::mosek::fusion::WorkStack > _2848,monty::rc_ptr< ::mosek::fusion::WorkStack > _2849) { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->eval(_2847,_2848,_2849); }void mosek::fusion::p_ExprPermuteDims::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2847,monty::rc_ptr< ::mosek::fusion::WorkStack > _2848,monty::rc_ptr< ::mosek::fusion::WorkStack > _2849){
  expr->eval(_2848,_2847,_2849);
  int _2850 = _2848->popi32();
  int _2851 = _2848->popi32(_2850);
  std::shared_ptr< monty::ndarray< long long,1 > > _2852 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2850)));
  _checked_ptr_1<long long> _ptr__2852(_2852 ? _2852->raw() : nullptr,_2852 ? _2852->size(0) : 0);
  _ptr__2852[(_2850 - (int)1)] = (int)1;
  int _8144 = (int)1;
  int _8145 = _2850;
  for (int _2853 = _8144; _2853 < _8145; ++_2853)
  {
    {
      _ptr__2852[((_2850 - _2853) - (int)1)] = safe_mul( _ptr__2852[(_2850 - _2853)],((*mosek::fusion::p_WorkStack::_get_impl(_2848)->i32)((safe_add( _2851,_2850 ) - _2853))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2854 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2850)));
  _checked_ptr_1<int> _ptr__2854(_2854 ? _2854->raw() : nullptr,_2854 ? _2854->size(0) : 0);
  _ptr__2854[(_2850 - (int)1)] = (int)1;
  int _8146 = (int)1;
  int _8147 = _2850;
  for (int _2855 = _8146; _2855 < _8147; ++_2855)
  {
    {
      _ptr__2854[((_2850 - _2855) - (int)1)] = safe_mul( _ptr__2854[(_2850 - _2855)],((*mosek::fusion::p_WorkStack::_get_impl(_2848)->i32)(safe_add( _2851,((*dperm)((_2850 - _2855))) ))) );
    }
  }
  int _2856 = _2848->popi32();
  int _2857 = _2848->popi32();
  bool _2858 = (_2848->popi32() != (int)0);
  int _2859 = _2848->popi32(safe_add( _2856,(int)1 ));
  int _8148;
  bool _8149 = (!_2858);
  if (_8149)
  {
    _8148 = (-(int)1);
  }
  else
  {
    _8148 = _2848->popi64(_2856);
  }
  int _2860 = _8148;
  int _2861 = _2848->popi64(_2857);
  int _2862 = _2848->popf64(_2856);
  int _2863 = _2848->popf64(_2857);
  std::shared_ptr< monty::ndarray< int,1 > > _2864 = mosek::fusion::p_WorkStack::_get_impl(_2848)->i32;
  _checked_ptr_1<int> _ptr__2864(_2864 ? _2864->raw() : nullptr,_2864 ? _2864->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2865 = mosek::fusion::p_WorkStack::_get_impl(_2848)->i64;
  _checked_ptr_1<long long> _ptr__2865(_2865 ? _2865->raw() : nullptr,_2865 ? _2865->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2866 = mosek::fusion::p_WorkStack::_get_impl(_2848)->f64;
  _checked_ptr_1<double> _ptr__2866(_2866 ? _2866->raw() : nullptr,_2866 ? _2866->size(0) : 0);
  if (_2858)
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2867 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2856)));
      _checked_ptr_1<long long> _ptr__2867(_2867 ? _2867->raw() : nullptr,_2867 ? _2867->size(0) : 0);
      {
        int _8150 = (int)0;
        int _8151 = _2856;
        for (int _2868 = _8150; _2868 < _8151; ++_2868)
        {
          {
            long long _2869 = (long long)0;
            int _8152 = (int)0;
            int _8153 = _2850;
            for (int _2870 = _8152; _2870 < _8153; ++_2870)
            {
              {
                _2869 += safe_mul( ((_ptr__2865[safe_add( _2860,_2868 )] / _ptr__2852[_2870]) % _ptr__2864[safe_add( _2851,_2870 )]),_ptr__2854[((*dperm)(_2870))] );
              }
            }
            _ptr__2867[_2868] = _2869;
          }
        }
      }
      std::vector<long long> _8154;
      for (int _2872 = (int)0, _8155 = _2856; _2872 < _8155 ; ++_2872)
      {
        _8154.push_back(_2872);
      }
      auto _8156 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8154.size()),_8154.begin(),_8154.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _2871 = _8156;
      _checked_ptr_1<long long> _ptr__2871(_2871 ? _2871->raw() : nullptr,_2871 ? _2871->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2871,_2867,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2856));
      int _2873 = _2847->alloci32(safe_add( _2856,(int)1 ));
      int _2874 = _2847->alloci64(_2857);
      int _2875 = _2847->alloci64(_2856);
      int _2876 = _2847->allocf64(_2857);
      int _2877 = _2847->allocf64(_2856);
      _2847->pushi32((int)1);
      _2847->pushi32(_2857);
      _2847->pushi32(_2856);
      int _8157 = (int)0;
      int _8158 = _2850;
      for (int _2878 = _8157; _2878 < _8158; ++_2878)
      {
        {
          _2847->pushi32(_ptr__2864[safe_add( _2851,((*dperm)(_2878)) )]);
        }
      }
      _2847->pushi32(_2850);
      std::shared_ptr< monty::ndarray< int,1 > > _2879 = mosek::fusion::p_WorkStack::_get_impl(_2847)->i32;
      _checked_ptr_1<int> _ptr__2879(_2879 ? _2879->raw() : nullptr,_2879 ? _2879->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2880 = mosek::fusion::p_WorkStack::_get_impl(_2847)->i64;
      _checked_ptr_1<long long> _ptr__2880(_2880 ? _2880->raw() : nullptr,_2880 ? _2880->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2881 = mosek::fusion::p_WorkStack::_get_impl(_2847)->f64;
      _checked_ptr_1<double> _ptr__2881(_2881 ? _2881->raw() : nullptr,_2881 ? _2881->size(0) : 0);
      _ptr__2879[_2873] = (int)0;
      int _2882 = (int)0;
      int _2883 = (int)0;
      int _8159 = (int)0;
      int _8160 = _2856;
      for (int _2884 = _8159; _2884 < _8160; ++_2884)
      {
        {
          long long _2885 = _ptr__2871[_2884];
          int _8161 = _ptr__2864[safe_add( _2859,_2885 )];
          int _8162 = _ptr__2864[safe_add( safe_add( _2859,_2885 ),(int)1 )];
          for (int _2886 = _8161; _2886 < _8162; ++_2886)
          {
            {
              _ptr__2880[safe_add( _2874,_2883 )] = _ptr__2865[safe_add( _2861,_2886 )];
              _ptr__2881[safe_add( _2876,_2883 )] = _ptr__2866[safe_add( _2863,_2886 )];
              ++ _2883;
            }
          }
          _ptr__2880[safe_add( _2875,_2884 )] = _ptr__2867[_2885];
          _ptr__2881[safe_add( _2877,_2884 )] = _ptr__2866[safe_add( _2862,_2885 )];
          ++ _2882;
          _ptr__2879[safe_add( safe_add( _2873,_2884 ),(int)1 )] = _2883;
        }
      }
    }
  }
  else
  {
    {
      int _2887 = _2847->alloci32(safe_add( _2856,(int)1 ));
      int _2888 = _2847->alloci64(_2857);
      int _2889 = _2847->allocf64(_2857);
      int _2890 = _2847->allocf64(_2856);
      _2847->pushi32((int)0);
      _2847->pushi32(_2857);
      _2847->pushi32(_2856);
      int _8163 = (int)0;
      int _8164 = _2850;
      for (int _2891 = _8163; _2891 < _8164; ++_2891)
      {
        {
          _2847->pushi32(_ptr__2864[safe_add( _2851,((*dperm)(_2891)) )]);
        }
      }
      _2847->pushi32(_2850);
      std::shared_ptr< monty::ndarray< int,1 > > _2892 = mosek::fusion::p_WorkStack::_get_impl(_2847)->i32;
      _checked_ptr_1<int> _ptr__2892(_2892 ? _2892->raw() : nullptr,_2892 ? _2892->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2893 = mosek::fusion::p_WorkStack::_get_impl(_2847)->i64;
      _checked_ptr_1<long long> _ptr__2893(_2893 ? _2893->raw() : nullptr,_2893 ? _2893->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2894 = mosek::fusion::p_WorkStack::_get_impl(_2847)->f64;
      _checked_ptr_1<double> _ptr__2894(_2894 ? _2894->raw() : nullptr,_2894 ? _2894->size(0) : 0);
      _ptr__2892[_2887] = (int)0;
      int _2895 = (int)0;
      int _2896 = (int)0;
      int _8165 = (int)0;
      int _8166 = _2856;
      for (int _2897 = _8165; _2897 < _8166; ++_2897)
      {
        {
          long long _2898 = (long long)0;
          int _8167 = (int)0;
          int _8168 = _2850;
          for (int _2899 = _8167; _2899 < _8168; ++_2899)
          {
            {
              _2898 += safe_mul( ((_2897 / _ptr__2852[((*dperm)(_2899))]) % _ptr__2864[safe_add( _2851,((*dperm)(_2899)) )]),_ptr__2854[_2899] );
            }
          }
          int _8169 = _ptr__2864[safe_add( _2859,_2898 )];
          int _8170 = _ptr__2864[safe_add( safe_add( _2859,_2898 ),(int)1 )];
          for (int _2900 = _8169; _2900 < _8170; ++_2900)
          {
            {
              _ptr__2893[safe_add( _2888,_2896 )] = _ptr__2865[safe_add( _2861,_2900 )];
              _ptr__2894[safe_add( _2889,_2896 )] = _ptr__2866[safe_add( _2863,_2900 )];
              ++ _2896;
            }
          }
          _ptr__2894[safe_add( _2890,_2895 )] = _ptr__2866[safe_add( _2862,_2898 )];
          ++ _2895;
          _ptr__2892[safe_add( _2887,_2895 )] = _2896;
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprPermuteDims::computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2901,std::shared_ptr< monty::ndarray< int,1 > > _2902){
  _checked_ptr_1<int> _ptr__2901(_2901 ? _2901->raw() : nullptr, _2901 ? _2901->size(0) : 0);
  _checked_ptr_1<int> _ptr__2902(_2902 ? _2902->raw() : nullptr, _2902 ? _2902->size(0) : 0);
  std::vector<int> _8171;
  for (int _2903 = (int)0, _8172 = (int)((_2901)->size(0)); _2903 < _8172 ; ++_2903)
  {
    _8171.push_back(_ptr__2902[_ptr__2901[_2903]]);
  }
  auto _8173 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8171.size()),_8171.begin(),_8171.end()));
  return _8173;
}
void mosek::fusion::p_ExprPermuteDims::destroy(){dperm.reset();expr.reset();}void mosek::fusion::ExprPermuteDims::destroy() { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->destroy(); }mosek::fusion::ExprTranspose::ExprTranspose(mosek::fusion::p_ExprTranspose *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprTranspose()" << this << std::endl; */ }mosek::fusion::ExprTranspose::~ExprTranspose() {  /* std::cout << "~ExprTranspose()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprTranspose::p_ExprTranspose  (::mosek::fusion::ExprTranspose * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprTranspose::t mosek::fusion::p_ExprTranspose::_new_ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2904){ return new mosek::fusion::ExprTranspose(_2904); }mosek::fusion::ExprTranspose::ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2904) :    ExprTranspose(new mosek::fusion::p_ExprTranspose(this)){ mosek::fusion::p_ExprTranspose::_get_impl(this)->_initialize(_2904); }void mosek::fusion::p_ExprTranspose::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2904){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprTranspose::transposeShape(_2904->getShape()));
    mosek::fusion::p_ExprTranspose::_get_impl(::mosek::fusion::ExprTranspose::t(_pubthis))->expr = _2904;
  }
}void mosek::fusion::ExprTranspose :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2905,monty::rc_ptr< ::mosek::fusion::WorkStack > _2906,monty::rc_ptr< ::mosek::fusion::WorkStack > _2907) { mosek::fusion::p_ExprTranspose::_get_impl(this)->eval(_2905,_2906,_2907); }void mosek::fusion::p_ExprTranspose::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2905,monty::rc_ptr< ::mosek::fusion::WorkStack > _2906,monty::rc_ptr< ::mosek::fusion::WorkStack > _2907){
  expr->eval(_2906,_2905,_2907);
  _2906->pop_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_2906)->nd != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      int _2908 = mosek::fusion::p_WorkStack::_get_impl(_2906)->shape_base;
      int _2909 = mosek::fusion::p_WorkStack::_get_impl(_2906)->nelem;
      int _2910 = mosek::fusion::p_WorkStack::_get_impl(_2906)->nnz;
      bool _2911 = mosek::fusion::p_WorkStack::_get_impl(_2906)->hassp;
      int _2912 = mosek::fusion::p_WorkStack::_get_impl(_2906)->ptr_base;
      int _2913 = mosek::fusion::p_WorkStack::_get_impl(_2906)->sp_base;
      int _2914 = mosek::fusion::p_WorkStack::_get_impl(_2906)->nidxs_base;
      int _2915 = mosek::fusion::p_WorkStack::_get_impl(_2906)->bfix_base;
      int _2916 = mosek::fusion::p_WorkStack::_get_impl(_2906)->cof_base;
      int _2917 = ((*mosek::fusion::p_WorkStack::_get_impl(_2906)->i32)(_2908));
      int _2918 = ((*mosek::fusion::p_WorkStack::_get_impl(_2906)->i32)(safe_add( _2908,(int)1 )));
      std::shared_ptr< monty::ndarray< int,1 > > _2919 = mosek::fusion::p_WorkStack::_get_impl(_2906)->i32;
      _checked_ptr_1<int> _ptr__2919(_2919 ? _2919->raw() : nullptr,_2919 ? _2919->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2920 = mosek::fusion::p_WorkStack::_get_impl(_2906)->i64;
      _checked_ptr_1<long long> _ptr__2920(_2920 ? _2920->raw() : nullptr,_2920 ? _2920->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2921 = mosek::fusion::p_WorkStack::_get_impl(_2906)->f64;
      _checked_ptr_1<double> _ptr__2921(_2921 ? _2921->raw() : nullptr,_2921 ? _2921->size(0) : 0);
      _2905->alloc_expr((int)2,_2909,_2910,_2911);
      int _2922 = mosek::fusion::p_WorkStack::_get_impl(_2905)->ptr_base;
      int _2923 = mosek::fusion::p_WorkStack::_get_impl(_2905)->nidxs_base;
      int _2924 = mosek::fusion::p_WorkStack::_get_impl(_2905)->sp_base;
      int _2925 = mosek::fusion::p_WorkStack::_get_impl(_2905)->cof_base;
      int _2926 = mosek::fusion::p_WorkStack::_get_impl(_2905)->bfix_base;
      int _2927 = mosek::fusion::p_WorkStack::_get_impl(_2905)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2928 = mosek::fusion::p_WorkStack::_get_impl(_2905)->i32;
      _checked_ptr_1<int> _ptr__2928(_2928 ? _2928->raw() : nullptr,_2928 ? _2928->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2929 = mosek::fusion::p_WorkStack::_get_impl(_2905)->i64;
      _checked_ptr_1<long long> _ptr__2929(_2929 ? _2929->raw() : nullptr,_2929 ? _2929->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2930 = mosek::fusion::p_WorkStack::_get_impl(_2905)->f64;
      _checked_ptr_1<double> _ptr__2930(_2930 ? _2930->raw() : nullptr,_2930 ? _2930->size(0) : 0);
      _ptr__2928[_2927] = _2918;
      _ptr__2928[safe_add( _2927,(int)1 )] = _2917;
      if (_2911)
      {
        {
          int _2931 = _2907->alloci32(_2909);
          int _2932 = _2907->alloci32(safe_add( _2918,(int)1 ));
          std::shared_ptr< monty::ndarray< int,1 > > _2933 = mosek::fusion::p_WorkStack::_get_impl(_2907)->i32;
          _checked_ptr_1<int> _ptr__2933(_2933 ? _2933->raw() : nullptr,_2933 ? _2933->size(0) : 0);
          int _8174 = (int)0;
          int _8175 = safe_add( _2918,(int)1 );
          for (int _2934 = _8174; _2934 < _8175; ++_2934)
          {
            {
              _ptr__2933[safe_add( _2932,_2934 )] = (int)0;
            }
          }
          int _8176 = (int)0;
          int _8177 = _2909;
          for (int _2935 = _8176; _2935 < _8177; ++_2935)
          {
            {
              ++ _ptr__2933[safe_add( safe_add( _2932,(_ptr__2920[safe_add( _2913,_2935 )] % _2918) ),(int)1 )];
            }
          }
          int _8178 = (int)0;
          int _8179 = _2918;
          for (int _2936 = _8178; _2936 < _8179; ++_2936)
          {
            {
              _ptr__2933[safe_add( safe_add( _2932,_2936 ),(int)1 )] += _ptr__2933[safe_add( _2932,_2936 )];
            }
          }
          int _8180 = (int)0;
          int _8181 = _2909;
          for (int _2937 = _8180; _2937 < _8181; ++_2937)
          {
            {
              long long _2938 = (_ptr__2920[safe_add( _2913,_2937 )] % _2918);
              _ptr__2933[safe_add( _2931,_ptr__2933[safe_add( _2932,_2938 )] )] = _2937;
              ++ _ptr__2933[safe_add( _2932,_2938 )];
            }
          }
          _ptr__2928[_2922] = (int)0;
          int _2939 = (int)0;
          int _8182 = (int)0;
          int _8183 = _2909;
          for (int _2940 = _8182; _2940 < _8183; ++_2940)
          {
            {
              int _2941 = _ptr__2933[safe_add( _2931,_2940 )];
              int _8184 = _ptr__2919[safe_add( _2912,_2941 )];
              int _8185 = _ptr__2919[safe_add( safe_add( _2912,_2941 ),(int)1 )];
              for (int _2942 = _8184; _2942 < _8185; ++_2942)
              {
                {
                  _ptr__2929[safe_add( _2923,_2939 )] = _ptr__2920[safe_add( _2914,_2942 )];
                  _ptr__2930[safe_add( _2925,_2939 )] = _ptr__2921[safe_add( _2916,_2942 )];
                  ++ _2939;
                }
              }
              long long _2943 = (_ptr__2920[safe_add( _2913,_2941 )] / _2918);
              long long _2944 = (_ptr__2920[safe_add( _2913,_2941 )] % _2918);
              _ptr__2928[safe_add( safe_add( _2922,_2940 ),(int)1 )] = _2939;
              _ptr__2929[safe_add( _2924,_2940 )] = safe_add( safe_mul( _2944,_2917 ),_2943 );
              _ptr__2930[safe_add( _2926,_2940 )] = _ptr__2921[safe_add( _2915,_2941 )];
            }
          }
        }
      }
      else
      {
        {
          _ptr__2928[_2922] = (int)0;
          int _2945 = (int)0;
          int _2946 = (int)0;
          int _8186 = (int)0;
          int _8187 = _2918;
          for (int _2947 = _8186; _2947 < _8187; ++_2947)
          {
            {
              int _8188 = (int)0;
              int _8189 = _2917;
              for (int _2948 = _8188; _2948 < _8189; ++_2948)
              {
                {
                  int _2949 = safe_add( safe_mul( _2948,_2918 ),_2947 );
                  int _8190 = _ptr__2919[safe_add( _2912,_2949 )];
                  int _8191 = _ptr__2919[safe_add( safe_add( _2912,_2949 ),(int)1 )];
                  for (int _2950 = _8190; _2950 < _8191; ++_2950)
                  {
                    {
                      _ptr__2929[safe_add( _2923,_2945 )] = _ptr__2920[safe_add( _2914,_2950 )];
                      _ptr__2930[safe_add( _2925,_2945 )] = _ptr__2921[safe_add( _2916,_2950 )];
                      ++ _2945;
                    }
                  }
                  _ptr__2930[safe_add( _2926,_2946 )] = _ptr__2921[safe_add( _2915,_2949 )];
                  _ptr__2928[safe_add( safe_add( _2922,_2946 ),(int)1 )] = _2945;
                  ++ _2946;
                }
              }
            }
          }
        }
      }
      _2907->clear();
    }
  }
}
std::string mosek::fusion::ExprTranspose :: toString() { return mosek::fusion::p_ExprTranspose::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprTranspose::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprTranspose("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprTranspose::transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2951){
  _checked_ptr_1<int> _ptr__2951(_2951 ? _2951->raw() : nullptr, _2951 ? _2951->size(0) : 0);
  if (((int)((_2951)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__2951[(int)1]),(int)(_ptr__2951[(int)0])});
    }
  }
}
void mosek::fusion::p_ExprTranspose::destroy(){expr.reset();}void mosek::fusion::ExprTranspose::destroy() { mosek::fusion::p_ExprTranspose::_get_impl(this)->destroy(); }mosek::fusion::ExprStack::ExprStack(mosek::fusion::p_ExprStack *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprStack()" << this << std::endl; */ }mosek::fusion::ExprStack::~ExprStack() {  /* std::cout << "~ExprStack()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprStack::p_ExprStack  (::mosek::fusion::ExprStack * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprStack::t mosek::fusion::p_ExprStack::_new_ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2952,    int _2953){ return new mosek::fusion::ExprStack(_2952,_2953); }mosek::fusion::ExprStack::ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2952,    int _2953) :    ExprStack(new mosek::fusion::p_ExprStack(this)){ mosek::fusion::p_ExprStack::_get_impl(this)->_initialize(_2952,_2953); }void mosek::fusion::p_ExprStack::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2952,    int _2953){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprStack::getshape(_2952,_2953));
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8192;
    for (int _2954 = (int)0, _8193 = (int)((_2952)->size(0)); _2954 < _8193 ; ++_2954)
    {
      _8192.push_back(((*_2952)(_2954)));
    }
    auto _8194 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8192.size()),_8192.begin(),_8192.end()));
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->exprs = _8194;
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->dim = _2953;
  }
}void mosek::fusion::ExprStack :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2955,monty::rc_ptr< ::mosek::fusion::WorkStack > _2956,monty::rc_ptr< ::mosek::fusion::WorkStack > _2957) { mosek::fusion::p_ExprStack::_get_impl(this)->eval(_2955,_2956,_2957); }void mosek::fusion::p_ExprStack::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2955,monty::rc_ptr< ::mosek::fusion::WorkStack > _2956,monty::rc_ptr< ::mosek::fusion::WorkStack > _2957){
  int _2958 = (int)((exprs)->size(0));
  if ((_2958 == (int)1))
  {
    {
      ((*exprs)((int)0))->eval(_2955,_2956,_2957);
    }
  }
  else
  {
    {
      int _8195 = (int)0;
      int _8196 = _2958;
      for (int _2959 = _8195; _2959 < _8196; ++_2959)
      {
        {
          ((*exprs)(((_2958 - _2959) - (int)1)))->eval(_2956,_2955,_2957);
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2960 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2960(_2960 ? _2960->raw() : nullptr,_2960 ? _2960->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2961 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2961(_2961 ? _2961->raw() : nullptr,_2961 ? _2961->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2962 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2962(_2962 ? _2962->raw() : nullptr,_2962 ? _2962->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2963 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2963(_2963 ? _2963->raw() : nullptr,_2963 ? _2963->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _2964 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_2958)));
      std::shared_ptr< monty::ndarray< int,1 > > _2965 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2965(_2965 ? _2965->raw() : nullptr,_2965 ? _2965->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2966 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2966(_2966 ? _2966->raw() : nullptr,_2966 ? _2966->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2967 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2967(_2967 ? _2967->raw() : nullptr,_2967 ? _2967->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2968 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2968(_2968 ? _2968->raw() : nullptr,_2968 ? _2968->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2969 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2969(_2969 ? _2969->raw() : nullptr,_2969 ? _2969->size(0) : 0);
      int _8197 = (int)0;
      int _8198 = _2958;
      for (int _2970 = _8197; _2970 < _8198; ++_2970)
      {
        {
          _2956->pop_expr();
          _ptr__2960[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->nd;
          _ptr__2961[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->shape_base;
          _ptr__2962[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->nelem;
          _ptr__2963[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->nnz;
          ((*_2964)(_2970)) = mosek::fusion::p_WorkStack::_get_impl(_2956)->hassp;
          _ptr__2965[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->ptr_base;
          _ptr__2967[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->sp_base;
          _ptr__2966[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->nidxs_base;
          _ptr__2969[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->bfix_base;
          _ptr__2968[_2970] = mosek::fusion::p_WorkStack::_get_impl(_2956)->cof_base;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2971 = mosek::fusion::p_WorkStack::_get_impl(_2956)->i32;
      _checked_ptr_1<int> _ptr__2971(_2971 ? _2971->raw() : nullptr,_2971 ? _2971->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2972 = mosek::fusion::p_WorkStack::_get_impl(_2956)->i64;
      _checked_ptr_1<long long> _ptr__2972(_2972 ? _2972->raw() : nullptr,_2972 ? _2972->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2973 = mosek::fusion::p_WorkStack::_get_impl(_2956)->f64;
      _checked_ptr_1<double> _ptr__2973(_2973 ? _2973->raw() : nullptr,_2973 ? _2973->size(0) : 0);
      int _2974 = _ptr__2960[(int)0];
      int _2975 = _ptr__2961[(int)0];
      bool _2976 = (!((*_2964)((int)0)));
      bool _2977 = false;
      int _8199 = (int)1;
      int _8200 = _2958;
      for (int _2978 = _8199; _2978 < _8200; ++_2978)
      {
        {
          _2977 = (_2977 || ((dim != _2978) && (_ptr__2960[_2978] != _2974)));
          if ((!_2977))
          {
            {
              int _8201 = (int)0;
              int _8202 = dim;
              for (int _2979 = _8201; _2979 < _8202; ++_2979)
              {
                {
                  _2977 = (_2977 || (_ptr__2971[safe_add( _2975,_2979 )] != _ptr__2971[safe_add( _ptr__2961[_2978],_2979 )]));
                }
              }
            }
          }
          {}
          if ((!_2977))
          {
            {
              int _8203 = safe_add( dim,(int)1 );
              int _8204 = _2974;
              for (int _2980 = _8203; _2980 < _8204; ++_2980)
              {
                {
                  _2977 = (_2977 || (_ptr__2971[safe_add( _2975,_2980 )] != _ptr__2971[safe_add( _ptr__2961[_2978],_2980 )]));
                }
              }
            }
          }
          {}
          _2976 = (_2976 && (!((*_2964)(_2978))));
        }
      }
      if (_2977)
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
        }
      }
      {}
      int _2981 = (int)0;
      if ((dim < _2974))
      {
        {
          int _8205 = (int)0;
          int _8206 = _2958;
          for (int _2982 = _8205; _2982 < _8206; ++_2982)
          {
            {
              _2981 += _ptr__2971[safe_add( _ptr__2961[_2982],dim )];
            }
          }
        }
      }
      else
      {
        {
          _2981 = _2958;
        }
      }
      int _8207;
      bool _8208 = (dim < _2974);
      if (_8208)
      {
        _8207 = _2974;
      }
      else
      {
        _8207 = safe_add( _2974,(int)1 );
      }
      int _2983 = _8207;
      if ((_2983 != _pubthis->getND()))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Oops!!"));
        }
      }
      {}
      int _2984 = (int)0;
      int _2985 = (int)0;
      {
        int _8209 = (int)0;
        int _8210 = _2958;
        for (int _2986 = _8209; _2986 < _8210; ++_2986)
        {
          {
            _2985 += _ptr__2963[_2986];
          }
        }
        int _8211 = (int)0;
        int _8212 = _2958;
        for (int _2987 = _8211; _2987 < _8212; ++_2987)
        {
          {
            _2984 += _ptr__2962[_2987];
          }
        }
      }
      int _2988 = (int)1;
      int _8213 = (int)0;
      int _8214 = dim;
      for (int _2989 = _8213; _2989 < _8214; ++_2989)
      {
        {
          _2988 *= _ptr__2971[safe_add( _2975,_2989 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _8215;
      bool _8216 = (dim < _2974);
      if (_8216)
      {
        std::vector<int> _8217;
        for (int _2991 = (int)0, _8218 = _2958; _2991 < _8218 ; ++_2991)
        {
          _8217.push_back(_ptr__2971[safe_add( _ptr__2961[_2991],dim )]);
        }
        auto _8219 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8217.size()),_8217.begin(),_8217.end()));
        _8215 = _8219;
      }
      else
      {
        std::vector<int> _8220;
        for (int _2992 = (int)0, _8221 = _2958; _2992 < _8221 ; ++_2992)
        {
          _8220.push_back((int)1);
        }
        auto _8222 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8220.size()),_8220.begin(),_8220.end()));
        _8215 = _8222;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2990 = _8215;
      _checked_ptr_1<int> _ptr__2990(_2990 ? _2990->raw() : nullptr,_2990 ? _2990->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2993 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2958)));
      _checked_ptr_1<int> _ptr__2993(_2993 ? _2993->raw() : nullptr,_2993 ? _2993->size(0) : 0);
      _ptr__2993[(int)0] = (int)0;
      int _8223 = (int)1;
      int _8224 = _2958;
      for (int _2994 = _8223; _2994 < _8224; ++_2994)
      {
        {
          _ptr__2993[_2994] = safe_add( _ptr__2993[(_2994 - (int)1)],_ptr__2990[(_2994 - (int)1)] );
        }
      }
      int _2995 = (int)0;
      int _8225 = (int)0;
      int _8226 = _2958;
      for (int _2996 = _8225; _2996 < _8226; ++_2996)
      {
        {
          _2995 += _ptr__2990[_2996];
        }
      }
      int _2997 = (int)1;
      int _8227 = safe_add( dim,(int)1 );
      int _8228 = _2974;
      for (int _2998 = _8227; _2998 < _8228; ++_2998)
      {
        {
          _2997 *= _ptr__2971[safe_add( _2975,_2998 )];
        }
      }
      if (_2976)
      {
        {
          _2955->alloc_expr(_2983,_2984,_2985,false);
          int _2999 = mosek::fusion::p_WorkStack::_get_impl(_2955)->ptr_base;
          int _3000 = mosek::fusion::p_WorkStack::_get_impl(_2955)->shape_base;
          int _3001 = mosek::fusion::p_WorkStack::_get_impl(_2955)->nidxs_base;
          int _3002 = mosek::fusion::p_WorkStack::_get_impl(_2955)->cof_base;
          int _3003 = mosek::fusion::p_WorkStack::_get_impl(_2955)->bfix_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3004 = mosek::fusion::p_WorkStack::_get_impl(_2955)->i32;
          _checked_ptr_1<int> _ptr__3004(_3004 ? _3004->raw() : nullptr,_3004 ? _3004->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3005 = mosek::fusion::p_WorkStack::_get_impl(_2955)->i64;
          _checked_ptr_1<long long> _ptr__3005(_3005 ? _3005->raw() : nullptr,_3005 ? _3005->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3006 = mosek::fusion::p_WorkStack::_get_impl(_2955)->f64;
          _checked_ptr_1<double> _ptr__3006(_3006 ? _3006->raw() : nullptr,_3006 ? _3006->size(0) : 0);
          int _8229 = (int)0;
          int _8230 = _2974;
          for (int _3007 = _8229; _3007 < _8230; ++_3007)
          {
            {
              _ptr__3004[safe_add( _3000,_3007 )] = _ptr__2971[safe_add( _2975,_3007 )];
            }
          }
          _ptr__3004[safe_add( _3000,dim )] = _2981;
          {
            _ptr__3004[_2999] = (int)0;
            {
              int _3008 = (int)0;
              int _8231 = (int)0;
              int _8232 = _2958;
              for (int _3009 = _8231; _3009 < _8232; ++_3009)
              {
                {
                  int _3010 = _ptr__2965[_3009];
                  int _3011 = (int)0;
                  int _8233 = (int)0;
                  int _8234 = _2988;
                  for (int _3012 = _8233; _3012 < _8234; ++_3012)
                  {
                    {
                      int _8235 = (int)0;
                      int _8236 = _ptr__2990[_3009];
                      for (int _3013 = _8235; _3013 < _8236; ++_3013)
                      {
                        {
                          int _8237 = (int)0;
                          int _8238 = _2997;
                          for (int _3014 = _8237; _3014 < _8238; ++_3014)
                          {
                            {
                              int _3015 = safe_add( safe_add( _3014,safe_mul( safe_add( _3013,_3008 ),_2997 ) ),safe_mul( safe_mul( _3012,_2995 ),_2997 ) );
                              int _3016 = (_ptr__2971[safe_add( safe_add( _3010,_3011 ),(int)1 )] - _ptr__2971[safe_add( _3010,_3011 )]);
                              _ptr__3004[safe_add( safe_add( _2999,_3015 ),(int)1 )] = _3016;
                              _ptr__3006[safe_add( _3003,_3015 )] = _ptr__2973[safe_add( _ptr__2969[_3009],_3011 )];
                              ++ _3011;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3008 += _ptr__2990[_3009];
                }
              }
              int _8239 = (int)0;
              int _8240 = _2984;
              for (int _3017 = _8239; _3017 < _8240; ++_3017)
              {
                {
                  _ptr__3004[safe_add( safe_add( _2999,_3017 ),(int)1 )] += _ptr__3004[safe_add( _2999,_3017 )];
                }
              }
            }
            {
              int _3018 = (int)0;
              int _8241 = (int)0;
              int _8242 = _2958;
              for (int _3019 = _8241; _3019 < _8242; ++_3019)
              {
                {
                  int _3020 = _ptr__2965[_3019];
                  int _3021 = (int)0;
                  int _8243 = (int)0;
                  int _8244 = _2988;
                  for (int _3022 = _8243; _3022 < _8244; ++_3022)
                  {
                    {
                      int _8245 = (int)0;
                      int _8246 = _ptr__2990[_3019];
                      for (int _3023 = _8245; _3023 < _8246; ++_3023)
                      {
                        {
                          int _8247 = (int)0;
                          int _8248 = _2997;
                          for (int _3024 = _8247; _3024 < _8248; ++_3024)
                          {
                            {
                              int _3025 = safe_add( safe_add( _3024,safe_mul( safe_add( _3023,_3018 ),_2997 ) ),safe_mul( safe_mul( _3022,_2995 ),_2997 ) );
                              int _3026 = _ptr__2971[safe_add( _3020,_3021 )];
                              int _3027 = (_ptr__2971[safe_add( safe_add( _3020,_3021 ),(int)1 )] - _3026);
                              int _8249 = (int)0;
                              int _8250 = _3027;
                              for (int _3028 = _8249; _3028 < _8250; ++_3028)
                              {
                                {
                                  _ptr__3005[safe_add( safe_add( _3001,_ptr__3004[safe_add( _2999,_3025 )] ),_3028 )] = _ptr__2972[safe_add( safe_add( _ptr__2966[_3019],_3026 ),_3028 )];
                                }
                              }
                              int _8251 = (int)0;
                              int _8252 = _3027;
                              for (int _3029 = _8251; _3029 < _8252; ++_3029)
                              {
                                {
                                  _ptr__3006[safe_add( safe_add( _3002,_ptr__3004[safe_add( _2999,_3025 )] ),_3029 )] = _ptr__2973[safe_add( safe_add( _ptr__2968[_3019],_3026 ),_3029 )];
                                }
                              }
                              ++ _3021;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3018 += _ptr__2990[_3019];
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _3030 = (int)1;
          int _8253 = (int)0;
          int _8254 = dim;
          for (int _3031 = _8253; _3031 < _8254; ++_3031)
          {
            {
              _3030 *= _ptr__2971[safe_add( _2975,_3031 )];
            }
          }
          _3030 *= _2981;
          int _8255 = safe_add( dim,(int)1 );
          int _8256 = _2974;
          for (int _3032 = _8255; _3032 < _8256; ++_3032)
          {
            {
              _3030 *= _ptr__2971[safe_add( _2975,_3032 )];
            }
          }
          bool _3033 = (_2984 < _3030);
          _2955->alloc_expr(_2983,_2984,_2985,_3033);
          int _3034 = mosek::fusion::p_WorkStack::_get_impl(_2955)->ptr_base;
          int _3035 = mosek::fusion::p_WorkStack::_get_impl(_2955)->nidxs_base;
          int _8257;
          bool _8258 = _3033;
          if (_8258)
          {
            _8257 = mosek::fusion::p_WorkStack::_get_impl(_2955)->sp_base;
          }
          else
          {
            _8257 = _2955->alloci64(_2984);
          }
          int _3036 = _8257;
          int _3037 = mosek::fusion::p_WorkStack::_get_impl(_2955)->cof_base;
          int _3038 = mosek::fusion::p_WorkStack::_get_impl(_2955)->bfix_base;
          int _3039 = mosek::fusion::p_WorkStack::_get_impl(_2955)->shape_base;
          int _8259 = (int)0;
          int _8260 = _2974;
          for (int _3040 = _8259; _3040 < _8260; ++_3040)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_2955)->i32)(safe_add( _3039,_3040 ))) = _ptr__2971[safe_add( _2975,_3040 )];
            }
          }
          ((*mosek::fusion::p_WorkStack::_get_impl(_2955)->i32)(safe_add( _3039,dim ))) = _2981;
          int _3041 = _2957->alloci32(safe_add( _2984,(int)1 ));
          int _3042 = _2957->alloci64(_2985);
          int _3043 = _2957->alloci64(_2984);
          int _3044 = _2957->allocf64(_2985);
          int _3045 = _2957->allocf64(_2984);
          std::shared_ptr< monty::ndarray< int,1 > > _3046 = mosek::fusion::p_WorkStack::_get_impl(_2955)->i32;
          _checked_ptr_1<int> _ptr__3046(_3046 ? _3046->raw() : nullptr,_3046 ? _3046->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3047 = mosek::fusion::p_WorkStack::_get_impl(_2955)->i64;
          _checked_ptr_1<long long> _ptr__3047(_3047 ? _3047->raw() : nullptr,_3047 ? _3047->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3048 = mosek::fusion::p_WorkStack::_get_impl(_2955)->f64;
          _checked_ptr_1<double> _ptr__3048(_3048 ? _3048->raw() : nullptr,_3048 ? _3048->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _3049 = mosek::fusion::p_WorkStack::_get_impl(_2957)->i32;
          _checked_ptr_1<int> _ptr__3049(_3049 ? _3049->raw() : nullptr,_3049 ? _3049->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3050 = mosek::fusion::p_WorkStack::_get_impl(_2957)->i64;
          _checked_ptr_1<long long> _ptr__3050(_3050 ? _3050->raw() : nullptr,_3050 ? _3050->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3051 = mosek::fusion::p_WorkStack::_get_impl(_2957)->f64;
          _checked_ptr_1<double> _ptr__3051(_3051 ? _3051->raw() : nullptr,_3051 ? _3051->size(0) : 0);
          {
            int _3052 = (int)0;
            int _3053 = (int)0;
            int _8261 = (int)0;
            int _8262 = _2958;
            for (int _3054 = _8261; _3054 < _8262; ++_3054)
            {
              {
                ::mosek::fusion::Utils::Tools::arraycopy(_2972,_ptr__2966[_3054],_3050,safe_add( _3042,_3053 ),_ptr__2963[_3054]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2973,_ptr__2968[_3054],_3051,safe_add( _3044,_3053 ),_ptr__2963[_3054]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2973,_ptr__2969[_3054],_3051,safe_add( _3045,_3052 ),_ptr__2962[_3054]);
                _3053 += _ptr__2963[_3054];
                _3052 += _ptr__2962[_3054];
              }
            }
          }
          {
            _ptr__3049[_3041] = (int)0;
            int _3055 = (int)0;
            int _3056 = (int)0;
            int _8263 = (int)0;
            int _8264 = _2958;
            for (int _3057 = _8263; _3057 < _8264; ++_3057)
            {
              {
                int _3058 = _ptr__2990[_3057];
                int _3059 = safe_mul( _3058,_2997 );
                int _3060 = _2997;
                if (((*_2964)(_3057)))
                {
                  {
                    int _8265 = (int)0;
                    int _8266 = _ptr__2962[_3057];
                    for (int _3061 = _8265; _3061 < _8266; ++_3061)
                    {
                      {
                        long long _3062 = (_ptr__2972[safe_add( _ptr__2967[_3057],_3061 )] / _3059);
                        long long _3063 = ((_ptr__2972[safe_add( _ptr__2967[_3057],_3061 )] / _3060) % _3058);
                        long long _3064 = (_ptr__2972[safe_add( _ptr__2967[_3057],_3061 )] % _2997);
                        _ptr__3050[safe_add( _3043,_3056 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3062,_2981 ),_3063 ),_ptr__2993[_3057] ),_2997 ),_3064 );
                        _ptr__3049[safe_add( safe_add( _3041,_3056 ),(int)1 )] = safe_add( _3055,_ptr__2971[safe_add( safe_add( _ptr__2965[_3057],_3061 ),(int)1 )] );
                        ++ _3056;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _3065 = (int)0;
                    int _8267 = (int)0;
                    int _8268 = _2988;
                    for (int _3066 = _8267; _3066 < _8268; ++_3066)
                    {
                      {
                        int _8269 = (int)0;
                        int _8270 = _3058;
                        for (int _3067 = _8269; _3067 < _8270; ++_3067)
                        {
                          {
                            int _8271 = (int)0;
                            int _8272 = _2997;
                            for (int _3068 = _8271; _3068 < _8272; ++_3068)
                            {
                              {
                                _ptr__3050[safe_add( _3043,_3056 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3066,_2981 ),_3067 ),_ptr__2993[_3057] ),_2997 ),_3068 );
                                _ptr__3049[safe_add( safe_add( _3041,_3056 ),(int)1 )] = safe_add( _3055,_ptr__2971[safe_add( safe_add( _ptr__2965[_3057],_3065 ),(int)1 )] );
                                ++ _3056;
                                ++ _3065;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                _3055 += _ptr__2963[_3057];
              }
            }
          }
          if ((dim > (int)0))
          {
            {
              int _3069 = (int)0;
              int _8273 = (int)0;
              int _8274 = _2983;
              for (int _3070 = _8273; _3070 < _8274; ++_3070)
              {
                {
                  if ((_3069 < _ptr__3046[safe_add( _3039,_3070 )]))
                  {
                    {
                      _3069 = _ptr__3046[safe_add( _3039,_3070 )];
                    }
                  }
                  {}
                }
              }
              std::shared_ptr< monty::ndarray< long long,1 > > _3071 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2983)));
              _checked_ptr_1<long long> _ptr__3071(_3071 ? _3071->raw() : nullptr,_3071 ? _3071->size(0) : 0);
              _ptr__3071[(_2983 - (int)1)] = (int)1;
              int _8275 = (int)1;
              int _8276 = _2983;
              for (int _3072 = _8275; _3072 < _8276; ++_3072)
              {
                {
                  _ptr__3071[((_2983 - _3072) - (int)1)] = safe_mul( _ptr__3071[(_2983 - _3072)],_ptr__3046[(safe_add( _3039,_2983 ) - _3072)] );
                }
              }
              int _3073 = _2957->alloci32(_2984);
              int _3074 = _2957->alloci32(_2984);
              int _3075 = _2957->alloci32(safe_add( _3069,(int)1 ));
              std::shared_ptr< monty::ndarray< int,1 > > _3076 = mosek::fusion::p_WorkStack::_get_impl(_2957)->i32;
              _checked_ptr_1<int> _ptr__3076(_3076 ? _3076->raw() : nullptr,_3076 ? _3076->size(0) : 0);
              std::shared_ptr< monty::ndarray< long long,1 > > _3077 = mosek::fusion::p_WorkStack::_get_impl(_2957)->i64;
              _checked_ptr_1<long long> _ptr__3077(_3077 ? _3077->raw() : nullptr,_3077 ? _3077->size(0) : 0);
              std::shared_ptr< monty::ndarray< double,1 > > _3078 = mosek::fusion::p_WorkStack::_get_impl(_2957)->f64;
              _checked_ptr_1<double> _ptr__3078(_3078 ? _3078->raw() : nullptr,_3078 ? _3078->size(0) : 0);
              {
                int _8277 = (int)0;
                int _8278 = _2984;
                for (int _3079 = _8277; _3079 < _8278; ++_3079)
                {
                  {
                    _ptr__3076[safe_add( _3073,_3079 )] = _3079;
                  }
                }
                int _8279 = (int)0;
                int _8280 = _2983;
                for (int _3080 = _8279; _3080 < _8280; ++_3080)
                {
                  {
                    int _3081 = ((_2983 - _3080) - (int)1);
                    int _3082 = _ptr__3046[safe_add( _3039,_3081 )];
                    int _8281 = (int)0;
                    int _8282 = safe_add( _3082,(int)1 );
                    for (int _3083 = _8281; _3083 < _8282; ++_3083)
                    {
                      {
                        _ptr__3076[safe_add( _3075,_3083 )] = (int)0;
                      }
                    }
                    int _8283 = (int)0;
                    int _8284 = _2984;
                    for (int _3084 = _8283; _3084 < _8284; ++_3084)
                    {
                      {
                        int _3085 = _ptr__3076[safe_add( _3073,_3084 )];
                        long long _3086 = ((_ptr__3077[safe_add( _3043,_3085 )] / _ptr__3071[_3081]) % _3082);
                        ++ _ptr__3076[safe_add( safe_add( _3075,_3086 ),(int)1 )];
                      }
                    }
                    {
                      int _8285 = (int)0;
                      int _8286 = _3082;
                      for (int _3087 = _8285; _3087 < _8286; ++_3087)
                      {
                        {
                          _ptr__3076[safe_add( safe_add( _3075,_3087 ),(int)1 )] += _ptr__3076[safe_add( _3075,_3087 )];
                        }
                      }
                      int _8287 = (int)0;
                      int _8288 = _2984;
                      for (int _3088 = _8287; _3088 < _8288; ++_3088)
                      {
                        {
                          int _3089 = _ptr__3076[safe_add( _3073,_3088 )];
                          long long _3090 = ((_ptr__3077[safe_add( _3043,_3089 )] / _ptr__3071[_3081]) % _3082);
                          _ptr__3076[safe_add( _3074,_ptr__3076[safe_add( _3075,_3090 )] )] = _3089;
                          ++ _ptr__3076[safe_add( _3075,_3090 )];
                        }
                      }
                    }
                    int _3091 = _3073;
                    _3073 = _3074;
                    _3074 = _3091;
                  }
                }
                int _3092 = (int)0;
                _ptr__3046[_3034] = (int)0;
                int _8289 = (int)0;
                int _8290 = _2984;
                for (int _3093 = _8289; _3093 < _8290; ++_3093)
                {
                  {
                    int _3094 = _ptr__3076[safe_add( _3073,_3093 )];
                    int _3095 = _ptr__3076[safe_add( _3041,_3094 )];
                    int _3096 = _ptr__3076[safe_add( safe_add( _3041,_3094 ),(int)1 )];
                    int _3097 = (_3096 - _3095);
                    _ptr__3046[safe_add( safe_add( _3034,_3093 ),(int)1 )] = safe_add( _ptr__3046[safe_add( _3034,_3093 )],_3097 );
                    _ptr__3048[safe_add( _3038,_3093 )] = _ptr__3078[safe_add( _3045,_3094 )];
                    _ptr__3047[safe_add( _3036,_3093 )] = _ptr__3077[safe_add( _3043,_3094 )];
                    int _8291 = _3095;
                    int _8292 = _3096;
                    for (int _3098 = _8291; _3098 < _8292; ++_3098)
                    {
                      {
                        _ptr__3047[safe_add( _3035,_3092 )] = _ptr__3077[safe_add( _3042,_3098 )];
                        _ptr__3048[safe_add( _3037,_3092 )] = _ptr__3078[safe_add( _3044,_3098 )];
                        ++ _3092;
                      }
                    }
                  }
                }
              }
            }
          }
          else
          {
            {
              int _3099 = (int)0;
              _ptr__3046[_3034] = (int)0;
              int _8293 = (int)0;
              int _8294 = _2984;
              for (int _3100 = _8293; _3100 < _8294; ++_3100)
              {
                {
                  int _3101 = _ptr__3049[safe_add( _3041,_3100 )];
                  int _3102 = _ptr__3049[safe_add( safe_add( _3041,_3100 ),(int)1 )];
                  int _3103 = (_3102 - _3101);
                  _ptr__3046[safe_add( safe_add( _3034,_3100 ),(int)1 )] = safe_add( _ptr__3046[safe_add( _3034,_3100 )],_3103 );
                  _ptr__3048[safe_add( _3038,_3100 )] = _ptr__3051[safe_add( _3045,_3100 )];
                  _ptr__3047[safe_add( _3036,_3100 )] = _ptr__3050[safe_add( _3043,_3100 )];
                  int _8295 = _3101;
                  int _8296 = _3102;
                  for (int _3104 = _8295; _3104 < _8296; ++_3104)
                  {
                    {
                      _ptr__3047[safe_add( _3035,_3099 )] = _ptr__3050[safe_add( _3042,_3104 )];
                      _ptr__3048[safe_add( _3037,_3099 )] = _ptr__3051[safe_add( _3044,_3104 )];
                      ++ _3099;
                    }
                  }
                }
              }
            }
          }
          if ((!_3033))
          {
            {
              _2955->popi64(_2984);
            }
          }
          {}
          _2957->clear();
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprStack::getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3105,int _3106){
  if (((int)((_3105)->size(0)) == (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot stack empty list"));
    }
  }
  else if(((int)((_3105)->size(0)) == (int)1))
  {
    {
      return ((*_3105)((int)0))->getShape();
    }
  }
  else
  {
    {
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _8297;
      for (int _3108 = (int)0, _8298 = (int)((_3105)->size(0)); _3108 < _8298 ; ++_3108)
      {
        _8297.push_back(((*_3105)(_3108))->getShape());
      }
      auto _8299 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_8297.size()),_8297.begin(),_8297.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _3107 = _8299;
      std::shared_ptr< monty::ndarray< int,1 > > _3109 = ((*_3107)((int)0));
      _checked_ptr_1<int> _ptr__3109(_3109 ? _3109->raw() : nullptr,_3109 ? _3109->size(0) : 0);
      int _3110 = (int)((_3109)->size(0));
      int _8300 = (int)1;
      int _8301 = (int)((_3107)->size(0));
      for (int _3111 = _8300; _3111 < _8301; ++_3111)
      {
        {
          if ((_3110 != (int)((((*_3107)(_3111)))->size(0))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
            }
          }
          {}
          int _8302 = (int)0;
          int _8303 = _3106;
          for (int _3112 = _8302; _3112 < _8303; ++_3112)
          {
            {
              if ((_ptr__3109[_3112] != ((*((*_3107)(_3111)))(_3112))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
          int _8304 = safe_add( _3106,(int)1 );
          int _8305 = _3110;
          for (int _3113 = _8304; _3113 < _8305; ++_3113)
          {
            {
              if ((_ptr__3109[_3113] != ((*((*_3107)(_3111)))(_3113))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
        }
      }
      if ((_3106 == _3110))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3114 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _3110,(int)1 ))));
          _checked_ptr_1<int> _ptr__3114(_3114 ? _3114->raw() : nullptr,_3114 ? _3114->size(0) : 0);
          int _8306 = (int)0;
          int _8307 = _3110;
          for (int _3115 = _8306; _3115 < _8307; ++_3115)
          {
            {
              _ptr__3114[_3115] = _ptr__3109[_3115];
            }
          }
          _ptr__3114[_3110] = (int)((_3107)->size(0));
          return _3114;
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3116 = _3109;
          _checked_ptr_1<int> _ptr__3116(_3116 ? _3116->raw() : nullptr,_3116 ? _3116->size(0) : 0);
          int _8308 = (int)1;
          int _8309 = (int)((_3107)->size(0));
          for (int _3117 = _8308; _3117 < _8309; ++_3117)
          {
            {
              _ptr__3116[_3106] += ((*((*_3107)(_3117)))(_3106));
            }
          }
          return _3116;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprStack :: toString() { return mosek::fusion::p_ExprStack::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprStack::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _3118 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprStack(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)((int)0))->toString());
  int _8310 = (int)1;
  int _8311 = (int)((exprs)->size(0));
  for (int _3119 = _8310; _3119 < _8311; ++_3119)
  {
    {
      _3118->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)(_3119))->toString());
    }
  }
  _3118->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _3118->toString();
}
void mosek::fusion::p_ExprStack::destroy(){exprs.reset();}void mosek::fusion::ExprStack::destroy() { mosek::fusion::p_ExprStack::_get_impl(this)->destroy(); }mosek::fusion::ExprInner::ExprInner(mosek::fusion::p_ExprInner *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprInner()" << this << std::endl; */ }mosek::fusion::ExprInner::~ExprInner() {  /* std::cout << "~ExprInner()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprInner::p_ExprInner  (::mosek::fusion::ExprInner * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3120,    std::shared_ptr< monty::ndarray< long long,1 > > _3121,    std::shared_ptr< monty::ndarray< double,1 > > _3122){ return new mosek::fusion::ExprInner(_3120,_3121,_3122); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3120,    std::shared_ptr< monty::ndarray< long long,1 > > _3121,    std::shared_ptr< monty::ndarray< double,1 > > _3122) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3120,_3121,_3122); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3120,    std::shared_ptr< monty::ndarray< long long,1 > > _3121,    std::shared_ptr< monty::ndarray< double,1 > > _3122){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__3121(_3121 ? _3121->raw() : nullptr, _3121 ? _3121->size(0) : 0);
    _checked_ptr_1<double> _ptr__3122(_3122 ? _3122->raw() : nullptr, _3122 ? _3122->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->expr = _3120;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vsub = _3121;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vcof = _3122;
    if (((int)((_3121)->size(0)) != (int)((_3122)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of vcof and vsub"));
      }
    }
    {}
    std::shared_ptr< monty::ndarray< int,1 > > _3123 = _3120->getShape();
    _checked_ptr_1<int> _ptr__3123(_3123 ? _3123->raw() : nullptr,_3123 ? _3123->size(0) : 0);
    long long _3124 = ::mosek::fusion::p_Set::size(_3123);
    int _8312 = (int)1;
    int _8313 = (int)((_3121)->size(0));
    for (int _3125 = _8312; _3125 < _8313; ++_3125)
    {
      {
        if ((_ptr__3121[_3125] <= _ptr__3121[(_3125 - (int)1)]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Unordered coefficcient subscripts"));
          }
        }
        {}
      }
    }
    if (((int)((_3121)->size(0)) > (int)0))
    {
      {
        if (((_ptr__3121[(int)0] < (int)0) || (_ptr__3121[((int)((_3121)->size(0)) - (int)1)] > _3124)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Coefficient subscript out of bounds"));
          }
        }
        {}
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3126,    std::shared_ptr< monty::ndarray< double,1 > > _3127){ return new mosek::fusion::ExprInner(_3126,_3127); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3126,    std::shared_ptr< monty::ndarray< double,1 > > _3127) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3126,_3127); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3126,    std::shared_ptr< monty::ndarray< double,1 > > _3127){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3127(_3127 ? _3127->raw() : nullptr, _3127 ? _3127->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3126,::mosek::fusion::p_ExprInner::range((int)((_3127)->size(0))),_3127);
    std::shared_ptr< monty::ndarray< int,1 > > _3128 = _3126->getShape();
    _checked_ptr_1<int> _ptr__3128(_3128 ? _3128->raw() : nullptr,_3128 ? _3128->size(0) : 0);
    if ((((int)((_3128)->size(0)) != (int)1) || (_ptr__3128[(int)0] != (int)((_3127)->size(0)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3129,    std::shared_ptr< monty::ndarray< int,2 > > _3130,    std::shared_ptr< monty::ndarray< double,1 > > _3131){ return new mosek::fusion::ExprInner(_3129,_3130,_3131); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3129,    std::shared_ptr< monty::ndarray< int,2 > > _3130,    std::shared_ptr< monty::ndarray< double,1 > > _3131) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3129,_3130,_3131); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3129,    std::shared_ptr< monty::ndarray< int,2 > > _3130,    std::shared_ptr< monty::ndarray< double,1 > > _3131){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3131(_3131 ? _3131->raw() : nullptr, _3131 ? _3131->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3129,::mosek::fusion::p_ExprInner::convert(_3129->getShape(),_3130),_3131);
  }
}void mosek::fusion::ExprInner :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3132,monty::rc_ptr< ::mosek::fusion::WorkStack > _3133,monty::rc_ptr< ::mosek::fusion::WorkStack > _3134) { mosek::fusion::p_ExprInner::_get_impl(this)->eval(_3132,_3133,_3134); }void mosek::fusion::p_ExprInner::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3132,monty::rc_ptr< ::mosek::fusion::WorkStack > _3133,monty::rc_ptr< ::mosek::fusion::WorkStack > _3134){
  expr->eval(_3133,_3132,_3134);
  int _3135 = _3133->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _3136 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3135)));
  _checked_ptr_1<int> _ptr__3136(_3136 ? _3136->raw() : nullptr,_3136 ? _3136->size(0) : 0);
  _3133->popi32(_3135,_3136,(int)0);
  int _3137 = _3133->popi32();
  int _3138 = _3133->popi32();
  bool _3139 = (_3133->popi32() != (int)0);
  int _3140 = _3133->popi32(safe_add( _3137,(int)1 ));
  int _8314;
  bool _8315 = _3139;
  if (_8315)
  {
    _8314 = _3133->popi64(_3137);
  }
  else
  {
    _8314 = (int)0;
  }
  int _3141 = _8314;
  int _3142 = _3133->popi64(_3138);
  int _3143 = _3133->popf64(_3137);
  int _3144 = _3133->popf64(_3138);
  std::shared_ptr< monty::ndarray< int,1 > > _3145 = mosek::fusion::p_WorkStack::_get_impl(_3133)->i32;
  _checked_ptr_1<int> _ptr__3145(_3145 ? _3145->raw() : nullptr,_3145 ? _3145->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3146 = mosek::fusion::p_WorkStack::_get_impl(_3133)->i64;
  _checked_ptr_1<long long> _ptr__3146(_3146 ? _3146->raw() : nullptr,_3146 ? _3146->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3147 = mosek::fusion::p_WorkStack::_get_impl(_3133)->f64;
  _checked_ptr_1<double> _ptr__3147(_3147 ? _3147->raw() : nullptr,_3147 ? _3147->size(0) : 0);
  int _3148 = (int)0;
  if (_3139)
  {
    {
      int _3149 = (int)0;
      int _3150 = (int)0;
      while ( ((_3150 < (int)((vsub)->size(0))) && (_3149 < _3137)) )
      {
        {
          if ((_ptr__3146[safe_add( _3141,_3149 )] < ((*vsub)(_3150))))
          {
            {
              ++ _3149;
            }
          }
          else if((_ptr__3146[safe_add( _3141,_3149 )] > ((*vsub)(_3150))))
          {
            {
              ++ _3150;
            }
          }
          else
          {
            {
              _3148 += (_ptr__3145[safe_add( safe_add( _3140,_3149 ),(int)1 )] - _ptr__3145[safe_add( _3140,_3149 )]);
              ++ _3150;
              ++ _3149;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8316 = (int)0;
      int _8317 = (int)((vsub)->size(0));
      for (int _3151 = _8316; _3151 < _8317; ++_3151)
      {
        {
          _3148 += (_ptr__3145[safe_add( safe_add( _3140,((*vsub)(_3151)) ),(int)1 )] - _ptr__3145[safe_add( _3140,((*vsub)(_3151)) )]);
        }
      }
    }
  }
  int _3152 = _3132->alloci32((int)2);
  int _3153 = _3132->alloci64(_3148);
  int _3154 = _3132->allocf64(_3148);
  int _3155 = _3132->allocf64((int)1);
  _3132->pushi32((int)0);
  _3132->pushi32(_3148);
  _3132->pushi32((int)1);
  _3132->pushi32((int)0);
  std::shared_ptr< monty::ndarray< int,1 > > _3156 = mosek::fusion::p_WorkStack::_get_impl(_3132)->i32;
  _checked_ptr_1<int> _ptr__3156(_3156 ? _3156->raw() : nullptr,_3156 ? _3156->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3157 = mosek::fusion::p_WorkStack::_get_impl(_3132)->i64;
  _checked_ptr_1<long long> _ptr__3157(_3157 ? _3157->raw() : nullptr,_3157 ? _3157->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3158 = mosek::fusion::p_WorkStack::_get_impl(_3132)->f64;
  _checked_ptr_1<double> _ptr__3158(_3158 ? _3158->raw() : nullptr,_3158 ? _3158->size(0) : 0);
  _ptr__3156[_3152] = (int)0;
  _ptr__3156[safe_add( _3152,(int)1 )] = _3148;
  int _3159 = (int)0;
  double _3160 = 0.0;
  if (_3139)
  {
    {
      int _3161 = (int)0;
      int _3162 = (int)0;
      while ( ((_3162 < (int)((vsub)->size(0))) && (_3161 < _3137)) )
      {
        {
          if ((_ptr__3146[safe_add( _3141,_3161 )] < ((*vsub)(_3162))))
          {
            {
              ++ _3161;
            }
          }
          else if((_ptr__3146[safe_add( _3141,_3161 )] > ((*vsub)(_3162))))
          {
            {
              ++ _3162;
            }
          }
          else
          {
            {
              int _3163 = _ptr__3145[safe_add( _3140,_3161 )];
              int _3164 = _ptr__3145[safe_add( safe_add( _3140,_3161 ),(int)1 )];
              int _8318 = _3163;
              int _8319 = _3164;
              for (int _3165 = _8318; _3165 < _8319; ++_3165)
              {
                {
                  _ptr__3157[safe_add( _3153,_3159 )] = _ptr__3146[safe_add( _3142,_3165 )];
                  _ptr__3158[safe_add( _3154,_3159 )] = (((*vcof)(_3162)) * _ptr__3147[safe_add( _3144,_3165 )]);
                  ++ _3159;
                }
              }
              _3160 += (((*vcof)(_3162)) * _ptr__3147[safe_add( _3143,_3161 )]);
              ++ _3162;
              ++ _3161;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8320 = (int)0;
      int _8321 = (int)((vsub)->size(0));
      for (int _3166 = _8320; _3166 < _8321; ++_3166)
      {
        {
          int _3167 = _ptr__3145[safe_add( _3140,((*vsub)(_3166)) )];
          int _3168 = _ptr__3145[safe_add( safe_add( _3140,((*vsub)(_3166)) ),(int)1 )];
          int _8322 = _3167;
          int _8323 = _3168;
          for (int _3169 = _8322; _3169 < _8323; ++_3169)
          {
            {
              _ptr__3157[safe_add( _3153,_3159 )] = _ptr__3146[safe_add( _3142,_3169 )];
              _ptr__3158[safe_add( _3154,_3159 )] = (((*vcof)(_3166)) * _ptr__3147[safe_add( _3144,_3169 )]);
              ++ _3159;
            }
          }
          _3160 += (((*vcof)(_3166)) * _ptr__3147[safe_add( _3143,((*vsub)(_3166)) )]);
        }
      }
    }
  }
  _ptr__3158[_3155] = _3160;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::range(int _3170){
  std::vector<long long> _8324;
  for (int _3171 = (int)0, _8325 = _3170; _3171 < _8325 ; ++_3171)
  {
    _8324.push_back(_3171);
  }
  auto _8326 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8324.size()),_8324.begin(),_8324.end()));
  return _8326;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::convert(std::shared_ptr< monty::ndarray< int,1 > > _3172,std::shared_ptr< monty::ndarray< int,2 > > _3173){
  _checked_ptr_1<int> _ptr__3172(_3172 ? _3172->raw() : nullptr, _3172 ? _3172->size(0) : 0);
  int _3174 = (int)((_3172)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _3175 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3174)));
  _checked_ptr_1<long long> _ptr__3175(_3175 ? _3175->raw() : nullptr,_3175 ? _3175->size(0) : 0);
  _ptr__3175[(_3174 - (int)1)] = (int)1;
  int _8327 = (int)1;
  int _8328 = _3174;
  for (int _3176 = _8327; _3176 < _8328; ++_3176)
  {
    {
      _ptr__3175[((_3174 - _3176) - (int)1)] = safe_mul( _ptr__3175[(_3174 - _3176)],_ptr__3172[(_3174 - _3176)] );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _3177 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_3173)->size(0)))));
  _checked_ptr_1<long long> _ptr__3177(_3177 ? _3177->raw() : nullptr,_3177 ? _3177->size(0) : 0);
  int _8329 = (int)0;
  int _8330 = (int)((_3173)->size(0));
  for (int _3178 = _8329; _3178 < _8330; ++_3178)
  {
    {
      int _8331 = (int)0;
      int _8332 = _3174;
      for (int _3179 = _8331; _3179 < _8332; ++_3179)
      {
        {
          _ptr__3177[_3178] += safe_mul( _ptr__3175[_3179],((*_3173)(_3178,_3179)) );
        }
      }
    }
  }
  return _3177;
}
std::string mosek::fusion::ExprInner :: toString() { return mosek::fusion::p_ExprInner::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprInner::toString(){
  return std::string ("ExprInner()");
}
void mosek::fusion::p_ExprInner::destroy(){vcof.reset();vsub.reset();expr.reset();}void mosek::fusion::ExprInner::destroy() { mosek::fusion::p_ExprInner::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight(mosek::fusion::p_ExprMulDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulDiagRight::~ExprMulDiagRight() {  /* std::cout << "~ExprMulDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagRight::p_ExprMulDiagRight  (::mosek::fusion::ExprMulDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3180,    int _3181,    std::shared_ptr< monty::ndarray< int,1 > > _3182,    std::shared_ptr< monty::ndarray< int,1 > > _3183,    std::shared_ptr< monty::ndarray< double,1 > > _3184,    monty::rc_ptr< ::mosek::fusion::Expression > _3185,    int _3186){ return new mosek::fusion::ExprMulDiagRight(_3180,_3181,_3182,_3183,_3184,_3185,_3186); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3180,    int _3181,    std::shared_ptr< monty::ndarray< int,1 > > _3182,    std::shared_ptr< monty::ndarray< int,1 > > _3183,    std::shared_ptr< monty::ndarray< double,1 > > _3184,    monty::rc_ptr< ::mosek::fusion::Expression > _3185,    int _3186) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3180,_3181,_3182,_3183,_3184,_3185,_3186); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3180,    int _3181,    std::shared_ptr< monty::ndarray< int,1 > > _3182,    std::shared_ptr< monty::ndarray< int,1 > > _3183,    std::shared_ptr< monty::ndarray< double,1 > > _3184,    monty::rc_ptr< ::mosek::fusion::Expression > _3185,    int _3186){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3182(_3182 ? _3182->raw() : nullptr, _3182 ? _3182->size(0) : 0);
    _checked_ptr_1<int> _ptr__3183(_3183 ? _3183->raw() : nullptr, _3183 ? _3183->size(0) : 0);
    _checked_ptr_1<double> _ptr__3184(_3184 ? _3184->raw() : nullptr, _3184 ? _3184->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3181)}));
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim0 = _3180;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim1 = _3181;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi = _3182;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj = _3183;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval = _3184;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr = _3185;
  }
}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3187,    int _3188,    std::shared_ptr< monty::ndarray< int,1 > > _3189,    std::shared_ptr< monty::ndarray< int,1 > > _3190,    std::shared_ptr< monty::ndarray< double,1 > > _3191,    monty::rc_ptr< ::mosek::fusion::Expression > _3192){ return new mosek::fusion::ExprMulDiagRight(_3187,_3188,_3189,_3190,_3191,_3192); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3187,    int _3188,    std::shared_ptr< monty::ndarray< int,1 > > _3189,    std::shared_ptr< monty::ndarray< int,1 > > _3190,    std::shared_ptr< monty::ndarray< double,1 > > _3191,    monty::rc_ptr< ::mosek::fusion::Expression > _3192) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3187,_3188,_3189,_3190,_3191,_3192); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3187,    int _3188,    std::shared_ptr< monty::ndarray< int,1 > > _3189,    std::shared_ptr< monty::ndarray< int,1 > > _3190,    std::shared_ptr< monty::ndarray< double,1 > > _3191,    monty::rc_ptr< ::mosek::fusion::Expression > _3192){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3189(_3189 ? _3189->raw() : nullptr, _3189 ? _3189->size(0) : 0);
    _checked_ptr_1<int> _ptr__3190(_3190 ? _3190->raw() : nullptr, _3190 ? _3190->size(0) : 0);
    _checked_ptr_1<double> _ptr__3191(_3191 ? _3191->raw() : nullptr, _3191 ? _3191->size(0) : 0);
    mosek::fusion::p_ExprMulDiagRight::_initialize(_3187,_3188,_3189,_3190,_3191,_3192,::mosek::fusion::p_ExprMulDiagRight::validate(_3187,_3188,_3189,_3190,_3191,_3192));
  }
}void mosek::fusion::ExprMulDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3193,monty::rc_ptr< ::mosek::fusion::WorkStack > _3194,monty::rc_ptr< ::mosek::fusion::WorkStack > _3195) { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->eval(_3193,_3194,_3195); }void mosek::fusion::p_ExprMulDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3193,monty::rc_ptr< ::mosek::fusion::WorkStack > _3194,monty::rc_ptr< ::mosek::fusion::WorkStack > _3195){
  mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr->eval(_3194,_3193,_3195);
  int _3196 = (int)0;
  int _3197 = (int)99999;
  int _3198 = (int)0;
  bool _3199 = (_3194->peeki32((int)5) != (int)0);
  if (_3199)
  {
    {
      _3198 = _3194->peeki32((int)2);
      _3197 = _3194->alloci32(safe_add( _3198,(int)1 ));
      _3196 += safe_add( _3198,(int)1 );
    }
  }
  {}
  int _3200 = (int)((mval)->size(0));
  int _3201 = _3194->alloci32(_3200);
  int _3202 = _3194->alloci32(safe_add( mdim1,(int)1 ));
  _3196 += safe_add( safe_add( _3200,mdim1 ),(int)1 );
  {
    std::shared_ptr< monty::ndarray< int,1 > > _3203 = mosek::fusion::p_WorkStack::_get_impl(_3194)->i32;
    _checked_ptr_1<int> _ptr__3203(_3203 ? _3203->raw() : nullptr,_3203 ? _3203->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _3204 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj;
    _checked_ptr_1<int> _ptr__3204(_3204 ? _3204->raw() : nullptr,_3204 ? _3204->size(0) : 0);
    {
      int _8333 = (int)0;
      int _8334 = safe_add( mdim1,(int)1 );
      for (int _3205 = _8333; _3205 < _8334; ++_3205)
      {
        {
          _ptr__3203[safe_add( _3202,_3205 )] = (int)0;
        }
      }
      int _8335 = (int)0;
      int _8336 = _3200;
      for (int _3206 = _8335; _3206 < _8336; ++_3206)
      {
        {
          ++ _ptr__3203[safe_add( safe_add( _3202,_ptr__3204[_3206] ),(int)1 )];
        }
      }
      int _8337 = (int)0;
      int _8338 = mdim1;
      for (int _3207 = _8337; _3207 < _8338; ++_3207)
      {
        {
          _ptr__3203[safe_add( safe_add( _3202,_3207 ),(int)1 )] += _ptr__3203[safe_add( _3202,_3207 )];
        }
      }
      int _8339 = (int)0;
      int _8340 = _3200;
      for (int _3208 = _8339; _3208 < _8340; ++_3208)
      {
        {
          _ptr__3203[safe_add( _3201,_ptr__3203[safe_add( _3202,_ptr__3204[_3208] )] )] = _3208;
          ++ _ptr__3203[safe_add( _3202,_ptr__3204[_3208] )];
        }
      }
      int _8341 = (int)0;
      int _8342 = mdim1;
      for (int _3209 = _8341; _3209 < _8342; ++_3209)
      {
        {
          _ptr__3203[(safe_add( _3202,mdim1 ) - _3209)] = _ptr__3203[((safe_add( _3202,mdim1 ) - _3209) - (int)1)];
        }
      }
      _ptr__3203[_3202] = (int)0;
    }
  }
  _3194->popi32(_3196);
  int _3210 = _3194->popi32();
  if ((_3210 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3211 = _3194->popi32();
  int _3212 = _3194->popi32();
  int _3213 = _3194->popi32();
  int _3214 = _3194->popi32();
  bool _3215 = (_3194->popi32() != (int)0);
  int _3216 = _3194->popi32(safe_add( _3213,(int)1 ));
  int _8343;
  bool _8344 = _3215;
  if (_8344)
  {
    _8343 = _3194->popi64(_3213);
  }
  else
  {
    _8343 = (int)9999;
  }
  int _3217 = _8343;
  int _3218 = _3194->popi64(_3214);
  int _3219 = _3194->popf64(_3213);
  int _3220 = _3194->popf64(_3214);
  std::shared_ptr< monty::ndarray< int,1 > > _3221 = mosek::fusion::p_WorkStack::_get_impl(_3194)->i32;
  _checked_ptr_1<int> _ptr__3221(_3221 ? _3221->raw() : nullptr,_3221 ? _3221->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3222 = mosek::fusion::p_WorkStack::_get_impl(_3194)->i64;
  _checked_ptr_1<long long> _ptr__3222(_3222 ? _3222->raw() : nullptr,_3222 ? _3222->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3223 = mosek::fusion::p_WorkStack::_get_impl(_3194)->f64;
  _checked_ptr_1<double> _ptr__3223(_3223 ? _3223->raw() : nullptr,_3223 ? _3223->size(0) : 0);
  if (_3215)
  {
    {
      int _8345 = (int)0;
      int _8346 = safe_add( _3212,(int)1 );
      for (int _3224 = _8345; _3224 < _8346; ++_3224)
      {
        {
          _ptr__3221[safe_add( _3197,_3224 )] = (int)0;
        }
      }
      int _8347 = (int)0;
      int _8348 = _3213;
      for (int _3225 = _8347; _3225 < _8348; ++_3225)
      {
        {
          ++ _ptr__3221[safe_add( safe_add( _3197,(_ptr__3222[safe_add( _3217,_3225 )] / _3211) ),(int)1 )];
        }
      }
      int _8349 = (int)0;
      int _8350 = _3212;
      for (int _3226 = _8349; _3226 < _8350; ++_3226)
      {
        {
          _ptr__3221[safe_add( safe_add( _3197,_3226 ),(int)1 )] += _ptr__3221[safe_add( _3197,_3226 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3227 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3227(_3227 ? _3227->raw() : nullptr,_3227 ? _3227->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3228 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3228(_3228 ? _3228->raw() : nullptr,_3228 ? _3228->size(0) : 0);
      int _3229 = (int)0;
      int _3230 = (int)0;
      {
        int _8351 = (int)0;
        int _8352 = _3212;
        for (int _3231 = _8351; _3231 < _8352; ++_3231)
        {
          {
            int _3232 = _ptr__3221[safe_add( safe_add( _3202,_3231 ),(int)1 )];
            int _3233 = _ptr__3221[safe_add( _3202,_3231 )];
            int _3234 = _ptr__3221[safe_add( safe_add( _3197,_3231 ),(int)1 )];
            int _3235 = _ptr__3221[safe_add( _3197,_3231 )];
            bool _3236 = false;
            while ( ((_3235 < _3234) && (_3233 < _3232)) )
            {
              {
                int _3237 = _ptr__3221[safe_add( _3201,_3233 )];
                long long _3238 = (_ptr__3222[safe_add( _3217,_3235 )] % _3211);
                if ((_ptr__3227[_3237] < _3238))
                {
                  {
                    ++ _3233;
                  }
                }
                else if((_ptr__3227[_3237] > _3238))
                {
                  {
                    ++ _3235;
                  }
                }
                else
                {
                  {
                    _3236 = true;
                    _3229 += (_ptr__3221[safe_add( safe_add( _3216,_3235 ),(int)1 )] - _ptr__3221[safe_add( _3216,_3235 )]);
                    ++ _3235;
                    ++ _3233;
                  }
                }
              }
            }
            if (_3236)
            {
              {
                ++ _3230;
              }
            }
            {}
          }
        }
      }
      bool _3239 = (_3230 < _3212);
      int _3240 = _3193->alloci32(safe_add( _3230,(int)1 ));
      int _3241 = _3193->alloci64(_3229);
      int _3242 = _3193->alloci64(_3230);
      int _3243 = _3193->allocf64(_3229);
      int _3244 = _3193->allocf64(_3230);
      int _8353;
      bool _8354 = _3239;
      if (_8354)
      {
        _8353 = (int)1;
      }
      else
      {
        _8353 = (int)0;
      }
      _3193->pushi32(_8353);
      _3193->pushi32(_3229);
      _3193->pushi32(_3230);
      _3193->pushi32(_3212);
      _3193->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3245 = mosek::fusion::p_WorkStack::_get_impl(_3193)->i32;
      _checked_ptr_1<int> _ptr__3245(_3245 ? _3245->raw() : nullptr,_3245 ? _3245->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3246 = mosek::fusion::p_WorkStack::_get_impl(_3193)->i64;
      _checked_ptr_1<long long> _ptr__3246(_3246 ? _3246->raw() : nullptr,_3246 ? _3246->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3247 = mosek::fusion::p_WorkStack::_get_impl(_3193)->f64;
      _checked_ptr_1<double> _ptr__3247(_3247 ? _3247->raw() : nullptr,_3247 ? _3247->size(0) : 0);
      {
        int _3248 = (int)0;
        int _3249 = (int)0;
        _ptr__3245[_3240] = (int)0;
        int _8355 = (int)0;
        int _8356 = _3212;
        for (int _3250 = _8355; _3250 < _8356; ++_3250)
        {
          {
            int _3251 = _ptr__3221[safe_add( safe_add( _3202,_3250 ),(int)1 )];
            int _3252 = _ptr__3221[safe_add( _3202,_3250 )];
            int _3253 = _ptr__3221[safe_add( safe_add( _3197,_3250 ),(int)1 )];
            int _3254 = _ptr__3221[safe_add( _3197,_3250 )];
            bool _3255 = false;
            double _3256 = 0.0;
            while ( ((_3254 < _3253) && (_3252 < _3251)) )
            {
              {
                int _3257 = _ptr__3221[safe_add( _3201,_3252 )];
                long long _3258 = (_ptr__3222[safe_add( _3217,_3254 )] % _3211);
                if ((_ptr__3227[_3257] < _3258))
                {
                  {
                    ++ _3252;
                  }
                }
                else if((_ptr__3227[_3257] > _3258))
                {
                  {
                    ++ _3254;
                  }
                }
                else
                {
                  {
                    _3255 = true;
                    int _8357 = _ptr__3221[safe_add( _3216,_3254 )];
                    int _8358 = _ptr__3221[safe_add( safe_add( _3216,_3254 ),(int)1 )];
                    for (int _3259 = _8357; _3259 < _8358; ++_3259)
                    {
                      {
                        _ptr__3246[safe_add( _3241,_3249 )] = _ptr__3222[safe_add( _3218,_3259 )];
                        _ptr__3247[safe_add( _3243,_3249 )] = (_ptr__3223[safe_add( _3220,_3259 )] * _ptr__3228[_3257]);
                        ++ _3249;
                      }
                    }
                    _3256 += (_ptr__3223[safe_add( _3219,_3254 )] * _ptr__3228[_3257]);
                    ++ _3254;
                    ++ _3252;
                  }
                }
              }
            }
            if (_3255)
            {
              {
                _ptr__3245[safe_add( safe_add( _3240,_3248 ),(int)1 )] = _3249;
                _ptr__3246[safe_add( _3242,_3248 )] = _3250;
                _ptr__3247[safe_add( _3244,_3248 )] = _3256;
                ++ _3248;
              }
            }
            {}
          }
        }
      }
      if ((!_3239))
      {
        {
          _3193->popi64(_3230);
        }
      }
      {}
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _3260 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3260(_3260 ? _3260->raw() : nullptr,_3260 ? _3260->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3261 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3261(_3261 ? _3261->raw() : nullptr,_3261 ? _3261->size(0) : 0);
      int _3262 = (int)0;
      int _3263 = (int)0;
      {
        int _8359 = (int)0;
        int _8360 = _3212;
        for (int _3264 = _8359; _3264 < _8360; ++_3264)
        {
          {
            bool _3265 = false;
            int _8361 = _ptr__3221[safe_add( _3202,_3264 )];
            int _8362 = _ptr__3221[safe_add( safe_add( _3202,_3264 ),(int)1 )];
            for (int _3266 = _8361; _3266 < _8362; ++_3266)
            {
              {
                int _3267 = _ptr__3221[safe_add( _3201,_3266 )];
                int _3268 = safe_add( safe_mul( _3264,_3211 ),_ptr__3260[_3267] );
                _3263 += (_ptr__3221[safe_add( safe_add( _3216,_3268 ),(int)1 )] - _ptr__3221[safe_add( _3216,_3268 )]);
                if ((_ptr__3221[safe_add( safe_add( _3216,_3268 ),(int)1 )] > _ptr__3221[safe_add( _3216,_3268 )]))
                {
                  {
                    _3265 = true;
                  }
                }
                {}
              }
            }
            if (_3265)
            {
              {
                ++ _3262;
              }
            }
            {}
          }
        }
      }
      bool _3269 = (_3262 < _3212);
      int _3270 = _3193->alloci32(safe_add( _3262,(int)1 ));
      int _3271 = _3193->alloci64(_3263);
      int _3272 = _3193->alloci64(_3262);
      int _3273 = _3193->allocf64(_3263);
      int _3274 = _3193->allocf64(_3262);
      int _8363;
      bool _8364 = _3269;
      if (_8364)
      {
        _8363 = (int)1;
      }
      else
      {
        _8363 = (int)0;
      }
      _3193->pushi32(_8363);
      _3193->pushi32(_3263);
      _3193->pushi32(_3262);
      _3193->pushi32(_3212);
      _3193->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3275 = mosek::fusion::p_WorkStack::_get_impl(_3193)->i32;
      _checked_ptr_1<int> _ptr__3275(_3275 ? _3275->raw() : nullptr,_3275 ? _3275->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3276 = mosek::fusion::p_WorkStack::_get_impl(_3193)->i64;
      _checked_ptr_1<long long> _ptr__3276(_3276 ? _3276->raw() : nullptr,_3276 ? _3276->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3277 = mosek::fusion::p_WorkStack::_get_impl(_3193)->f64;
      _checked_ptr_1<double> _ptr__3277(_3277 ? _3277->raw() : nullptr,_3277 ? _3277->size(0) : 0);
      {
        int _3278 = (int)0;
        int _3279 = (int)0;
        _ptr__3275[_3270] = (int)0;
        int _8365 = (int)0;
        int _8366 = _3212;
        for (int _3280 = _8365; _3280 < _8366; ++_3280)
        {
          {
            bool _3281 = false;
            double _3282 = 0.0;
            int _8367 = _ptr__3221[safe_add( _3202,_3280 )];
            int _8368 = _ptr__3221[safe_add( safe_add( _3202,_3280 ),(int)1 )];
            for (int _3283 = _8367; _3283 < _8368; ++_3283)
            {
              {
                int _3284 = _ptr__3221[safe_add( _3201,_3283 )];
                int _3285 = safe_add( safe_mul( _3280,_3211 ),_ptr__3260[_3284] );
                int _8369 = _ptr__3221[safe_add( _3216,_3285 )];
                int _8370 = _ptr__3221[safe_add( safe_add( _3216,_3285 ),(int)1 )];
                for (int _3286 = _8369; _3286 < _8370; ++_3286)
                {
                  {
                    _3281 = true;
                    _ptr__3276[safe_add( _3271,_3279 )] = _ptr__3222[safe_add( _3218,_3286 )];
                    _ptr__3277[safe_add( _3273,_3279 )] = (_ptr__3223[safe_add( _3220,_3286 )] * _ptr__3261[_3284]);
                    ++ _3279;
                  }
                }
                _3282 += (_ptr__3223[safe_add( _3219,_3285 )] * _ptr__3261[_3284]);
              }
            }
            if (_3281)
            {
              {
                _ptr__3277[safe_add( _3274,_3278 )] = _3282;
                _ptr__3276[safe_add( _3272,_3278 )] = _3280;
                _ptr__3275[safe_add( safe_add( _3270,_3278 ),(int)1 )] = _3279;
                ++ _3278;
              }
            }
            {}
          }
        }
      }
      if ((!_3269))
      {
        {
          _3193->popi64(_3262);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagRight::validate(int _3287,int _3288,std::shared_ptr< monty::ndarray< int,1 > > _3289,std::shared_ptr< monty::ndarray< int,1 > > _3290,std::shared_ptr< monty::ndarray< double,1 > > _3291,monty::rc_ptr< ::mosek::fusion::Expression > _3292){
  _checked_ptr_1<int> _ptr__3289(_3289 ? _3289->raw() : nullptr, _3289 ? _3289->size(0) : 0);
  _checked_ptr_1<int> _ptr__3290(_3290 ? _3290->raw() : nullptr, _3290 ? _3290->size(0) : 0);
  _checked_ptr_1<double> _ptr__3291(_3291 ? _3291->raw() : nullptr, _3291 ? _3291->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3293 = _3292->getShape();
  _checked_ptr_1<int> _ptr__3293(_3293 ? _3293->raw() : nullptr,_3293 ? _3293->size(0) : 0);
  if (((int)((_3293)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3294 = _ptr__3293[(int)0];
  int _3295 = _ptr__3293[(int)1];
  if (((_3287 < (int)0) || ((_3288 < (int)0) || ((_3294 < (int)0) || (_3295 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3287 != _3295) || (_3288 != _3294)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3289)->size(0)) != (int)((_3290)->size(0))) || ((int)((_3289)->size(0)) != (int)((_3291)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3296 = (int)((_3289)->size(0));
  int _8371 = (int)0;
  int _8372 = _3296;
  for (int _3297 = _8371; _3297 < _8372; ++_3297)
  {
    {
      if (((_ptr__3289[_3297] < (int)0) || ((_ptr__3289[_3297] >= _3287) || ((_ptr__3290[_3297] < (int)0) || (_ptr__3290[_3297] >= _3288)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8373 = (int)0;
  int _8374 = (_3296 - (int)1);
  for (int _3298 = _8373; _3298 < _8374; ++_3298)
  {
    {
      if (((_ptr__3289[_3298] > _ptr__3289[safe_add( _3298,(int)1 )]) || ((_ptr__3289[_3298] == _ptr__3289[safe_add( _3298,(int)1 )]) && (_ptr__3290[_3298] >= _ptr__3290[safe_add( _3298,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8375 = (int)0;
  int _8376 = _3296;
  for (int _3299 = _8375; _3299 < _8376; ++_3299)
  {
    {
      if (((_ptr__3289[_3299] < (int)0) || ((_ptr__3289[_3299] >= _3287) || ((_ptr__3290[_3299] < (int)0) || (_ptr__3290[_3299] >= _3288)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagRight :: toString() { return mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagRight::toString(){
  return std::string ("ExprMulDiagRight()");
}
void mosek::fusion::p_ExprMulDiagRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagRight::destroy() { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft(mosek::fusion::p_ExprMulDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulDiagLeft::~ExprMulDiagLeft() {  /* std::cout << "~ExprMulDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagLeft::p_ExprMulDiagLeft  (::mosek::fusion::ExprMulDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3300,    int _3301,    std::shared_ptr< monty::ndarray< int,1 > > _3302,    std::shared_ptr< monty::ndarray< int,1 > > _3303,    std::shared_ptr< monty::ndarray< double,1 > > _3304,    monty::rc_ptr< ::mosek::fusion::Expression > _3305,    int _3306){ return new mosek::fusion::ExprMulDiagLeft(_3300,_3301,_3302,_3303,_3304,_3305,_3306); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3300,    int _3301,    std::shared_ptr< monty::ndarray< int,1 > > _3302,    std::shared_ptr< monty::ndarray< int,1 > > _3303,    std::shared_ptr< monty::ndarray< double,1 > > _3304,    monty::rc_ptr< ::mosek::fusion::Expression > _3305,    int _3306) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3300,_3301,_3302,_3303,_3304,_3305,_3306); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3300,    int _3301,    std::shared_ptr< monty::ndarray< int,1 > > _3302,    std::shared_ptr< monty::ndarray< int,1 > > _3303,    std::shared_ptr< monty::ndarray< double,1 > > _3304,    monty::rc_ptr< ::mosek::fusion::Expression > _3305,    int _3306){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3302(_3302 ? _3302->raw() : nullptr, _3302 ? _3302->size(0) : 0);
    _checked_ptr_1<int> _ptr__3303(_3303 ? _3303->raw() : nullptr, _3303 ? _3303->size(0) : 0);
    _checked_ptr_1<double> _ptr__3304(_3304 ? _3304->raw() : nullptr, _3304 ? _3304->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3300)}));
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim0 = _3300;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim1 = _3301;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubi = _3302;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubj = _3303;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mval = _3304;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr = _3305;
  }
}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3307,    int _3308,    std::shared_ptr< monty::ndarray< int,1 > > _3309,    std::shared_ptr< monty::ndarray< int,1 > > _3310,    std::shared_ptr< monty::ndarray< double,1 > > _3311,    monty::rc_ptr< ::mosek::fusion::Expression > _3312){ return new mosek::fusion::ExprMulDiagLeft(_3307,_3308,_3309,_3310,_3311,_3312); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3307,    int _3308,    std::shared_ptr< monty::ndarray< int,1 > > _3309,    std::shared_ptr< monty::ndarray< int,1 > > _3310,    std::shared_ptr< monty::ndarray< double,1 > > _3311,    monty::rc_ptr< ::mosek::fusion::Expression > _3312) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3307,_3308,_3309,_3310,_3311,_3312); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3307,    int _3308,    std::shared_ptr< monty::ndarray< int,1 > > _3309,    std::shared_ptr< monty::ndarray< int,1 > > _3310,    std::shared_ptr< monty::ndarray< double,1 > > _3311,    monty::rc_ptr< ::mosek::fusion::Expression > _3312){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3309(_3309 ? _3309->raw() : nullptr, _3309 ? _3309->size(0) : 0);
    _checked_ptr_1<int> _ptr__3310(_3310 ? _3310->raw() : nullptr, _3310 ? _3310->size(0) : 0);
    _checked_ptr_1<double> _ptr__3311(_3311 ? _3311->raw() : nullptr, _3311 ? _3311->size(0) : 0);
    mosek::fusion::p_ExprMulDiagLeft::_initialize(_3307,_3308,_3309,_3310,_3311,_3312,::mosek::fusion::p_ExprMulDiagLeft::validate(_3307,_3308,_3309,_3310,_3311,_3312));
  }
}void mosek::fusion::ExprMulDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3313,monty::rc_ptr< ::mosek::fusion::WorkStack > _3314,monty::rc_ptr< ::mosek::fusion::WorkStack > _3315) { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->eval(_3313,_3314,_3315); }void mosek::fusion::p_ExprMulDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3313,monty::rc_ptr< ::mosek::fusion::WorkStack > _3314,monty::rc_ptr< ::mosek::fusion::WorkStack > _3315){
  mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr->eval(_3314,_3313,_3315);
  if ((_3314->peeki32() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3316 = (int)((msubi)->size(0));
  int _3317 = (int)9999;
  int _3318 = (int)9999;
  int _3319 = (int)0;
  int _3320 = _3314->peeki32((int)5);
  if ((_3320 != (int)0))
  {
    {
      int _3321 = _3314->peeki32((int)1);
      int _3322 = _3314->peeki32((int)3);
      _3317 = _3314->alloci32(safe_add( _3321,(int)1 ));
      _3318 = _3314->alloci32(_3322);
      _3319 += safe_add( safe_add( _3322,_3321 ),(int)1 );
    }
  }
  {}
  int _3323 = _3314->alloci32(safe_add( mdim0,(int)1 ));
  _3319 += safe_add( mdim0,(int)1 );
  _3314->popi32(_3319);
  std::shared_ptr< monty::ndarray< int,1 > > _3324 = mosek::fusion::p_WorkStack::_get_impl(_3314)->i32;
  _checked_ptr_1<int> _ptr__3324(_3324 ? _3324->raw() : nullptr,_3324 ? _3324->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3325 = mosek::fusion::p_WorkStack::_get_impl(_3314)->i64;
  _checked_ptr_1<long long> _ptr__3325(_3325 ? _3325->raw() : nullptr,_3325 ? _3325->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3326 = mosek::fusion::p_WorkStack::_get_impl(_3314)->f64;
  _checked_ptr_1<double> _ptr__3326(_3326 ? _3326->raw() : nullptr,_3326 ? _3326->size(0) : 0);
  int _8377 = (int)0;
  int _8378 = safe_add( mdim0,(int)1 );
  for (int _3327 = _8377; _3327 < _8378; ++_3327)
  {
    {
      _ptr__3324[safe_add( _3323,_3327 )] = (int)0;
    }
  }
  int _8379 = (int)0;
  int _8380 = _3316;
  for (int _3328 = _8379; _3328 < _8380; ++_3328)
  {
    {
      ++ _ptr__3324[safe_add( safe_add( _3323,((*msubi)(_3328)) ),(int)1 )];
    }
  }
  int _8381 = (int)0;
  int _8382 = mdim0;
  for (int _3329 = _8381; _3329 < _8382; ++_3329)
  {
    {
      _ptr__3324[safe_add( safe_add( _3323,_3329 ),(int)1 )] += _ptr__3324[safe_add( _3323,_3329 )];
    }
  }
  int _3330 = _3314->popi32();
  int _3331 = _3314->popi32();
  int _3332 = _3314->popi32();
  int _3333 = _3314->popi32();
  int _3334 = _3314->popi32();
  bool _3335 = (_3314->popi32() != (int)0);
  int _3336 = _3314->popi32(safe_add( _3333,(int)1 ));
  int _8383;
  bool _8384 = _3335;
  if (_8384)
  {
    _8383 = _3314->popi64(_3333);
  }
  else
  {
    _8383 = (int)9999;
  }
  int _3337 = _8383;
  int _3338 = _3314->popi64(_3334);
  int _3339 = _3314->popf64(_3333);
  int _3340 = _3314->popf64(_3334);
  if ((!_3335))
  {
    {
      int _3341 = (int)((msubi)->size(0));
      int _3342 = (int)0;
      int _8385 = (int)0;
      int _8386 = mdim0;
      for (int _3343 = _8385; _3343 < _8386; ++_3343)
      {
        {
          if ((_ptr__3324[safe_add( _3323,_3343 )] < _ptr__3324[safe_add( safe_add( _3323,_3343 ),(int)1 )]))
          {
            {
              ++ _3342;
            }
          }
          {}
        }
      }
      bool _3344 = (_3342 < mdim0);
      int _3345 = _3313->alloci32(safe_add( _3342,(int)1 ));
      int _3346 = _3313->alloci64(_3341);
      int _3347 = _3313->alloci64(_3342);
      int _3348 = _3313->allocf64(_3341);
      int _3349 = _3313->allocf64(_3342);
      int _8387;
      bool _8388 = _3344;
      if (_8388)
      {
        _8387 = (int)1;
      }
      else
      {
        _8387 = (int)0;
      }
      _3313->pushi32(_8387);
      _3313->pushi32(_3341);
      _3313->pushi32(_3342);
      _3313->pushi32(mdim0);
      _3313->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3350 = mosek::fusion::p_WorkStack::_get_impl(_3313)->i32;
      _checked_ptr_1<int> _ptr__3350(_3350 ? _3350->raw() : nullptr,_3350 ? _3350->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3351 = mosek::fusion::p_WorkStack::_get_impl(_3313)->i64;
      _checked_ptr_1<long long> _ptr__3351(_3351 ? _3351->raw() : nullptr,_3351 ? _3351->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3352 = mosek::fusion::p_WorkStack::_get_impl(_3313)->f64;
      _checked_ptr_1<double> _ptr__3352(_3352 ? _3352->raw() : nullptr,_3352 ? _3352->size(0) : 0);
      {
        _ptr__3350[_3345] = (int)0;
        int _3353 = (int)0;
        int _3354 = (int)0;
        int _8389 = (int)0;
        int _8390 = mdim0;
        for (int _3355 = _8389; _3355 < _8390; ++_3355)
        {
          {
            if ((_ptr__3324[safe_add( _3323,_3355 )] < _ptr__3324[safe_add( safe_add( _3323,_3355 ),(int)1 )]))
            {
              {
                int _3356 = (int)0;
                int _8391 = _ptr__3324[safe_add( _3323,_3355 )];
                int _8392 = _ptr__3324[safe_add( safe_add( _3323,_3355 ),(int)1 )];
                for (int _3357 = _8391; _3357 < _8392; ++_3357)
                {
                  {
                    int _3358 = ((*msubj)(_3357));
                    int _3359 = safe_add( safe_mul( _3358,_3331 ),_3355 );
                    int _8393 = _ptr__3324[safe_add( _3336,_3359 )];
                    int _8394 = _ptr__3324[safe_add( safe_add( _3336,_3359 ),(int)1 )];
                    for (int _3360 = _8393; _3360 < _8394; ++_3360)
                    {
                      {
                        _ptr__3351[safe_add( _3346,_3354 )] = _ptr__3325[safe_add( _3338,_3360 )];
                        _ptr__3352[safe_add( _3348,_3354 )] = (_ptr__3326[safe_add( _3340,_3360 )] * ((*mval)(_3357)));
                        ++ _3354;
                      }
                    }
                  }
                }
                _ptr__3352[safe_add( _3349,_3353 )] = _3356;
                _ptr__3351[safe_add( _3347,_3353 )] = _3355;
                _ptr__3350[safe_add( safe_add( _3345,_3353 ),(int)1 )] = _3354;
                ++ _3353;
              }
            }
            {}
          }
        }
      }
      if ((!_3344))
      {
        {
          _3313->popi64(_3342);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _8395 = (int)0;
      int _8396 = safe_add( _3331,(int)1 );
      for (int _3361 = _8395; _3361 < _8396; ++_3361)
      {
        {
          _ptr__3324[safe_add( _3317,_3361 )] = (int)0;
        }
      }
      int _8397 = (int)0;
      int _8398 = _3333;
      for (int _3362 = _8397; _3362 < _8398; ++_3362)
      {
        {
          ++ _ptr__3324[safe_add( safe_add( _3317,(_ptr__3325[safe_add( _3337,_3362 )] % _3331) ),(int)1 )];
        }
      }
      int _8399 = (int)0;
      int _8400 = _3331;
      for (int _3363 = _8399; _3363 < _8400; ++_3363)
      {
        {
          _ptr__3324[safe_add( safe_add( _3317,_3363 ),(int)1 )] += _ptr__3324[safe_add( _3317,_3363 )];
        }
      }
      int _8401 = (int)0;
      int _8402 = _3333;
      for (int _3364 = _8401; _3364 < _8402; ++_3364)
      {
        {
          long long _3365 = (_ptr__3325[safe_add( _3337,_3364 )] % _3331);
          _ptr__3324[safe_add( _3318,_ptr__3324[safe_add( _3317,_3365 )] )] = _3364;
          ++ _ptr__3324[safe_add( _3317,_3365 )];
        }
      }
      int _8403 = (int)0;
      int _8404 = _3331;
      for (int _3366 = _8403; _3366 < _8404; ++_3366)
      {
        {
          _ptr__3324[(safe_add( _3317,_3331 ) - _3366)] = _ptr__3324[((safe_add( _3317,_3331 ) - _3366) - (int)1)];
        }
      }
      _ptr__3324[_3317] = (int)0;
      int _3367 = (int)0;
      int _3368 = (int)0;
      {
        int _8405 = (int)0;
        int _8406 = mdim0;
        for (int _3369 = _8405; _3369 < _8406; ++_3369)
        {
          {
            int _3370 = _ptr__3324[safe_add( safe_add( _3317,_3369 ),(int)1 )];
            int _3371 = _ptr__3324[safe_add( _3317,_3369 )];
            int _3372 = _ptr__3324[safe_add( safe_add( _3323,_3369 ),(int)1 )];
            int _3373 = _ptr__3324[safe_add( _3323,_3369 )];
            bool _3374 = false;
            while ( ((_3373 < _3372) && (_3371 < _3370)) )
            {
              {
                int _3375 = _ptr__3324[safe_add( _3318,_3371 )];
                long long _3376 = (_ptr__3325[safe_add( _3337,_3375 )] / _3331);
                if ((((*msubj)(_3373)) < _3376))
                {
                  {
                    ++ _3373;
                  }
                }
                else if((((*msubj)(_3373)) > _3376))
                {
                  {
                    ++ _3371;
                  }
                }
                else
                {
                  {
                    _3374 = true;
                    _3368 += (_ptr__3324[safe_add( safe_add( _3336,_3375 ),(int)1 )] - _ptr__3324[safe_add( _3336,_3375 )]);
                    ++ _3373;
                    ++ _3371;
                  }
                }
              }
            }
            if (_3374)
            {
              {
                ++ _3367;
              }
            }
            {}
          }
        }
      }
      int _3377 = _3367;
      int _3378 = _3368;
      bool _3379 = (_3377 < mdim0);
      int _3380 = _3313->alloci32(safe_add( _3377,(int)1 ));
      int _3381 = _3313->alloci64(_3378);
      int _3382 = _3313->alloci64(_3377);
      int _3383 = _3313->allocf64(_3378);
      int _3384 = _3313->allocf64(_3377);
      int _8407;
      bool _8408 = _3379;
      if (_8408)
      {
        _8407 = (int)1;
      }
      else
      {
        _8407 = (int)0;
      }
      _3313->pushi32(_8407);
      _3313->pushi32(_3378);
      _3313->pushi32(_3377);
      _3313->pushi32(mdim0);
      _3313->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3385 = mosek::fusion::p_WorkStack::_get_impl(_3313)->i32;
      _checked_ptr_1<int> _ptr__3385(_3385 ? _3385->raw() : nullptr,_3385 ? _3385->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3386 = mosek::fusion::p_WorkStack::_get_impl(_3313)->i64;
      _checked_ptr_1<long long> _ptr__3386(_3386 ? _3386->raw() : nullptr,_3386 ? _3386->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3387 = mosek::fusion::p_WorkStack::_get_impl(_3313)->f64;
      _checked_ptr_1<double> _ptr__3387(_3387 ? _3387->raw() : nullptr,_3387 ? _3387->size(0) : 0);
      {
        _ptr__3385[_3380] = (int)0;
        int _3388 = (int)0;
        int _3389 = (int)0;
        int _8409 = (int)0;
        int _8410 = mdim0;
        for (int _3390 = _8409; _3390 < _8410; ++_3390)
        {
          {
            int _3391 = _ptr__3324[safe_add( safe_add( _3317,_3390 ),(int)1 )];
            int _3392 = _ptr__3324[safe_add( _3317,_3390 )];
            int _3393 = _ptr__3324[safe_add( safe_add( _3323,_3390 ),(int)1 )];
            int _3394 = _ptr__3324[safe_add( _3323,_3390 )];
            bool _3395 = false;
            double _3396 = 0.0;
            while ( ((_3394 < _3393) && (_3392 < _3391)) )
            {
              {
                int _3397 = _ptr__3324[safe_add( _3318,_3392 )];
                long long _3398 = (_ptr__3325[safe_add( _3337,_3397 )] / _3331);
                if ((((*msubj)(_3394)) < _3398))
                {
                  {
                    ++ _3394;
                  }
                }
                else if((((*msubj)(_3394)) > _3398))
                {
                  {
                    ++ _3392;
                  }
                }
                else
                {
                  {
                    _3395 = true;
                    int _8411 = _ptr__3324[safe_add( _3336,_3397 )];
                    int _8412 = _ptr__3324[safe_add( safe_add( _3336,_3397 ),(int)1 )];
                    for (int _3399 = _8411; _3399 < _8412; ++_3399)
                    {
                      {
                        _ptr__3386[safe_add( _3381,_3389 )] = _ptr__3325[safe_add( _3338,_3399 )];
                        _ptr__3387[safe_add( _3383,_3389 )] = (_ptr__3326[safe_add( _3340,_3399 )] * ((*mval)(_3394)));
                        ++ _3389;
                      }
                    }
                    _3396 += _ptr__3326[safe_add( _3339,_3397 )];
                    ++ _3394;
                    ++ _3392;
                  }
                }
              }
            }
            if (_3395)
            {
              {
                _ptr__3386[safe_add( _3382,_3388 )] = _3390;
                _ptr__3387[safe_add( _3384,_3388 )] = (_3396 * ((*mval)(_3394)));
                _ptr__3385[safe_add( safe_add( _3380,_3388 ),(int)1 )] = _3389;
                ++ _3388;
              }
            }
            {}
          }
        }
      }
      if ((!_3379))
      {
        {
          _3313->popi64(_3377);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagLeft::validate(int _3400,int _3401,std::shared_ptr< monty::ndarray< int,1 > > _3402,std::shared_ptr< monty::ndarray< int,1 > > _3403,std::shared_ptr< monty::ndarray< double,1 > > _3404,monty::rc_ptr< ::mosek::fusion::Expression > _3405){
  _checked_ptr_1<int> _ptr__3402(_3402 ? _3402->raw() : nullptr, _3402 ? _3402->size(0) : 0);
  _checked_ptr_1<int> _ptr__3403(_3403 ? _3403->raw() : nullptr, _3403 ? _3403->size(0) : 0);
  _checked_ptr_1<double> _ptr__3404(_3404 ? _3404->raw() : nullptr, _3404 ? _3404->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3406 = _3405->getShape();
  _checked_ptr_1<int> _ptr__3406(_3406 ? _3406->raw() : nullptr,_3406 ? _3406->size(0) : 0);
  if (((int)((_3406)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3407 = _ptr__3406[(int)0];
  int _3408 = _ptr__3406[(int)1];
  if (((_3400 < (int)0) || (_3401 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3401 != _3407) || (_3400 != _3408)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3402)->size(0)) != (int)((_3403)->size(0))) || ((int)((_3402)->size(0)) != (int)((_3404)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3409 = (int)((_3402)->size(0));
  int _8413 = (int)0;
  int _8414 = _3409;
  for (int _3410 = _8413; _3410 < _8414; ++_3410)
  {
    {
      if (((_ptr__3402[_3410] < (int)0) || ((_ptr__3402[_3410] >= _3400) || ((_ptr__3403[_3410] < (int)0) || (_ptr__3403[_3410] >= _3401)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8415 = (int)0;
  int _8416 = (_3409 - (int)1);
  for (int _3411 = _8415; _3411 < _8416; ++_3411)
  {
    {
      if (((_ptr__3402[_3411] > _ptr__3402[safe_add( _3411,(int)1 )]) || ((_ptr__3402[_3411] == _ptr__3402[safe_add( _3411,(int)1 )]) && (_ptr__3403[_3411] >= _ptr__3403[safe_add( _3411,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8417 = (int)0;
  int _8418 = _3409;
  for (int _3412 = _8417; _3412 < _8418; ++_3412)
  {
    {
      if (((_ptr__3402[_3412] < (int)0) || ((_ptr__3402[_3412] >= _3400) || ((_ptr__3403[_3412] < (int)0) || (_ptr__3403[_3412] >= _3401)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagLeft :: toString() { return mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagLeft::toString(){
  return std::string ("ExprMulDiagLeft()");
}
void mosek::fusion::p_ExprMulDiagLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagLeft::destroy() { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulElement::ExprMulElement(mosek::fusion::p_ExprMulElement *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulElement()" << this << std::endl; */ }mosek::fusion::ExprMulElement::~ExprMulElement() {  /* std::cout << "~ExprMulElement()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulElement::p_ExprMulElement  (::mosek::fusion::ExprMulElement * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3413,    std::shared_ptr< monty::ndarray< long long,1 > > _3414,    monty::rc_ptr< ::mosek::fusion::Expression > _3415){ return new mosek::fusion::ExprMulElement(_3413,_3414,_3415); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3413,    std::shared_ptr< monty::ndarray< long long,1 > > _3414,    monty::rc_ptr< ::mosek::fusion::Expression > _3415) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3413,_3414,_3415); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3413,    std::shared_ptr< monty::ndarray< long long,1 > > _3414,    monty::rc_ptr< ::mosek::fusion::Expression > _3415){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3413(_3413 ? _3413->raw() : nullptr, _3413 ? _3413->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3414(_3414 ? _3414->raw() : nullptr, _3414 ? _3414->size(0) : 0);
    mosek::fusion::p_ExprMulElement::_initialize(_3413,_3414,_3415,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3416 = _3415->getShape();
    _checked_ptr_1<int> _ptr__3416(_3416 ? _3416->raw() : nullptr,_3416 ? _3416->size(0) : 0);
    if (((int)((_3413)->size(0)) != (int)((_3414)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix specification"));
      }
    }
    {}
    long long _3417 = ::mosek::fusion::p_Set::size(_3416);
    int _8419 = (int)0;
    int _8420 = (int)((_3414)->size(0));
    for (int _3418 = _8419; _3418 < _8420; ++_3418)
    {
      {
        if (((_ptr__3414[_3418] < (int)0) || (_ptr__3414[_3418] >= _3417)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
          }
        }
        {}
      }
    }
    int _8421 = (int)0;
    int _8422 = ((int)((_3414)->size(0)) - (int)1);
    for (int _3419 = _8421; _3419 < _8422; ++_3419)
    {
      {
        if ((_ptr__3414[_3419] >= _ptr__3414[safe_add( _3419,(int)1 )]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3420,    std::shared_ptr< monty::ndarray< long long,1 > > _3421,    monty::rc_ptr< ::mosek::fusion::Expression > _3422,    int _3423){ return new mosek::fusion::ExprMulElement(_3420,_3421,_3422,_3423); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3420,    std::shared_ptr< monty::ndarray< long long,1 > > _3421,    monty::rc_ptr< ::mosek::fusion::Expression > _3422,    int _3423) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3420,_3421,_3422,_3423); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3420,    std::shared_ptr< monty::ndarray< long long,1 > > _3421,    monty::rc_ptr< ::mosek::fusion::Expression > _3422,    int _3423){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3420(_3420 ? _3420->raw() : nullptr, _3420 ? _3420->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3421(_3421 ? _3421->raw() : nullptr, _3421 ? _3421->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_3422->getShape());
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->expr = _3422;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->mcof = _3420;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->msp = _3421;
  }
}void mosek::fusion::ExprMulElement :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3424,monty::rc_ptr< ::mosek::fusion::WorkStack > _3425,monty::rc_ptr< ::mosek::fusion::WorkStack > _3426) { mosek::fusion::p_ExprMulElement::_get_impl(this)->eval(_3424,_3425,_3426); }void mosek::fusion::p_ExprMulElement::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3424,monty::rc_ptr< ::mosek::fusion::WorkStack > _3425,monty::rc_ptr< ::mosek::fusion::WorkStack > _3426){
  expr->eval(_3425,_3424,_3426);
  int _3427 = _3425->popi32();
  int _3428 = _3425->popi32(_3427);
  int _3429 = _3425->popi32();
  int _3430 = _3425->popi32();
  bool _3431 = (_3425->popi32() != (int)0);
  int _3432 = _3425->popi32(safe_add( _3429,(int)1 ));
  int _8423;
  bool _8424 = _3431;
  if (_8424)
  {
    _8423 = _3425->popi64(_3429);
  }
  else
  {
    _8423 = (-(int)1);
  }
  int _3433 = _8423;
  int _3434 = _3425->popi64(_3430);
  int _3435 = _3425->popf64(_3429);
  int _3436 = _3425->popf64(_3430);
  std::shared_ptr< monty::ndarray< int,1 > > _3437 = mosek::fusion::p_WorkStack::_get_impl(_3425)->i32;
  _checked_ptr_1<int> _ptr__3437(_3437 ? _3437->raw() : nullptr,_3437 ? _3437->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3438 = mosek::fusion::p_WorkStack::_get_impl(_3425)->i64;
  _checked_ptr_1<long long> _ptr__3438(_3438 ? _3438->raw() : nullptr,_3438 ? _3438->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3439 = mosek::fusion::p_WorkStack::_get_impl(_3425)->f64;
  _checked_ptr_1<double> _ptr__3439(_3439 ? _3439->raw() : nullptr,_3439 ? _3439->size(0) : 0);
  int _3440 = (int)0;
  int _3441 = (int)0;
  if ((!_3431))
  {
    {
      _3441 = (int)((msp)->size(0));
      int _8425 = (int)0;
      int _8426 = (int)((msp)->size(0));
      for (int _3442 = _8425; _3442 < _8426; ++_3442)
      {
        {
          _3440 += (_ptr__3437[safe_add( safe_add( _3432,((*msp)(_3442)) ),(int)1 )] - _ptr__3437[safe_add( _3432,((*msp)(_3442)) )]);
        }
      }
    }
  }
  else
  {
    {
      int _3443 = (int)((msp)->size(0));
      int _3444 = (int)0;
      int _3445 = _3429;
      int _3446 = (int)0;
      while ( ((_3444 < _3443) && (_3446 < _3445)) )
      {
        {
          if ((((*msp)(_3444)) < _ptr__3438[safe_add( _3433,_3446 )]))
          {
            {
              ++ _3444;
            }
          }
          else if((((*msp)(_3444)) > _ptr__3438[safe_add( _3433,_3446 )]))
          {
            {
              ++ _3446;
            }
          }
          else
          {
            {
              _3440 += (_ptr__3437[safe_add( safe_add( _3432,_3446 ),(int)1 )] - _ptr__3437[safe_add( _3432,_3446 )]);
              ++ _3444;
              ++ _3446;
              ++ _3441;
            }
          }
        }
      }
    }
  }
  int _3447 = _3424->alloci32(safe_add( _3441,(int)1 ));
  int _3448 = _3424->alloci64(_3440);
  int _3449 = _3424->alloci64(_3441);
  int _3450 = _3424->allocf64(_3440);
  int _3451 = _3424->allocf64(_3441);
  int _3452 = (int)1;
  int _8427 = (int)0;
  int _8428 = _3427;
  for (int _3453 = _8427; _3453 < _8428; ++_3453)
  {
    {
      _3452 *= _ptr__3437[safe_add( _3428,_3453 )];
    }
  }
  bool _3454 = (_3441 < _3452);
  int _8429;
  bool _8430 = _3454;
  if (_8430)
  {
    _8429 = (int)1;
  }
  else
  {
    _8429 = (int)0;
  }
  _3424->pushi32(_8429);
  _3424->pushi32(_3440);
  _3424->pushi32(_3441);
  int _3455 = _3424->alloci32(_3427);
  _3424->pushi32(_3427);
  std::shared_ptr< monty::ndarray< int,1 > > _3456 = mosek::fusion::p_WorkStack::_get_impl(_3424)->i32;
  _checked_ptr_1<int> _ptr__3456(_3456 ? _3456->raw() : nullptr,_3456 ? _3456->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3457 = mosek::fusion::p_WorkStack::_get_impl(_3424)->i64;
  _checked_ptr_1<long long> _ptr__3457(_3457 ? _3457->raw() : nullptr,_3457 ? _3457->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3458 = mosek::fusion::p_WorkStack::_get_impl(_3424)->f64;
  _checked_ptr_1<double> _ptr__3458(_3458 ? _3458->raw() : nullptr,_3458 ? _3458->size(0) : 0);
  {
    int _3459 = (int)0;
    int _3460 = (int)0;
    _ptr__3456[_3447] = (int)0;
    int _8431 = (int)0;
    int _8432 = _3427;
    for (int _3461 = _8431; _3461 < _8432; ++_3461)
    {
      {
        _ptr__3456[safe_add( _3455,_3461 )] = _ptr__3437[safe_add( _3428,_3461 )];
      }
    }
    if ((!_3431))
    {
      {
        int _8433 = (int)0;
        int _8434 = (int)((msp)->size(0));
        for (int _3462 = _8433; _3462 < _8434; ++_3462)
        {
          {
            int _3463 = _ptr__3437[safe_add( _3432,((*msp)(_3462)) )];
            int _3464 = _ptr__3437[safe_add( safe_add( _3432,((*msp)(_3462)) ),(int)1 )];
            int _8435 = _3463;
            int _8436 = _3464;
            for (int _3465 = _8435; _3465 < _8436; ++_3465)
            {
              {
                _ptr__3457[safe_add( _3448,_3460 )] = _ptr__3438[safe_add( _3434,_3465 )];
                _ptr__3458[safe_add( _3450,_3460 )] = (_ptr__3439[safe_add( _3436,_3465 )] * ((*mcof)(_3462)));
                ++ _3460;
              }
            }
            _ptr__3456[safe_add( safe_add( _3447,_3462 ),(int)1 )] = _3460;
            _ptr__3458[safe_add( _3451,_3462 )] = (_ptr__3439[safe_add( _3435,((*msp)(_3462)) )] * ((*mcof)(_3462)));
            _ptr__3457[safe_add( _3449,_3462 )] = ((*msp)(_3462));
          }
        }
      }
    }
    else
    {
      {
        int _3466 = (int)((msp)->size(0));
        int _3467 = (int)0;
        int _3468 = _3429;
        int _3469 = (int)0;
        while ( ((_3467 < _3466) && (_3469 < _3468)) )
        {
          {
            if ((((*msp)(_3467)) < _ptr__3438[safe_add( _3433,_3469 )]))
            {
              {
                ++ _3467;
              }
            }
            else if((((*msp)(_3467)) > _ptr__3438[safe_add( _3433,_3469 )]))
            {
              {
                ++ _3469;
              }
            }
            else
            {
              {
                int _3470 = _ptr__3437[safe_add( _3432,_3469 )];
                int _3471 = _ptr__3437[safe_add( safe_add( _3432,_3469 ),(int)1 )];
                int _8437 = _3470;
                int _8438 = _3471;
                for (int _3472 = _8437; _3472 < _8438; ++_3472)
                {
                  {
                    _ptr__3457[safe_add( _3448,_3460 )] = _ptr__3438[safe_add( _3434,_3472 )];
                    _ptr__3458[safe_add( _3448,_3460 )] = (_ptr__3439[safe_add( _3434,_3472 )] * ((*mcof)(_3467)));
                    ++ _3460;
                  }
                }
                _ptr__3456[safe_add( safe_add( _3447,_3459 ),(int)1 )] = _3460;
                _ptr__3458[safe_add( _3451,_3459 )] = (_ptr__3439[safe_add( _3435,_3469 )] * ((*mcof)(_3467)));
                _ptr__3457[safe_add( _3449,_3459 )] = ((*msp)(_3467));
                ++ _3459;
                ++ _3467;
                ++ _3469;
              }
            }
          }
        }
      }
    }
  }
  if ((!_3454))
  {
    {
      _3424->popi64(_3441);
    }
  }
  {}
}
std::string mosek::fusion::ExprMulElement :: toString() { return mosek::fusion::p_ExprMulElement::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulElement::toString(){
  return std::string ("ExprMulElement()");
}
void mosek::fusion::p_ExprMulElement::destroy(){expr.reset();msp.reset();mcof.reset();}void mosek::fusion::ExprMulElement::destroy() { mosek::fusion::p_ExprMulElement::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst(mosek::fusion::p_ExprMulScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulScalarConst::~ExprMulScalarConst() {  /* std::cout << "~ExprMulScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarConst::p_ExprMulScalarConst  (::mosek::fusion::ExprMulScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarConst::t mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst  (double _3473,    monty::rc_ptr< ::mosek::fusion::Expression > _3474){ return new mosek::fusion::ExprMulScalarConst(_3473,_3474); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst  (double _3473,    monty::rc_ptr< ::mosek::fusion::Expression > _3474) :    ExprMulScalarConst(new mosek::fusion::p_ExprMulScalarConst(this)){ mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->_initialize(_3473,_3474); }void mosek::fusion::p_ExprMulScalarConst::_initialize  (double _3473,    monty::rc_ptr< ::mosek::fusion::Expression > _3474){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3474->getShape());
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->c = _3473;
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->expr = _3474;
  }
}void mosek::fusion::ExprMulScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3475,monty::rc_ptr< ::mosek::fusion::WorkStack > _3476,monty::rc_ptr< ::mosek::fusion::WorkStack > _3477) { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->eval(_3475,_3476,_3477); }void mosek::fusion::p_ExprMulScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3475,monty::rc_ptr< ::mosek::fusion::WorkStack > _3476,monty::rc_ptr< ::mosek::fusion::WorkStack > _3477){
  expr->eval(_3475,_3476,_3477);
  int _3478 = _3475->peeki32((int)0);
  int _3479 = _3475->peeki32(safe_add( _3478,(int)1 ));
  int _3480 = _3475->peeki32(safe_add( _3478,(int)2 ));
  int _3481 = (mosek::fusion::p_WorkStack::_get_impl(_3475)->pf64 - _3479);
  int _3482 = (_3481 - _3480);
  std::shared_ptr< monty::ndarray< double,1 > > _3483 = mosek::fusion::p_WorkStack::_get_impl(_3475)->f64;
  _checked_ptr_1<double> _ptr__3483(_3483 ? _3483->raw() : nullptr,_3483 ? _3483->size(0) : 0);
  int _8439 = (int)0;
  int _8440 = safe_add( _3480,_3479 );
  for (int _3484 = _8439; _3484 < _8440; ++_3484)
  {
    {
      _ptr__3483[safe_add( _3482,_3484 )] *= c;
    }
  }
}
std::string mosek::fusion::ExprMulScalarConst :: toString() { return mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarConst::toString(){
  return std::string ("ExprMulScalarConst()");
}
void mosek::fusion::p_ExprMulScalarConst::destroy(){expr.reset();}void mosek::fusion::ExprMulScalarConst::destroy() { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprScalarMul::ExprScalarMul(mosek::fusion::p_ExprScalarMul *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprScalarMul()" << this << std::endl; */ }mosek::fusion::ExprScalarMul::~ExprScalarMul() {  /* std::cout << "~ExprScalarMul()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprScalarMul::p_ExprScalarMul  (::mosek::fusion::ExprScalarMul * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3485,    int _3486,    std::shared_ptr< monty::ndarray< int,1 > > _3487,    std::shared_ptr< monty::ndarray< int,1 > > _3488,    std::shared_ptr< monty::ndarray< double,1 > > _3489,    monty::rc_ptr< ::mosek::fusion::Expression > _3490,    int _3491){ return new mosek::fusion::ExprScalarMul(_3485,_3486,_3487,_3488,_3489,_3490,_3491); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3485,    int _3486,    std::shared_ptr< monty::ndarray< int,1 > > _3487,    std::shared_ptr< monty::ndarray< int,1 > > _3488,    std::shared_ptr< monty::ndarray< double,1 > > _3489,    monty::rc_ptr< ::mosek::fusion::Expression > _3490,    int _3491) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3485,_3486,_3487,_3488,_3489,_3490,_3491); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3485,    int _3486,    std::shared_ptr< monty::ndarray< int,1 > > _3487,    std::shared_ptr< monty::ndarray< int,1 > > _3488,    std::shared_ptr< monty::ndarray< double,1 > > _3489,    monty::rc_ptr< ::mosek::fusion::Expression > _3490,    int _3491){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3487(_3487 ? _3487->raw() : nullptr, _3487 ? _3487->size(0) : 0);
    _checked_ptr_1<int> _ptr__3488(_3488 ? _3488->raw() : nullptr, _3488 ? _3488->size(0) : 0);
    _checked_ptr_1<double> _ptr__3489(_3489 ? _3489->raw() : nullptr, _3489 ? _3489->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3485),(int)(_3486)}));
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim0 = _3485;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim1 = _3486;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubi = _3487;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubj = _3488;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mval = _3489;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr = _3490;
  }
}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3492,    int _3493,    std::shared_ptr< monty::ndarray< int,1 > > _3494,    std::shared_ptr< monty::ndarray< int,1 > > _3495,    std::shared_ptr< monty::ndarray< double,1 > > _3496,    monty::rc_ptr< ::mosek::fusion::Expression > _3497){ return new mosek::fusion::ExprScalarMul(_3492,_3493,_3494,_3495,_3496,_3497); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3492,    int _3493,    std::shared_ptr< monty::ndarray< int,1 > > _3494,    std::shared_ptr< monty::ndarray< int,1 > > _3495,    std::shared_ptr< monty::ndarray< double,1 > > _3496,    monty::rc_ptr< ::mosek::fusion::Expression > _3497) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3492,_3493,_3494,_3495,_3496,_3497); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3492,    int _3493,    std::shared_ptr< monty::ndarray< int,1 > > _3494,    std::shared_ptr< monty::ndarray< int,1 > > _3495,    std::shared_ptr< monty::ndarray< double,1 > > _3496,    monty::rc_ptr< ::mosek::fusion::Expression > _3497){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3494(_3494 ? _3494->raw() : nullptr, _3494 ? _3494->size(0) : 0);
    _checked_ptr_1<int> _ptr__3495(_3495 ? _3495->raw() : nullptr, _3495 ? _3495->size(0) : 0);
    _checked_ptr_1<double> _ptr__3496(_3496 ? _3496->raw() : nullptr, _3496 ? _3496->size(0) : 0);
    mosek::fusion::p_ExprScalarMul::_initialize(_3492,_3493,_3494,_3495,_3496,_3497,::mosek::fusion::p_ExprScalarMul::validate(_3492,_3493,_3494,_3495,_3496,_3497));
  }
}void mosek::fusion::ExprScalarMul :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3498,monty::rc_ptr< ::mosek::fusion::WorkStack > _3499,monty::rc_ptr< ::mosek::fusion::WorkStack > _3500) { mosek::fusion::p_ExprScalarMul::_get_impl(this)->eval(_3498,_3499,_3500); }void mosek::fusion::p_ExprScalarMul::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3498,monty::rc_ptr< ::mosek::fusion::WorkStack > _3499,monty::rc_ptr< ::mosek::fusion::WorkStack > _3500){
  mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr->eval(_3499,_3498,_3500);
  _3499->pop_expr();
  int _3501 = mosek::fusion::p_WorkStack::_get_impl(_3499)->nd;
  int _3502 = mosek::fusion::p_WorkStack::_get_impl(_3499)->nelem;
  int _3503 = mosek::fusion::p_WorkStack::_get_impl(_3499)->nnz;
  bool _3504 = mosek::fusion::p_WorkStack::_get_impl(_3499)->hassp;
  int _3505 = mosek::fusion::p_WorkStack::_get_impl(_3499)->ptr_base;
  int _3506 = mosek::fusion::p_WorkStack::_get_impl(_3499)->sp_base;
  int _3507 = mosek::fusion::p_WorkStack::_get_impl(_3499)->nidxs_base;
  int _3508 = mosek::fusion::p_WorkStack::_get_impl(_3499)->bfix_base;
  int _3509 = mosek::fusion::p_WorkStack::_get_impl(_3499)->cof_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3510 = mosek::fusion::p_WorkStack::_get_impl(_3499)->i64;
  _checked_ptr_1<long long> _ptr__3510(_3510 ? _3510->raw() : nullptr,_3510 ? _3510->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3511 = mosek::fusion::p_WorkStack::_get_impl(_3499)->f64;
  _checked_ptr_1<double> _ptr__3511(_3511 ? _3511->raw() : nullptr,_3511 ? _3511->size(0) : 0);
  int _3512 = (int)((mval)->size(0));
  if ((_3501 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression shape"));
    }
  }
  {}
  if ((_3502 == (int)0))
  {
    {
      _3498->alloc_expr((int)2,(int)0,(int)0,true);
      ((*mosek::fusion::p_WorkStack::_get_impl(_3498)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3498)->shape_base)) = mdim0;
      ((*mosek::fusion::p_WorkStack::_get_impl(_3498)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_3498)->shape_base,(int)1 ))) = mdim1;
    }
  }
  else
  {
    {
      _3498->alloc_expr((int)2,_3512,safe_mul( _3512,_3503 ),true);
      int _3513 = mosek::fusion::p_WorkStack::_get_impl(_3498)->ptr_base;
      int _3514 = mosek::fusion::p_WorkStack::_get_impl(_3498)->nidxs_base;
      int _3515 = mosek::fusion::p_WorkStack::_get_impl(_3498)->sp_base;
      int _3516 = mosek::fusion::p_WorkStack::_get_impl(_3498)->cof_base;
      int _3517 = mosek::fusion::p_WorkStack::_get_impl(_3498)->bfix_base;
      int _3518 = mosek::fusion::p_WorkStack::_get_impl(_3498)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _3519 = mosek::fusion::p_WorkStack::_get_impl(_3498)->i32;
      _checked_ptr_1<int> _ptr__3519(_3519 ? _3519->raw() : nullptr,_3519 ? _3519->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3520 = mosek::fusion::p_WorkStack::_get_impl(_3498)->i64;
      _checked_ptr_1<long long> _ptr__3520(_3520 ? _3520->raw() : nullptr,_3520 ? _3520->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3521 = mosek::fusion::p_WorkStack::_get_impl(_3498)->f64;
      _checked_ptr_1<double> _ptr__3521(_3521 ? _3521->raw() : nullptr,_3521 ? _3521->size(0) : 0);
      _ptr__3519[_3518] = mdim0;
      _ptr__3519[safe_add( _3518,(int)1 )] = mdim1;
      int _3522 = (int)0;
      _ptr__3519[_3513] = (int)0;
      int _8441 = (int)0;
      int _8442 = _3512;
      for (int _3523 = _8441; _3523 < _8442; ++_3523)
      {
        {
          int _8443 = (int)0;
          int _8444 = _3503;
          for (int _3524 = _8443; _3524 < _8444; ++_3524)
          {
            {
              _ptr__3520[safe_add( _3514,_3522 )] = _ptr__3510[safe_add( _3507,_3524 )];
              _ptr__3521[safe_add( _3516,_3522 )] = (_ptr__3511[safe_add( _3509,_3524 )] * ((*mval)(_3523)));
              ++ _3522;
            }
          }
          _ptr__3520[safe_add( _3515,_3523 )] = safe_add( safe_mul( ((*msubi)(_3523)),mdim1 ),((*msubj)(_3523)) );
          _ptr__3521[safe_add( _3517,_3523 )] = (((*mval)(_3523)) * _ptr__3511[_3508]);
          _ptr__3519[safe_add( safe_add( _3513,_3523 ),(int)1 )] = _3522;
        }
      }
    }
  }
}
int mosek::fusion::p_ExprScalarMul::validate(int _3525,int _3526,std::shared_ptr< monty::ndarray< int,1 > > _3527,std::shared_ptr< monty::ndarray< int,1 > > _3528,std::shared_ptr< monty::ndarray< double,1 > > _3529,monty::rc_ptr< ::mosek::fusion::Expression > _3530){
  _checked_ptr_1<int> _ptr__3527(_3527 ? _3527->raw() : nullptr, _3527 ? _3527->size(0) : 0);
  _checked_ptr_1<int> _ptr__3528(_3528 ? _3528->raw() : nullptr, _3528 ? _3528->size(0) : 0);
  _checked_ptr_1<double> _ptr__3529(_3529 ? _3529->raw() : nullptr, _3529 ? _3529->size(0) : 0);
  int _3531 = _3530->getND();
  if ((_3531 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3525 < (int)0) || (_3526 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((((int)((_3527)->size(0)) != (int)((_3528)->size(0))) || ((int)((_3527)->size(0)) != (int)((_3529)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3532 = (int)((_3527)->size(0));
  int _8445 = (int)0;
  int _8446 = _3532;
  for (int _3533 = _8445; _3533 < _8446; ++_3533)
  {
    {
      if (((_ptr__3527[_3533] < (int)0) || ((_ptr__3527[_3533] >= _3525) || ((_ptr__3528[_3533] < (int)0) || (_ptr__3528[_3533] >= _3526)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8447 = (int)0;
  int _8448 = (_3532 - (int)1);
  for (int _3534 = _8447; _3534 < _8448; ++_3534)
  {
    {
      if (((_ptr__3527[_3534] > _ptr__3527[safe_add( _3534,(int)1 )]) || ((_ptr__3527[_3534] == _ptr__3527[safe_add( _3534,(int)1 )]) && (_ptr__3528[_3534] >= _ptr__3528[safe_add( _3534,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8449 = (int)0;
  int _8450 = _3532;
  for (int _3535 = _8449; _3535 < _8450; ++_3535)
  {
    {
      if (((_ptr__3527[_3535] < (int)0) || ((_ptr__3527[_3535] >= _3525) || ((_ptr__3528[_3535] < (int)0) || (_ptr__3528[_3535] >= _3526)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprScalarMul :: toString() { return mosek::fusion::p_ExprScalarMul::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprScalarMul::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprScalarMul(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprScalarMul::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprScalarMul::destroy() { mosek::fusion::p_ExprScalarMul::_get_impl(this)->destroy(); }mosek::fusion::ExprMulRight::ExprMulRight(mosek::fusion::p_ExprMulRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulRight()" << this << std::endl; */ }mosek::fusion::ExprMulRight::~ExprMulRight() {  /* std::cout << "~ExprMulRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulRight::p_ExprMulRight  (::mosek::fusion::ExprMulRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3536,    int _3537,    std::shared_ptr< monty::ndarray< int,1 > > _3538,    std::shared_ptr< monty::ndarray< int,1 > > _3539,    std::shared_ptr< monty::ndarray< double,1 > > _3540,    monty::rc_ptr< ::mosek::fusion::Expression > _3541,    int _3542){ return new mosek::fusion::ExprMulRight(_3536,_3537,_3538,_3539,_3540,_3541,_3542); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3536,    int _3537,    std::shared_ptr< monty::ndarray< int,1 > > _3538,    std::shared_ptr< monty::ndarray< int,1 > > _3539,    std::shared_ptr< monty::ndarray< double,1 > > _3540,    monty::rc_ptr< ::mosek::fusion::Expression > _3541,    int _3542) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3536,_3537,_3538,_3539,_3540,_3541,_3542); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3536,    int _3537,    std::shared_ptr< monty::ndarray< int,1 > > _3538,    std::shared_ptr< monty::ndarray< int,1 > > _3539,    std::shared_ptr< monty::ndarray< double,1 > > _3540,    monty::rc_ptr< ::mosek::fusion::Expression > _3541,    int _3542){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3538(_3538 ? _3538->raw() : nullptr, _3538 ? _3538->size(0) : 0);
    _checked_ptr_1<int> _ptr__3539(_3539 ? _3539->raw() : nullptr, _3539 ? _3539->size(0) : 0);
    _checked_ptr_1<double> _ptr__3540(_3540 ? _3540->raw() : nullptr, _3540 ? _3540->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulRight::computeshape(_3537,_3541->getShape()));
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim0 = _3536;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim1 = _3537;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubi = _3538;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubj = _3539;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mval = _3540;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr = _3541;
  }
}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3543,    int _3544,    std::shared_ptr< monty::ndarray< int,1 > > _3545,    std::shared_ptr< monty::ndarray< int,1 > > _3546,    std::shared_ptr< monty::ndarray< double,1 > > _3547,    monty::rc_ptr< ::mosek::fusion::Expression > _3548){ return new mosek::fusion::ExprMulRight(_3543,_3544,_3545,_3546,_3547,_3548); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3543,    int _3544,    std::shared_ptr< monty::ndarray< int,1 > > _3545,    std::shared_ptr< monty::ndarray< int,1 > > _3546,    std::shared_ptr< monty::ndarray< double,1 > > _3547,    monty::rc_ptr< ::mosek::fusion::Expression > _3548) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3543,_3544,_3545,_3546,_3547,_3548); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3543,    int _3544,    std::shared_ptr< monty::ndarray< int,1 > > _3545,    std::shared_ptr< monty::ndarray< int,1 > > _3546,    std::shared_ptr< monty::ndarray< double,1 > > _3547,    monty::rc_ptr< ::mosek::fusion::Expression > _3548){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3545(_3545 ? _3545->raw() : nullptr, _3545 ? _3545->size(0) : 0);
    _checked_ptr_1<int> _ptr__3546(_3546 ? _3546->raw() : nullptr, _3546 ? _3546->size(0) : 0);
    _checked_ptr_1<double> _ptr__3547(_3547 ? _3547->raw() : nullptr, _3547 ? _3547->size(0) : 0);
    mosek::fusion::p_ExprMulRight::_initialize(_3543,_3544,_3545,_3546,_3547,_3548,::mosek::fusion::p_ExprMulRight::validate(_3543,_3544,_3545,_3546,_3547,_3548));
  }
}void mosek::fusion::ExprMulRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3549,monty::rc_ptr< ::mosek::fusion::WorkStack > _3550,monty::rc_ptr< ::mosek::fusion::WorkStack > _3551) { mosek::fusion::p_ExprMulRight::_get_impl(this)->eval(_3549,_3550,_3551); }void mosek::fusion::p_ExprMulRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3549,monty::rc_ptr< ::mosek::fusion::WorkStack > _3550,monty::rc_ptr< ::mosek::fusion::WorkStack > _3551){
  mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr->eval(_3550,_3549,_3551);
  _3550->peek_expr();
  int _3552 = mosek::fusion::p_WorkStack::_get_impl(_3550)->nd;
  bool _3553 = mosek::fusion::p_WorkStack::_get_impl(_3550)->hassp;
  int _3554 = (int)((mval)->size(0));
  bool _3555 = (_3554 < safe_mul( mdim0,mdim1 ));
  int _3556 = ((*mosek::fusion::p_WorkStack::_get_impl(_3550)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3550)->shape_base));
  if (_3555)
  {
    {
      int _3557 = _3550->alloci32(safe_add( mdim1,(int)1 ));
      int _3558 = _3550->alloci32(_3554);
      int _3559 = _3550->alloci32(safe_add( _3556,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3560 = mosek::fusion::p_WorkStack::_get_impl(_3550)->i32;
      _checked_ptr_1<int> _ptr__3560(_3560 ? _3560->raw() : nullptr,_3560 ? _3560->size(0) : 0);
      int _8451 = (int)0;
      int _8452 = safe_add( mdim1,(int)1 );
      for (int _3561 = _8451; _3561 < _8452; ++_3561)
      {
        {
          _ptr__3560[safe_add( _3557,_3561 )] = (int)0;
        }
      }
      int _8453 = (int)0;
      int _8454 = _3554;
      for (int _3562 = _8453; _3562 < _8454; ++_3562)
      {
        {
          ++ _ptr__3560[safe_add( safe_add( _3557,((*msubj)(_3562)) ),(int)1 )];
        }
      }
      int _8455 = (int)0;
      int _8456 = mdim1;
      for (int _3563 = _8455; _3563 < _8456; ++_3563)
      {
        {
          _ptr__3560[safe_add( safe_add( _3557,_3563 ),(int)1 )] += _ptr__3560[safe_add( _3557,_3563 )];
        }
      }
      int _8457 = (int)0;
      int _8458 = _3554;
      for (int _3564 = _8457; _3564 < _8458; ++_3564)
      {
        {
          _ptr__3560[safe_add( _3558,_3564 )] = _ptr__3560[safe_add( _3557,((*msubj)(_3564)) )];
          ++ _ptr__3560[safe_add( _3557,((*msubj)(_3564)) )];
        }
      }
      int _8459 = (int)0;
      int _8460 = mdim1;
      for (int _3565 = _8459; _3565 < _8460; ++_3565)
      {
        {
          _ptr__3560[(safe_add( _3557,mdim1 ) - _3565)] = _ptr__3560[((safe_add( _3557,mdim1 ) - _3565) - (int)1)];
        }
      }
      _ptr__3560[_3557] = (int)0;
      int _8461 = (int)0;
      int _8462 = safe_add( _3556,(int)1 );
      for (int _3566 = _8461; _3566 < _8462; ++_3566)
      {
        {
          _ptr__3560[safe_add( _3559,_3566 )] = (int)0;
        }
      }
      _3550->popi32(safe_add( safe_add( safe_add( _3556,mdim1 ),(int)2 ),_3554 ));
      int _3567 = _3550->popi32();
      if ((_3567 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3568 = _3550->popi32();
      int _3569 = _3550->popi32();
      int _3570 = _3550->popi32();
      int _3571 = _3550->popi32();
      bool _3572 = (_3550->popi32() != (int)0);
      int _3573 = _3550->popi32(safe_add( _3570,(int)1 ));
      int _8463;
      bool _8464 = _3572;
      if (_8464)
      {
        _8463 = _3550->popi64(_3570);
      }
      else
      {
        _8463 = (int)999999;
      }
      int _3574 = _8463;
      int _3575 = _3550->popi64(_3571);
      int _3576 = _3550->popf64(_3570);
      int _3577 = _3550->popf64(_3571);
      std::shared_ptr< monty::ndarray< int,1 > > _3578 = mosek::fusion::p_WorkStack::_get_impl(_3550)->i32;
      _checked_ptr_1<int> _ptr__3578(_3578 ? _3578->raw() : nullptr,_3578 ? _3578->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3579 = mosek::fusion::p_WorkStack::_get_impl(_3550)->i64;
      _checked_ptr_1<long long> _ptr__3579(_3579 ? _3579->raw() : nullptr,_3579 ? _3579->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3580 = mosek::fusion::p_WorkStack::_get_impl(_3550)->f64;
      _checked_ptr_1<double> _ptr__3580(_3580 ? _3580->raw() : nullptr,_3580 ? _3580->size(0) : 0);
      if (_3572)
      {
        {
          int _8465 = (int)0;
          int _8466 = _3570;
          for (int _3581 = _8465; _3581 < _8466; ++_3581)
          {
            {
              ++ _ptr__3578[safe_add( safe_add( _3559,(_ptr__3579[safe_add( _3574,_3581 )] / _3568) ),(int)1 )];
            }
          }
          int _8467 = (int)0;
          int _8468 = _3569;
          for (int _3582 = _8467; _3582 < _8468; ++_3582)
          {
            {
              _ptr__3578[safe_add( safe_add( _3559,_3582 ),(int)1 )] += _ptr__3578[safe_add( _3559,_3582 )];
            }
          }
          int _3583 = (int)0;
          int _3584 = (int)0;
          int _8469 = (int)0;
          int _8470 = _3569;
          for (int _3585 = _8469; _3585 < _8470; ++_3585)
          {
            {
              int _8471 = (int)0;
              int _8472 = mdim1;
              for (int _3586 = _8471; _3586 < _8472; ++_3586)
              {
                {
                  bool _3587 = false;
                  int _3588 = _ptr__3578[safe_add( safe_add( _3559,_3585 ),(int)1 )];
                  int _3589 = _ptr__3578[safe_add( _3559,_3585 )];
                  int _3590 = _ptr__3578[safe_add( safe_add( _3557,_3586 ),(int)1 )];
                  int _3591 = _ptr__3578[safe_add( _3557,_3586 )];
                  while ( ((_3589 < _3588) && (_3591 < _3590)) )
                  {
                    {
                      int _3592 = _ptr__3578[safe_add( _3558,_3591 )];
                      if (((_ptr__3579[safe_add( _3574,_3589 )] % _3568) < ((*msubi)(_3592))))
                      {
                        {
                          ++ _3589;
                        }
                      }
                      else if(((_ptr__3579[safe_add( _3574,_3589 )] % _3568) > ((*msubi)(_3592))))
                      {
                        {
                          ++ _3591;
                        }
                      }
                      else
                      {
                        {
                          _3584 += (_ptr__3578[safe_add( safe_add( _3573,_3589 ),(int)1 )] - _ptr__3578[safe_add( _3573,_3589 )]);
                          ++ _3589;
                          ++ _3591;
                          _3587 = true;
                        }
                      }
                    }
                  }
                  if (_3587)
                  {
                    {
                      ++ _3583;
                    }
                  }
                  {}
                }
              }
            }
          }
          bool _3593 = (_3583 < safe_mul( _3569,mdim1 ));
          _3549->alloc_expr((int)2,_3583,_3584,_3593);
          int _3594 = mosek::fusion::p_WorkStack::_get_impl(_3549)->ptr_base;
          int _3595 = mosek::fusion::p_WorkStack::_get_impl(_3549)->nidxs_base;
          int _8473;
          bool _8474 = _3593;
          if (_8474)
          {
            _8473 = mosek::fusion::p_WorkStack::_get_impl(_3549)->sp_base;
          }
          else
          {
            _8473 = _3549->alloci64(_3583);
          }
          int _3596 = _8473;
          int _3597 = mosek::fusion::p_WorkStack::_get_impl(_3549)->cof_base;
          int _3598 = mosek::fusion::p_WorkStack::_get_impl(_3549)->bfix_base;
          int _3599 = mosek::fusion::p_WorkStack::_get_impl(_3549)->shape_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3600 = mosek::fusion::p_WorkStack::_get_impl(_3549)->i32;
          _checked_ptr_1<int> _ptr__3600(_3600 ? _3600->raw() : nullptr,_3600 ? _3600->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3601 = mosek::fusion::p_WorkStack::_get_impl(_3549)->i64;
          _checked_ptr_1<long long> _ptr__3601(_3601 ? _3601->raw() : nullptr,_3601 ? _3601->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3602 = mosek::fusion::p_WorkStack::_get_impl(_3549)->f64;
          _checked_ptr_1<double> _ptr__3602(_3602 ? _3602->raw() : nullptr,_3602 ? _3602->size(0) : 0);
          _ptr__3600[_3599] = _3569;
          _ptr__3600[safe_add( _3599,(int)1 )] = mdim1;
          int _3603 = (int)0;
          int _3604 = (int)0;
          _ptr__3600[_3594] = (int)0;
          int _8475 = (int)0;
          int _8476 = _3569;
          for (int _3605 = _8475; _3605 < _8476; ++_3605)
          {
            {
              int _8477 = (int)0;
              int _8478 = mdim1;
              for (int _3606 = _8477; _3606 < _8478; ++_3606)
              {
                {
                  bool _3607 = false;
                  double _3608 = 0.0;
                  int _3609 = _ptr__3578[safe_add( safe_add( _3559,_3605 ),(int)1 )];
                  int _3610 = _ptr__3578[safe_add( _3559,_3605 )];
                  int _3611 = _ptr__3578[safe_add( safe_add( _3557,_3606 ),(int)1 )];
                  int _3612 = _ptr__3578[safe_add( _3557,_3606 )];
                  while ( ((_3610 < _3609) && (_3612 < _3611)) )
                  {
                    {
                      int _3613 = _ptr__3578[safe_add( _3558,_3612 )];
                      if (((_ptr__3579[safe_add( _3574,_3610 )] % _3568) < ((*msubi)(_3613))))
                      {
                        {
                          ++ _3610;
                        }
                      }
                      else if(((_ptr__3579[safe_add( _3574,_3610 )] % _3568) > ((*msubi)(_3613))))
                      {
                        {
                          ++ _3612;
                        }
                      }
                      else
                      {
                        {
                          int _3614 = (_ptr__3578[safe_add( safe_add( _3573,_3610 ),(int)1 )] - _ptr__3578[safe_add( _3573,_3610 )]);
                          _3608 += (((*mval)(_3613)) * _ptr__3580[safe_add( _3576,_3610 )]);
                          int _8479 = (int)0;
                          int _8480 = _3614;
                          for (int _3615 = _8479; _3615 < _8480; ++_3615)
                          {
                            {
                              _ptr__3601[safe_add( safe_add( _3595,_3604 ),_3615 )] = _ptr__3579[safe_add( safe_add( _3575,_ptr__3578[safe_add( _3573,_3610 )] ),_3615 )];
                            }
                          }
                          int _8481 = (int)0;
                          int _8482 = _3614;
                          for (int _3616 = _8481; _3616 < _8482; ++_3616)
                          {
                            {
                              _ptr__3602[safe_add( safe_add( _3597,_3604 ),_3616 )] = (_ptr__3580[safe_add( safe_add( _3577,_ptr__3578[safe_add( _3573,_3610 )] ),_3616 )] * ((*mval)(_3613)));
                            }
                          }
                          _3604 += _3614;
                          ++ _3610;
                          ++ _3612;
                          _3607 = true;
                        }
                      }
                      if (_3607)
                      {
                        {
                          _ptr__3600[safe_add( safe_add( _3594,_3603 ),(int)1 )] = _3604;
                          _ptr__3602[safe_add( _3598,_3603 )] = _3608;
                          _ptr__3601[safe_add( _3596,_3603 )] = safe_add( safe_mul( _3605,mdim1 ),_3606 );
                          ++ _3603;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          if ((!_3593))
          {
            {
              _3549->popi64(_3583);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _3617 = safe_mul( _3569,mdim1 );
          int _3618 = (int)0;
          int _8483 = (int)0;
          int _8484 = _3569;
          for (int _3619 = _8483; _3619 < _8484; ++_3619)
          {
            {
              int _8485 = (int)0;
              int _8486 = mdim1;
              for (int _3620 = _8485; _3620 < _8486; ++_3620)
              {
                {
                  int _8487 = _ptr__3578[safe_add( _3557,_3620 )];
                  int _8488 = _ptr__3578[safe_add( safe_add( _3557,_3620 ),(int)1 )];
                  for (int _3621 = _8487; _3621 < _8488; ++_3621)
                  {
                    {
                      int _3622 = _ptr__3578[safe_add( _3558,_3621 )];
                      int _3623 = safe_add( safe_mul( _3619,_3568 ),((*msubi)(_3622)) );
                      _3618 += (_ptr__3578[safe_add( safe_add( _3573,_3623 ),(int)1 )] - _ptr__3578[safe_add( _3573,_3623 )]);
                    }
                  }
                }
              }
            }
          }
          bool _3624 = (_3617 < safe_mul( _3569,mdim1 ));
          int _3625 = _3549->alloci32(safe_add( _3617,(int)1 ));
          int _8489;
          bool _8490 = _3624;
          if (_8490)
          {
            _8489 = (int)1;
          }
          else
          {
            _8489 = (int)0;
          }
          _3549->pushi32(_8489);
          _3549->pushi32(_3618);
          _3549->pushi32(_3617);
          _3549->pushi32(_3569);
          _3549->pushi32(mdim1);
          _3549->pushi32((int)2);
          int _3626 = _3549->alloci64(_3618);
          int _3627 = _3549->alloci64(_3617);
          int _3628 = _3549->allocf64(_3618);
          int _3629 = _3549->allocf64(_3617);
          std::shared_ptr< monty::ndarray< int,1 > > _3630 = mosek::fusion::p_WorkStack::_get_impl(_3549)->i32;
          _checked_ptr_1<int> _ptr__3630(_3630 ? _3630->raw() : nullptr,_3630 ? _3630->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3631 = mosek::fusion::p_WorkStack::_get_impl(_3549)->i64;
          _checked_ptr_1<long long> _ptr__3631(_3631 ? _3631->raw() : nullptr,_3631 ? _3631->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3632 = mosek::fusion::p_WorkStack::_get_impl(_3549)->f64;
          _checked_ptr_1<double> _ptr__3632(_3632 ? _3632->raw() : nullptr,_3632 ? _3632->size(0) : 0);
          int _3633 = (int)0;
          int _3634 = (int)0;
          _ptr__3630[_3625] = (int)0;
          int _8491 = (int)0;
          int _8492 = _3569;
          for (int _3635 = _8491; _3635 < _8492; ++_3635)
          {
            {
              int _8493 = (int)0;
              int _8494 = mdim1;
              for (int _3636 = _8493; _3636 < _8494; ++_3636)
              {
                {
                  int _3637 = safe_mul( _3635,_3568 );
                  double _3638 = 0.0;
                  int _8495 = _ptr__3578[safe_add( _3557,_3636 )];
                  int _8496 = _ptr__3578[safe_add( safe_add( _3557,_3636 ),(int)1 )];
                  for (int _3639 = _8495; _3639 < _8496; ++_3639)
                  {
                    {
                      int _3640 = _ptr__3578[safe_add( _3558,_3639 )];
                      int _3641 = safe_add( _3637,((*msubi)(_3640)) );
                      int _3642 = _ptr__3578[safe_add( _3573,_3641 )];
                      int _3643 = (_ptr__3578[safe_add( safe_add( _3573,_3641 ),(int)1 )] - _ptr__3578[safe_add( _3573,_3641 )]);
                      int _8497 = (int)0;
                      int _8498 = _3643;
                      for (int _3644 = _8497; _3644 < _8498; ++_3644)
                      {
                        {
                          _ptr__3631[safe_add( safe_add( _3626,_3634 ),_3644 )] = _ptr__3579[safe_add( safe_add( _3575,_3642 ),_3644 )];
                        }
                      }
                      int _8499 = (int)0;
                      int _8500 = _3643;
                      for (int _3645 = _8499; _3645 < _8500; ++_3645)
                      {
                        {
                          _ptr__3632[safe_add( safe_add( _3628,_3634 ),_3645 )] = (_ptr__3580[safe_add( safe_add( _3577,_3642 ),_3645 )] * ((*mval)(_3640)));
                        }
                      }
                      _3638 += (_ptr__3580[safe_add( safe_add( _3576,_3637 ),((*msubi)(_3640)) )] * ((*mval)(_3640)));
                      _3634 += _3643;
                    }
                  }
                  _ptr__3630[safe_add( safe_add( _3625,_3633 ),(int)1 )] = _3634;
                  _ptr__3632[safe_add( _3629,_3633 )] = _3638;
                  _ptr__3631[safe_add( _3627,_3633 )] = safe_add( safe_mul( _3635,mdim1 ),_3636 );
                  ++ _3633;
                }
              }
            }
          }
          if ((!_3624))
          {
            {
              _3549->popi64(_3617);
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _3646 = _3551->alloci32(safe_add( _3556,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3647 = mosek::fusion::p_WorkStack::_get_impl(_3551)->i32;
      _checked_ptr_1<int> _ptr__3647(_3647 ? _3647->raw() : nullptr,_3647 ? _3647->size(0) : 0);
      int _8501 = (int)0;
      int _8502 = safe_add( _3556,(int)1 );
      for (int _3648 = _8501; _3648 < _8502; ++_3648)
      {
        {
          _ptr__3647[safe_add( _3646,_3648 )] = (int)0;
        }
      }
      _3550->pop_expr();
      std::shared_ptr< monty::ndarray< int,1 > > _3649 = mosek::fusion::p_WorkStack::_get_impl(_3550)->i32;
      _checked_ptr_1<int> _ptr__3649(_3649 ? _3649->raw() : nullptr,_3649 ? _3649->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3650 = mosek::fusion::p_WorkStack::_get_impl(_3550)->i64;
      _checked_ptr_1<long long> _ptr__3650(_3650 ? _3650->raw() : nullptr,_3650 ? _3650->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3651 = mosek::fusion::p_WorkStack::_get_impl(_3550)->f64;
      _checked_ptr_1<double> _ptr__3651(_3651 ? _3651->raw() : nullptr,_3651 ? _3651->size(0) : 0);
      int _3652 = mosek::fusion::p_WorkStack::_get_impl(_3550)->nd;
      int _3653 = mosek::fusion::p_WorkStack::_get_impl(_3550)->nelem;
      int _3654 = mosek::fusion::p_WorkStack::_get_impl(_3550)->nnz;
      bool _3655 = mosek::fusion::p_WorkStack::_get_impl(_3550)->hassp;
      int _3656 = _3654;
      int _3657 = _3653;
      int _3658 = mosek::fusion::p_WorkStack::_get_impl(_3550)->shape_base;
      int _3659 = mosek::fusion::p_WorkStack::_get_impl(_3550)->ptr_base;
      int _3660 = mosek::fusion::p_WorkStack::_get_impl(_3550)->sp_base;
      int _3661 = mosek::fusion::p_WorkStack::_get_impl(_3550)->nidxs_base;
      int _3662 = mosek::fusion::p_WorkStack::_get_impl(_3550)->bfix_base;
      int _3663 = mosek::fusion::p_WorkStack::_get_impl(_3550)->cof_base;
      int _3664 = _ptr__3649[_3658];
      int _3665 = _ptr__3649[safe_add( _3658,(int)1 )];
      if ((_3652 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,1 > > _3666 = mosek::fusion::p_WorkStack::_get_impl(_3550)->i32;
      _checked_ptr_1<int> _ptr__3666(_3666 ? _3666->raw() : nullptr,_3666 ? _3666->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3667 = mosek::fusion::p_WorkStack::_get_impl(_3550)->i64;
      _checked_ptr_1<long long> _ptr__3667(_3667 ? _3667->raw() : nullptr,_3667 ? _3667->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3668 = mosek::fusion::p_WorkStack::_get_impl(_3550)->f64;
      _checked_ptr_1<double> _ptr__3668(_3668 ? _3668->raw() : nullptr,_3668 ? _3668->size(0) : 0);
      int _3669 = safe_mul( _3664,mdim1 );
      int _3670 = safe_mul( _3654,mdim1 );
      bool _3671 = false;
      int _3672 = (int)2;
      _3549->alloc_expr(_3672,_3669,_3670,_3671);
      std::shared_ptr< monty::ndarray< int,1 > > _3673 = mosek::fusion::p_WorkStack::_get_impl(_3549)->i32;
      _checked_ptr_1<int> _ptr__3673(_3673 ? _3673->raw() : nullptr,_3673 ? _3673->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3674 = mosek::fusion::p_WorkStack::_get_impl(_3549)->i64;
      _checked_ptr_1<long long> _ptr__3674(_3674 ? _3674->raw() : nullptr,_3674 ? _3674->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3675 = mosek::fusion::p_WorkStack::_get_impl(_3549)->f64;
      _checked_ptr_1<double> _ptr__3675(_3675 ? _3675->raw() : nullptr,_3675 ? _3675->size(0) : 0);
      int _3676 = mosek::fusion::p_WorkStack::_get_impl(_3549)->shape_base;
      int _3677 = mosek::fusion::p_WorkStack::_get_impl(_3549)->ptr_base;
      int _3678 = mosek::fusion::p_WorkStack::_get_impl(_3549)->nidxs_base;
      int _3679 = mosek::fusion::p_WorkStack::_get_impl(_3549)->sp_base;
      int _3680 = mosek::fusion::p_WorkStack::_get_impl(_3549)->cof_base;
      int _3681 = mosek::fusion::p_WorkStack::_get_impl(_3549)->bfix_base;
      _ptr__3673[_3676] = _3664;
      _ptr__3673[safe_add( _3676,(int)1 )] = mdim1;
      int _3682 = (int)0;
      int _3683 = (int)0;
      _ptr__3673[_3677] = (int)0;
      if (_3655)
      {
        {
          int _8503 = (int)0;
          int _8504 = _3653;
          for (int _3684 = _8503; _3684 < _8504; ++_3684)
          {
            {
              ++ _ptr__3647[safe_add( safe_add( _3646,(_ptr__3667[safe_add( _3660,_3684 )] / _3665) ),(int)1 )];
            }
          }
          int _8505 = (int)0;
          int _8506 = _3664;
          for (int _3685 = _8505; _3685 < _8506; ++_3685)
          {
            {
              _ptr__3647[safe_add( safe_add( _3646,_3685 ),(int)1 )] += _ptr__3647[safe_add( _3646,_3685 )];
            }
          }
          int _8507 = (int)0;
          int _8508 = _3664;
          for (int _3686 = _8507; _3686 < _8508; ++_3686)
          {
            {
              int _8509 = (int)0;
              int _8510 = mdim1;
              for (int _3687 = _8509; _3687 < _8510; ++_3687)
              {
                {
                  double _3688 = 0.0;
                  int _3689 = (int)0;
                  int _8511 = _ptr__3647[safe_add( _3646,_3686 )];
                  int _8512 = _ptr__3647[safe_add( safe_add( _3646,_3686 ),(int)1 )];
                  for (int _3690 = _8511; _3690 < _8512; ++_3690)
                  {
                    {
                      long long _3691 = safe_add( _3687,safe_mul( (_ptr__3667[safe_add( _3660,_3690 )] % _3665),mdim1 ) );
                      _3688 += (_ptr__3668[safe_add( _3662,_3690 )] * ((*mval)(_3691)));
                      int _8513 = _ptr__3666[safe_add( _3659,_3690 )];
                      int _8514 = _ptr__3666[safe_add( safe_add( _3659,_3690 ),(int)1 )];
                      for (int _3692 = _8513; _3692 < _8514; ++_3692)
                      {
                        {
                          _ptr__3674[safe_add( safe_add( _3678,_3682 ),_3689 )] = _ptr__3667[safe_add( _3661,_3692 )];
                          _ptr__3675[safe_add( safe_add( _3680,_3682 ),_3689 )] = (_ptr__3668[safe_add( _3663,_3692 )] * ((*mval)(_3691)));
                          ++ _3689;
                        }
                      }
                    }
                  }
                  _3682 += _3689;
                  _ptr__3673[safe_add( safe_add( _3677,_3683 ),(int)1 )] = _3682;
                  _ptr__3675[safe_add( _3681,_3683 )] = _3688;
                  ++ _3683;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _8515 = (int)0;
          int _8516 = _3664;
          for (int _3693 = _8515; _3693 < _8516; ++_3693)
          {
            {
              int _8517 = (int)0;
              int _8518 = mdim1;
              for (int _3694 = _8517; _3694 < _8518; ++_3694)
              {
                {
                  double _3695 = 0.0;
                  int _3696 = (int)0;
                  int _8519 = (int)0;
                  int _8520 = _3665;
                  for (int _3697 = _8519; _3697 < _8520; ++_3697)
                  {
                    {
                      int _3698 = safe_add( safe_mul( _3693,_3665 ),_3697 );
                      int _3699 = safe_add( _3694,safe_mul( _3697,mdim1 ) );
                      _3695 += (_ptr__3668[safe_add( _3662,_3698 )] * ((*mval)(_3699)));
                      int _8521 = _ptr__3666[safe_add( _3659,_3698 )];
                      int _8522 = _ptr__3666[safe_add( safe_add( _3659,_3698 ),(int)1 )];
                      for (int _3700 = _8521; _3700 < _8522; ++_3700)
                      {
                        {
                          _ptr__3674[safe_add( safe_add( _3678,_3682 ),_3696 )] = _ptr__3667[safe_add( _3661,_3700 )];
                          _ptr__3675[safe_add( safe_add( _3680,_3682 ),_3696 )] = (_ptr__3668[safe_add( _3663,_3700 )] * ((*mval)(_3699)));
                          ++ _3696;
                        }
                      }
                    }
                  }
                  _3682 += _3696;
                  _ptr__3673[safe_add( safe_add( _3677,_3683 ),(int)1 )] = _3682;
                  _ptr__3675[safe_add( _3681,_3683 )] = _3695;
                  ++ _3683;
                }
              }
            }
          }
        }
      }
      _3551->clear();
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulRight::computeshape(int _3701,std::shared_ptr< monty::ndarray< int,1 > > _3702){
  _checked_ptr_1<int> _ptr__3702(_3702 ? _3702->raw() : nullptr, _3702 ? _3702->size(0) : 0);
  if (((int)((_3702)->size(0)) == (int)1))
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_3701)});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__3702[(int)0]),(int)(_3701)});
    }
  }
}
int mosek::fusion::p_ExprMulRight::validate(int _3703,int _3704,std::shared_ptr< monty::ndarray< int,1 > > _3705,std::shared_ptr< monty::ndarray< int,1 > > _3706,std::shared_ptr< monty::ndarray< double,1 > > _3707,monty::rc_ptr< ::mosek::fusion::Expression > _3708){
  _checked_ptr_1<int> _ptr__3705(_3705 ? _3705->raw() : nullptr, _3705 ? _3705->size(0) : 0);
  _checked_ptr_1<int> _ptr__3706(_3706 ? _3706->raw() : nullptr, _3706 ? _3706->size(0) : 0);
  _checked_ptr_1<double> _ptr__3707(_3707 ? _3707->raw() : nullptr, _3707 ? _3707->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3709 = _3708->getShape();
  _checked_ptr_1<int> _ptr__3709(_3709 ? _3709->raw() : nullptr,_3709 ? _3709->size(0) : 0);
  if (((int)((_3709)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3710 = _ptr__3709[(int)0];
  int _3711 = _ptr__3709[(int)1];
  if (((_3703 < (int)0) || ((_3704 < (int)0) || ((_3710 < (int)0) || (_3711 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3703 != _3711))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3705)->size(0)) != (int)((_3706)->size(0))) || ((int)((_3705)->size(0)) != (int)((_3707)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3712 = (int)((_3705)->size(0));
  {
    bool _3713 = false;
    int _8523 = (int)0;
    int _8524 = _3712;
    for (int _3714 = _8523; _3714 < _8524; ++_3714)
    {
      {
        _3713 = (_3713 || ((_ptr__3705[_3714] < (int)0) || ((_ptr__3705[_3714] >= _3703) || ((_ptr__3706[_3714] < (int)0) || (_ptr__3706[_3714] >= _3704)))));
      }
    }
    if (_3713)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
      }
    }
    {}
  }
  {
    bool _3715 = false;
    int _8525 = (int)0;
    int _8526 = (_3712 - (int)1);
    for (int _3716 = _8525; _3716 < _8526; ++_3716)
    {
      {
        _3715 = (_3715 || ((_ptr__3705[_3716] > _ptr__3705[safe_add( _3716,(int)1 )]) || ((_ptr__3705[_3716] == _ptr__3705[safe_add( _3716,(int)1 )]) && (_ptr__3706[_3716] >= _ptr__3706[safe_add( _3716,(int)1 )]))));
      }
    }
    if (_3715)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
      }
    }
    {}
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulRight :: toString() { return mosek::fusion::p_ExprMulRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulRight(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulRight::destroy() { mosek::fusion::p_ExprMulRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulLeft::ExprMulLeft(mosek::fusion::p_ExprMulLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulLeft()" << this << std::endl; */ }mosek::fusion::ExprMulLeft::~ExprMulLeft() {  /* std::cout << "~ExprMulLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulLeft::p_ExprMulLeft  (::mosek::fusion::ExprMulLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3717,    int _3718,    std::shared_ptr< monty::ndarray< int,1 > > _3719,    std::shared_ptr< monty::ndarray< int,1 > > _3720,    std::shared_ptr< monty::ndarray< double,1 > > _3721,    monty::rc_ptr< ::mosek::fusion::Expression > _3722,    int _3723){ return new mosek::fusion::ExprMulLeft(_3717,_3718,_3719,_3720,_3721,_3722,_3723); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3717,    int _3718,    std::shared_ptr< monty::ndarray< int,1 > > _3719,    std::shared_ptr< monty::ndarray< int,1 > > _3720,    std::shared_ptr< monty::ndarray< double,1 > > _3721,    monty::rc_ptr< ::mosek::fusion::Expression > _3722,    int _3723) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3717,_3718,_3719,_3720,_3721,_3722,_3723); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3717,    int _3718,    std::shared_ptr< monty::ndarray< int,1 > > _3719,    std::shared_ptr< monty::ndarray< int,1 > > _3720,    std::shared_ptr< monty::ndarray< double,1 > > _3721,    monty::rc_ptr< ::mosek::fusion::Expression > _3722,    int _3723){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3719(_3719 ? _3719->raw() : nullptr, _3719 ? _3719->size(0) : 0);
    _checked_ptr_1<int> _ptr__3720(_3720 ? _3720->raw() : nullptr, _3720 ? _3720->size(0) : 0);
    _checked_ptr_1<double> _ptr__3721(_3721 ? _3721->raw() : nullptr, _3721 ? _3721->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulLeft::computeshape(_3717,_3718,_3722->getShape()));
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim0 = _3717;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim1 = _3718;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubi = _3719;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubj = _3720;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mval = _3721;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr = _3722;
  }
}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3724,    int _3725,    std::shared_ptr< monty::ndarray< int,1 > > _3726,    std::shared_ptr< monty::ndarray< int,1 > > _3727,    std::shared_ptr< monty::ndarray< double,1 > > _3728,    monty::rc_ptr< ::mosek::fusion::Expression > _3729){ return new mosek::fusion::ExprMulLeft(_3724,_3725,_3726,_3727,_3728,_3729); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3724,    int _3725,    std::shared_ptr< monty::ndarray< int,1 > > _3726,    std::shared_ptr< monty::ndarray< int,1 > > _3727,    std::shared_ptr< monty::ndarray< double,1 > > _3728,    monty::rc_ptr< ::mosek::fusion::Expression > _3729) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3724,_3725,_3726,_3727,_3728,_3729); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3724,    int _3725,    std::shared_ptr< monty::ndarray< int,1 > > _3726,    std::shared_ptr< monty::ndarray< int,1 > > _3727,    std::shared_ptr< monty::ndarray< double,1 > > _3728,    monty::rc_ptr< ::mosek::fusion::Expression > _3729){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3726(_3726 ? _3726->raw() : nullptr, _3726 ? _3726->size(0) : 0);
    _checked_ptr_1<int> _ptr__3727(_3727 ? _3727->raw() : nullptr, _3727 ? _3727->size(0) : 0);
    _checked_ptr_1<double> _ptr__3728(_3728 ? _3728->raw() : nullptr, _3728 ? _3728->size(0) : 0);
    mosek::fusion::p_ExprMulLeft::_initialize(_3724,_3725,_3726,_3727,_3728,_3729,::mosek::fusion::p_ExprMulLeft::validate(_3724,_3725,_3726,_3727,_3728,_3729));
  }
}void mosek::fusion::ExprMulLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3730,monty::rc_ptr< ::mosek::fusion::WorkStack > _3731,monty::rc_ptr< ::mosek::fusion::WorkStack > _3732) { mosek::fusion::p_ExprMulLeft::_get_impl(this)->eval(_3730,_3731,_3732); }void mosek::fusion::p_ExprMulLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3730,monty::rc_ptr< ::mosek::fusion::WorkStack > _3731,monty::rc_ptr< ::mosek::fusion::WorkStack > _3732){
  mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr->eval(_3731,_3730,_3732);
  _3731->pop_expr();
  int _3733 = mosek::fusion::p_WorkStack::_get_impl(_3731)->nd;
  int _3734 = mosek::fusion::p_WorkStack::_get_impl(_3731)->nnz;
  int _3735 = mosek::fusion::p_WorkStack::_get_impl(_3731)->nelem;
  bool _3736 = mosek::fusion::p_WorkStack::_get_impl(_3731)->hassp;
  int _3737 = mosek::fusion::p_WorkStack::_get_impl(_3731)->shape_base;
  int _3738 = mosek::fusion::p_WorkStack::_get_impl(_3731)->ptr_base;
  int _3739 = mosek::fusion::p_WorkStack::_get_impl(_3731)->sp_base;
  int _3740 = mosek::fusion::p_WorkStack::_get_impl(_3731)->nidxs_base;
  int _3741 = mosek::fusion::p_WorkStack::_get_impl(_3731)->bfix_base;
  int _3742 = mosek::fusion::p_WorkStack::_get_impl(_3731)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3743 = mosek::fusion::p_WorkStack::_get_impl(_3731)->i32;
  _checked_ptr_1<int> _ptr__3743(_3743 ? _3743->raw() : nullptr,_3743 ? _3743->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3744 = mosek::fusion::p_WorkStack::_get_impl(_3731)->i64;
  _checked_ptr_1<long long> _ptr__3744(_3744 ? _3744->raw() : nullptr,_3744 ? _3744->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3745 = mosek::fusion::p_WorkStack::_get_impl(_3731)->f64;
  _checked_ptr_1<double> _ptr__3745(_3745 ? _3745->raw() : nullptr,_3745 ? _3745->size(0) : 0);
  if ((_3733 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3746 = (int)9999;
  int _3747 = (int)9999;
  int _3748 = (int)9999;
  int _3749 = _ptr__3743[_3737];
  int _3750 = _ptr__3743[safe_add( _3737,(int)1 )];
  int _3751 = (int)((msubi)->size(0));
  bool _3752 = (_3751 < safe_mul( mdim0,mdim1 ));
  bool _3753 = false;
  int _3754 = (int)0;
  int _3755 = (int)0;
  if (_3736)
  {
    {
      _3746 = _3732->alloci32(_3735);
      _3747 = _3732->alloci32(_3735);
      _3748 = _3732->alloci32(safe_add( _3750,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3756 = mosek::fusion::p_WorkStack::_get_impl(_3732)->i32;
      _checked_ptr_1<int> _ptr__3756(_3756 ? _3756->raw() : nullptr,_3756 ? _3756->size(0) : 0);
      int _8527 = (int)0;
      int _8528 = safe_add( _3750,(int)1 );
      for (int _3757 = _8527; _3757 < _8528; ++_3757)
      {
        {
          _ptr__3756[safe_add( _3748,_3757 )] = (int)0;
        }
      }
      int _8529 = (int)0;
      int _8530 = _3735;
      for (int _3758 = _8529; _3758 < _8530; ++_3758)
      {
        {
          ++ _ptr__3756[safe_add( safe_add( _3748,(_ptr__3744[safe_add( _3739,_3758 )] % _3750) ),(int)1 )];
        }
      }
      int _8531 = (int)0;
      int _8532 = _3750;
      for (int _3759 = _8531; _3759 < _8532; ++_3759)
      {
        {
          _ptr__3756[safe_add( safe_add( _3748,_3759 ),(int)1 )] += _ptr__3756[safe_add( _3748,_3759 )];
        }
      }
      int _8533 = (int)0;
      int _8534 = _3735;
      for (int _3760 = _8533; _3760 < _8534; ++_3760)
      {
        {
          long long _3761 = (_ptr__3744[safe_add( _3739,_3760 )] % _3750);
          _ptr__3756[safe_add( _3746,_ptr__3756[safe_add( _3748,_3761 )] )] = _3760;
          ++ _ptr__3756[safe_add( _3748,_3761 )];
        }
      }
      int _8535 = (int)0;
      int _8536 = _3750;
      for (int _3762 = _8535; _3762 < _8536; ++_3762)
      {
        {
          _ptr__3756[(safe_add( _3748,_3750 ) - _3762)] = _ptr__3756[((safe_add( _3748,_3750 ) - _3762) - (int)1)];
        }
      }
      _ptr__3756[_3748] = (int)0;
      if (_3752)
      {
        {
          int _3763 = (int)0;
          while ( (_3763 < _3751) )
          {
            {
              int _3764 = ((*msubi)(_3763));
              int _3765 = safe_add( _3763,(int)1 );
              while ( ((_3765 < _3751) && (((*msubi)(_3765)) == ((*msubi)(_3763)))) )
              {
                {
                  ++ _3765;
                }
              }
              int _8537 = (int)0;
              int _8538 = _3750;
              for (int _3766 = _8537; _3766 < _8538; ++_3766)
              {
                {
                  bool _3767 = false;
                  int _3768 = _3765;
                  int _3769 = _3763;
                  int _3770 = _ptr__3756[safe_add( safe_add( _3748,_3766 ),(int)1 )];
                  int _3771 = _ptr__3756[safe_add( _3748,_3766 )];
                  while ( ((_3769 < _3768) && (_3771 < _3770)) )
                  {
                    {
                      int _3772 = _ptr__3756[safe_add( _3746,_3771 )];
                      if ((((*msubj)(_3769)) < (_ptr__3744[safe_add( _3739,_3772 )] / _3750)))
                      {
                        {
                          ++ _3769;
                        }
                      }
                      else if((((*msubj)(_3769)) > (_ptr__3744[safe_add( _3739,_3772 )] / _3750)))
                      {
                        {
                          ++ _3771;
                        }
                      }
                      else
                      {
                        {
                          _3767 = true;
                          _3755 += (_ptr__3743[safe_add( safe_add( _3738,_3772 ),(int)1 )] - _ptr__3743[safe_add( _3738,_3772 )]);
                          ++ _3771;
                          ++ _3769;
                        }
                      }
                    }
                  }
                  if (_3767)
                  {
                    {
                      ++ _3754;
                    }
                  }
                  {}
                }
              }
              _3763 = _3765;
            }
          }
        }
      }
      else
      {
        {
          _3754 = safe_mul( mdim0,_3750 );
          _3755 = safe_mul( _3734,mdim0 );
        }
      }
    }
  }
  else
  {
    {
      if (_3752)
      {
        {
          int _3773 = (int)0;
          while ( (_3773 < _3751) )
          {
            {
              int _3774 = safe_add( _3773,(int)1 );
              while ( ((_3774 < _3751) && (((*msubi)(_3773)) == ((*msubi)(_3774)))) )
              {
                {
                  ++ _3774;
                }
              }
              int _3775 = ((*msubi)(_3773));
              int _8539 = (int)0;
              int _8540 = _3750;
              for (int _3776 = _8539; _3776 < _8540; ++_3776)
              {
                {
                  bool _3777 = false;
                  int _8541 = _3773;
                  int _8542 = _3774;
                  for (int _3778 = _8541; _3778 < _8542; ++_3778)
                  {
                    {
                      int _3779 = safe_add( safe_mul( ((*msubj)(_3778)),_3750 ),_3776 );
                      _3755 += (_ptr__3743[safe_add( safe_add( _3738,_3779 ),(int)1 )] - _ptr__3743[safe_add( _3738,_3779 )]);
                      _3777 = true;
                    }
                  }
                  if (_3777)
                  {
                    {
                      ++ _3754;
                    }
                  }
                  {}
                }
              }
              _3773 = _3774;
            }
          }
        }
      }
      else
      {
        {
          _3755 = safe_mul( _3734,mdim0 );
          _3754 = safe_mul( mdim0,_3750 );
        }
      }
    }
  }
  _3753 = (_3754 < safe_mul( mdim0,_3750 ));
  int _3780 = (int)2;
  _3730->alloc_expr(_3780,_3754,_3755,_3753);
  int _3781 = mosek::fusion::p_WorkStack::_get_impl(_3730)->ptr_base;
  int _3782 = mosek::fusion::p_WorkStack::_get_impl(_3730)->nidxs_base;
  int _8543;
  bool _8544 = _3753;
  if (_8544)
  {
    _8543 = mosek::fusion::p_WorkStack::_get_impl(_3730)->sp_base;
  }
  else
  {
    _8543 = _3730->alloci64(_3754);
  }
  int _3783 = _8543;
  int _3784 = mosek::fusion::p_WorkStack::_get_impl(_3730)->cof_base;
  int _3785 = mosek::fusion::p_WorkStack::_get_impl(_3730)->bfix_base;
  int _3786 = mosek::fusion::p_WorkStack::_get_impl(_3730)->shape_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3787 = mosek::fusion::p_WorkStack::_get_impl(_3730)->i64;
  _checked_ptr_1<long long> _ptr__3787(_3787 ? _3787->raw() : nullptr,_3787 ? _3787->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3788 = mosek::fusion::p_WorkStack::_get_impl(_3730)->f64;
  _checked_ptr_1<double> _ptr__3788(_3788 ? _3788->raw() : nullptr,_3788 ? _3788->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3789 = mosek::fusion::p_WorkStack::_get_impl(_3730)->i32;
  _checked_ptr_1<int> _ptr__3789(_3789 ? _3789->raw() : nullptr,_3789 ? _3789->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3790 = mosek::fusion::p_WorkStack::_get_impl(_3732)->i32;
  _checked_ptr_1<int> _ptr__3790(_3790 ? _3790->raw() : nullptr,_3790 ? _3790->size(0) : 0);
  _ptr__3789[_3786] = mdim0;
  _ptr__3789[safe_add( _3786,(int)1 )] = _3750;
  if (_3736)
  {
    {
      _ptr__3789[_3781] = (int)0;
      if (_3752)
      {
        {
          int _3791 = (int)0;
          int _3792 = (int)0;
          int _3793 = (int)0;
          while ( (_3793 < _3751) )
          {
            {
              int _3794 = ((*msubi)(_3793));
              int _3795 = safe_add( _3793,(int)1 );
              while ( ((_3795 < _3751) && (((*msubi)(_3795)) == ((*msubi)(_3793)))) )
              {
                {
                  ++ _3795;
                }
              }
              int _8545 = (int)0;
              int _8546 = _3750;
              for (int _3796 = _8545; _3796 < _8546; ++_3796)
              {
                {
                  bool _3797 = false;
                  double _3798 = 0.0;
                  int _3799 = _3795;
                  int _3800 = _3793;
                  int _3801 = _ptr__3790[safe_add( safe_add( _3748,_3796 ),(int)1 )];
                  int _3802 = _ptr__3790[safe_add( _3748,_3796 )];
                  while ( ((_3800 < _3799) && (_3802 < _3801)) )
                  {
                    {
                      int _3803 = _ptr__3790[safe_add( _3746,_3802 )];
                      if ((((*msubj)(_3800)) < (_ptr__3744[safe_add( _3739,_3803 )] / _3750)))
                      {
                        {
                          ++ _3800;
                        }
                      }
                      else if((((*msubj)(_3800)) > (_ptr__3744[safe_add( _3739,_3803 )] / _3750)))
                      {
                        {
                          ++ _3802;
                        }
                      }
                      else
                      {
                        {
                          _3797 = true;
                          _3798 += (_ptr__3745[safe_add( _3741,_3803 )] * ((*mval)(_3800)));
                          int _3804 = (_ptr__3743[safe_add( safe_add( _3738,_3803 ),(int)1 )] - _ptr__3743[safe_add( _3738,_3803 )]);
                          int _8547 = (int)0;
                          int _8548 = _3804;
                          for (int _3805 = _8547; _3805 < _8548; ++_3805)
                          {
                            {
                              _ptr__3787[safe_add( safe_add( _3782,_3792 ),_3805 )] = _ptr__3744[safe_add( safe_add( _3740,_ptr__3743[safe_add( _3738,_3803 )] ),_3805 )];
                            }
                          }
                          int _8549 = (int)0;
                          int _8550 = _3804;
                          for (int _3806 = _8549; _3806 < _8550; ++_3806)
                          {
                            {
                              _ptr__3788[safe_add( safe_add( _3784,_3792 ),_3806 )] = (_ptr__3745[safe_add( safe_add( _3742,_ptr__3743[safe_add( _3738,_3803 )] ),_3806 )] * ((*mval)(_3800)));
                            }
                          }
                          ++ _3800;
                          ++ _3802;
                          _3792 += _3804;
                        }
                      }
                    }
                  }
                  if (_3797)
                  {
                    {
                      _ptr__3789[safe_add( safe_add( _3781,_3791 ),(int)1 )] = _3792;
                      _ptr__3787[safe_add( _3783,_3791 )] = safe_add( safe_mul( _3794,_3750 ),_3796 );
                      _ptr__3788[safe_add( _3785,_3791 )] = _3798;
                      ++ _3791;
                    }
                  }
                  {}
                }
              }
              _3793 = _3795;
            }
          }
        }
      }
      else
      {
        {
          int _3807 = (int)0;
          int _3808 = (int)0;
          int _8551 = (int)0;
          int _8552 = mdim0;
          for (int _3809 = _8551; _3809 < _8552; ++_3809)
          {
            {
              int _8553 = (int)0;
              int _8554 = _3750;
              for (int _3810 = _8553; _3810 < _8554; ++_3810)
              {
                {
                  double _3811 = 0.0;
                  int _8555 = _ptr__3790[safe_add( _3748,_3810 )];
                  int _8556 = _ptr__3790[safe_add( safe_add( _3748,_3810 ),(int)1 )];
                  for (int _3812 = _8555; _3812 < _8556; ++_3812)
                  {
                    {
                      int _3813 = _ptr__3790[safe_add( _3746,_3812 )];
                      long long _3814 = safe_add( safe_mul( _3809,mdim1 ),(_ptr__3744[safe_add( _3739,_3813 )] / _3750) );
                      _3811 += (_ptr__3745[safe_add( _3741,_3813 )] * ((*mval)(_3814)));
                      int _3815 = (_ptr__3743[safe_add( safe_add( _3738,_3813 ),(int)1 )] - _ptr__3743[safe_add( _3738,_3813 )]);
                      int _8557 = (int)0;
                      int _8558 = _3815;
                      for (int _3816 = _8557; _3816 < _8558; ++_3816)
                      {
                        {
                          _ptr__3787[safe_add( safe_add( _3782,_3808 ),_3816 )] = _ptr__3744[safe_add( safe_add( _3740,_ptr__3743[safe_add( _3738,_3813 )] ),_3816 )];
                          _ptr__3788[safe_add( safe_add( _3784,_3808 ),_3816 )] = (_ptr__3745[safe_add( safe_add( _3742,_ptr__3743[safe_add( _3738,_3813 )] ),_3816 )] * ((*mval)(_3814)));
                        }
                      }
                      _3808 += _3815;
                    }
                  }
                  _ptr__3789[safe_add( safe_add( _3781,_3807 ),(int)1 )] = _3808;
                  _ptr__3788[safe_add( _3785,_3807 )] = _3811;
                  ++ _3807;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _ptr__3789[_3781] = (int)0;
      int _3817 = (int)0;
      int _3818 = (int)0;
      int _3819 = (int)0;
      while ( (_3817 < _3751) )
      {
        {
          int _3820 = safe_add( _3817,(int)1 );
          while ( ((_3820 < _3751) && (((*msubi)(_3817)) == ((*msubi)(_3820)))) )
          {
            {
              ++ _3820;
            }
          }
          int _3821 = ((*msubi)(_3817));
          int _8559 = (int)0;
          int _8560 = _3750;
          for (int _3822 = _8559; _3822 < _8560; ++_3822)
          {
            {
              double _3823 = 0.0;
              bool _3824 = false;
              int _8561 = _3817;
              int _8562 = _3820;
              for (int _3825 = _8561; _3825 < _8562; ++_3825)
              {
                {
                  int _3826 = safe_add( safe_mul( ((*msubj)(_3825)),_3750 ),_3822 );
                  int _3827 = (_ptr__3743[safe_add( safe_add( _3738,_3826 ),(int)1 )] - _ptr__3743[safe_add( _3738,_3826 )]);
                  int _8563 = (int)0;
                  int _8564 = _3827;
                  for (int _3828 = _8563; _3828 < _8564; ++_3828)
                  {
                    {
                      _ptr__3787[safe_add( safe_add( _3782,_3819 ),_3828 )] = _ptr__3744[safe_add( safe_add( _3740,_ptr__3743[safe_add( _3738,_3826 )] ),_3828 )];
                    }
                  }
                  int _8565 = (int)0;
                  int _8566 = _3827;
                  for (int _3829 = _8565; _3829 < _8566; ++_3829)
                  {
                    {
                      _ptr__3788[safe_add( safe_add( _3784,_3819 ),_3829 )] = (_ptr__3745[safe_add( safe_add( _3742,_ptr__3743[safe_add( _3738,_3826 )] ),_3829 )] * ((*mval)(_3825)));
                    }
                  }
                  _3823 += (_ptr__3745[safe_add( _3741,_3826 )] * ((*mval)(_3825)));
                  _3824 = true;
                  _3819 += _3827;
                }
              }
              if (_3824)
              {
                {
                  _ptr__3787[safe_add( _3783,_3818 )] = safe_add( safe_mul( _3821,_3750 ),_3822 );
                  _ptr__3788[safe_add( _3785,_3818 )] = _3823;
                  _ptr__3789[safe_add( safe_add( _3781,_3818 ),(int)1 )] = _3819;
                  ++ _3818;
                }
              }
              {}
            }
          }
          _3817 = _3820;
        }
      }
    }
  }
  _3730->peek_expr();
  if ((!_3753))
  {
    {
      _3730->popi64(_3754);
    }
  }
  {}
  _3732->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulLeft::computeshape(int _3830,int _3831,std::shared_ptr< monty::ndarray< int,1 > > _3832){
  _checked_ptr_1<int> _ptr__3832(_3832 ? _3832->raw() : nullptr, _3832 ? _3832->size(0) : 0);
  if (((int)((_3832)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  else if((_3831 != _ptr__3832[(int)0]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3830),(int)(_ptr__3832[(int)1])});
}
int mosek::fusion::p_ExprMulLeft::validate(int _3833,int _3834,std::shared_ptr< monty::ndarray< int,1 > > _3835,std::shared_ptr< monty::ndarray< int,1 > > _3836,std::shared_ptr< monty::ndarray< double,1 > > _3837,monty::rc_ptr< ::mosek::fusion::Expression > _3838){
  _checked_ptr_1<int> _ptr__3835(_3835 ? _3835->raw() : nullptr, _3835 ? _3835->size(0) : 0);
  _checked_ptr_1<int> _ptr__3836(_3836 ? _3836->raw() : nullptr, _3836 ? _3836->size(0) : 0);
  _checked_ptr_1<double> _ptr__3837(_3837 ? _3837->raw() : nullptr, _3837 ? _3837->size(0) : 0);
  if ((_3838->getND() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3839 = _3838->getDim((int)0);
  int _3840 = _3838->getDim((int)0);
  if (((_3833 < (int)0) || (_3834 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3834 != _3839))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3835)->size(0)) != (int)((_3836)->size(0))) || ((int)((_3835)->size(0)) != (int)((_3837)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3841 = (int)((_3835)->size(0));
  int _8567 = (int)0;
  int _8568 = _3841;
  for (int _3842 = _8567; _3842 < _8568; ++_3842)
  {
    {
      if (((_ptr__3835[_3842] < (int)0) || ((_ptr__3835[_3842] >= _3833) || ((_ptr__3836[_3842] < (int)0) || (_ptr__3836[_3842] >= _3834)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8569 = (int)0;
  int _8570 = (_3841 - (int)1);
  for (int _3843 = _8569; _3843 < _8570; ++_3843)
  {
    {
      if (((_ptr__3835[_3843] > _ptr__3835[safe_add( _3843,(int)1 )]) || ((_ptr__3835[_3843] == _ptr__3835[safe_add( _3843,(int)1 )]) && (_ptr__3836[_3843] >= _ptr__3836[safe_add( _3843,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8571 = (int)0;
  int _8572 = _3841;
  for (int _3844 = _8571; _3844 < _8572; ++_3844)
  {
    {
      if (((_ptr__3835[_3844] < (int)0) || ((_ptr__3835[_3844] >= _3833) || ((_ptr__3836[_3844] < (int)0) || (_ptr__3836[_3844] >= _3834)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulLeft :: toString() { return mosek::fusion::p_ExprMulLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulLeft(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulLeft::destroy() { mosek::fusion::p_ExprMulLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVar::ExprMulVar(mosek::fusion::p_ExprMulVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVar()" << this << std::endl; */ }mosek::fusion::ExprMulVar::~ExprMulVar() {  /* std::cout << "~ExprMulVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVar::p_ExprMulVar  (::mosek::fusion::ExprMulVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3845,    int _3846,    int _3847,    std::shared_ptr< monty::ndarray< int,1 > > _3848,    std::shared_ptr< monty::ndarray< int,1 > > _3849,    std::shared_ptr< monty::ndarray< double,1 > > _3850,    monty::rc_ptr< ::mosek::fusion::Variable > _3851){ return new mosek::fusion::ExprMulVar(_3845,_3846,_3847,_3848,_3849,_3850,_3851); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3845,    int _3846,    int _3847,    std::shared_ptr< monty::ndarray< int,1 > > _3848,    std::shared_ptr< monty::ndarray< int,1 > > _3849,    std::shared_ptr< monty::ndarray< double,1 > > _3850,    monty::rc_ptr< ::mosek::fusion::Variable > _3851) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3845,_3846,_3847,_3848,_3849,_3850,_3851); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3845,    int _3846,    int _3847,    std::shared_ptr< monty::ndarray< int,1 > > _3848,    std::shared_ptr< monty::ndarray< int,1 > > _3849,    std::shared_ptr< monty::ndarray< double,1 > > _3850,    monty::rc_ptr< ::mosek::fusion::Variable > _3851){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3848(_3848 ? _3848->raw() : nullptr, _3848 ? _3848->size(0) : 0);
    _checked_ptr_1<int> _ptr__3849(_3849 ? _3849->raw() : nullptr, _3849 ? _3849->size(0) : 0);
    _checked_ptr_1<double> _ptr__3850(_3850 ? _3850->raw() : nullptr, _3850 ? _3850->size(0) : 0);
    mosek::fusion::p_ExprMulVar::_initialize(_3845,_3846,_3847,_3848,_3849,_3850,_3851,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3852 = _3851->getShape();
    _checked_ptr_1<int> _ptr__3852(_3852 ? _3852->raw() : nullptr,_3852 ? _3852->size(0) : 0);
    int _3853 = (int)((_3852)->size(0));
    if ((_3853 != (int)2))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if((_3845 && (_ptr__3852[(int)0] != _3847)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if(((!_3845) && (_ptr__3852[(int)1] != _3846)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    if ((((int)((_3848)->size(0)) != (int)((_3849)->size(0))) || ((int)((_3848)->size(0)) != (int)((_3850)->size(0)))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching matrix data lengths"));
      }
    }
    {}
    validate(_3846,_3847,_3848,_3849,_3850);
  }
}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3854,    int _3855,    int _3856,    std::shared_ptr< monty::ndarray< int,1 > > _3857,    std::shared_ptr< monty::ndarray< int,1 > > _3858,    std::shared_ptr< monty::ndarray< double,1 > > _3859,    monty::rc_ptr< ::mosek::fusion::Variable > _3860,    int _3861){ return new mosek::fusion::ExprMulVar(_3854,_3855,_3856,_3857,_3858,_3859,_3860,_3861); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3854,    int _3855,    int _3856,    std::shared_ptr< monty::ndarray< int,1 > > _3857,    std::shared_ptr< monty::ndarray< int,1 > > _3858,    std::shared_ptr< monty::ndarray< double,1 > > _3859,    monty::rc_ptr< ::mosek::fusion::Variable > _3860,    int _3861) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3854,_3855,_3856,_3857,_3858,_3859,_3860,_3861); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3854,    int _3855,    int _3856,    std::shared_ptr< monty::ndarray< int,1 > > _3857,    std::shared_ptr< monty::ndarray< int,1 > > _3858,    std::shared_ptr< monty::ndarray< double,1 > > _3859,    monty::rc_ptr< ::mosek::fusion::Variable > _3860,    int _3861){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3857(_3857 ? _3857->raw() : nullptr, _3857 ? _3857->size(0) : 0);
    _checked_ptr_1<int> _ptr__3858(_3858 ? _3858->raw() : nullptr, _3858 ? _3858->size(0) : 0);
    _checked_ptr_1<double> _ptr__3859(_3859 ? _3859->raw() : nullptr, _3859 ? _3859->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulVar::resshape(_3855,_3856,_3860->getShape(),_3854));
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->left = _3854;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->x = _3860;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi = _3855;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj = _3856;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi = ::mosek::fusion::Utils::Tools::arraycopy(_3857);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj = ::mosek::fusion::Utils::Tools::arraycopy(_3858);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof = ::mosek::fusion::Utils::Tools::arraycopy(_3859);
  }
}void mosek::fusion::ExprMulVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3862,monty::rc_ptr< ::mosek::fusion::WorkStack > _3863,monty::rc_ptr< ::mosek::fusion::WorkStack > _3864) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval(_3862,_3863,_3864); }void mosek::fusion::p_ExprMulVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3862,monty::rc_ptr< ::mosek::fusion::WorkStack > _3863,monty::rc_ptr< ::mosek::fusion::WorkStack > _3864){
  if (left)
  {
    {
      _pubthis->eval_left(_3862,_3863,_3864);
    }
  }
  else
  {
    {
      _pubthis->eval_right(_3862,_3863,_3864);
    }
  }
}
void mosek::fusion::ExprMulVar :: eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3865,monty::rc_ptr< ::mosek::fusion::WorkStack > _3866,monty::rc_ptr< ::mosek::fusion::WorkStack > _3867) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_right(_3865,_3866,_3867); }void mosek::fusion::p_ExprMulVar::eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3865,monty::rc_ptr< ::mosek::fusion::WorkStack > _3866,monty::rc_ptr< ::mosek::fusion::WorkStack > _3867){
  int _3868 = mosek::fusion::p_WorkStack::_get_impl(_3866)->pi32;
  int _3869 = mosek::fusion::p_WorkStack::_get_impl(_3866)->pi64;
  int _3870 = x->numInst();
  int _3871 = _3866->alloci64(_3870);
  int _3872 = _3866->alloci64(_3870);
  int _3873 = _3866->alloci32(_3870);
  int _3874 = _3866->alloci32(_3870);
  std::shared_ptr< monty::ndarray< int,1 > > _3875 = x->getShape();
  _checked_ptr_1<int> _ptr__3875(_3875 ? _3875->raw() : nullptr,_3875 ? _3875->size(0) : 0);
  int _3876 = (int)((_3875)->size(0));
  long long _3877 = safe_mul( _ptr__3875[(int)0],_ptr__3875[(int)1] );
  int _3878 = _ptr__3875[(int)1];
  int _3879 = _ptr__3875[(int)0];
  int _3880 = _3866->alloci32(safe_add( _3879,(int)1 ));
  int _3881 = (int)((mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _3882 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3882(_3882 ? _3882->raw() : nullptr,_3882 ? _3882->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3883 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3883(_3883 ? _3883->raw() : nullptr,_3883 ? _3883->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3884 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3884(_3884 ? _3884->raw() : nullptr,_3884 ? _3884->size(0) : 0);
  int _3885 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3886 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  bool _3887 = ((_3881 / _3885) == _3886);
  int _3888 = _3866->alloci32(_3881);
  int _3889 = _3866->alloci32(safe_add( mdimj,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3890 = mosek::fusion::p_WorkStack::_get_impl(_3866)->i32;
  _checked_ptr_1<int> _ptr__3890(_3890 ? _3890->raw() : nullptr,_3890 ? _3890->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3891 = mosek::fusion::p_WorkStack::_get_impl(_3866)->i64;
  _checked_ptr_1<long long> _ptr__3891(_3891 ? _3891->raw() : nullptr,_3891 ? _3891->size(0) : 0);
  int _3892 = (int)0;
  int _3893 = (int)0;
  x->inst(_3872,_3891,_3871,_3891);
  if (_3887)
  {
    {
      int _3894 = (int)0;
      if ((_3870 > (int)0))
      {
        {
          _3894 = (int)1;
          if ((_3879 > (int)1))
          {
            {
              if ((_3878 == (int)1))
              {
                {
                  int _8573 = (int)1;
                  int _8574 = _3870;
                  for (int _3895 = _8573; _3895 < _8574; ++_3895)
                  {
                    {
                      if ((_ptr__3891[safe_add( _3872,_3895 )] > _ptr__3891[(safe_add( _3872,_3895 ) - (int)1)]))
                      {
                        {
                          ++ _3894;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              else
              {
                {
                  int _8575 = (int)1;
                  int _8576 = _3870;
                  for (int _3896 = _8575; _3896 < _8576; ++_3896)
                  {
                    {
                      if (((_ptr__3891[safe_add( _3872,_3896 )] / _3878) > (_ptr__3891[(safe_add( _3872,_3896 ) - (int)1)] / _3878)))
                      {
                        {
                          ++ _3894;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          {}
        }
      }
      {}
      _3893 = safe_mul( _3894,_3886 );
      _3892 = safe_mul( _3870,_3886 );
      bool _3897 = (_3894 < _3879);
      int _3898 = _3865->alloci32(safe_add( _3893,(int)1 ));
      int _8577;
      bool _8578 = _3897;
      if (_8578)
      {
        _8577 = (int)1;
      }
      else
      {
        _8577 = (int)0;
      }
      _3865->pushi32(_8577);
      _3865->pushi32(_3892);
      _3865->pushi32(_3893);
      _3865->pushi32(_3879);
      _3865->pushi32(_3886);
      _3865->pushi32((int)2);
      int _3899 = _3865->alloci64(_3892);
      int _3900 = _3865->alloci64(_3893);
      int _3901 = _3865->allocf64(_3892);
      int _3902 = _3865->allocf64(_3893);
      std::shared_ptr< monty::ndarray< int,1 > > _3903 = mosek::fusion::p_WorkStack::_get_impl(_3865)->i32;
      _checked_ptr_1<int> _ptr__3903(_3903 ? _3903->raw() : nullptr,_3903 ? _3903->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3904 = mosek::fusion::p_WorkStack::_get_impl(_3865)->i64;
      _checked_ptr_1<long long> _ptr__3904(_3904 ? _3904->raw() : nullptr,_3904 ? _3904->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3905 = mosek::fusion::p_WorkStack::_get_impl(_3865)->f64;
      _checked_ptr_1<double> _ptr__3905(_3905 ? _3905->raw() : nullptr,_3905 ? _3905->size(0) : 0);
      {
        int _3906 = (int)0;
        int _3907 = (int)0;
        int _3908 = (int)0;
        _ptr__3903[_3898] = (int)0;
        while ( (_3906 < _3870) )
        {
          {
            int _3909 = _3906;
            ++ _3906;
            while ( ((_3906 < _3870) && ((_ptr__3891[safe_add( _3872,_3906 )] / _3878) == (_ptr__3891[safe_add( _3872,_3909 )] / _3878))) )
            {
              {
                ++ _3906;
              }
            }
            long long _3910 = (_ptr__3891[safe_add( _3872,_3909 )] / _3878);
            int _8579 = (int)0;
            int _8580 = _3886;
            for (int _3911 = _8579; _3911 < _8580; ++_3911)
            {
              {
                int _8581 = _3909;
                int _8582 = _3906;
                for (int _3912 = _8581; _3912 < _8582; ++_3912)
                {
                  {
                    long long _3913 = (_ptr__3891[safe_add( _3872,_3912 )] % _3878);
                    _ptr__3904[safe_add( _3899,_3908 )] = _ptr__3891[safe_add( _3871,_3912 )];
                    _ptr__3905[safe_add( _3901,_3908 )] = _ptr__3884[safe_add( safe_mul( _3913,_3886 ),_3911 )];
                    ++ _3908;
                  }
                }
                _ptr__3903[safe_add( safe_add( _3898,_3907 ),(int)1 )] = _3908;
                _ptr__3905[safe_add( _3902,_3907 )] = 0.0;
                _ptr__3904[safe_add( _3900,_3907 )] = safe_add( safe_mul( _3910,_3886 ),_3911 );
                ++ _3907;
              }
            }
          }
        }
      }
      if ((!_3897))
      {
        {
          _3865->popi64(_3893);
        }
      }
      {}
    }
  }
  else
  {
    {
      {
        if ((_3886 == (int)1))
        {
          {
            int _8583 = (int)0;
            int _8584 = _3881;
            for (int _3914 = _8583; _3914 < _8584; ++_3914)
            {
              {
                _ptr__3890[safe_add( _3888,_3914 )] = _3914;
              }
            }
            _ptr__3890[_3889] = (int)0;
            _ptr__3890[safe_add( _3889,(int)1 )] = _3881;
          }
        }
        else
        {
          {
            _ptr__3890[_3889] = (int)0;
            int _8585 = (int)0;
            int _8586 = safe_add( _3886,(int)1 );
            for (int _3915 = _8585; _3915 < _8586; ++_3915)
            {
              {
                _ptr__3890[safe_add( _3889,_3915 )] = (int)0;
              }
            }
            int _8587 = (int)0;
            int _8588 = _3881;
            for (int _3916 = _8587; _3916 < _8588; ++_3916)
            {
              {
                ++ _ptr__3890[safe_add( safe_add( _3889,_ptr__3883[_3916] ),(int)1 )];
              }
            }
            int _8589 = (int)0;
            int _8590 = mdimj;
            for (int _3917 = _8589; _3917 < _8590; ++_3917)
            {
              {
                _ptr__3890[safe_add( safe_add( _3889,_3917 ),(int)1 )] += _ptr__3890[safe_add( _3889,_3917 )];
              }
            }
            int _8591 = (int)0;
            int _8592 = _3881;
            for (int _3918 = _8591; _3918 < _8592; ++_3918)
            {
              {
                _ptr__3890[safe_add( _3888,_ptr__3890[safe_add( _3889,_ptr__3883[_3918] )] )] = _3918;
                ++ _ptr__3890[safe_add( _3889,_ptr__3883[_3918] )];
              }
            }
            int _8593 = (int)0;
            int _8594 = _3886;
            for (int _3919 = _8593; _3919 < _8594; ++_3919)
            {
              {
                _ptr__3890[(safe_add( _3889,_3886 ) - _3919)] = _ptr__3890[((safe_add( _3889,_3886 ) - _3919) - (int)1)];
              }
            }
            _ptr__3890[_3889] = (int)0;
          }
        }
      }
      if (((_3870 / _3879) == _3878))
      {
        {
          int _3920 = (int)0;
          {
            int _3921 = (int)0;
            while ( (_3921 < _3881) )
            {
              {
                ++ _3921;
                while ( ((_3921 < _3881) && (_ptr__3883[_ptr__3890[(safe_add( _3888,_3921 ) - (int)1)]] == _ptr__3883[_ptr__3890[safe_add( _3888,_3921 )]])) )
                {
                  {
                    ++ _3921;
                  }
                }
                ++ _3920;
              }
            }
          }
          _3893 = safe_mul( _3920,_3879 );
          _3892 = safe_mul( _3881,_3879 );
          bool _3922 = (_3920 < _3886);
          int _3923 = _3865->alloci32(safe_add( _3893,(int)1 ));
          int _8595;
          bool _8596 = _3922;
          if (_8596)
          {
            _8595 = (int)1;
          }
          else
          {
            _8595 = (int)0;
          }
          _3865->pushi32(_8595);
          _3865->pushi32(_3892);
          _3865->pushi32(_3893);
          _3865->pushi32(_3879);
          _3865->pushi32(_3886);
          _3865->pushi32((int)2);
          int _3924 = _3865->alloci64(_3892);
          int _3925 = _3865->alloci64(_3893);
          int _3926 = _3865->allocf64(_3892);
          int _3927 = _3865->allocf64(_3893);
          std::shared_ptr< monty::ndarray< int,1 > > _3928 = mosek::fusion::p_WorkStack::_get_impl(_3865)->i32;
          _checked_ptr_1<int> _ptr__3928(_3928 ? _3928->raw() : nullptr,_3928 ? _3928->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3929 = mosek::fusion::p_WorkStack::_get_impl(_3865)->i64;
          _checked_ptr_1<long long> _ptr__3929(_3929 ? _3929->raw() : nullptr,_3929 ? _3929->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3930 = mosek::fusion::p_WorkStack::_get_impl(_3865)->f64;
          _checked_ptr_1<double> _ptr__3930(_3930 ? _3930->raw() : nullptr,_3930 ? _3930->size(0) : 0);
          _ptr__3928[_3923] = (int)0;
          int _3931 = (int)0;
          int _3932 = (int)0;
          int _8597 = (int)0;
          int _8598 = _3879;
          for (int _3933 = _8597; _3933 < _8598; ++_3933)
          {
            {
              int _3934 = (int)0;
              while ( (_3934 < _3881) )
              {
                {
                  int _3935 = _3934;
                  ++ _3934;
                  while ( ((_3934 < _3881) && (_ptr__3883[_ptr__3890[safe_add( _3888,_3935 )]] == _ptr__3883[_ptr__3890[safe_add( _3888,_3934 )]])) )
                  {
                    {
                      ++ _3934;
                    }
                  }
                  int _3936 = _ptr__3883[_ptr__3890[safe_add( _3888,_3935 )]];
                  int _8599 = _3935;
                  int _8600 = _3934;
                  for (int _3937 = _8599; _3937 < _8600; ++_3937)
                  {
                    {
                      int _3938 = _ptr__3882[_ptr__3890[safe_add( _3888,_3937 )]];
                      _ptr__3929[safe_add( _3924,_3932 )] = _ptr__3891[safe_add( safe_add( _3871,safe_mul( _3933,_3878 ) ),_3938 )];
                      _ptr__3930[safe_add( _3926,_3932 )] = _ptr__3884[_ptr__3890[safe_add( _3888,_3937 )]];
                      ++ _3932;
                    }
                  }
                  _ptr__3930[safe_add( _3927,_3931 )] = 0.0;
                  _ptr__3929[safe_add( _3925,_3931 )] = safe_add( safe_mul( _3933,_3886 ),_3936 );
                  _ptr__3928[safe_add( safe_add( _3923,_3931 ),(int)1 )] = _3932;
                  ++ _3931;
                }
              }
            }
          }
          if ((!_3922))
          {
            {
              _3865->popi64(_3893);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _8601 = (int)0;
          int _8602 = safe_add( _3879,(int)1 );
          for (int _3939 = _8601; _3939 < _8602; ++_3939)
          {
            {
              _ptr__3890[safe_add( _3880,_3939 )] = (int)0;
            }
          }
          if ((_3876 == (int)1))
          {
            {
              int _8603 = (int)0;
              int _8604 = _3870;
              for (int _3940 = _8603; _3940 < _8604; ++_3940)
              {
                {
                  _ptr__3890[safe_add( _3873,_3940 )] = (int)0;
                }
              }
              int _8605 = (int)0;
              int _8606 = _3870;
              for (int _3941 = _8605; _3941 < _8606; ++_3941)
              {
                {
                  _ptr__3890[safe_add( _3874,_3941 )] = (int)_ptr__3891[safe_add( _3872,_3941 )];
                }
              }
              _ptr__3890[_3880] = (int)0;
              _ptr__3890[safe_add( _3880,(int)1 )] = _3870;
            }
          }
          else
          {
            {
              int _8607 = (int)0;
              int _8608 = _3870;
              for (int _3942 = _8607; _3942 < _8608; ++_3942)
              {
                {
                  _ptr__3890[safe_add( _3873,_3942 )] = (int)(_ptr__3891[safe_add( _3872,_3942 )] / _ptr__3875[(int)1]);
                }
              }
              int _8609 = (int)0;
              int _8610 = _3870;
              for (int _3943 = _8609; _3943 < _8610; ++_3943)
              {
                {
                  _ptr__3890[safe_add( _3874,_3943 )] = (int)(_ptr__3891[safe_add( _3872,_3943 )] % _ptr__3875[(int)1]);
                }
              }
              _ptr__3890[_3880] = (int)0;
              int _8611 = (int)0;
              int _8612 = _3870;
              for (int _3944 = _8611; _3944 < _8612; ++_3944)
              {
                {
                  ++ _ptr__3890[safe_add( safe_add( _3880,_ptr__3890[safe_add( _3873,_3944 )] ),(int)1 )];
                }
              }
              int _8613 = (int)0;
              int _8614 = _3879;
              for (int _3945 = _8613; _3945 < _8614; ++_3945)
              {
                {
                  _ptr__3890[safe_add( safe_add( _3880,_3945 ),(int)1 )] += _ptr__3890[safe_add( _3880,_3945 )];
                }
              }
            }
          }
          int _8615 = (int)0;
          int _8616 = _3879;
          for (int _3946 = _8615; _3946 < _8616; ++_3946)
          {
            {
              int _8617 = (int)0;
              int _8618 = mdimj;
              for (int _3947 = _8617; _3947 < _8618; ++_3947)
              {
                {
                  int _3948 = (int)0;
                  int _3949 = _ptr__3890[safe_add( safe_add( _3880,_3946 ),(int)1 )];
                  int _3950 = _ptr__3890[safe_add( safe_add( _3889,_3947 ),(int)1 )];
                  int _3951 = _ptr__3890[safe_add( _3880,_3946 )];
                  int _3952 = _ptr__3890[safe_add( _3889,_3947 )];
                  while ( ((_3952 < _3950) && (_3951 < _3949)) )
                  {
                    {
                      if ((_ptr__3882[_ptr__3890[safe_add( _3888,_3952 )]] < _ptr__3890[safe_add( _3874,_3951 )]))
                      {
                        {
                          ++ _3952;
                        }
                      }
                      else if((_ptr__3882[_ptr__3890[safe_add( _3888,_3952 )]] > _ptr__3890[safe_add( _3874,_3951 )]))
                      {
                        {
                          ++ _3951;
                        }
                      }
                      else
                      {
                        {
                          ++ _3948;
                          ++ _3952;
                          ++ _3951;
                        }
                      }
                    }
                  }
                  if ((_3948 > (int)0))
                  {
                    {
                      _3892 += _3948;
                      ++ _3893;
                    }
                  }
                  {}
                }
              }
            }
          }
          int _3953 = _3865->alloci32(safe_add( _3893,(int)1 ));
          bool _8619;
          bool _8620 = (_3893 < safe_mul( _3878,mdimi ));
          if (_8620)
          {
            _8619 = true;
          }
          else
          {
            _8619 = false;
          }
          bool _3954 = _8619;
          int _8621;
          bool _8622 = _3954;
          if (_8622)
          {
            _8621 = (int)1;
          }
          else
          {
            _8621 = (int)0;
          }
          _3865->pushi32(_8621);
          _3865->pushi32(_3892);
          _3865->pushi32(_3893);
          _3865->pushi32(_3879);
          _3865->pushi32(mdimj);
          _3865->pushi32((int)2);
          int _3955 = _3865->alloci64(_3892);
          int _3956 = _3865->alloci64(_3893);
          int _3957 = _3865->allocf64(_3892);
          int _3958 = _3865->allocf64(_3893);
          std::shared_ptr< monty::ndarray< int,1 > > _3959 = mosek::fusion::p_WorkStack::_get_impl(_3865)->i32;
          _checked_ptr_1<int> _ptr__3959(_3959 ? _3959->raw() : nullptr,_3959 ? _3959->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3960 = mosek::fusion::p_WorkStack::_get_impl(_3865)->i64;
          _checked_ptr_1<long long> _ptr__3960(_3960 ? _3960->raw() : nullptr,_3960 ? _3960->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3961 = mosek::fusion::p_WorkStack::_get_impl(_3865)->f64;
          _checked_ptr_1<double> _ptr__3961(_3961 ? _3961->raw() : nullptr,_3961 ? _3961->size(0) : 0);
          {
            int _3962 = (int)0;
            int _3963 = (int)0;
            int _3964 = (int)0;
            _ptr__3959[_3953] = (int)0;
            int _8623 = (int)0;
            int _8624 = _3893;
            for (int _3965 = _8623; _3965 < _8624; ++_3965)
            {
              {
                _ptr__3961[safe_add( _3958,_3965 )] = 0.0;
              }
            }
            int _8625 = (int)0;
            int _8626 = _3879;
            for (int _3966 = _8625; _3966 < _8626; ++_3966)
            {
              {
                int _8627 = (int)0;
                int _8628 = mdimj;
                for (int _3967 = _8627; _3967 < _8628; ++_3967)
                {
                  {
                    int _3968 = (int)0;
                    int _3969 = _ptr__3890[safe_add( safe_add( _3880,_3966 ),(int)1 )];
                    int _3970 = _ptr__3890[safe_add( safe_add( _3889,_3967 ),(int)1 )];
                    int _3971 = _ptr__3890[safe_add( _3880,_3966 )];
                    int _3972 = _ptr__3890[safe_add( _3889,_3967 )];
                    while ( ((_3972 < _3970) && (_3971 < _3969)) )
                    {
                      {
                        if ((_ptr__3882[_ptr__3890[safe_add( _3888,_3972 )]] < _ptr__3890[safe_add( _3874,_3971 )]))
                        {
                          {
                            ++ _3972;
                          }
                        }
                        else if((_ptr__3882[_ptr__3890[safe_add( _3888,_3972 )]] > _ptr__3890[safe_add( _3874,_3971 )]))
                        {
                          {
                            ++ _3971;
                          }
                        }
                        else
                        {
                          {
                            _ptr__3960[safe_add( _3955,_3964 )] = _ptr__3891[safe_add( _3871,_3971 )];
                            _ptr__3961[safe_add( _3957,_3964 )] = _ptr__3884[_ptr__3890[safe_add( _3888,_3972 )]];
                            ++ _3968;
                            ++ _3964;
                            ++ _3972;
                            ++ _3971;
                          }
                        }
                      }
                    }
                    if ((_3968 > (int)0))
                    {
                      {
                        _ptr__3959[safe_add( safe_add( _3953,_3963 ),(int)1 )] = _3964;
                        _ptr__3960[safe_add( _3956,_3963 )] = _3962;
                        ++ _3963;
                      }
                    }
                    {}
                    ++ _3962;
                  }
                }
              }
            }
          }
          if ((!_3954))
          {
            {
              _3865->popi64(_3893);
            }
          }
          {}
        }
      }
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_3866)->pi32 = _3868;
  mosek::fusion::p_WorkStack::_get_impl(_3866)->pi64 = _3869;
}
void mosek::fusion::ExprMulVar :: eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3973,monty::rc_ptr< ::mosek::fusion::WorkStack > _3974,monty::rc_ptr< ::mosek::fusion::WorkStack > _3975) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_left(_3973,_3974,_3975); }void mosek::fusion::p_ExprMulVar::eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3973,monty::rc_ptr< ::mosek::fusion::WorkStack > _3974,monty::rc_ptr< ::mosek::fusion::WorkStack > _3975){
  int _3976 = x->numInst();
  std::shared_ptr< monty::ndarray< int,1 > > _3977 = x->getShape();
  _checked_ptr_1<int> _ptr__3977(_3977 ? _3977->raw() : nullptr,_3977 ? _3977->size(0) : 0);
  int _3978 = (int)((_3977)->size(0));
  int _3979 = _3975->alloci64(_3976);
  int _3980 = _3975->alloci64(_3976);
  int _3981 = _3975->alloci32(_3976);
  int _3982 = _3975->alloci32(_3976);
  int _3983 = _3975->alloci32(_3976);
  int _3984 = _3975->alloci32(safe_add( mdimi,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3985 = x->getShape();
  _checked_ptr_1<int> _ptr__3985(_3985 ? _3985->raw() : nullptr,_3985 ? _3985->size(0) : 0);
  int _3986 = (int)((_3985)->size(0));
  int _8629;
  bool _8630 = (_3986 == (int)1);
  if (_8630)
  {
    _8629 = (int)1;
  }
  else
  {
    _8629 = _ptr__3985[(int)1];
  }
  int _3987 = _8629;
  int _3988 = _ptr__3985[(int)0];
  int _3989 = _3975->alloci32(safe_add( _3987,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3990 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3990(_3990 ? _3990->raw() : nullptr,_3990 ? _3990->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3991 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3991(_3991 ? _3991->raw() : nullptr,_3991 ? _3991->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3992 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3992(_3992 ? _3992->raw() : nullptr,_3992 ? _3992->size(0) : 0);
  int _3993 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3994 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  int _3995 = (int)0;
  int _3996 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _3997 = mosek::fusion::p_WorkStack::_get_impl(_3975)->i32;
  _checked_ptr_1<int> _ptr__3997(_3997 ? _3997->raw() : nullptr,_3997 ? _3997->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3998 = mosek::fusion::p_WorkStack::_get_impl(_3975)->i64;
  _checked_ptr_1<long long> _ptr__3998(_3998 ? _3998->raw() : nullptr,_3998 ? _3998->size(0) : 0);
  x->inst(_3980,_3998,_3979,_3998);
  {
    int _8631 = (int)0;
    int _8632 = safe_add( _3993,(int)1 );
    for (int _3999 = _8631; _3999 < _8632; ++_3999)
    {
      {
        _ptr__3997[safe_add( _3984,_3999 )] = (int)0;
      }
    }
    int _8633 = (int)0;
    int _8634 = (int)((_3990)->size(0));
    for (int _4000 = _8633; _4000 < _8634; ++_4000)
    {
      {
        ++ _ptr__3997[safe_add( safe_add( _3984,_ptr__3990[_4000] ),(int)1 )];
      }
    }
    int _8635 = (int)0;
    int _8636 = _3993;
    for (int _4001 = _8635; _4001 < _8636; ++_4001)
    {
      {
        _ptr__3997[safe_add( safe_add( _3984,_4001 ),(int)1 )] += _ptr__3997[safe_add( _3984,_4001 )];
      }
    }
    if ((_3986 == (int)1))
    {
      {
        int _8637 = (int)0;
        int _8638 = _3976;
        for (int _4002 = _8637; _4002 < _8638; ++_4002)
        {
          {
            _ptr__3997[safe_add( _3981,_4002 )] = (int)_ptr__3998[safe_add( _3980,_4002 )];
          }
        }
        int _8639 = (int)0;
        int _8640 = _3976;
        for (int _4003 = _8639; _4003 < _8640; ++_4003)
        {
          {
            _ptr__3997[safe_add( _3982,_4003 )] = (int)0;
          }
        }
      }
    }
    else
    {
      {
        int _8641 = (int)0;
        int _8642 = _3976;
        for (int _4004 = _8641; _4004 < _8642; ++_4004)
        {
          {
            _ptr__3997[safe_add( _3981,_4004 )] = (int)(_ptr__3998[safe_add( _3980,_4004 )] / _3987);
          }
        }
        int _8643 = (int)0;
        int _8644 = _3976;
        for (int _4005 = _8643; _4005 < _8644; ++_4005)
        {
          {
            _ptr__3997[safe_add( _3982,_4005 )] = (int)(_ptr__3998[safe_add( _3980,_4005 )] % _3987);
          }
        }
      }
    }
    if ((_3986 > (int)1))
    {
      {
        int _8645 = (int)0;
        int _8646 = safe_add( _3987,(int)1 );
        for (int _4006 = _8645; _4006 < _8646; ++_4006)
        {
          {
            _ptr__3997[safe_add( _3989,_4006 )] = (int)0;
          }
        }
        int _8647 = (int)0;
        int _8648 = _3976;
        for (int _4007 = _8647; _4007 < _8648; ++_4007)
        {
          {
            ++ _ptr__3997[safe_add( safe_add( _3989,_ptr__3997[safe_add( _3982,_4007 )] ),(int)1 )];
          }
        }
        int _8649 = (int)0;
        int _8650 = _3987;
        for (int _4008 = _8649; _4008 < _8650; ++_4008)
        {
          {
            _ptr__3997[safe_add( safe_add( _3989,_4008 ),(int)1 )] += _ptr__3997[safe_add( _3989,_4008 )];
          }
        }
        int _8651 = (int)0;
        int _8652 = _3976;
        for (int _4009 = _8651; _4009 < _8652; ++_4009)
        {
          {
            _ptr__3997[safe_add( _3983,_ptr__3997[safe_add( _3989,_ptr__3997[safe_add( _3982,_4009 )] )] )] = _4009;
            ++ _ptr__3997[safe_add( _3989,_ptr__3997[safe_add( _3982,_4009 )] )];
          }
        }
        int _8653 = (int)0;
        int _8654 = _3987;
        for (int _4010 = _8653; _4010 < _8654; ++_4010)
        {
          {
            _ptr__3997[(safe_add( _3989,_3987 ) - _4010)] = _ptr__3997[((safe_add( _3989,_3987 ) - _4010) - (int)1)];
          }
        }
        _ptr__3997[_3989] = (int)0;
      }
    }
    else
    {
      {
        _ptr__3997[_3989] = (int)0;
        _ptr__3997[safe_add( _3989,(int)1 )] = _3976;
        int _8655 = (int)0;
        int _8656 = _3976;
        for (int _4011 = _8655; _4011 < _8656; ++_4011)
        {
          {
            _ptr__3997[safe_add( _3983,_4011 )] = _4011;
          }
        }
      }
    }
    int _8657 = (int)0;
    int _8658 = _3993;
    for (int _4012 = _8657; _4012 < _8658; ++_4012)
    {
      {
        int _8659 = (int)0;
        int _8660 = _3987;
        for (int _4013 = _8659; _4013 < _8660; ++_4013)
        {
          {
            int _4014 = (int)0;
            int _4015 = _ptr__3997[safe_add( safe_add( _3989,_4013 ),(int)1 )];
            int _4016 = _ptr__3997[safe_add( safe_add( _3984,_4012 ),(int)1 )];
            int _4017 = _ptr__3997[safe_add( _3989,_4013 )];
            int _4018 = _ptr__3997[safe_add( _3984,_4012 )];
            while ( ((_4018 < _4016) && (_4017 < _4015)) )
            {
              {
                if ((_ptr__3991[_4018] < _ptr__3997[safe_add( _3981,_ptr__3997[safe_add( _3983,_4017 )] )]))
                {
                  {
                    ++ _4018;
                  }
                }
                else if((_ptr__3991[_4018] > _ptr__3997[safe_add( _3981,_ptr__3997[safe_add( _3983,_4017 )] )]))
                {
                  {
                    ++ _4017;
                  }
                }
                else
                {
                  {
                    ++ _4014;
                    ++ _4018;
                    ++ _4017;
                  }
                }
              }
            }
            if ((_4014 > (int)0))
            {
              {
                _3995 += _4014;
                ++ _3996;
              }
            }
            {}
          }
        }
      }
    }
  }
  bool _8661;
  bool _8662 = (_3996 < safe_mul( _3987,_3993 ));
  if (_8662)
  {
    _8661 = true;
  }
  else
  {
    _8661 = false;
  }
  bool _4019 = _8661;
  int _4020 = _3986;
  _3973->alloc_expr(_4020,_3996,_3995,_4019);
  int _4021 = mosek::fusion::p_WorkStack::_get_impl(_3973)->ptr_base;
  int _4022 = mosek::fusion::p_WorkStack::_get_impl(_3973)->shape_base;
  int _4023 = mosek::fusion::p_WorkStack::_get_impl(_3973)->nidxs_base;
  int _8663;
  bool _8664 = _4019;
  if (_8664)
  {
    _8663 = mosek::fusion::p_WorkStack::_get_impl(_3973)->sp_base;
  }
  else
  {
    _8663 = _3973->alloci64(_3996);
  }
  int _4024 = _8663;
  int _4025 = mosek::fusion::p_WorkStack::_get_impl(_3973)->cof_base;
  int _4026 = mosek::fusion::p_WorkStack::_get_impl(_3973)->bfix_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4027 = mosek::fusion::p_WorkStack::_get_impl(_3973)->i32;
  _checked_ptr_1<int> _ptr__4027(_4027 ? _4027->raw() : nullptr,_4027 ? _4027->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4028 = mosek::fusion::p_WorkStack::_get_impl(_3973)->i64;
  _checked_ptr_1<long long> _ptr__4028(_4028 ? _4028->raw() : nullptr,_4028 ? _4028->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4029 = mosek::fusion::p_WorkStack::_get_impl(_3973)->f64;
  _checked_ptr_1<double> _ptr__4029(_4029 ? _4029->raw() : nullptr,_4029 ? _4029->size(0) : 0);
  _ptr__4027[_4022] = _3993;
  if ((_3986 > (int)1))
  {
    {
      _ptr__4027[safe_add( _4022,(int)1 )] = _3987;
    }
  }
  {}
  {
    int _4030 = (int)0;
    int _4031 = (int)0;
    int _4032 = (int)0;
    _ptr__4027[_4021] = (int)0;
    int _8665 = (int)0;
    int _8666 = _3996;
    for (int _4033 = _8665; _4033 < _8666; ++_4033)
    {
      {
        _ptr__4029[safe_add( _4026,_4033 )] = 0.0;
      }
    }
    int _8667 = (int)0;
    int _8668 = _3993;
    for (int _4034 = _8667; _4034 < _8668; ++_4034)
    {
      {
        int _8669 = (int)0;
        int _8670 = _3987;
        for (int _4035 = _8669; _4035 < _8670; ++_4035)
        {
          {
            int _4036 = (int)0;
            int _4037 = _ptr__3997[safe_add( safe_add( _3989,_4035 ),(int)1 )];
            int _4038 = _ptr__3997[safe_add( safe_add( _3984,_4034 ),(int)1 )];
            int _4039 = _ptr__3997[safe_add( _3989,_4035 )];
            int _4040 = _ptr__3997[safe_add( _3984,_4034 )];
            while ( ((_4040 < _4038) && (_4039 < _4037)) )
            {
              {
                if ((_ptr__3991[_4040] < _ptr__3997[safe_add( _3981,_ptr__3997[safe_add( _3983,_4039 )] )]))
                {
                  {
                    ++ _4040;
                  }
                }
                else if((_ptr__3991[_4040] > _ptr__3997[safe_add( _3981,_ptr__3997[safe_add( _3983,_4039 )] )]))
                {
                  {
                    ++ _4039;
                  }
                }
                else
                {
                  {
                    _ptr__4028[safe_add( _4023,_4032 )] = _ptr__3998[safe_add( _3979,_ptr__3997[safe_add( _3983,_4039 )] )];
                    _ptr__4029[safe_add( _4025,_4032 )] = _ptr__3992[_4040];
                    ++ _4036;
                    ++ _4032;
                    ++ _4040;
                    ++ _4039;
                  }
                }
              }
            }
            if ((_4036 > (int)0))
            {
              {
                _ptr__4027[safe_add( safe_add( _4021,_4031 ),(int)1 )] = _4032;
                _ptr__4028[safe_add( _4024,_4031 )] = _4030;
                ++ _4031;
              }
            }
            {}
            ++ _4030;
          }
        }
      }
    }
  }
  if ((!_4019))
  {
    {
      _3973->popi64(_3996);
    }
  }
  {}
  _3975->clear();
}
void mosek::fusion::p_ExprMulVar::validate(int _4041,int _4042,std::shared_ptr< monty::ndarray< int,1 > > _4043,std::shared_ptr< monty::ndarray< int,1 > > _4044,std::shared_ptr< monty::ndarray< double,1 > > _4045){
  _checked_ptr_1<int> _ptr__4043(_4043 ? _4043->raw() : nullptr, _4043 ? _4043->size(0) : 0);
  _checked_ptr_1<int> _ptr__4044(_4044 ? _4044->raw() : nullptr, _4044 ? _4044->size(0) : 0);
  _checked_ptr_1<double> _ptr__4045(_4045 ? _4045->raw() : nullptr, _4045 ? _4045->size(0) : 0);
  bool _4046 = true;
  {
    int _8671 = (int)0;
    int _8672 = (int)((_4043)->size(0));
    for (int _4047 = _8671; _4047 < _8672; ++_4047)
    {
      {
        if (((_ptr__4043[_4047] < (int)0) || ((_ptr__4043[_4047] >= _4041) || ((_ptr__4044[_4047] < (int)0) || (_ptr__4044[_4047] >= _4042)))))
        {
          {
            _4046 = false;
          }
        }
        {}
      }
    }
    int _8673 = (int)1;
    int _8674 = (int)((_4043)->size(0));
    for (int _4048 = _8673; _4048 < _8674; ++_4048)
    {
      {
        if (((_ptr__4043[(_4048 - (int)1)] > _ptr__4043[_4048]) || ((_ptr__4043[(_4048 - (int)1)] == _ptr__4043[_4048]) && (_ptr__4044[(_4048 - (int)1)] >= _ptr__4044[_4048]))))
        {
          {
            _4046 = false;
          }
        }
        {}
      }
    }
  }
  if ((!_4046))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulVar::resshape(int _4049,int _4050,std::shared_ptr< monty::ndarray< int,1 > > _4051,bool _4052){
  _checked_ptr_1<int> _ptr__4051(_4051 ? _4051->raw() : nullptr, _4051 ? _4051->size(0) : 0);
  if (_4052)
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4049),(int)(_ptr__4051[(int)1])});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__4051[(int)0]),(int)(_4050)});
    }
  }
}
std::string mosek::fusion::ExprMulVar :: toString() { return mosek::fusion::p_ExprMulVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVar::toString(){
  if (left)
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",M)"))->toString();
    }
  }
}
void mosek::fusion::p_ExprMulVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulVar::destroy() { mosek::fusion::p_ExprMulVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar(mosek::fusion::p_ExprMulScalarVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarVar()" << this << std::endl; */ }mosek::fusion::ExprMulScalarVar::~ExprMulScalarVar() {  /* std::cout << "~ExprMulScalarVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarVar::p_ExprMulScalarVar  (::mosek::fusion::ExprMulScalarVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4053,    int _4054,    std::shared_ptr< monty::ndarray< int,1 > > _4055,    std::shared_ptr< monty::ndarray< int,1 > > _4056,    std::shared_ptr< monty::ndarray< double,1 > > _4057,    monty::rc_ptr< ::mosek::fusion::Variable > _4058){ return new mosek::fusion::ExprMulScalarVar(_4053,_4054,_4055,_4056,_4057,_4058); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4053,    int _4054,    std::shared_ptr< monty::ndarray< int,1 > > _4055,    std::shared_ptr< monty::ndarray< int,1 > > _4056,    std::shared_ptr< monty::ndarray< double,1 > > _4057,    monty::rc_ptr< ::mosek::fusion::Variable > _4058) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4053,_4054,_4055,_4056,_4057,_4058); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4053,    int _4054,    std::shared_ptr< monty::ndarray< int,1 > > _4055,    std::shared_ptr< monty::ndarray< int,1 > > _4056,    std::shared_ptr< monty::ndarray< double,1 > > _4057,    monty::rc_ptr< ::mosek::fusion::Variable > _4058){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4055(_4055 ? _4055->raw() : nullptr, _4055 ? _4055->size(0) : 0);
    _checked_ptr_1<int> _ptr__4056(_4056 ? _4056->raw() : nullptr, _4056 ? _4056->size(0) : 0);
    _checked_ptr_1<double> _ptr__4057(_4057 ? _4057->raw() : nullptr, _4057 ? _4057->size(0) : 0);
    mosek::fusion::p_ExprMulScalarVar::_initialize(_4053,_4054,::mosek::fusion::Utils::Tools::arraycopy(_4055),::mosek::fusion::Utils::Tools::arraycopy(_4056),::mosek::fusion::Utils::Tools::arraycopy(_4057),_4058,(int)1);
    if ((_4058->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid Variable size"));
      }
    }
    {}
    if (((_4053 < (int)0) || ((_4054 < (int)0) || (((int)((_4055)->size(0)) != (int)((_4056)->size(0))) || ((int)((_4055)->size(0)) != (int)((_4057)->size(0)))))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    int _8675 = (int)0;
    int _8676 = (int)((_4055)->size(0));
    for (int _4059 = _8675; _4059 < _8676; ++_4059)
    {
      {
        if (((_ptr__4055[_4059] < (int)0) || ((_ptr__4055[_4059] >= _4053) || ((_ptr__4056[_4059] < (int)0) || (_ptr__4056[_4059] >= _4054)))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid Matrix data"));
          }
        }
        {}
      }
    }
    int _8677 = (int)1;
    int _8678 = (int)((_4055)->size(0));
    for (int _4060 = _8677; _4060 < _8678; ++_4060)
    {
      {
        if (((_ptr__4055[_4060] < _ptr__4055[(_4060 - (int)1)]) || ((_ptr__4055[_4060] == _ptr__4055[(_4060 - (int)1)]) && (_ptr__4056[_4060] <= _ptr__4056[(_4060 - (int)1)]))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not correctly sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4061,    int _4062,    std::shared_ptr< monty::ndarray< int,1 > > _4063,    std::shared_ptr< monty::ndarray< int,1 > > _4064,    std::shared_ptr< monty::ndarray< double,1 > > _4065,    monty::rc_ptr< ::mosek::fusion::Variable > _4066,    int _4067){ return new mosek::fusion::ExprMulScalarVar(_4061,_4062,_4063,_4064,_4065,_4066,_4067); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4061,    int _4062,    std::shared_ptr< monty::ndarray< int,1 > > _4063,    std::shared_ptr< monty::ndarray< int,1 > > _4064,    std::shared_ptr< monty::ndarray< double,1 > > _4065,    monty::rc_ptr< ::mosek::fusion::Variable > _4066,    int _4067) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4061,_4062,_4063,_4064,_4065,_4066,_4067); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4061,    int _4062,    std::shared_ptr< monty::ndarray< int,1 > > _4063,    std::shared_ptr< monty::ndarray< int,1 > > _4064,    std::shared_ptr< monty::ndarray< double,1 > > _4065,    monty::rc_ptr< ::mosek::fusion::Variable > _4066,    int _4067){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4063(_4063 ? _4063->raw() : nullptr, _4063 ? _4063->size(0) : 0);
    _checked_ptr_1<int> _ptr__4064(_4064 ? _4064->raw() : nullptr, _4064 ? _4064->size(0) : 0);
    _checked_ptr_1<double> _ptr__4065(_4065 ? _4065->raw() : nullptr, _4065 ? _4065->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4061),(int)(_4062)}));
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimi = _4061;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimj = _4062;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubi = _4063;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubj = _4064;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mcof = _4065;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->x = _4066;
  }
}void mosek::fusion::ExprMulScalarVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4068,monty::rc_ptr< ::mosek::fusion::WorkStack > _4069,monty::rc_ptr< ::mosek::fusion::WorkStack > _4070) { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->eval(_4068,_4069,_4070); }void mosek::fusion::p_ExprMulScalarVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4068,monty::rc_ptr< ::mosek::fusion::WorkStack > _4069,monty::rc_ptr< ::mosek::fusion::WorkStack > _4070){
  if ((x->numInst() == (int)0))
  {
    {
      _4068->alloc_expr((int)2,(int)0,(int)0,false);
      ((*mosek::fusion::p_WorkStack::_get_impl(_4068)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4068)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4068)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4068)->shape_base,(int)1 ))) = mdimj;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4071 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1)));
      _checked_ptr_1<long long> _ptr__4071(_4071 ? _4071->raw() : nullptr,_4071 ? _4071->size(0) : 0);
      x->inst((int)0,_4071);
      long long _4072 = _ptr__4071[(int)0];
      int _4073 = (int)((msubi)->size(0));
      int _4074 = _4073;
      bool _4075 = (_4073 < safe_mul( mdimi,mdimj ));
      _4068->alloc_expr((int)2,_4073,_4074,_4075);
      int _4076 = mosek::fusion::p_WorkStack::_get_impl(_4068)->ptr_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4068)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4068)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4068)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4068)->shape_base,(int)1 ))) = mdimj;
      int _4077 = mosek::fusion::p_WorkStack::_get_impl(_4068)->nidxs_base;
      int _4078 = mosek::fusion::p_WorkStack::_get_impl(_4068)->sp_base;
      int _4079 = mosek::fusion::p_WorkStack::_get_impl(_4068)->cof_base;
      int _4080 = mosek::fusion::p_WorkStack::_get_impl(_4068)->bfix_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4081 = mosek::fusion::p_WorkStack::_get_impl(_4068)->i32;
      _checked_ptr_1<int> _ptr__4081(_4081 ? _4081->raw() : nullptr,_4081 ? _4081->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4082 = mosek::fusion::p_WorkStack::_get_impl(_4068)->i64;
      _checked_ptr_1<long long> _ptr__4082(_4082 ? _4082->raw() : nullptr,_4082 ? _4082->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4083 = mosek::fusion::p_WorkStack::_get_impl(_4068)->f64;
      _checked_ptr_1<double> _ptr__4083(_4083 ? _4083->raw() : nullptr,_4083 ? _4083->size(0) : 0);
      {
        int _8679 = (int)0;
        int _8680 = _4073;
        for (int _4084 = _8679; _4084 < _8680; ++_4084)
        {
          {
            _ptr__4083[safe_add( _4080,_4084 )] = (int)0;
          }
        }
        int _8681 = (int)0;
        int _8682 = _4074;
        for (int _4085 = _8681; _4085 < _8682; ++_4085)
        {
          {
            _ptr__4083[safe_add( _4079,_4085 )] = ((*mcof)(_4085));
          }
        }
        int _8683 = (int)0;
        int _8684 = _4074;
        for (int _4086 = _8683; _4086 < _8684; ++_4086)
        {
          {
            _ptr__4082[safe_add( _4077,_4086 )] = _4072;
          }
        }
        if (_4075)
        {
          {
            int _8685 = (int)0;
            int _8686 = _4073;
            for (int _4087 = _8685; _4087 < _8686; ++_4087)
            {
              {
                _ptr__4082[safe_add( _4078,_4087 )] = safe_add( safe_mul( ((*msubi)(_4087)),mdimj ),((*msubj)(_4087)) );
              }
            }
          }
        }
        {}
        int _8687 = (int)0;
        int _8688 = safe_add( _4073,(int)1 );
        for (int _4088 = _8687; _4088 < _8688; ++_4088)
        {
          {
            _ptr__4081[safe_add( _4076,_4088 )] = _4088;
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprMulScalarVar :: toString() { return mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulScalarVar(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("), "))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulScalarVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulScalarVar::destroy() { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst(mosek::fusion::p_ExprMulVarScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVarScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulVarScalarConst::~ExprMulVarScalarConst() {  /* std::cout << "~ExprMulVarScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVarScalarConst::p_ExprMulVarScalarConst  (::mosek::fusion::ExprMulVarScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVarScalarConst::t mosek::fusion::p_ExprMulVarScalarConst::_new_ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4089,    double _4090){ return new mosek::fusion::ExprMulVarScalarConst(_4089,_4090); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4089,    double _4090) :    ExprMulVarScalarConst(new mosek::fusion::p_ExprMulVarScalarConst(this)){ mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->_initialize(_4089,_4090); }void mosek::fusion::p_ExprMulVarScalarConst::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4089,    double _4090){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4089->getShape());
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->x = _4089;
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->c = _4090;
  }
}void mosek::fusion::ExprMulVarScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4091,monty::rc_ptr< ::mosek::fusion::WorkStack > _4092,monty::rc_ptr< ::mosek::fusion::WorkStack > _4093) { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->eval(_4091,_4092,_4093); }void mosek::fusion::p_ExprMulVarScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4091,monty::rc_ptr< ::mosek::fusion::WorkStack > _4092,monty::rc_ptr< ::mosek::fusion::WorkStack > _4093){
  int _4094 = x->numInst();
  int _4095 = _4094;
  std::shared_ptr< monty::ndarray< int,1 > > _4096 = x->getShape();
  _checked_ptr_1<int> _ptr__4096(_4096 ? _4096->raw() : nullptr,_4096 ? _4096->size(0) : 0);
  int _4097 = (int)((_4096)->size(0));
  int _4098 = _4091->alloci32(safe_add( _4095,(int)1 ));
  int _4099 = _4091->alloci64(_4094);
  bool _4100 = (::mosek::fusion::p_Set::size(_4096) > _4095);
  int _8689;
  bool _8690 = _4100;
  if (_8690)
  {
    _8689 = _4091->alloci64(_4095);
  }
  else
  {
    _8689 = (int)0;
  }
  int _4101 = _8689;
  int _4102 = _4091->allocf64(_4094);
  int _4103 = _4091->allocf64(_4095);
  if (_4100)
  {
    {
      x->inst(_4101,mosek::fusion::p_WorkStack::_get_impl(_4091)->i64,_4099,mosek::fusion::p_WorkStack::_get_impl(_4091)->i64);
    }
  }
  else
  {
    {
      x->inst(_4099,mosek::fusion::p_WorkStack::_get_impl(_4091)->i64);
    }
  }
  int _8691;
  bool _8692 = _4100;
  if (_8692)
  {
    _8691 = (int)1;
  }
  else
  {
    _8691 = (int)0;
  }
  _4091->pushi32(_8691);
  _4091->pushi32(_4095);
  _4091->pushi32(_4094);
  int _8693 = (int)0;
  int _8694 = _4097;
  for (int _4104 = _8693; _4104 < _8694; ++_4104)
  {
    {
      _4091->pushi32(_ptr__4096[_4104]);
    }
  }
  _4091->pushi32(_4097);
  std::shared_ptr< monty::ndarray< int,1 > > _4105 = mosek::fusion::p_WorkStack::_get_impl(_4091)->i32;
  _checked_ptr_1<int> _ptr__4105(_4105 ? _4105->raw() : nullptr,_4105 ? _4105->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4106 = mosek::fusion::p_WorkStack::_get_impl(_4091)->i64;
  _checked_ptr_1<long long> _ptr__4106(_4106 ? _4106->raw() : nullptr,_4106 ? _4106->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4107 = mosek::fusion::p_WorkStack::_get_impl(_4091)->f64;
  _checked_ptr_1<double> _ptr__4107(_4107 ? _4107->raw() : nullptr,_4107 ? _4107->size(0) : 0);
  {
    int _8695 = (int)0;
    int _8696 = safe_add( _4095,(int)1 );
    for (int _4108 = _8695; _4108 < _8696; ++_4108)
    {
      {
        _ptr__4105[safe_add( _4098,_4108 )] = _4108;
      }
    }
    int _8697 = (int)0;
    int _8698 = _4094;
    for (int _4109 = _8697; _4109 < _8698; ++_4109)
    {
      {
        _ptr__4107[safe_add( _4102,_4109 )] = 1.0;
      }
    }
    int _8699 = (int)0;
    int _8700 = _4095;
    for (int _4110 = _8699; _4110 < _8700; ++_4110)
    {
      {
        _ptr__4107[safe_add( _4103,_4110 )] = 0.0;
      }
    }
  }
}
std::string mosek::fusion::ExprMulVarScalarConst :: toString() { return mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVarScalarConst::toString(){
  return std::string ("ExprMulVarScalarConst()");
}
void mosek::fusion::p_ExprMulVarScalarConst::destroy(){x.reset();}void mosek::fusion::ExprMulVarScalarConst::destroy() { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprAdd::ExprAdd(mosek::fusion::p_ExprAdd *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprAdd()" << this << std::endl; */ }mosek::fusion::ExprAdd::~ExprAdd() {  /* std::cout << "~ExprAdd()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprAdd::p_ExprAdd  (::mosek::fusion::ExprAdd * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprAdd::t mosek::fusion::p_ExprAdd::_new_ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4111,    monty::rc_ptr< ::mosek::fusion::Expression > _4112,    double _4113,    double _4114){ return new mosek::fusion::ExprAdd(_4111,_4112,_4113,_4114); }mosek::fusion::ExprAdd::ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4111,    monty::rc_ptr< ::mosek::fusion::Expression > _4112,    double _4113,    double _4114) :    ExprAdd(new mosek::fusion::p_ExprAdd(this)){ mosek::fusion::p_ExprAdd::_get_impl(this)->_initialize(_4111,_4112,_4113,_4114); }void mosek::fusion::p_ExprAdd::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4111,    monty::rc_ptr< ::mosek::fusion::Expression > _4112,    double _4113,    double _4114){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4111->getShape());
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e1 = _4111;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e2 = _4112;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1 = _4113;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2 = _4114;
    if ((_4111->getND() != _4112->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
    int _8701 = (int)0;
    int _8702 = _4111->getND();
    for (int _4115 = _8701; _4115 < _8702; ++_4115)
    {
      {
        if ((_4111->getDim(_4115) != _4112->getDim(_4115)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprAdd :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4116,monty::rc_ptr< ::mosek::fusion::WorkStack > _4117,monty::rc_ptr< ::mosek::fusion::WorkStack > _4118) { mosek::fusion::p_ExprAdd::_get_impl(this)->eval(_4116,_4117,_4118); }void mosek::fusion::p_ExprAdd::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4116,monty::rc_ptr< ::mosek::fusion::WorkStack > _4117,monty::rc_ptr< ::mosek::fusion::WorkStack > _4118){
  e1->eval(_4117,_4116,_4118);
  e2->eval(_4117,_4116,_4118);
  _4117->pop_expr();
  int _4119 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nd;
  int _4120 = mosek::fusion::p_WorkStack::_get_impl(_4117)->shape_base;
  int _4121 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nelem;
  int _4122 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nnz;
  bool _4123 = mosek::fusion::p_WorkStack::_get_impl(_4117)->hassp;
  int _4124 = mosek::fusion::p_WorkStack::_get_impl(_4117)->ptr_base;
  int _4125 = mosek::fusion::p_WorkStack::_get_impl(_4117)->sp_base;
  int _4126 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nidxs_base;
  int _4127 = mosek::fusion::p_WorkStack::_get_impl(_4117)->bfix_base;
  int _4128 = mosek::fusion::p_WorkStack::_get_impl(_4117)->cof_base;
  _4117->pop_expr();
  int _4129 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nd;
  int _4130 = mosek::fusion::p_WorkStack::_get_impl(_4117)->shape_base;
  int _4131 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nelem;
  int _4132 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nnz;
  bool _4133 = mosek::fusion::p_WorkStack::_get_impl(_4117)->hassp;
  int _4134 = mosek::fusion::p_WorkStack::_get_impl(_4117)->ptr_base;
  int _4135 = mosek::fusion::p_WorkStack::_get_impl(_4117)->sp_base;
  int _4136 = mosek::fusion::p_WorkStack::_get_impl(_4117)->nidxs_base;
  int _4137 = mosek::fusion::p_WorkStack::_get_impl(_4117)->bfix_base;
  int _4138 = mosek::fusion::p_WorkStack::_get_impl(_4117)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4139 = mosek::fusion::p_WorkStack::_get_impl(_4117)->i32;
  _checked_ptr_1<int> _ptr__4139(_4139 ? _4139->raw() : nullptr,_4139 ? _4139->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4140 = mosek::fusion::p_WorkStack::_get_impl(_4117)->i64;
  _checked_ptr_1<long long> _ptr__4140(_4140 ? _4140->raw() : nullptr,_4140 ? _4140->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4141 = mosek::fusion::p_WorkStack::_get_impl(_4117)->f64;
  _checked_ptr_1<double> _ptr__4141(_4141 ? _4141->raw() : nullptr,_4141 ? _4141->size(0) : 0);
  if ((_4129 != _4119))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
  {}
  int _8703 = (int)0;
  int _8704 = _4129;
  for (int _4142 = _8703; _4142 < _8704; ++_4142)
  {
    {
      if ((_ptr__4139[safe_add( _4130,_4142 )] != _ptr__4139[safe_add( _4120,_4142 )]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      {}
    }
  }
  if (((!_4133) && (!_4123)))
  {
    {
      int _4143 = _4131;
      int _4144 = safe_add( _4132,_4122 );
      int _4145 = _4129;
      _4116->alloc_expr(_4145,_4143,_4144,false);
      int _4146 = mosek::fusion::p_WorkStack::_get_impl(_4116)->shape_base;
      int _4147 = mosek::fusion::p_WorkStack::_get_impl(_4116)->ptr_base;
      int _4148 = mosek::fusion::p_WorkStack::_get_impl(_4116)->sp_base;
      int _4149 = mosek::fusion::p_WorkStack::_get_impl(_4116)->nidxs_base;
      int _4150 = mosek::fusion::p_WorkStack::_get_impl(_4116)->bfix_base;
      int _4151 = mosek::fusion::p_WorkStack::_get_impl(_4116)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4152 = mosek::fusion::p_WorkStack::_get_impl(_4116)->i32;
      _checked_ptr_1<int> _ptr__4152(_4152 ? _4152->raw() : nullptr,_4152 ? _4152->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4153 = mosek::fusion::p_WorkStack::_get_impl(_4116)->i64;
      _checked_ptr_1<long long> _ptr__4153(_4153 ? _4153->raw() : nullptr,_4153 ? _4153->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4154 = mosek::fusion::p_WorkStack::_get_impl(_4116)->f64;
      _checked_ptr_1<double> _ptr__4154(_4154 ? _4154->raw() : nullptr,_4154 ? _4154->size(0) : 0);
      int _8705 = (int)0;
      int _8706 = _4145;
      for (int _4155 = _8705; _4155 < _8706; ++_4155)
      {
        {
          _ptr__4152[safe_add( _4146,_4155 )] = _ptr__4139[safe_add( _4130,_4155 )];
        }
      }
      int _4156 = (int)0;
      _ptr__4152[_4147] = (int)0;
      int _8707 = (int)0;
      int _8708 = _4143;
      for (int _4157 = _8707; _4157 < _8708; ++_4157)
      {
        {
          int _8709 = _ptr__4139[safe_add( _4134,_4157 )];
          int _8710 = _ptr__4139[safe_add( safe_add( _4134,_4157 ),(int)1 )];
          for (int _4158 = _8709; _4158 < _8710; ++_4158)
          {
            {
              _ptr__4153[safe_add( _4149,_4156 )] = _ptr__4140[safe_add( _4136,_4158 )];
              _ptr__4154[safe_add( _4151,_4156 )] = (_ptr__4141[safe_add( _4138,_4158 )] * m1);
              ++ _4156;
            }
          }
          int _8711 = _ptr__4139[safe_add( _4124,_4157 )];
          int _8712 = _ptr__4139[safe_add( safe_add( _4124,_4157 ),(int)1 )];
          for (int _4159 = _8711; _4159 < _8712; ++_4159)
          {
            {
              _ptr__4153[safe_add( _4149,_4156 )] = _ptr__4140[safe_add( _4126,_4159 )];
              _ptr__4154[safe_add( _4151,_4156 )] = (_ptr__4141[safe_add( _4128,_4159 )] * m2);
              ++ _4156;
            }
          }
          _ptr__4152[safe_add( safe_add( _4147,_4157 ),(int)1 )] = _4156;
          _ptr__4154[safe_add( _4150,_4157 )] = ((_ptr__4141[safe_add( _4137,_4157 )] * m1) + (_ptr__4141[safe_add( _4127,_4157 )] * m2));
        }
      }
    }
  }
  else if(((!_4133) || (!_4123)))
  {
    {
      if ((!_4123))
      {
        {
          int _4160 = _4121;
          int _4161 = _4122;
          int _4162 = _4124;
          int _4163 = _4125;
          int _4164 = _4126;
          int _4165 = _4127;
          int _4166 = _4128;
          _4121 = _4131;
          _4122 = _4132;
          _4124 = _4134;
          _4125 = _4135;
          _4126 = _4136;
          _4127 = _4137;
          _4128 = _4138;
          _4131 = _4160;
          _4132 = _4161;
          _4134 = _4162;
          _4135 = _4163;
          _4136 = _4164;
          _4137 = _4165;
          _4138 = _4166;
        }
      }
      {}
      double _8713;
      bool _8714 = (!_4133);
      if (_8714)
      {
        _8713 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      else
      {
        _8713 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      double _4167 = _8713;
      double _8715;
      bool _8716 = (!_4133);
      if (_8716)
      {
        _8715 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      else
      {
        _8715 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      double _4168 = _8715;
      int _4169 = _4131;
      int _4170 = safe_add( _4132,_4122 );
      int _4171 = _4129;
      _4116->alloc_expr(_4171,_4169,_4170,false);
      int _4172 = mosek::fusion::p_WorkStack::_get_impl(_4116)->shape_base;
      int _4173 = mosek::fusion::p_WorkStack::_get_impl(_4116)->ptr_base;
      int _4174 = mosek::fusion::p_WorkStack::_get_impl(_4116)->sp_base;
      int _4175 = mosek::fusion::p_WorkStack::_get_impl(_4116)->nidxs_base;
      int _4176 = mosek::fusion::p_WorkStack::_get_impl(_4116)->bfix_base;
      int _4177 = mosek::fusion::p_WorkStack::_get_impl(_4116)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4178 = mosek::fusion::p_WorkStack::_get_impl(_4116)->i32;
      _checked_ptr_1<int> _ptr__4178(_4178 ? _4178->raw() : nullptr,_4178 ? _4178->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4179 = mosek::fusion::p_WorkStack::_get_impl(_4116)->i64;
      _checked_ptr_1<long long> _ptr__4179(_4179 ? _4179->raw() : nullptr,_4179 ? _4179->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4180 = mosek::fusion::p_WorkStack::_get_impl(_4116)->f64;
      _checked_ptr_1<double> _ptr__4180(_4180 ? _4180->raw() : nullptr,_4180 ? _4180->size(0) : 0);
      {
        int _4181 = (int)0;
        int _8717 = (int)0;
        int _8718 = _4171;
        for (int _4182 = _8717; _4182 < _8718; ++_4182)
        {
          {
            _ptr__4178[safe_add( _4172,_4182 )] = _ptr__4139[safe_add( _4130,_4182 )];
          }
        }
        int _8719 = (int)0;
        int _8720 = safe_add( _4169,(int)1 );
        for (int _4183 = _8719; _4183 < _8720; ++_4183)
        {
          {
            _ptr__4178[safe_add( _4173,_4183 )] = (int)0;
          }
        }
        int _8721 = (int)0;
        int _8722 = _4131;
        for (int _4184 = _8721; _4184 < _8722; ++_4184)
        {
          {
            _ptr__4178[safe_add( safe_add( _4173,_4184 ),(int)1 )] += (_ptr__4139[safe_add( safe_add( _4134,_4184 ),(int)1 )] - _ptr__4139[safe_add( _4134,_4184 )]);
          }
        }
        int _8723 = (int)0;
        int _8724 = _4121;
        for (int _4185 = _8723; _4185 < _8724; ++_4185)
        {
          {
            long long _4186 = _ptr__4140[safe_add( _4125,_4185 )];
            _ptr__4178[safe_add( safe_add( _4173,_4186 ),(int)1 )] += (_ptr__4139[safe_add( safe_add( _4124,_4185 ),(int)1 )] - _ptr__4139[safe_add( _4124,_4185 )]);
          }
        }
        int _8725 = (int)0;
        int _8726 = _4169;
        for (int _4187 = _8725; _4187 < _8726; ++_4187)
        {
          {
            _ptr__4178[safe_add( safe_add( _4173,_4187 ),(int)1 )] += _ptr__4178[safe_add( _4173,_4187 )];
          }
        }
        int _8727 = (int)0;
        int _8728 = _4131;
        for (int _4188 = _8727; _4188 < _8728; ++_4188)
        {
          {
            int _4189 = _ptr__4178[safe_add( _4173,_4188 )];
            int _4190 = _ptr__4139[safe_add( _4134,_4188 )];
            int _4191 = (_ptr__4139[safe_add( safe_add( _4134,_4188 ),(int)1 )] - _ptr__4139[safe_add( _4134,_4188 )]);
            int _8729 = (int)0;
            int _8730 = _4191;
            for (int _4192 = _8729; _4192 < _8730; ++_4192)
            {
              {
                _ptr__4179[safe_add( safe_add( _4175,_4189 ),_4192 )] = _ptr__4140[safe_add( safe_add( _4136,_4190 ),_4192 )];
                _ptr__4180[safe_add( safe_add( _4177,_4189 ),_4192 )] = (_ptr__4141[safe_add( safe_add( _4138,_4190 ),_4192 )] * _4167);
              }
            }
            _ptr__4178[safe_add( _4173,_4188 )] += _4191;
            _ptr__4180[safe_add( _4176,_4188 )] = (_ptr__4141[safe_add( _4137,_4188 )] * _4167);
          }
        }
        int _8731 = (int)0;
        int _8732 = _4121;
        for (int _4193 = _8731; _4193 < _8732; ++_4193)
        {
          {
            long long _4194 = _ptr__4140[safe_add( _4125,_4193 )];
            int _4195 = _ptr__4178[safe_add( _4173,_4194 )];
            int _4196 = _ptr__4139[safe_add( _4124,_4193 )];
            int _4197 = (_ptr__4139[safe_add( safe_add( _4124,_4193 ),(int)1 )] - _ptr__4139[safe_add( _4124,_4193 )]);
            int _8733 = (int)0;
            int _8734 = _4197;
            for (int _4198 = _8733; _4198 < _8734; ++_4198)
            {
              {
                _ptr__4179[safe_add( safe_add( _4175,_4195 ),_4198 )] = _ptr__4140[safe_add( safe_add( _4126,_4196 ),_4198 )];
                _ptr__4180[safe_add( safe_add( _4177,_4195 ),_4198 )] = (_ptr__4141[safe_add( safe_add( _4128,_4196 ),_4198 )] * _4168);
              }
            }
            _ptr__4178[safe_add( _4173,_4194 )] += _4197;
            _ptr__4180[safe_add( _4176,_4194 )] += (_ptr__4141[safe_add( _4127,_4193 )] * _4168);
          }
        }
        int _8735 = (int)0;
        int _8736 = _4169;
        for (int _4199 = _8735; _4199 < _8736; ++_4199)
        {
          {
            _ptr__4178[(safe_add( _4173,_4169 ) - _4199)] = _ptr__4178[((safe_add( _4173,_4169 ) - _4199) - (int)1)];
          }
        }
        _ptr__4178[_4173] = (int)0;
      }
    }
  }
  else
  {
    {
      int _4200 = safe_add( _4132,_4122 );
      int _4201 = (int)0;
      int _4202 = _4129;
      long long _4203 = (long long)1;
      int _8737 = (int)0;
      int _8738 = _4202;
      for (int _4204 = _8737; _4204 < _8738; ++_4204)
      {
        {
          _4203 *= _ptr__4139[safe_add( _4130,_4204 )];
        }
      }
      {
        int _4205 = (int)0;
        int _4206 = (int)0;
        while ( ((_4206 < _4131) && (_4205 < _4121)) )
        {
          {
            if ((_ptr__4140[safe_add( _4135,_4206 )] < _ptr__4140[safe_add( _4125,_4205 )]))
            {
              {
                ++ _4201;
                ++ _4206;
              }
            }
            else if((_ptr__4140[safe_add( _4135,_4206 )] > _ptr__4140[safe_add( _4125,_4205 )]))
            {
              {
                ++ _4201;
                ++ _4205;
              }
            }
            else
            {
              {
                ++ _4201;
                ++ _4206;
                ++ _4205;
              }
            }
          }
        }
        _4201 += (safe_add( (_4131 - _4206),_4121 ) - _4205);
      }
      bool _4207 = (_4201 < _4203);
      _4116->alloc_expr(_4202,_4201,_4200,_4207);
      int _4208 = mosek::fusion::p_WorkStack::_get_impl(_4116)->shape_base;
      int _4209 = mosek::fusion::p_WorkStack::_get_impl(_4116)->ptr_base;
      int _8739;
      bool _8740 = _4207;
      if (_8740)
      {
        _8739 = mosek::fusion::p_WorkStack::_get_impl(_4116)->sp_base;
      }
      else
      {
        _8739 = _4116->alloci64(_4201);
      }
      int _4210 = _8739;
      int _4211 = mosek::fusion::p_WorkStack::_get_impl(_4116)->nidxs_base;
      int _4212 = mosek::fusion::p_WorkStack::_get_impl(_4116)->bfix_base;
      int _4213 = mosek::fusion::p_WorkStack::_get_impl(_4116)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4214 = mosek::fusion::p_WorkStack::_get_impl(_4116)->i32;
      _checked_ptr_1<int> _ptr__4214(_4214 ? _4214->raw() : nullptr,_4214 ? _4214->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4215 = mosek::fusion::p_WorkStack::_get_impl(_4116)->i64;
      _checked_ptr_1<long long> _ptr__4215(_4215 ? _4215->raw() : nullptr,_4215 ? _4215->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4216 = mosek::fusion::p_WorkStack::_get_impl(_4116)->f64;
      _checked_ptr_1<double> _ptr__4216(_4216 ? _4216->raw() : nullptr,_4216 ? _4216->size(0) : 0);
      int _8741 = (int)0;
      int _8742 = _4202;
      for (int _4217 = _8741; _4217 < _8742; ++_4217)
      {
        {
          _ptr__4214[safe_add( _4208,_4217 )] = _ptr__4139[safe_add( _4130,_4217 )];
        }
      }
      {
        _ptr__4214[_4209] = (int)0;
        int _4218 = (int)0;
        int _4219 = (int)0;
        int _4220 = (int)0;
        int _4221 = (int)0;
        while ( ((_4221 < _4131) && (_4220 < _4121)) )
        {
          {
            if ((_ptr__4140[safe_add( _4135,_4221 )] < _ptr__4140[safe_add( _4125,_4220 )]))
            {
              {
                int _8743 = _ptr__4139[safe_add( _4134,_4221 )];
                int _8744 = _ptr__4139[safe_add( safe_add( _4134,_4221 ),(int)1 )];
                for (int _4222 = _8743; _4222 < _8744; ++_4222)
                {
                  {
                    _ptr__4215[safe_add( _4211,_4219 )] = _ptr__4140[safe_add( _4136,_4222 )];
                    _ptr__4216[safe_add( _4213,_4219 )] = (m1 * _ptr__4141[safe_add( _4138,_4222 )]);
                    ++ _4219;
                  }
                }
                _ptr__4216[safe_add( _4212,_4218 )] = (m1 * _ptr__4141[safe_add( _4137,_4221 )]);
                _ptr__4215[safe_add( _4210,_4218 )] = _ptr__4140[safe_add( _4135,_4221 )];
                _ptr__4214[safe_add( safe_add( _4209,_4218 ),(int)1 )] = _4219;
                ++ _4218;
                ++ _4221;
              }
            }
            else if((_ptr__4140[safe_add( _4125,_4220 )] < _ptr__4140[safe_add( _4135,_4221 )]))
            {
              {
                int _8745 = _ptr__4139[safe_add( _4124,_4220 )];
                int _8746 = _ptr__4139[safe_add( safe_add( _4124,_4220 ),(int)1 )];
                for (int _4223 = _8745; _4223 < _8746; ++_4223)
                {
                  {
                    _ptr__4215[safe_add( _4211,_4219 )] = _ptr__4140[safe_add( _4126,_4223 )];
                    _ptr__4216[safe_add( _4213,_4219 )] = (m2 * _ptr__4141[safe_add( _4128,_4223 )]);
                    ++ _4219;
                  }
                }
                _ptr__4216[safe_add( _4212,_4218 )] = (m1 * _ptr__4141[safe_add( _4127,_4221 )]);
                _ptr__4215[safe_add( _4210,_4218 )] = _ptr__4140[safe_add( _4125,_4220 )];
                _ptr__4214[safe_add( safe_add( _4209,_4218 ),(int)1 )] = _4219;
                ++ _4218;
                ++ _4220;
              }
            }
            else
            {
              {
                int _8747 = _ptr__4139[safe_add( _4134,_4221 )];
                int _8748 = _ptr__4139[safe_add( safe_add( _4134,_4221 ),(int)1 )];
                for (int _4224 = _8747; _4224 < _8748; ++_4224)
                {
                  {
                    _ptr__4215[safe_add( _4211,_4219 )] = _ptr__4140[safe_add( _4136,_4224 )];
                    _ptr__4216[safe_add( _4213,_4219 )] = (m1 * _ptr__4141[safe_add( _4138,_4224 )]);
                    ++ _4219;
                  }
                }
                int _8749 = _ptr__4139[safe_add( _4124,_4220 )];
                int _8750 = _ptr__4139[safe_add( safe_add( _4124,_4220 ),(int)1 )];
                for (int _4225 = _8749; _4225 < _8750; ++_4225)
                {
                  {
                    _ptr__4215[safe_add( _4211,_4219 )] = _ptr__4140[safe_add( _4126,_4225 )];
                    _ptr__4216[safe_add( _4213,_4219 )] = (m2 * _ptr__4141[safe_add( _4128,_4225 )]);
                    ++ _4219;
                  }
                }
                _ptr__4216[safe_add( _4212,_4218 )] = ((m1 * _ptr__4141[safe_add( _4137,_4221 )]) + (m2 * _ptr__4141[safe_add( _4127,_4220 )]));
                _ptr__4215[safe_add( _4210,_4218 )] = _ptr__4140[safe_add( _4135,_4221 )];
                _ptr__4214[safe_add( safe_add( _4209,_4218 ),(int)1 )] = _4219;
                ++ _4218;
                ++ _4221;
                ++ _4220;
              }
            }
          }
        }
        while ( (_4221 < _4131) )
        {
          {
            int _8751 = _ptr__4139[safe_add( _4134,_4221 )];
            int _8752 = _ptr__4139[safe_add( safe_add( _4134,_4221 ),(int)1 )];
            for (int _4226 = _8751; _4226 < _8752; ++_4226)
            {
              {
                _ptr__4215[safe_add( _4211,_4219 )] = _ptr__4140[safe_add( _4136,_4226 )];
                _ptr__4216[safe_add( _4213,_4219 )] = (m1 * _ptr__4141[safe_add( _4138,_4226 )]);
                ++ _4219;
              }
            }
            _ptr__4216[safe_add( _4212,_4218 )] = (m1 * _ptr__4141[safe_add( _4137,_4221 )]);
            _ptr__4215[safe_add( _4210,_4218 )] = _ptr__4140[safe_add( _4135,_4221 )];
            _ptr__4214[safe_add( safe_add( _4209,_4218 ),(int)1 )] = _4219;
            ++ _4218;
            ++ _4221;
          }
        }
        while ( (_4220 < _4121) )
        {
          {
            int _8753 = _ptr__4139[safe_add( _4124,_4220 )];
            int _8754 = _ptr__4139[safe_add( safe_add( _4124,_4220 ),(int)1 )];
            for (int _4227 = _8753; _4227 < _8754; ++_4227)
            {
              {
                _ptr__4215[safe_add( _4211,_4219 )] = _ptr__4140[safe_add( _4126,_4227 )];
                _ptr__4216[safe_add( _4213,_4219 )] = (m2 * _ptr__4141[safe_add( _4128,_4227 )]);
                ++ _4219;
              }
            }
            _ptr__4216[safe_add( _4212,_4218 )] = (m1 * _ptr__4141[safe_add( _4127,_4220 )]);
            _ptr__4215[safe_add( _4210,_4218 )] = _ptr__4140[safe_add( _4125,_4220 )];
            _ptr__4214[safe_add( safe_add( _4209,_4218 ),(int)1 )] = _4219;
            ++ _4218;
            ++ _4220;
          }
        }
      }
      if ((!_4207))
      {
        {
          _4116->popi64(_4201);
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprAdd :: toString() { return mosek::fusion::p_ExprAdd::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprAdd::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprAdd("))->__mosek_2fusion_2Utils_2StringBuffer__a(e1->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e2->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprAdd::destroy(){e2.reset();e1.reset();}void mosek::fusion::ExprAdd::destroy() { mosek::fusion::p_ExprAdd::_get_impl(this)->destroy(); }mosek::fusion::ExprWSum::ExprWSum(mosek::fusion::p_ExprWSum *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprWSum()" << this << std::endl; */ }mosek::fusion::ExprWSum::~ExprWSum() {  /* std::cout << "~ExprWSum()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprWSum::p_ExprWSum  (::mosek::fusion::ExprWSum * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprWSum::t mosek::fusion::p_ExprWSum::_new_ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4228,    std::shared_ptr< monty::ndarray< double,1 > > _4229){ return new mosek::fusion::ExprWSum(_4228,_4229); }mosek::fusion::ExprWSum::ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4228,    std::shared_ptr< monty::ndarray< double,1 > > _4229) :    ExprWSum(new mosek::fusion::p_ExprWSum(this)){ mosek::fusion::p_ExprWSum::_get_impl(this)->_initialize(_4228,_4229); }void mosek::fusion::p_ExprWSum::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4228,    std::shared_ptr< monty::ndarray< double,1 > > _4229){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__4229(_4229 ? _4229->raw() : nullptr, _4229 ? _4229->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(((*_4228)((int)0))->getShape());
    if (((int)((_4229)->size(0)) != (int)((_4228)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching weights and expressions array lengths"));
      }
    }
    {}
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->w = ::mosek::fusion::Utils::Tools::arraycopy(_4229);
    std::shared_ptr< monty::ndarray< int,1 > > _4230 = ((*_4228)((int)0))->getShape();
    _checked_ptr_1<int> _ptr__4230(_4230 ? _4230->raw() : nullptr,_4230 ? _4230->size(0) : 0);
    int _4231 = (int)((_4230)->size(0));
    int _8755 = (int)1;
    int _8756 = (int)((_4228)->size(0));
    for (int _4232 = _8755; _4232 < _8756; ++_4232)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4233 = ((*_4228)(_4232))->getShape();
        _checked_ptr_1<int> _ptr__4233(_4233 ? _4233->raw() : nullptr,_4233 ? _4233->size(0) : 0);
        if ((_4231 != (int)((_4233)->size(0))))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
          }
        }
        else
        {
          {
            int _8757 = (int)0;
            int _8758 = _4231;
            for (int _4234 = _8757; _4234 < _8758; ++_4234)
            {
              {
                if ((_ptr__4230[_4234] != _ptr__4233[_4234]))
                {
                  {
                    throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8759;
    for (int _4235 = (int)0, _8760 = (int)((_4228)->size(0)); _4235 < _8760 ; ++_4235)
    {
      _8759.push_back(((*_4228)(_4235)));
    }
    auto _8761 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8759.size()),_8759.begin(),_8759.end()));
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->es = _8761;
  }
}void mosek::fusion::ExprWSum :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4236,monty::rc_ptr< ::mosek::fusion::WorkStack > _4237,monty::rc_ptr< ::mosek::fusion::WorkStack > _4238) { mosek::fusion::p_ExprWSum::_get_impl(this)->eval(_4236,_4237,_4238); }void mosek::fusion::p_ExprWSum::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4236,monty::rc_ptr< ::mosek::fusion::WorkStack > _4237,monty::rc_ptr< ::mosek::fusion::WorkStack > _4238){
  int _4239 = (int)((es)->size(0));
  int _8762 = (int)0;
  int _8763 = _4239;
  for (int _4240 = _8762; _4240 < _8763; ++_4240)
  {
    {
      ((*es)(_4240))->eval(_4237,_4236,_4238);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4241 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
  _checked_ptr_1<int> _ptr__4241(_4241 ? _4241->raw() : nullptr,_4241 ? _4241->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4242 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
  _checked_ptr_1<int> _ptr__4242(_4242 ? _4242->raw() : nullptr,_4242 ? _4242->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4243 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
  _checked_ptr_1<int> _ptr__4243(_4243 ? _4243->raw() : nullptr,_4243 ? _4243->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4244 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
  _checked_ptr_1<int> _ptr__4244(_4244 ? _4244->raw() : nullptr,_4244 ? _4244->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4245 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
  _checked_ptr_1<int> _ptr__4245(_4245 ? _4245->raw() : nullptr,_4245 ? _4245->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4246 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
  _checked_ptr_1<int> _ptr__4246(_4246 ? _4246->raw() : nullptr,_4246 ? _4246->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4247 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
  _checked_ptr_1<int> _ptr__4247(_4247 ? _4247->raw() : nullptr,_4247 ? _4247->size(0) : 0);
  int _4248 = _4237->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4249 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4248)));
  _checked_ptr_1<int> _ptr__4249(_4249 ? _4249->raw() : nullptr,_4249 ? _4249->size(0) : 0);
  _4237->popi32(_4248,_4249,(int)0);
  {
    _ptr__4241[(_4239 - (int)1)] = _4237->popi32();
    _ptr__4242[(_4239 - (int)1)] = _4237->popi32();
    bool _4250 = (_4237->popi32() != (int)0);
    _ptr__4243[(_4239 - (int)1)] = _4237->popi32(safe_add( _ptr__4241[(_4239 - (int)1)],(int)1 ));
    int _8764;
    bool _8765 = _4250;
    if (_8765)
    {
      _8764 = _4237->popi64(_ptr__4241[(_4239 - (int)1)]);
    }
    else
    {
      _8764 = (-(int)1);
    }
    _ptr__4245[(_4239 - (int)1)] = _8764;
    _ptr__4244[(_4239 - (int)1)] = _4237->popi64(_ptr__4242[(_4239 - (int)1)]);
    _ptr__4247[(_4239 - (int)1)] = _4237->popf64(_ptr__4241[(_4239 - (int)1)]);
    _ptr__4246[(_4239 - (int)1)] = _4237->popf64(_ptr__4242[(_4239 - (int)1)]);
  }
  int _8766 = (int)1;
  int _8767 = _4239;
  for (int _4251 = _8766; _4251 < _8767; ++_4251)
  {
    {
      int _4252 = ((_4239 - _4251) - (int)1);
      _4237->popi32();
      _4237->popi32(_4248);
      _ptr__4241[_4252] = _4237->popi32();
      _ptr__4242[_4252] = _4237->popi32();
      bool _4253 = (_4237->popi32() != (int)0);
      _ptr__4243[_4252] = _4237->popi32(safe_add( _ptr__4241[_4252],(int)1 ));
      int _8768;
      bool _8769 = _4253;
      if (_8769)
      {
        _8768 = _4237->popi64(_ptr__4241[_4252]);
      }
      else
      {
        _8768 = (-(int)1);
      }
      _ptr__4245[_4252] = _8768;
      _ptr__4244[_4252] = _4237->popi64(_ptr__4242[_4252]);
      _ptr__4247[_4252] = _4237->popf64(_ptr__4241[_4252]);
      _ptr__4246[_4252] = _4237->popf64(_ptr__4242[_4252]);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4254 = mosek::fusion::p_WorkStack::_get_impl(_4237)->i32;
  _checked_ptr_1<int> _ptr__4254(_4254 ? _4254->raw() : nullptr,_4254 ? _4254->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4255 = mosek::fusion::p_WorkStack::_get_impl(_4237)->i64;
  _checked_ptr_1<long long> _ptr__4255(_4255 ? _4255->raw() : nullptr,_4255 ? _4255->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4256 = mosek::fusion::p_WorkStack::_get_impl(_4237)->f64;
  _checked_ptr_1<double> _ptr__4256(_4256 ? _4256->raw() : nullptr,_4256 ? _4256->size(0) : 0);
  bool _4257 = false;
  int _8770 = (int)0;
  int _8771 = _4239;
  for (int _4258 = _8770; _4258 < _8771; ++_4258)
  {
    {
      if ((_ptr__4245[_4258] < (int)0))
      {
        {
          _4257 = true;
        }
      }
      {}
    }
  }
  int _4259 = (int)0;
  int _4260 = (int)0;
  if (_4257)
  {
    {
      _4259 = (int)::mosek::fusion::p_Set::size(_4249);
      int _8772 = (int)0;
      int _8773 = _4239;
      for (int _4261 = _8772; _4261 < _8773; ++_4261)
      {
        {
          _4260 += _ptr__4242[_4261];
        }
      }
    }
  }
  else
  {
    {
      bool _4262 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4263 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
      _checked_ptr_1<int> _ptr__4263(_4263 ? _4263->raw() : nullptr,_4263 ? _4263->size(0) : 0);
      int _8774 = (int)0;
      int _8775 = _4239;
      for (int _4264 = _8774; _4264 < _8775; ++_4264)
      {
        {
          _4260 += _ptr__4242[_4264];
        }
      }
      while ( (!_4262) )
      {
        {
          long long _4265 = (-(int)1);
          int _8776 = (int)0;
          int _8777 = _4239;
          for (int _4266 = _8776; _4266 < _8777; ++_4266)
          {
            {
              if (((_ptr__4263[_4266] < _ptr__4241[_4266]) && ((_4265 < (int)0) || (_ptr__4255[safe_add( _ptr__4245[_4266],_ptr__4263[_4266] )] < _4265))))
              {
                {
                  _4265 = _ptr__4255[safe_add( _ptr__4245[_4266],_ptr__4263[_4266] )];
                }
              }
              {}
            }
          }
          if ((_4265 < (int)0))
          {
            {
              _4262 = true;
            }
          }
          else
          {
            {
              int _8778 = (int)0;
              int _8779 = _4239;
              for (int _4267 = _8778; _4267 < _8779; ++_4267)
              {
                {
                  if (((_ptr__4263[_4267] < _ptr__4241[_4267]) && (_4265 == _ptr__4255[safe_add( _ptr__4245[_4267],_ptr__4263[_4267] )])))
                  {
                    {
                      ++ _ptr__4263[_4267];
                    }
                  }
                  {}
                }
              }
              ++ _4259;
            }
          }
        }
      }
    }
  }
  int _4268 = _4236->alloci32(safe_add( _4259,(int)1 ));
  int _4269 = _4236->alloci64(_4260);
  int _8780;
  bool _8781 = (!_4257);
  if (_8781)
  {
    _8780 = _4236->alloci64(_4259);
  }
  else
  {
    _8780 = (-(int)1);
  }
  int _4270 = _8780;
  int _4271 = _4236->allocf64(_4260);
  int _4272 = _4236->allocf64(_4259);
  int _8782;
  bool _8783 = _4257;
  if (_8783)
  {
    _8782 = (int)0;
  }
  else
  {
    _8782 = (int)1;
  }
  _4236->pushi32(_8782);
  _4236->pushi32(_4260);
  _4236->pushi32(_4259);
  int _8784 = (int)0;
  int _8785 = _4248;
  for (int _4273 = _8784; _4273 < _8785; ++_4273)
  {
    {
      _4236->pushi32(_ptr__4249[_4273]);
    }
  }
  _4236->pushi32(_4248);
  std::shared_ptr< monty::ndarray< int,1 > > _4274 = mosek::fusion::p_WorkStack::_get_impl(_4236)->i32;
  _checked_ptr_1<int> _ptr__4274(_4274 ? _4274->raw() : nullptr,_4274 ? _4274->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4275 = mosek::fusion::p_WorkStack::_get_impl(_4236)->i64;
  _checked_ptr_1<long long> _ptr__4275(_4275 ? _4275->raw() : nullptr,_4275 ? _4275->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4276 = mosek::fusion::p_WorkStack::_get_impl(_4236)->f64;
  _checked_ptr_1<double> _ptr__4276(_4276 ? _4276->raw() : nullptr,_4276 ? _4276->size(0) : 0);
  _ptr__4274[_4268] = (int)0;
  int _8786 = (int)0;
  int _8787 = _4259;
  for (int _4277 = _8786; _4277 < _8787; ++_4277)
  {
    {
      _ptr__4276[safe_add( _4272,_4277 )] = 0.0;
    }
  }
  int _8788 = (int)0;
  int _8789 = safe_add( _4259,(int)1 );
  for (int _4278 = _8788; _4278 < _8789; ++_4278)
  {
    {
      _ptr__4274[safe_add( _4268,_4278 )] = (int)0;
    }
  }
  if (_4257)
  {
    {
      int _8790 = (int)0;
      int _8791 = _4239;
      for (int _4279 = _8790; _4279 < _8791; ++_4279)
      {
        {
          if ((_ptr__4245[_4279] >= (int)0))
          {
            {
              int _8792 = (int)0;
              int _8793 = _ptr__4241[_4279];
              for (int _4280 = _8792; _4280 < _8793; ++_4280)
              {
                {
                  _ptr__4274[safe_add( safe_add( _4268,_ptr__4255[safe_add( _ptr__4245[_4279],_4280 )] ),(int)1 )] += (_ptr__4254[safe_add( safe_add( _ptr__4243[_4279],_4280 ),(int)1 )] - _ptr__4254[safe_add( _ptr__4243[_4279],_4280 )]);
                }
              }
            }
          }
          else
          {
            {
              int _8794 = (int)0;
              int _8795 = _ptr__4241[_4279];
              for (int _4281 = _8794; _4281 < _8795; ++_4281)
              {
                {
                  _ptr__4274[safe_add( safe_add( _4268,_4281 ),(int)1 )] += (_ptr__4254[safe_add( safe_add( _ptr__4243[_4279],_4281 ),(int)1 )] - _ptr__4254[safe_add( _ptr__4243[_4279],_4281 )]);
                }
              }
            }
          }
        }
      }
      int _8796 = (int)0;
      int _8797 = _4259;
      for (int _4282 = _8796; _4282 < _8797; ++_4282)
      {
        {
          _ptr__4274[safe_add( safe_add( _4268,_4282 ),(int)1 )] += _ptr__4274[safe_add( _4268,_4282 )];
        }
      }
      int _8798 = (int)0;
      int _8799 = _4239;
      for (int _4283 = _8798; _4283 < _8799; ++_4283)
      {
        {
          if ((_ptr__4245[_4283] >= (int)0))
          {
            {
              int _8800 = (int)0;
              int _8801 = _ptr__4241[_4283];
              for (int _4284 = _8800; _4284 < _8801; ++_4284)
              {
                {
                  int _4285 = _ptr__4254[safe_add( _ptr__4243[_4283],_4284 )];
                  int _4286 = _ptr__4254[safe_add( safe_add( _ptr__4243[_4283],_4284 ),(int)1 )];
                  long long _4287 = _ptr__4255[safe_add( _ptr__4245[_4283],_4284 )];
                  int _4288 = _ptr__4274[safe_add( _4268,_4287 )];
                  int _8802 = _4285;
                  int _8803 = _4286;
                  for (int _4289 = _8802; _4289 < _8803; ++_4289)
                  {
                    {
                      _ptr__4275[safe_add( _4269,_4288 )] = _ptr__4255[safe_add( _ptr__4244[_4283],_4289 )];
                      _ptr__4276[safe_add( _4271,_4288 )] = (((*w)(_4283)) * _ptr__4256[safe_add( _ptr__4246[_4283],_4289 )]);
                      ++ _4288;
                    }
                  }
                  _ptr__4276[safe_add( _4272,_4287 )] += (((*w)(_4283)) * _ptr__4256[safe_add( _ptr__4247[_4283],_4284 )]);
                  _ptr__4274[safe_add( _4268,_4287 )] += (_4286 - _4285);
                }
              }
            }
          }
          else
          {
            {
              int _8804 = (int)0;
              int _8805 = _ptr__4241[_4283];
              for (int _4290 = _8804; _4290 < _8805; ++_4290)
              {
                {
                  int _4291 = _ptr__4254[safe_add( _ptr__4243[_4283],_4290 )];
                  int _4292 = _ptr__4254[safe_add( safe_add( _ptr__4243[_4283],_4290 ),(int)1 )];
                  int _4293 = _4290;
                  int _4294 = _ptr__4274[safe_add( _4268,_4293 )];
                  int _8806 = _4291;
                  int _8807 = _4292;
                  for (int _4295 = _8806; _4295 < _8807; ++_4295)
                  {
                    {
                      _ptr__4275[safe_add( _4269,_4294 )] = _ptr__4255[safe_add( _ptr__4244[_4283],_4295 )];
                      _ptr__4276[safe_add( _4271,_4294 )] = (((*w)(_4283)) * _ptr__4256[safe_add( _ptr__4246[_4283],_4295 )]);
                      ++ _4294;
                    }
                  }
                  _ptr__4276[safe_add( _4272,_4293 )] += (((*w)(_4283)) * _ptr__4256[safe_add( _ptr__4247[_4283],_4290 )]);
                  _ptr__4274[safe_add( _4268,_4293 )] += (_4292 - _4291);
                }
              }
            }
          }
        }
      }
      int _8808 = (int)0;
      int _8809 = _4259;
      for (int _4296 = _8808; _4296 < _8809; ++_4296)
      {
        {
          _ptr__4274[(safe_add( _4268,_4259 ) - _4296)] = _ptr__4274[((safe_add( _4268,_4259 ) - _4296) - (int)1)];
        }
      }
      _ptr__4274[_4268] = (int)0;
    }
  }
  else
  {
    {
      bool _4297 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4298 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4239)));
      _checked_ptr_1<int> _ptr__4298(_4298 ? _4298->raw() : nullptr,_4298 ? _4298->size(0) : 0);
      int _4299 = (int)0;
      int _4300 = (int)0;
      while ( (!_4297) )
      {
        {
          long long _4301 = (-(int)1);
          int _8810 = (int)0;
          int _8811 = _4239;
          for (int _4302 = _8810; _4302 < _8811; ++_4302)
          {
            {
              if (((_ptr__4298[_4302] < _ptr__4241[_4302]) && ((_4301 < (int)0) || (_ptr__4255[safe_add( _ptr__4245[_4302],_ptr__4298[_4302] )] < _4301))))
              {
                {
                  _4301 = _ptr__4255[safe_add( _ptr__4245[_4302],_ptr__4298[_4302] )];
                }
              }
              {}
            }
          }
          if ((_4301 < (int)0))
          {
            {
              _4297 = true;
            }
          }
          else
          {
            {
              int _8812 = (int)0;
              int _8813 = _4239;
              for (int _4303 = _8812; _4303 < _8813; ++_4303)
              {
                {
                  if (((_ptr__4298[_4303] < _ptr__4241[_4303]) && (_4301 == _ptr__4255[safe_add( _ptr__4245[_4303],_ptr__4298[_4303] )])))
                  {
                    {
                      int _8814 = _ptr__4254[safe_add( _ptr__4243[_4303],_ptr__4298[_4303] )];
                      int _8815 = _ptr__4254[safe_add( safe_add( _ptr__4243[_4303],_ptr__4298[_4303] ),(int)1 )];
                      for (int _4304 = _8814; _4304 < _8815; ++_4304)
                      {
                        {
                          _ptr__4275[safe_add( _4269,_4300 )] = _ptr__4255[safe_add( _ptr__4244[_4303],_4304 )];
                          _ptr__4276[safe_add( _4271,_4300 )] = (((*w)(_4303)) * _ptr__4256[safe_add( _ptr__4246[_4303],_4304 )]);
                          ++ _4300;
                        }
                      }
                      _ptr__4276[safe_add( _4272,_4299 )] += (((*w)(_4303)) * _ptr__4256[safe_add( _ptr__4247[_4303],_ptr__4298[_4303] )]);
                      ++ _ptr__4298[_4303];
                    }
                  }
                  {}
                }
              }
              _ptr__4274[safe_add( safe_add( _4268,_4299 ),(int)1 )] = _4300;
              _ptr__4275[safe_add( _4270,_4299 )] = _4301;
            }
          }
          ++ _4299;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprWSum :: toString() { return mosek::fusion::p_ExprWSum::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprWSum::toString(){
  return std::string ("ExprWSum()");
}
void mosek::fusion::p_ExprWSum::destroy(){w.reset();es.reset();}void mosek::fusion::ExprWSum::destroy() { mosek::fusion::p_ExprWSum::_get_impl(this)->destroy(); }mosek::fusion::ExprSumReduce::ExprSumReduce(mosek::fusion::p_ExprSumReduce *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSumReduce()" << this << std::endl; */ }mosek::fusion::ExprSumReduce::~ExprSumReduce() {  /* std::cout << "~ExprSumReduce()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSumReduce::p_ExprSumReduce  (::mosek::fusion::ExprSumReduce * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSumReduce::t mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce  (int _4305,    monty::rc_ptr< ::mosek::fusion::Expression > _4306){ return new mosek::fusion::ExprSumReduce(_4305,_4306); }mosek::fusion::ExprSumReduce::ExprSumReduce  (int _4305,    monty::rc_ptr< ::mosek::fusion::Expression > _4306) :    ExprSumReduce(new mosek::fusion::p_ExprSumReduce(this)){ mosek::fusion::p_ExprSumReduce::_get_impl(this)->_initialize(_4305,_4306); }void mosek::fusion::p_ExprSumReduce::_initialize  (int _4305,    monty::rc_ptr< ::mosek::fusion::Expression > _4306){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSumReduce::computeShape(_4305,_4306->getShape()));
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->expr = _4306;
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->dim = _4305;
    std::shared_ptr< monty::ndarray< int,1 > > _4307 = _4306->getShape();
    _checked_ptr_1<int> _ptr__4307(_4307 ? _4307->raw() : nullptr,_4307 ? _4307->size(0) : 0);
    if (((int)((_4307)->size(0)) <= _4305))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid summing dimension"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSumReduce :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4308,monty::rc_ptr< ::mosek::fusion::WorkStack > _4309,monty::rc_ptr< ::mosek::fusion::WorkStack > _4310) { mosek::fusion::p_ExprSumReduce::_get_impl(this)->eval(_4308,_4309,_4310); }void mosek::fusion::p_ExprSumReduce::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4308,monty::rc_ptr< ::mosek::fusion::WorkStack > _4309,monty::rc_ptr< ::mosek::fusion::WorkStack > _4310){
  expr->eval(_4309,_4308,_4310);
  _4309->pop_expr();
  int _4311 = mosek::fusion::p_WorkStack::_get_impl(_4309)->nd;
  int _4312 = mosek::fusion::p_WorkStack::_get_impl(_4309)->shape_base;
  int _4313 = mosek::fusion::p_WorkStack::_get_impl(_4309)->nelem;
  int _4314 = mosek::fusion::p_WorkStack::_get_impl(_4309)->nnz;
  bool _4315 = mosek::fusion::p_WorkStack::_get_impl(_4309)->hassp;
  int _4316 = mosek::fusion::p_WorkStack::_get_impl(_4309)->ptr_base;
  int _4317 = mosek::fusion::p_WorkStack::_get_impl(_4309)->sp_base;
  int _4318 = mosek::fusion::p_WorkStack::_get_impl(_4309)->nidxs_base;
  int _4319 = mosek::fusion::p_WorkStack::_get_impl(_4309)->bfix_base;
  int _4320 = mosek::fusion::p_WorkStack::_get_impl(_4309)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4321 = mosek::fusion::p_WorkStack::_get_impl(_4309)->i32;
  _checked_ptr_1<int> _ptr__4321(_4321 ? _4321->raw() : nullptr,_4321 ? _4321->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4322 = mosek::fusion::p_WorkStack::_get_impl(_4309)->i64;
  _checked_ptr_1<long long> _ptr__4322(_4322 ? _4322->raw() : nullptr,_4322 ? _4322->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4323 = mosek::fusion::p_WorkStack::_get_impl(_4309)->f64;
  _checked_ptr_1<double> _ptr__4323(_4323 ? _4323->raw() : nullptr,_4323 ? _4323->size(0) : 0);
  int _4324 = (int)99999;
  int _4325 = (int)99999;
  int _4326 = (int)99999;
  if (_4315)
  {
    {
      int _4327 = (int)0;
      int _8816 = (int)0;
      int _8817 = _4311;
      for (int _4328 = _8816; _4328 < _8817; ++_4328)
      {
        {
          if ((_4327 < _ptr__4321[safe_add( _4312,_4328 )]))
          {
            {
              _4327 = _ptr__4321[safe_add( _4312,_4328 )];
            }
          }
          {}
        }
      }
      _4324 = _4310->alloci32(safe_add( _4327,(int)1 ));
      _4325 = _4310->alloci32(_4313);
      _4326 = _4310->alloci32(_4313);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _4329 = mosek::fusion::p_WorkStack::_get_impl(_4310)->i32;
  _checked_ptr_1<int> _ptr__4329(_4329 ? _4329->raw() : nullptr,_4329 ? _4329->size(0) : 0);
  if (_4315)
  {
    {
      int _4330 = _4325;
      int _4331 = _4326;
      int _8818 = (int)0;
      int _8819 = _4313;
      for (int _4332 = _8818; _4332 < _8819; ++_4332)
      {
        {
          _ptr__4329[safe_add( _4330,_4332 )] = _4332;
        }
      }
      if ((dim < (_4311 - (int)1)))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _4333 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4311)));
          _checked_ptr_1<long long> _ptr__4333(_4333 ? _4333->raw() : nullptr,_4333 ? _4333->size(0) : 0);
          _ptr__4333[(_4311 - (int)1)] = (int)1;
          int _8820 = (int)1;
          int _8821 = _4311;
          for (int _4334 = _8820; _4334 < _8821; ++_4334)
          {
            {
              _ptr__4333[((_4311 - _4334) - (int)1)] = safe_mul( _ptr__4333[(_4311 - _4334)],_ptr__4321[(safe_add( _4312,_4311 ) - _4334)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _4335 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((_4311 - (int)1))));
          _checked_ptr_1<int> _ptr__4335(_4335 ? _4335->raw() : nullptr,_4335 ? _4335->size(0) : 0);
          int _8822 = (int)0;
          int _8823 = dim;
          for (int _4336 = _8822; _4336 < _8823; ++_4336)
          {
            {
              _ptr__4335[((_4311 - _4336) - (int)2)] = _4336;
            }
          }
          int _8824 = safe_add( dim,(int)1 );
          int _8825 = _4311;
          for (int _4337 = _8824; _4337 < _8825; ++_4337)
          {
            {
              _ptr__4335[((_4311 - _4337) - (int)1)] = _4337;
            }
          }
          int _8826 = (int)0;
          int _8827 = (_4311 - (int)1);
          for (int _4338 = _8826; _4338 < _8827; ++_4338)
          {
            {
              int _4339 = _ptr__4335[_4338];
              int _4340 = _ptr__4321[safe_add( _4312,_4339 )];
              int _8828 = (int)0;
              int _8829 = safe_add( _4340,(int)1 );
              for (int _4341 = _8828; _4341 < _8829; ++_4341)
              {
                {
                  _ptr__4329[safe_add( _4324,_4341 )] = (int)0;
                }
              }
              int _8830 = (int)0;
              int _8831 = _4313;
              for (int _4342 = _8830; _4342 < _8831; ++_4342)
              {
                {
                  ++ _ptr__4329[safe_add( safe_add( _4324,(int)1 ),((_ptr__4322[safe_add( _4317,_4342 )] / _ptr__4333[_4339]) % _4340) )];
                }
              }
              int _8832 = (int)0;
              int _8833 = _4340;
              for (int _4343 = _8832; _4343 < _8833; ++_4343)
              {
                {
                  _ptr__4329[safe_add( safe_add( _4324,_4343 ),(int)1 )] += _ptr__4329[safe_add( _4324,_4343 )];
                }
              }
              int _8834 = (int)0;
              int _8835 = _4313;
              for (int _4344 = _8834; _4344 < _8835; ++_4344)
              {
                {
                  int _4345 = _ptr__4329[safe_add( _4330,_4344 )];
                  long long _4346 = ((_ptr__4322[safe_add( _4317,_4345 )] / _ptr__4333[_4339]) % _4340);
                  _ptr__4329[safe_add( _4331,_ptr__4329[safe_add( _4324,_4346 )] )] = _4345;
                  ++ _ptr__4329[safe_add( _4324,_4346 )];
                }
              }
              int _4347 = _4331;
              _4331 = _4330;
              _4330 = _4347;
            }
          }
        }
      }
      {}
      int _4348 = (int)1;
      int _8836 = (int)0;
      int _8837 = dim;
      for (int _4349 = _8836; _4349 < _8837; ++_4349)
      {
        {
          _4348 *= _ptr__4321[safe_add( _4312,_4349 )];
        }
      }
      int _4350 = _ptr__4321[safe_add( _4312,dim )];
      int _4351 = (int)1;
      int _8838 = safe_add( dim,(int)1 );
      int _8839 = _4311;
      for (int _4352 = _8838; _4352 < _8839; ++_4352)
      {
        {
          _4351 *= _ptr__4321[safe_add( _4312,_4352 )];
        }
      }
      int _4353 = safe_mul( _4351,_4350 );
      int _4354 = _4351;
      int _4355 = (int)1;
      int _4356 = (int)0;
      long long _4357 = (-(int)1);
      long long _4358 = (-(int)1);
      int _8840 = (int)0;
      int _8841 = _4313;
      for (int _4359 = _8840; _4359 < _8841; ++_4359)
      {
        {
          int _4360 = _ptr__4329[safe_add( _4330,_4359 )];
          long long _4361 = ((_ptr__4322[safe_add( _4317,_4360 )] / _4353) % _4348);
          long long _4362 = (_ptr__4322[safe_add( _4317,_4360 )] % _4351);
          if (((_4358 != _4361) || (_4357 != _4362)))
          {
            {
              _4358 = _4361;
              _4357 = _4362;
              ++ _4356;
            }
          }
          {}
        }
      }
      int _4363 = (_4311 - (int)1);
      bool _4364 = (_4356 < safe_mul( _4348,_4351 ));
      int _4365 = _4314;
      _4308->alloc_expr(_4363,_4356,_4365,_4364);
      int _4366 = mosek::fusion::p_WorkStack::_get_impl(_4308)->ptr_base;
      int _4367 = mosek::fusion::p_WorkStack::_get_impl(_4308)->nidxs_base;
      int _8842;
      bool _8843 = _4364;
      if (_8843)
      {
        _8842 = mosek::fusion::p_WorkStack::_get_impl(_4308)->sp_base;
      }
      else
      {
        _8842 = _4308->alloci64(_4356);
      }
      int _4368 = _8842;
      int _4369 = mosek::fusion::p_WorkStack::_get_impl(_4308)->cof_base;
      int _4370 = mosek::fusion::p_WorkStack::_get_impl(_4308)->bfix_base;
      int _4371 = mosek::fusion::p_WorkStack::_get_impl(_4308)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4372 = mosek::fusion::p_WorkStack::_get_impl(_4308)->i32;
      _checked_ptr_1<int> _ptr__4372(_4372 ? _4372->raw() : nullptr,_4372 ? _4372->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4373 = mosek::fusion::p_WorkStack::_get_impl(_4308)->i64;
      _checked_ptr_1<long long> _ptr__4373(_4373 ? _4373->raw() : nullptr,_4373 ? _4373->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4374 = mosek::fusion::p_WorkStack::_get_impl(_4308)->f64;
      _checked_ptr_1<double> _ptr__4374(_4374 ? _4374->raw() : nullptr,_4374 ? _4374->size(0) : 0);
      int _8844 = (int)0;
      int _8845 = dim;
      for (int _4375 = _8844; _4375 < _8845; ++_4375)
      {
        {
          _ptr__4372[safe_add( _4371,_4375 )] = _ptr__4321[safe_add( _4312,_4375 )];
        }
      }
      int _8846 = safe_add( dim,(int)1 );
      int _8847 = _4311;
      for (int _4376 = _8846; _4376 < _8847; ++_4376)
      {
        {
          _ptr__4372[(safe_add( _4371,_4376 ) - (int)1)] = _ptr__4321[safe_add( _4312,_4376 )];
        }
      }
      _ptr__4372[_4366] = (int)0;
      int _4377 = (int)0;
      int _4378 = (int)0;
      int _4379 = (int)0;
      while ( (_4379 < _4313) )
      {
        {
          int _4380 = _4379;
          long long _4381 = ((_ptr__4322[safe_add( _4317,_ptr__4329[safe_add( _4330,_4380 )] )] / _4353) % _4348);
          long long _4382 = (_ptr__4322[safe_add( _4317,_ptr__4329[safe_add( _4330,_4380 )] )] % _4351);
          ++ _4379;
          while ( ((_4379 < _4313) && ((_4381 == ((_ptr__4322[safe_add( _4317,_ptr__4329[safe_add( _4330,_4379 )] )] / _4353) % _4348)) && (_4382 == (_ptr__4322[safe_add( _4317,_ptr__4329[safe_add( _4330,_4379 )] )] % _4351)))) )
          {
            {
              ++ _4379;
            }
          }
          double _4383 = 0.0;
          int _8848 = _4380;
          int _8849 = _4379;
          for (int _4384 = _8848; _4384 < _8849; ++_4384)
          {
            {
              int _4385 = _ptr__4329[safe_add( _4330,_4384 )];
              int _8850 = _ptr__4321[safe_add( _4316,_4385 )];
              int _8851 = _ptr__4321[safe_add( safe_add( _4316,_4385 ),(int)1 )];
              for (int _4386 = _8850; _4386 < _8851; ++_4386)
              {
                {
                  _ptr__4373[safe_add( _4367,_4378 )] = _ptr__4322[safe_add( _4318,_4386 )];
                  _ptr__4374[safe_add( _4369,_4378 )] = _ptr__4323[safe_add( _4320,_4386 )];
                  ++ _4378;
                }
              }
              _4383 += _ptr__4323[safe_add( _4319,_4385 )];
            }
          }
          _ptr__4373[safe_add( _4368,_4377 )] = safe_add( safe_mul( _4381,_4351 ),_4382 );
          _ptr__4372[safe_add( safe_add( _4366,_4377 ),(int)1 )] = _4378;
          _ptr__4374[safe_add( _4370,_4377 )] = _4383;
          ++ _4377;
        }
      }
      if ((!_4364))
      {
        {
          _4308->popi64(_4356);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4387 = (int)1;
      int _8852 = (int)0;
      int _8853 = dim;
      for (int _4388 = _8852; _4388 < _8853; ++_4388)
      {
        {
          _4387 *= _ptr__4321[safe_add( _4312,_4388 )];
        }
      }
      int _4389 = _ptr__4321[safe_add( _4312,dim )];
      int _4390 = (int)1;
      int _8854 = safe_add( dim,(int)1 );
      int _8855 = _4311;
      for (int _4391 = _8854; _4391 < _8855; ++_4391)
      {
        {
          _4390 *= _ptr__4321[safe_add( _4312,_4391 )];
        }
      }
      int _4392 = safe_mul( _4390,_4389 );
      int _4393 = _4390;
      int _4394 = (int)1;
      int _4395 = safe_mul( _4387,_4390 );
      int _4396 = _4308->alloci32(safe_add( _4395,(int)1 ));
      int _4397 = _4308->alloci64(_4314);
      int _4398 = _4308->allocf64(_4314);
      int _4399 = _4308->allocf64(_4395);
      _4308->pushi32((int)0);
      _4308->pushi32(_4314);
      _4308->pushi32(_4395);
      int _4400 = _4308->alloci32((_4311 - (int)1));
      _4308->pushi32((_4311 - (int)1));
      std::shared_ptr< monty::ndarray< int,1 > > _4401 = mosek::fusion::p_WorkStack::_get_impl(_4308)->i32;
      _checked_ptr_1<int> _ptr__4401(_4401 ? _4401->raw() : nullptr,_4401 ? _4401->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4402 = mosek::fusion::p_WorkStack::_get_impl(_4308)->i64;
      _checked_ptr_1<long long> _ptr__4402(_4402 ? _4402->raw() : nullptr,_4402 ? _4402->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4403 = mosek::fusion::p_WorkStack::_get_impl(_4308)->f64;
      _checked_ptr_1<double> _ptr__4403(_4403 ? _4403->raw() : nullptr,_4403 ? _4403->size(0) : 0);
      int _8856 = (int)0;
      int _8857 = dim;
      for (int _4404 = _8856; _4404 < _8857; ++_4404)
      {
        {
          _ptr__4401[safe_add( _4400,_4404 )] = _ptr__4321[safe_add( _4312,_4404 )];
        }
      }
      int _8858 = safe_add( dim,(int)1 );
      int _8859 = _4311;
      for (int _4405 = _8858; _4405 < _8859; ++_4405)
      {
        {
          _ptr__4401[(safe_add( _4400,_4405 ) - (int)1)] = _ptr__4321[safe_add( _4312,_4405 )];
        }
      }
      int _4406 = (int)0;
      int _4407 = (int)0;
      _ptr__4401[_4396] = (int)0;
      int _8860 = (int)0;
      int _8861 = _4387;
      for (int _4408 = _8860; _4408 < _8861; ++_4408)
      {
        {
          int _8862 = (int)0;
          int _8863 = _4390;
          for (int _4409 = _8862; _4409 < _8863; ++_4409)
          {
            {
              double _4410 = 0.0;
              int _8864 = (int)0;
              int _8865 = _4389;
              for (int _4411 = _8864; _4411 < _8865; ++_4411)
              {
                {
                  int _4412 = safe_add( safe_add( safe_mul( _4408,_4392 ),safe_mul( _4411,_4393 ) ),_4409 );
                  int _8866 = _ptr__4321[safe_add( _4316,_4412 )];
                  int _8867 = _ptr__4321[safe_add( safe_add( _4316,_4412 ),(int)1 )];
                  for (int _4413 = _8866; _4413 < _8867; ++_4413)
                  {
                    {
                      _ptr__4402[safe_add( _4397,_4407 )] = _ptr__4322[safe_add( _4318,_4413 )];
                      _ptr__4403[safe_add( _4398,_4407 )] = _ptr__4323[safe_add( _4320,_4413 )];
                      ++ _4407;
                    }
                  }
                  _4410 += _ptr__4323[safe_add( _4319,_4412 )];
                }
              }
              _ptr__4401[safe_add( safe_add( _4396,_4406 ),(int)1 )] = _4407;
              _ptr__4403[safe_add( _4399,_4406 )] = _4410;
              ++ _4406;
            }
          }
        }
      }
    }
  }
  _4310->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSumReduce::computeShape(int _4414,std::shared_ptr< monty::ndarray< int,1 > > _4415){
  _checked_ptr_1<int> _ptr__4415(_4415 ? _4415->raw() : nullptr, _4415 ? _4415->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4416 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((_4415)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__4416(_4416 ? _4416->raw() : nullptr,_4416 ? _4416->size(0) : 0);
  int _8868 = (int)0;
  int _8869 = _4414;
  for (int _4417 = _8868; _4417 < _8869; ++_4417)
  {
    {
      _ptr__4416[_4417] = _ptr__4415[_4417];
    }
  }
  int _8870 = safe_add( _4414,(int)1 );
  int _8871 = (int)((_4415)->size(0));
  for (int _4418 = _8870; _4418 < _8871; ++_4418)
  {
    {
      _ptr__4416[(_4418 - (int)1)] = _ptr__4415[_4418];
    }
  }
  return _4416;
}
std::string mosek::fusion::ExprSumReduce :: toString() { return mosek::fusion::p_ExprSumReduce::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSumReduce::toString(){
  return std::string ("ExprSumReduce()");
}
void mosek::fusion::p_ExprSumReduce::destroy(){expr.reset();}void mosek::fusion::ExprSumReduce::destroy() { mosek::fusion::p_ExprSumReduce::_get_impl(this)->destroy(); }mosek::fusion::ExprDenseTril::ExprDenseTril(mosek::fusion::p_ExprDenseTril *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDenseTril()" << this << std::endl; */ }mosek::fusion::ExprDenseTril::~ExprDenseTril() {  /* std::cout << "~ExprDenseTril()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDenseTril::p_ExprDenseTril  (::mosek::fusion::ExprDenseTril * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4419,    int _4420,    monty::rc_ptr< ::mosek::fusion::Expression > _4421,    int _4422){ return new mosek::fusion::ExprDenseTril(_4419,_4420,_4421,_4422); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4419,    int _4420,    monty::rc_ptr< ::mosek::fusion::Expression > _4421,    int _4422) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4419,_4420,_4421,_4422); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4419,    int _4420,    monty::rc_ptr< ::mosek::fusion::Expression > _4421,    int _4422){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4421->getShape());
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->expr = _4421;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim0 = _4419;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim1 = _4420;
  }
}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4423,    int _4424,    monty::rc_ptr< ::mosek::fusion::Expression > _4425){ return new mosek::fusion::ExprDenseTril(_4423,_4424,_4425); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4423,    int _4424,    monty::rc_ptr< ::mosek::fusion::Expression > _4425) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4423,_4424,_4425); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4423,    int _4424,    monty::rc_ptr< ::mosek::fusion::Expression > _4425){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprDenseTril::_initialize(_4423,_4424,_4425,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4426 = _4425->getShape();
    _checked_ptr_1<int> _ptr__4426(_4426 ? _4426->raw() : nullptr,_4426 ? _4426->size(0) : 0);
    if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= (int)((_4426)->size(0))) || ((dim1 < (int)0) || ((dim1 >= (int)((_4426)->size(0))) || (_ptr__4426[dim0] != _ptr__4426[dim1])))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprDenseTril :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4427,monty::rc_ptr< ::mosek::fusion::WorkStack > _4428,monty::rc_ptr< ::mosek::fusion::WorkStack > _4429) { mosek::fusion::p_ExprDenseTril::_get_impl(this)->eval(_4427,_4428,_4429); }void mosek::fusion::p_ExprDenseTril::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4427,monty::rc_ptr< ::mosek::fusion::WorkStack > _4428,monty::rc_ptr< ::mosek::fusion::WorkStack > _4429){
  expr->eval(_4428,_4427,_4429);
  std::shared_ptr< monty::ndarray< int,1 > > _4430 = mosek::fusion::p_WorkStack::_get_impl(_4428)->i32;
  _checked_ptr_1<int> _ptr__4430(_4430 ? _4430->raw() : nullptr,_4430 ? _4430->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4431 = mosek::fusion::p_WorkStack::_get_impl(_4428)->i64;
  _checked_ptr_1<long long> _ptr__4431(_4431 ? _4431->raw() : nullptr,_4431 ? _4431->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4432 = mosek::fusion::p_WorkStack::_get_impl(_4428)->f64;
  _checked_ptr_1<double> _ptr__4432(_4432 ? _4432->raw() : nullptr,_4432 ? _4432->size(0) : 0);
  int _8872;
  bool _8873 = (dim0 < dim1);
  if (_8873)
  {
    _8872 = dim0;
  }
  else
  {
    _8872 = dim1;
  }
  int _4433 = _8872;
  int _8874;
  bool _8875 = (dim0 > dim1);
  if (_8875)
  {
    _8874 = dim0;
  }
  else
  {
    _8874 = dim1;
  }
  int _4434 = _8874;
  bool _4435 = (dim0 < dim1);
  int _4436 = _4428->popi32();
  int _4437 = _4428->popi32(_4436);
  int _4438 = _4428->popi32();
  int _4439 = _4428->popi32();
  bool _4440 = (_4428->popi32() != (int)0);
  int _4441 = _4428->popi32(safe_add( _4438,(int)1 ));
  int _8876;
  bool _8877 = _4440;
  if (_8877)
  {
    _8876 = _4428->popi64(_4438);
  }
  else
  {
    _8876 = (-(int)1);
  }
  int _4442 = _8876;
  int _4443 = _4428->popi64(_4439);
  int _4444 = _4428->popf64(_4438);
  int _4445 = _4428->popf64(_4439);
  std::vector<int> _8878;
  for (int _4447 = (int)0, _8879 = (int)5; _4447 < _8879 ; ++_4447)
  {
    _8878.push_back((int)1);
  }
  auto _8880 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8878.size()),_8878.begin(),_8878.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4446 = _8880;
  _checked_ptr_1<int> _ptr__4446(_4446 ? _4446->raw() : nullptr,_4446 ? _4446->size(0) : 0);
  int _8881 = (int)0;
  int _8882 = _4433;
  for (int _4448 = _8881; _4448 < _8882; ++_4448)
  {
    {
      _ptr__4446[(int)0] *= _ptr__4430[safe_add( _4437,_4448 )];
    }
  }
  _ptr__4446[(int)1] = _ptr__4430[safe_add( _4437,_4433 )];
  int _8883 = safe_add( _4433,(int)1 );
  int _8884 = _4434;
  for (int _4449 = _8883; _4449 < _8884; ++_4449)
  {
    {
      _ptr__4446[(int)2] *= _ptr__4430[safe_add( _4437,_4449 )];
    }
  }
  _ptr__4446[(int)3] = _ptr__4430[safe_add( _4437,_4434 )];
  int _8885 = safe_add( _4434,(int)1 );
  int _8886 = _4436;
  for (int _4450 = _8885; _4450 < _8886; ++_4450)
  {
    {
      _ptr__4446[(int)4] *= _ptr__4430[safe_add( _4437,_4450 )];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4451 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__4451(_4451 ? _4451->raw() : nullptr,_4451 ? _4451->size(0) : 0);
  _ptr__4451[(int)4] = (int)1;
  int _8887 = (int)1;
  int _8888 = (int)5;
  for (int _4452 = _8887; _4452 < _8888; ++_4452)
  {
    {
      _ptr__4451[(((int)5 - _4452) - (int)1)] = safe_mul( _ptr__4451[((int)5 - _4452)],_ptr__4446[((int)5 - _4452)] );
    }
  }
  int _4453 = (int)0;
  int _4454 = (int)0;
  {
    if (_4440)
    {
      {
        if (_4435)
        {
          {
            int _8889 = (int)0;
            int _8890 = _4438;
            for (int _4455 = _8889; _4455 < _8890; ++_4455)
            {
              {
                long long _4456 = ((_ptr__4431[safe_add( _4442,_4455 )] / _ptr__4451[(int)1]) % _ptr__4446[(int)1]);
                long long _4457 = ((_ptr__4431[safe_add( _4442,_4455 )] / _ptr__4451[(int)3]) % _ptr__4446[(int)3]);
                if ((_4456 >= _4457))
                {
                  {
                    _4453 += (_ptr__4430[safe_add( safe_add( _4441,_4455 ),(int)1 )] - _ptr__4430[safe_add( _4441,_4455 )]);
                    ++ _4454;
                  }
                }
                {}
              }
            }
          }
        }
        else
        {
          {
            int _8891 = (int)0;
            int _8892 = _4438;
            for (int _4458 = _8891; _4458 < _8892; ++_4458)
            {
              {
                long long _4459 = ((_ptr__4431[safe_add( _4442,_4458 )] / _ptr__4451[(int)1]) % _ptr__4446[(int)1]);
                long long _4460 = ((_ptr__4431[safe_add( _4442,_4458 )] / _ptr__4451[(int)3]) % _ptr__4446[(int)3]);
                if ((_4459 <= _4460))
                {
                  {
                    _4453 += (_ptr__4430[safe_add( safe_add( _4441,_4458 ),(int)1 )] - _ptr__4430[safe_add( _4441,_4458 )]);
                    ++ _4454;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    else
    {
      {
        _4454 = safe_mul( safe_mul( safe_mul( _ptr__4446[(int)0],_ptr__4446[(int)2] ),_ptr__4446[(int)4] ),(safe_mul( _ptr__4446[(int)1],safe_add( _ptr__4446[(int)1],(int)1 ) ) / (int)2) );
        if (_4435)
        {
          {
            int _8893 = (int)0;
            int _8894 = _ptr__4446[(int)0];
            for (int _4461 = _8893; _4461 < _8894; ++_4461)
            {
              {
                int _8895 = (int)0;
                int _8896 = _ptr__4446[(int)1];
                for (int _4462 = _8895; _4462 < _8896; ++_4462)
                {
                  {
                    int _8897 = (int)0;
                    int _8898 = _ptr__4446[(int)2];
                    for (int _4463 = _8897; _4463 < _8898; ++_4463)
                    {
                      {
                        int _8899 = (int)0;
                        int _8900 = safe_add( _4462,(int)1 );
                        for (int _4464 = _8899; _4464 < _8900; ++_4464)
                        {
                          {
                            int _8901 = (int)0;
                            int _8902 = _ptr__4446[(int)4];
                            for (int _4465 = _8901; _4465 < _8902; ++_4465)
                            {
                              {
                                int _4466 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4461,_ptr__4451[(int)0] ),safe_mul( _4462,_ptr__4451[(int)1] ) ),safe_mul( _4463,_ptr__4451[(int)2] ) ),safe_mul( _4464,_ptr__4451[(int)3] ) ),safe_mul( _4465,_ptr__4451[(int)4] ) );
                                _4453 += (_ptr__4430[safe_add( safe_add( _4441,_4466 ),(int)1 )] - _ptr__4430[safe_add( _4441,_4466 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        else
        {
          {
            int _8903 = (int)0;
            int _8904 = _ptr__4446[(int)0];
            for (int _4467 = _8903; _4467 < _8904; ++_4467)
            {
              {
                int _8905 = (int)0;
                int _8906 = _ptr__4446[(int)1];
                for (int _4468 = _8905; _4468 < _8906; ++_4468)
                {
                  {
                    int _8907 = (int)0;
                    int _8908 = _ptr__4446[(int)2];
                    for (int _4469 = _8907; _4469 < _8908; ++_4469)
                    {
                      {
                        int _8909 = _4468;
                        int _8910 = _ptr__4446[(int)3];
                        for (int _4470 = _8909; _4470 < _8910; ++_4470)
                        {
                          {
                            int _8911 = (int)0;
                            int _8912 = _ptr__4446[(int)4];
                            for (int _4471 = _8911; _4471 < _8912; ++_4471)
                            {
                              {
                                int _4472 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4467,_ptr__4451[(int)0] ),safe_mul( _4468,_ptr__4451[(int)1] ) ),safe_mul( _4469,_ptr__4451[(int)2] ) ),safe_mul( _4470,_ptr__4451[(int)3] ) ),safe_mul( _4471,_ptr__4451[(int)4] ) );
                                _4453 += (_ptr__4430[safe_add( safe_add( _4441,_4472 ),(int)1 )] - _ptr__4430[safe_add( _4441,_4472 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _4473 = (safe_mul( safe_mul( safe_mul( safe_mul( _ptr__4446[(int)0],_ptr__4446[(int)2] ),_ptr__4446[(int)4] ),_ptr__4446[(int)1] ),safe_add( _ptr__4446[(int)1],(int)1 ) ) / (int)2);
  int _4474 = _4427->alloci32(safe_add( _4473,(int)1 ));
  _4427->pushi32((int)1);
  _4427->pushi32(_4453);
  _4427->pushi32(_4473);
  int _8913 = (int)0;
  int _8914 = _4436;
  for (int _4475 = _8913; _4475 < _8914; ++_4475)
  {
    {
      _4427->pushi32(_ptr__4430[safe_add( _4437,_4475 )]);
    }
  }
  _4427->pushi32(_4436);
  int _4476 = _4427->alloci64(_4453);
  int _4477 = _4427->alloci64(_4473);
  int _4478 = _4427->allocf64(_4453);
  int _4479 = _4427->allocf64(_4473);
  std::shared_ptr< monty::ndarray< int,1 > > _4480 = mosek::fusion::p_WorkStack::_get_impl(_4427)->i32;
  _checked_ptr_1<int> _ptr__4480(_4480 ? _4480->raw() : nullptr,_4480 ? _4480->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4481 = mosek::fusion::p_WorkStack::_get_impl(_4427)->i64;
  _checked_ptr_1<long long> _ptr__4481(_4481 ? _4481->raw() : nullptr,_4481 ? _4481->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4482 = mosek::fusion::p_WorkStack::_get_impl(_4427)->f64;
  _checked_ptr_1<double> _ptr__4482(_4482 ? _4482->raw() : nullptr,_4482 ? _4482->size(0) : 0);
  _ptr__4480[_4474] = (int)0;
  if (_4435)
  {
    {
      int _4483 = (int)0;
      int _8915 = (int)0;
      int _8916 = _ptr__4446[(int)0];
      for (int _4484 = _8915; _4484 < _8916; ++_4484)
      {
        {
          int _8917 = (int)0;
          int _8918 = _ptr__4446[(int)1];
          for (int _4485 = _8917; _4485 < _8918; ++_4485)
          {
            {
              int _8919 = (int)0;
              int _8920 = _ptr__4446[(int)2];
              for (int _4486 = _8919; _4486 < _8920; ++_4486)
              {
                {
                  int _8921 = (int)0;
                  int _8922 = safe_add( _4485,(int)1 );
                  for (int _4487 = _8921; _4487 < _8922; ++_4487)
                  {
                    {
                      int _8923 = (int)0;
                      int _8924 = _ptr__4446[(int)4];
                      for (int _4488 = _8923; _4488 < _8924; ++_4488)
                      {
                        {
                          _ptr__4481[safe_add( _4477,_4483 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4484,_ptr__4451[(int)0] ),safe_mul( _4485,_ptr__4451[(int)1] ) ),safe_mul( _4486,_ptr__4451[(int)2] ) ),safe_mul( _4487,_ptr__4451[(int)3] ) ),safe_mul( _4488,_ptr__4451[(int)4] ) );
                          ++ _4483;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4489 = (int)0;
      int _8925 = (int)0;
      int _8926 = _ptr__4446[(int)0];
      for (int _4490 = _8925; _4490 < _8926; ++_4490)
      {
        {
          int _8927 = (int)0;
          int _8928 = _ptr__4446[(int)1];
          for (int _4491 = _8927; _4491 < _8928; ++_4491)
          {
            {
              int _8929 = (int)0;
              int _8930 = _ptr__4446[(int)2];
              for (int _4492 = _8929; _4492 < _8930; ++_4492)
              {
                {
                  int _8931 = _4491;
                  int _8932 = _ptr__4446[(int)3];
                  for (int _4493 = _8931; _4493 < _8932; ++_4493)
                  {
                    {
                      int _8933 = (int)0;
                      int _8934 = _ptr__4446[(int)4];
                      for (int _4494 = _8933; _4494 < _8934; ++_4494)
                      {
                        {
                          _ptr__4481[safe_add( _4477,_4489 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4490,_ptr__4451[(int)0] ),safe_mul( _4491,_ptr__4451[(int)1] ) ),safe_mul( _4492,_ptr__4451[(int)2] ) ),safe_mul( _4493,_ptr__4451[(int)3] ) ),safe_mul( _4494,_ptr__4451[(int)4] ) );
                          ++ _4489;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  {
    int _4495 = (int)0;
    if (_4440)
    {
      {
        int _4496 = (int)0;
        int _4497 = (int)0;
        while ( ((_4497 < _4438) && (_4496 < _4473)) )
        {
          {
            if ((_ptr__4431[safe_add( _4442,_4497 )] < _ptr__4481[safe_add( _4477,_4496 )]))
            {
              {
                ++ _4497;
              }
            }
            else if((_ptr__4431[safe_add( _4442,_4497 )] > _ptr__4481[safe_add( _4477,_4496 )]))
            {
              {
                _ptr__4482[safe_add( _4479,_4496 )] = 0.0;
                _ptr__4480[safe_add( safe_add( _4474,_4496 ),(int)1 )] = _4495;
                ++ _4496;
              }
            }
            else
            {
              {
                int _8935 = _ptr__4430[safe_add( _4441,_4497 )];
                int _8936 = _ptr__4430[safe_add( safe_add( _4441,_4497 ),(int)1 )];
                for (int _4498 = _8935; _4498 < _8936; ++_4498)
                {
                  {
                    _ptr__4481[safe_add( _4476,_4495 )] = _ptr__4431[safe_add( _4443,_4498 )];
                    _ptr__4482[safe_add( _4478,_4495 )] = _ptr__4432[safe_add( _4445,_4498 )];
                    ++ _4495;
                  }
                }
                _ptr__4482[safe_add( _4479,_4496 )] = _ptr__4432[safe_add( _4444,_4497 )];
                _ptr__4480[safe_add( safe_add( _4474,_4496 ),(int)1 )] = _4495;
                ++ _4497;
                ++ _4496;
              }
            }
          }
        }
        while ( (_4496 < _4473) )
        {
          {
            _ptr__4480[safe_add( safe_add( _4474,_4496 ),(int)1 )] = _4495;
            _ptr__4482[safe_add( _4479,_4496 )] = 0.0;
            ++ _4496;
          }
        }
      }
    }
    else
    {
      {
        int _8937 = (int)0;
        int _8938 = _4473;
        for (int _4499 = _8937; _4499 < _8938; ++_4499)
        {
          {
            long long _4500 = _ptr__4481[safe_add( _4477,_4499 )];
            _ptr__4482[safe_add( _4479,_4499 )] = _ptr__4432[safe_add( _4444,_4500 )];
            int _8939 = _ptr__4430[safe_add( _4441,_4500 )];
            int _8940 = _ptr__4430[safe_add( safe_add( _4441,_4500 ),(int)1 )];
            for (int _4501 = _8939; _4501 < _8940; ++_4501)
            {
              {
                _ptr__4481[safe_add( _4476,_4495 )] = _ptr__4431[safe_add( _4443,_4501 )];
                _ptr__4482[safe_add( _4478,_4495 )] = _ptr__4432[safe_add( _4445,_4501 )];
                ++ _4495;
              }
            }
            _ptr__4480[safe_add( safe_add( _4474,_4499 ),(int)1 )] = _4495;
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprDenseTril::destroy(){expr.reset();}void mosek::fusion::ExprDenseTril::destroy() { mosek::fusion::p_ExprDenseTril::_get_impl(this)->destroy(); }mosek::fusion::ExprDense::ExprDense(mosek::fusion::p_ExprDense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDense()" << this << std::endl; */ }mosek::fusion::ExprDense::~ExprDense() {  /* std::cout << "~ExprDense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDense::p_ExprDense  (::mosek::fusion::ExprDense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDense::t mosek::fusion::p_ExprDense::_new_ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4502){ return new mosek::fusion::ExprDense(_4502); }mosek::fusion::ExprDense::ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4502) :    ExprDense(new mosek::fusion::p_ExprDense(this)){ mosek::fusion::p_ExprDense::_get_impl(this)->_initialize(_4502); }void mosek::fusion::p_ExprDense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4502){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4502->getShape());
    mosek::fusion::p_ExprDense::_get_impl(::mosek::fusion::ExprDense::t(_pubthis))->expr = _4502;
  }
}void mosek::fusion::ExprDense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4503,monty::rc_ptr< ::mosek::fusion::WorkStack > _4504,monty::rc_ptr< ::mosek::fusion::WorkStack > _4505) { mosek::fusion::p_ExprDense::_get_impl(this)->eval(_4503,_4504,_4505); }void mosek::fusion::p_ExprDense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4503,monty::rc_ptr< ::mosek::fusion::WorkStack > _4504,monty::rc_ptr< ::mosek::fusion::WorkStack > _4505){
  expr->eval(_4503,_4504,_4505);
  _4503->peek_expr();
  if (mosek::fusion::p_WorkStack::_get_impl(_4503)->hassp)
  {
    {
      int _4506 = mosek::fusion::p_WorkStack::_get_impl(_4503)->nd;
      int _4507 = mosek::fusion::p_WorkStack::_get_impl(_4503)->nnz;
      int _4508 = mosek::fusion::p_WorkStack::_get_impl(_4503)->nelem;
      int _4509 = mosek::fusion::p_WorkStack::_get_impl(_4503)->sp_base;
      std::vector<int> _8941;
      for (int _4511 = (int)0, _8942 = _4506; _4511 < _8942 ; ++_4511)
      {
        _8941.push_back(((*mosek::fusion::p_WorkStack::_get_impl(_4503)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4503)->shape_base,_4511 ))));
      }
      auto _8943 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8941.size()),_8941.begin(),_8941.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _4510 = _8943;
      _checked_ptr_1<int> _ptr__4510(_4510 ? _4510->raw() : nullptr,_4510 ? _4510->size(0) : 0);
      int _4512 = (int)::mosek::fusion::p_Set::size(_4510);
      _4503->popi32(safe_add( (int)4,_4506 ));
      if ((_4512 == _4508))
      {
        {
          _4503->popi64(_4508);
          _4503->pushi32((int)0);
          _4503->pushi32(_4507);
          _4503->pushi32(_4508);
          int _4513 = _4503->alloci32(_4506);
          int _8944 = (int)0;
          int _8945 = _4506;
          for (int _4514 = _8944; _4514 < _8945; ++_4514)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_4503)->i32)(safe_add( _4513,_4514 ))) = _ptr__4510[_4514];
            }
          }
          _4503->pushi32(_4506);
          _4503->peek_expr();
        }
      }
      else
      {
        {
          int _4515 = _4505->alloci32(safe_add( _4512,(int)1 ));
          int _4516 = _4505->allocf64(_4512);
          std::shared_ptr< monty::ndarray< int,1 > > _4517 = mosek::fusion::p_WorkStack::_get_impl(_4505)->i32;
          _checked_ptr_1<int> _ptr__4517(_4517 ? _4517->raw() : nullptr,_4517 ? _4517->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4518 = mosek::fusion::p_WorkStack::_get_impl(_4505)->f64;
          _checked_ptr_1<double> _ptr__4518(_4518 ? _4518->raw() : nullptr,_4518 ? _4518->size(0) : 0);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4503)->f64,mosek::fusion::p_WorkStack::_get_impl(_4503)->bfix_base,_4518,_4516,_4508);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4503)->i32,mosek::fusion::p_WorkStack::_get_impl(_4503)->ptr_base,_4517,_4515,safe_add( _4508,(int)1 ));
          _4503->popi32(safe_add( _4508,(int)1 ));
          _4503->popf64(_4508);
          int _4519 = _4503->alloci32(safe_add( _4512,(int)1 ));
          int _4520 = _4503->allocf64(_4512);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _4521 = mosek::fusion::p_WorkStack::_get_impl(_4503)->i32;
            _checked_ptr_1<int> _ptr__4521(_4521 ? _4521->raw() : nullptr,_4521 ? _4521->size(0) : 0);
            std::shared_ptr< monty::ndarray< long long,1 > > _4522 = mosek::fusion::p_WorkStack::_get_impl(_4503)->i64;
            _checked_ptr_1<long long> _ptr__4522(_4522 ? _4522->raw() : nullptr,_4522 ? _4522->size(0) : 0);
            std::shared_ptr< monty::ndarray< double,1 > > _4523 = mosek::fusion::p_WorkStack::_get_impl(_4503)->f64;
            _checked_ptr_1<double> _ptr__4523(_4523 ? _4523->raw() : nullptr,_4523 ? _4523->size(0) : 0);
            _ptr__4521[_4519] = (int)0;
            int _4524 = (int)0;
            if ((_4508 > (int)0))
            {
              {
                int _8946 = (int)0;
                int _8947 = _4512;
                for (int _4525 = _8946; _4525 < _8947; ++_4525)
                {
                  {
                    if ((_ptr__4522[safe_add( _4509,_4524 )] == _4525))
                    {
                      {
                        _ptr__4523[safe_add( _4520,_4525 )] = _ptr__4518[safe_add( _4516,_4524 )];
                        ++ _4524;
                      }
                    }
                    else
                    {
                      {
                        _ptr__4523[safe_add( _4520,_4525 )] = (int)0;
                      }
                    }
                    _ptr__4521[safe_add( safe_add( _4519,_4525 ),(int)1 )] = _ptr__4517[safe_add( _4515,_4524 )];
                  }
                }
              }
            }
            else
            {
              {
                int _8948 = (int)0;
                int _8949 = _4512;
                for (int _4526 = _8948; _4526 < _8949; ++_4526)
                {
                  {
                    _ptr__4523[safe_add( _4520,_4526 )] = (int)0;
                    _ptr__4521[safe_add( safe_add( _4519,_4526 ),(int)1 )] = (int)0;
                  }
                }
              }
            }
          }
          _4503->popi64(_4508);
          _4503->pushi32((int)0);
          _4503->pushi32(_4507);
          _4503->pushi32(_4512);
          int _8950 = (int)0;
          int _8951 = _4506;
          for (int _4527 = _8950; _4527 < _8951; ++_4527)
          {
            {
              _4503->pushi32(_ptr__4510[_4527]);
            }
          }
          _4503->pushi32(_4506);
        }
      }
      _4503->peek_expr();
    }
  }
  {}
  _4505->clear();
}
std::string mosek::fusion::ExprDense :: toString() { return mosek::fusion::p_ExprDense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDense::destroy(){expr.reset();}void mosek::fusion::ExprDense::destroy() { mosek::fusion::p_ExprDense::_get_impl(this)->destroy(); }mosek::fusion::ExprSymmetrize::ExprSymmetrize(mosek::fusion::p_ExprSymmetrize *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSymmetrize()" << this << std::endl; */ }mosek::fusion::ExprSymmetrize::~ExprSymmetrize() {  /* std::cout << "~ExprSymmetrize()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSymmetrize::p_ExprSymmetrize  (::mosek::fusion::ExprSymmetrize * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4528,    int _4529,    monty::rc_ptr< ::mosek::fusion::Expression > _4530,    int _4531){ return new mosek::fusion::ExprSymmetrize(_4528,_4529,_4530,_4531); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4528,    int _4529,    monty::rc_ptr< ::mosek::fusion::Expression > _4530,    int _4531) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4528,_4529,_4530,_4531); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4528,    int _4529,    monty::rc_ptr< ::mosek::fusion::Expression > _4530,    int _4531){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4530->getShape());
    mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->expr = _4530;
    if ((_4528 < _4529))
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4528;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4529;
      }
    }
    else
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4529;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4528;
      }
    }
  }
}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4532,    int _4533,    monty::rc_ptr< ::mosek::fusion::Expression > _4534){ return new mosek::fusion::ExprSymmetrize(_4532,_4533,_4534); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4532,    int _4533,    monty::rc_ptr< ::mosek::fusion::Expression > _4534) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4532,_4533,_4534); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4532,    int _4533,    monty::rc_ptr< ::mosek::fusion::Expression > _4534){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprSymmetrize::_initialize(_4532,_4533,_4534,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4535 = _4534->getShape();
    _checked_ptr_1<int> _ptr__4535(_4535 ? _4535->raw() : nullptr,_4535 ? _4535->size(0) : 0);
    if (((dim0 < (int)0) || ((dim0 == dim1) || ((dim1 >= (int)((_4535)->size(0))) || (_ptr__4535[dim0] != _ptr__4535[dim1])))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSymmetrize :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4536,monty::rc_ptr< ::mosek::fusion::WorkStack > _4537,monty::rc_ptr< ::mosek::fusion::WorkStack > _4538) { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->eval(_4536,_4537,_4538); }void mosek::fusion::p_ExprSymmetrize::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4536,monty::rc_ptr< ::mosek::fusion::WorkStack > _4537,monty::rc_ptr< ::mosek::fusion::WorkStack > _4538){
  expr->eval(_4537,_4536,_4538);
  int _4539 = (int)0;
  int _4540 = _4537->peeki32();
  int _4541 = _4537->peeki32(safe_add( _4540,(int)3 ));
  int _4542 = _4537->peeki32(safe_add( _4540,(int)2 ));
  int _8952 = (int)0;
  int _8953 = _4540;
  for (int _4543 = _8952; _4543 < _8953; ++_4543)
  {
    {
      int _4544 = _4537->peeki32(safe_add( _4543,(int)1 ));
      if ((_4544 > _4539))
      {
        {
          _4544 = _4539;
        }
      }
      {}
    }
  }
  int _4545 = _4537->alloci32(_4542);
  int _4546 = _4537->alloci32(_4542);
  int _4547 = _4537->alloci32(safe_add( _4539,(int)1 ));
  int _4548 = _4537->alloci64(_4542);
  _4537->popi32(safe_add( safe_add( safe_mul( (int)2,_4542 ),_4539 ),(int)1 ));
  _4537->popi64(_4542);
  int _4549 = _4537->popi32();
  int _4550 = _4537->popi32(_4549);
  int _4551 = _4537->popi32();
  int _4552 = _4537->popi32();
  bool _4553 = (_4537->popi32() != (int)0);
  int _4554 = _4537->popi32(safe_add( _4551,(int)1 ));
  int _8954;
  bool _8955 = _4553;
  if (_8955)
  {
    _8954 = _4537->popi64(_4551);
  }
  else
  {
    _8954 = (-(int)1);
  }
  int _4555 = _8954;
  int _4556 = _4537->popi64(_4552);
  int _4557 = _4537->popf64(_4551);
  int _4558 = _4537->popf64(_4552);
  int _4559 = (int)0;
  int _4560 = (int)0;
  std::vector<int> _8956;
  for (int _4562 = (int)0, _8957 = (int)5; _4562 < _8957 ; ++_4562)
  {
    _8956.push_back((int)1);
  }
  auto _8958 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8956.size()),_8956.begin(),_8956.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4561 = _8958;
  _checked_ptr_1<int> _ptr__4561(_4561 ? _4561->raw() : nullptr,_4561 ? _4561->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4563 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)5)));
  _checked_ptr_1<long long> _ptr__4563(_4563 ? _4563->raw() : nullptr,_4563 ? _4563->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4564 = mosek::fusion::p_WorkStack::_get_impl(_4537)->i32;
  _checked_ptr_1<int> _ptr__4564(_4564 ? _4564->raw() : nullptr,_4564 ? _4564->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4565 = mosek::fusion::p_WorkStack::_get_impl(_4537)->i64;
  _checked_ptr_1<long long> _ptr__4565(_4565 ? _4565->raw() : nullptr,_4565 ? _4565->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4566 = mosek::fusion::p_WorkStack::_get_impl(_4537)->f64;
  _checked_ptr_1<double> _ptr__4566(_4566 ? _4566->raw() : nullptr,_4566 ? _4566->size(0) : 0);
  int _8959 = (int)0;
  int _8960 = dim0;
  for (int _4567 = _8959; _4567 < _8960; ++_4567)
  {
    {
      _ptr__4561[(int)0] *= _ptr__4564[safe_add( _4550,_4567 )];
    }
  }
  _ptr__4561[(int)1] = _ptr__4564[safe_add( _4550,dim0 )];
  int _8961 = safe_add( dim0,(int)1 );
  int _8962 = dim1;
  for (int _4568 = _8961; _4568 < _8962; ++_4568)
  {
    {
      _ptr__4561[(int)2] *= _ptr__4564[safe_add( _4550,_4568 )];
    }
  }
  _ptr__4561[(int)3] = _ptr__4564[safe_add( _4550,dim1 )];
  int _8963 = safe_add( dim1,(int)1 );
  int _8964 = _4549;
  for (int _4569 = _8963; _4569 < _8964; ++_4569)
  {
    {
      _ptr__4561[(int)4] *= _ptr__4564[safe_add( _4550,_4569 )];
    }
  }
  _ptr__4563[(int)4] = (int)1;
  int _8965 = (int)1;
  int _8966 = (int)5;
  for (int _4570 = _8965; _4570 < _8966; ++_4570)
  {
    {
      _ptr__4563[(((int)5 - _4570) - (int)1)] = safe_mul( _ptr__4563[((int)5 - _4570)],_ptr__4561[((int)5 - _4570)] );
    }
  }
  if (_4553)
  {
    {
      int _4571 = _4545;
      int _8967 = (int)0;
      int _8968 = _4551;
      for (int _4572 = _8967; _4572 < _8968; ++_4572)
      {
        {
          _ptr__4564[safe_add( _4571,_4572 )] = _4572;
        }
      }
      int _4573 = _4546;
      std::shared_ptr< monty::ndarray< int,1 > > _4574 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)2),(int)((int)3),(int)((int)0)});
      _checked_ptr_1<int> _ptr__4574(_4574 ? _4574->raw() : nullptr,_4574 ? _4574->size(0) : 0);
      int _8969 = (int)0;
      int _8970 = (int)4;
      for (int _4575 = _8969; _4575 < _8970; ++_4575)
      {
        {
          long long _4576 = _ptr__4563[_ptr__4574[_4575]];
          int _4577 = _ptr__4561[_ptr__4574[_4575]];
          if ((_4577 > (int)1))
          {
            {
              int _8971 = (int)0;
              int _8972 = safe_add( _4577,(int)1 );
              for (int _4578 = _8971; _4578 < _8972; ++_4578)
              {
                {
                  _ptr__4564[safe_add( _4547,_4578 )] = (int)0;
                }
              }
              int _8973 = (int)0;
              int _8974 = _4551;
              for (int _4579 = _8973; _4579 < _8974; ++_4579)
              {
                {
                  ++ _ptr__4564[safe_add( safe_add( _4547,((_ptr__4565[safe_add( _4555,_ptr__4564[safe_add( _4571,_4579 )] )] / _4576) % _4577) ),(int)1 )];
                }
              }
              int _8975 = (int)0;
              int _8976 = _ptr__4561[(int)3];
              for (int _4580 = _8975; _4580 < _8976; ++_4580)
              {
                {
                  _ptr__4564[safe_add( safe_add( _4547,_4580 ),(int)1 )] += _ptr__4564[safe_add( _4547,_4580 )];
                }
              }
              int _8977 = (int)0;
              int _8978 = _4551;
              for (int _4581 = _8977; _4581 < _8978; ++_4581)
              {
                {
                  int _4582 = _ptr__4564[safe_add( _4571,_4581 )];
                  long long _4583 = ((_ptr__4565[safe_add( _4555,_4582 )] / _4576) % _4577);
                  _ptr__4564[safe_add( _4573,_ptr__4564[safe_add( _4547,_4583 )] )] = _4582;
                  ++ _ptr__4564[safe_add( _4547,_4583 )];
                }
              }
              int _4584 = _4571;
              _4571 = _4573;
              _4573 = _4584;
            }
          }
          {}
        }
      }
      int _8979 = (int)0;
      int _8980 = _4551;
      for (int _4585 = _8979; _4585 < _8980; ++_4585)
      {
        {
          _ptr__4565[safe_add( _4548,_4585 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( ((_ptr__4565[safe_add( _4555,_4585 )] / _ptr__4563[(int)0]) % _ptr__4561[(int)0]),_ptr__4563[(int)0] ),safe_mul( ((_ptr__4565[safe_add( _4555,_4585 )] / _ptr__4563[(int)1]) % _ptr__4561[(int)1]),_ptr__4563[(int)3] ) ),safe_mul( ((_ptr__4565[safe_add( _4555,_4585 )] / _ptr__4563[(int)2]) % _ptr__4561[(int)2]),_ptr__4563[(int)2] ) ),safe_mul( ((_ptr__4565[safe_add( _4555,_4585 )] / _ptr__4563[(int)3]) % _ptr__4561[(int)3]),_ptr__4563[(int)1] ) ),safe_mul( ((_ptr__4565[safe_add( _4555,_4585 )] / _ptr__4563[(int)4]) % _ptr__4561[(int)4]),_ptr__4563[(int)4] ) );
        }
      }
      {
        int _4586 = (int)0;
        int _4587 = (int)0;
        while ( ((_4587 < _4551) && (_4586 < _4551)) )
        {
          {
            int _4588 = _ptr__4564[safe_add( _4571,_4586 )];
            if ((_ptr__4565[safe_add( _4555,_4587 )] < _ptr__4565[safe_add( _4548,_4588 )]))
            {
              {
                _4560 += (_ptr__4564[safe_add( safe_add( _4554,_4587 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4587 )]);
                ++ _4559;
                ++ _4587;
              }
            }
            else if((_ptr__4565[safe_add( _4555,_4587 )] > _ptr__4565[safe_add( _4548,_4588 )]))
            {
              {
                _4560 += (_ptr__4564[safe_add( safe_add( _4554,_4588 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4588 )]);
                ++ _4559;
                ++ _4586;
              }
            }
            else if((_ptr__4565[safe_add( _4555,_4587 )] != _ptr__4565[safe_add( _4555,_4588 )]))
            {
              {
                _4560 += (_ptr__4564[safe_add( safe_add( _4554,_4587 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4587 )]);
                _4560 += (_ptr__4564[safe_add( safe_add( _4554,_4588 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4588 )]);
                ++ _4559;
                ++ _4586;
                ++ _4587;
              }
            }
            else
            {
              {
                _4560 += (_ptr__4564[safe_add( safe_add( _4554,_4587 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4587 )]);
                ++ _4559;
                ++ _4586;
                ++ _4587;
              }
            }
          }
        }
        while ( (_4587 < _4551) )
        {
          {
            _4560 += (_ptr__4564[safe_add( safe_add( _4554,_4587 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4587 )]);
            ++ _4559;
            ++ _4587;
          }
        }
        while ( (_4586 < _4551) )
        {
          {
            int _4589 = _ptr__4564[safe_add( _4571,_4586 )];
            _4560 += (_ptr__4564[safe_add( safe_add( _4554,_4589 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4589 )]);
            ++ _4559;
            ++ _4586;
          }
        }
      }
      int _4590 = _4536->alloci32(safe_add( _4559,(int)1 ));
      _4536->pushi32((int)1);
      _4536->pushi32(_4560);
      _4536->pushi32(_4559);
      int _8981 = (int)0;
      int _8982 = _4549;
      for (int _4591 = _8981; _4591 < _8982; ++_4591)
      {
        {
          _4536->pushi32(_ptr__4564[safe_add( _4550,_4591 )]);
        }
      }
      _4536->pushi32(_4549);
      int _4592 = _4536->alloci64(_4560);
      int _4593 = _4536->alloci64(_4559);
      int _4594 = _4536->allocf64(_4560);
      int _4595 = _4536->allocf64(_4559);
      std::shared_ptr< monty::ndarray< int,1 > > _4596 = mosek::fusion::p_WorkStack::_get_impl(_4536)->i32;
      _checked_ptr_1<int> _ptr__4596(_4596 ? _4596->raw() : nullptr,_4596 ? _4596->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4597 = mosek::fusion::p_WorkStack::_get_impl(_4536)->i64;
      _checked_ptr_1<long long> _ptr__4597(_4597 ? _4597->raw() : nullptr,_4597 ? _4597->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4598 = mosek::fusion::p_WorkStack::_get_impl(_4536)->f64;
      _checked_ptr_1<double> _ptr__4598(_4598 ? _4598->raw() : nullptr,_4598 ? _4598->size(0) : 0);
      _ptr__4596[_4590] = (int)0;
      {
        int _4599 = (int)0;
        int _4600 = (int)0;
        int _4601 = (int)0;
        int _4602 = (int)0;
        _ptr__4564[_4590] = (int)0;
        while ( ((_4602 < _4551) && (_4601 < _4551)) )
        {
          {
            int _4603 = _ptr__4564[safe_add( _4571,_4601 )];
            if ((_ptr__4565[safe_add( _4555,_4602 )] < _ptr__4565[safe_add( _4548,_4603 )]))
            {
              {
                int _8983 = _ptr__4564[safe_add( _4554,_4602 )];
                int _8984 = _ptr__4564[safe_add( safe_add( _4554,_4602 ),(int)1 )];
                for (int _4604 = _8983; _4604 < _8984; ++_4604)
                {
                  {
                    _ptr__4597[safe_add( _4592,_4599 )] = _ptr__4565[safe_add( _4556,_4604 )];
                    _ptr__4598[safe_add( _4594,_4599 )] = (_ptr__4566[safe_add( _4558,_4604 )] * 0.5);
                    ++ _4599;
                  }
                }
                _ptr__4598[safe_add( _4595,_4600 )] = (_ptr__4566[safe_add( _4557,_4602 )] * 0.5);
                _ptr__4597[safe_add( _4593,_4600 )] = _ptr__4565[safe_add( _4555,_4602 )];
                _ptr__4596[safe_add( safe_add( _4590,_4600 ),(int)1 )] = _4599;
                ++ _4600;
                ++ _4602;
              }
            }
            else if((_ptr__4565[safe_add( _4555,_4602 )] > _ptr__4565[safe_add( _4548,_4603 )]))
            {
              {
                int _8985 = _ptr__4564[safe_add( _4554,_4603 )];
                int _8986 = _ptr__4564[safe_add( safe_add( _4554,_4603 ),(int)1 )];
                for (int _4605 = _8985; _4605 < _8986; ++_4605)
                {
                  {
                    _ptr__4597[safe_add( _4592,_4599 )] = _ptr__4565[safe_add( _4556,_4605 )];
                    _ptr__4598[safe_add( _4594,_4599 )] = (_ptr__4566[safe_add( _4558,_4605 )] * 0.5);
                    ++ _4599;
                  }
                }
                _ptr__4598[safe_add( _4595,_4600 )] = (_ptr__4566[safe_add( _4557,_4603 )] * 0.5);
                _ptr__4597[safe_add( _4593,_4600 )] = _ptr__4565[safe_add( _4548,_4603 )];
                _ptr__4596[safe_add( safe_add( _4590,_4600 ),(int)1 )] = _4599;
                ++ _4600;
                ++ _4601;
              }
            }
            else if((_ptr__4565[safe_add( _4555,_4602 )] != _ptr__4565[safe_add( _4555,_4603 )]))
            {
              {
                int _8987 = _ptr__4564[safe_add( _4554,_4602 )];
                int _8988 = _ptr__4564[safe_add( safe_add( _4554,_4602 ),(int)1 )];
                for (int _4606 = _8987; _4606 < _8988; ++_4606)
                {
                  {
                    _ptr__4597[safe_add( _4592,_4599 )] = _ptr__4565[safe_add( _4556,_4606 )];
                    _ptr__4598[safe_add( _4594,_4599 )] = (_ptr__4566[safe_add( _4558,_4606 )] * 0.5);
                    ++ _4599;
                  }
                }
                int _8989 = _ptr__4564[safe_add( _4554,_4603 )];
                int _8990 = _ptr__4564[safe_add( safe_add( _4554,_4603 ),(int)1 )];
                for (int _4607 = _8989; _4607 < _8990; ++_4607)
                {
                  {
                    _ptr__4597[safe_add( _4592,_4599 )] = _ptr__4565[safe_add( _4556,_4607 )];
                    _ptr__4598[safe_add( _4594,_4599 )] = (_ptr__4566[safe_add( _4558,_4607 )] * 0.5);
                    ++ _4599;
                  }
                }
                _ptr__4598[safe_add( _4595,_4600 )] = (0.5 * (_ptr__4566[safe_add( _4557,_4602 )] + _ptr__4566[safe_add( _4557,_4603 )]));
                _ptr__4597[safe_add( _4593,_4600 )] = _ptr__4565[safe_add( _4555,_4602 )];
                _ptr__4596[safe_add( safe_add( _4590,_4600 ),(int)1 )] = _4599;
                ++ _4600;
                ++ _4601;
                ++ _4602;
              }
            }
            else
            {
              {
                int _8991 = _ptr__4564[safe_add( _4554,_4602 )];
                int _8992 = _ptr__4564[safe_add( safe_add( _4554,_4602 ),(int)1 )];
                for (int _4608 = _8991; _4608 < _8992; ++_4608)
                {
                  {
                    _ptr__4597[safe_add( _4592,_4599 )] = _ptr__4565[safe_add( _4556,_4608 )];
                    _ptr__4598[safe_add( _4594,_4599 )] = _ptr__4566[safe_add( _4558,_4608 )];
                    ++ _4599;
                  }
                }
                _ptr__4598[safe_add( _4595,_4600 )] = _ptr__4566[safe_add( _4557,_4602 )];
                _ptr__4597[safe_add( _4593,_4600 )] = _ptr__4565[safe_add( _4555,_4602 )];
                _ptr__4596[safe_add( safe_add( _4590,_4600 ),(int)1 )] = _4599;
                ++ _4600;
                ++ _4601;
                ++ _4602;
              }
            }
          }
        }
        while ( (_4602 < _4551) )
        {
          {
            int _8993 = _ptr__4564[safe_add( _4554,_4602 )];
            int _8994 = _ptr__4564[safe_add( safe_add( _4554,_4602 ),(int)1 )];
            for (int _4609 = _8993; _4609 < _8994; ++_4609)
            {
              {
                _ptr__4597[safe_add( _4592,_4599 )] = _ptr__4565[safe_add( _4556,_4609 )];
                _ptr__4598[safe_add( _4594,_4599 )] = (_ptr__4566[safe_add( _4558,_4609 )] * 0.5);
                ++ _4599;
              }
            }
            _ptr__4598[safe_add( _4595,_4600 )] = (_ptr__4566[safe_add( _4557,_4602 )] * 0.5);
            _ptr__4597[safe_add( _4593,_4600 )] = _ptr__4565[safe_add( _4555,_4602 )];
            _ptr__4596[safe_add( safe_add( _4590,_4600 ),(int)1 )] = _4599;
            ++ _4600;
            ++ _4602;
          }
        }
        while ( (_4601 < _4551) )
        {
          {
            int _4610 = _ptr__4564[safe_add( _4571,_4601 )];
            int _8995 = _ptr__4564[safe_add( _4554,_4610 )];
            int _8996 = _ptr__4564[safe_add( safe_add( _4554,_4610 ),(int)1 )];
            for (int _4611 = _8995; _4611 < _8996; ++_4611)
            {
              {
                _ptr__4597[safe_add( _4592,_4599 )] = _ptr__4565[safe_add( _4556,_4611 )];
                _ptr__4598[safe_add( _4594,_4599 )] = (_ptr__4566[safe_add( _4558,_4611 )] * 0.5);
                ++ _4599;
              }
            }
            _ptr__4598[safe_add( _4595,_4600 )] = (_ptr__4566[safe_add( _4557,_4610 )] * 0.5);
            _ptr__4597[safe_add( _4593,_4600 )] = _ptr__4565[safe_add( _4548,_4610 )];
            _ptr__4596[safe_add( safe_add( _4590,_4600 ),(int)1 )] = _4599;
            ++ _4600;
            ++ _4601;
          }
        }
      }
    }
  }
  else
  {
    {
      _4559 = _4551;
      _4560 = safe_mul( _4552,(int)2 );
      int _8997 = (int)0;
      int _8998 = _ptr__4561[(int)0];
      for (int _4612 = _8997; _4612 < _8998; ++_4612)
      {
        {
          int _8999 = (int)0;
          int _9000 = _ptr__4561[(int)2];
          for (int _4613 = _8999; _4613 < _9000; ++_4613)
          {
            {
              int _9001 = (int)0;
              int _9002 = _ptr__4561[(int)4];
              for (int _4614 = _9001; _4614 < _9002; ++_4614)
              {
                {
                  int _9003 = (int)0;
                  int _9004 = _ptr__4561[(int)1];
                  for (int _4615 = _9003; _4615 < _9004; ++_4615)
                  {
                    {
                      long long _4616 = safe_add( safe_add( safe_add( safe_add( safe_mul( _ptr__4563[(int)0],_4612 ),safe_mul( _ptr__4563[(int)1],_4615 ) ),safe_mul( _ptr__4563[(int)2],_4613 ) ),safe_mul( _ptr__4563[(int)3],_4615 ) ),safe_mul( _ptr__4563[(int)4],_4614 ) );
                      _4560 -= (_ptr__4564[safe_add( safe_add( _4554,_4616 ),(int)1 )] - _ptr__4564[safe_add( _4554,_4616 )]);
                    }
                  }
                }
              }
            }
          }
        }
      }
      int _4617 = _4536->alloci32(safe_add( _4559,(int)1 ));
      _4536->pushi32((int)0);
      _4536->pushi32(_4560);
      _4536->pushi32(_4559);
      int _9005 = (int)0;
      int _9006 = _4549;
      for (int _4618 = _9005; _4618 < _9006; ++_4618)
      {
        {
          _4536->pushi32(_ptr__4564[safe_add( _4550,_4618 )]);
        }
      }
      _4536->pushi32(_4549);
      int _4619 = _4536->alloci64(_4560);
      int _4620 = _4536->allocf64(_4560);
      int _4621 = _4536->allocf64(_4559);
      std::shared_ptr< monty::ndarray< int,1 > > _4622 = mosek::fusion::p_WorkStack::_get_impl(_4536)->i32;
      _checked_ptr_1<int> _ptr__4622(_4622 ? _4622->raw() : nullptr,_4622 ? _4622->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4623 = mosek::fusion::p_WorkStack::_get_impl(_4536)->i64;
      _checked_ptr_1<long long> _ptr__4623(_4623 ? _4623->raw() : nullptr,_4623 ? _4623->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4624 = mosek::fusion::p_WorkStack::_get_impl(_4536)->f64;
      _checked_ptr_1<double> _ptr__4624(_4624 ? _4624->raw() : nullptr,_4624 ? _4624->size(0) : 0);
      int _4625 = (int)0;
      int _4626 = (int)0;
      _ptr__4622[_4617] = (int)0;
      int _4627 = (int)0;
      int _9007 = (int)0;
      int _9008 = _ptr__4561[(int)0];
      for (int _4628 = _9007; _4628 < _9008; ++_4628)
      {
        {
          int _9009 = (int)0;
          int _9010 = _ptr__4561[(int)1];
          for (int _4629 = _9009; _4629 < _9010; ++_4629)
          {
            {
              int _9011 = (int)0;
              int _9012 = _ptr__4561[(int)2];
              for (int _4630 = _9011; _4630 < _9012; ++_4630)
              {
                {
                  int _9013 = (int)0;
                  int _9014 = _ptr__4561[(int)3];
                  for (int _4631 = _9013; _4631 < _9014; ++_4631)
                  {
                    {
                      int _9015 = (int)0;
                      int _9016 = _ptr__4561[(int)4];
                      for (int _4632 = _9015; _4632 < _9016; ++_4632)
                      {
                        {
                          if ((_4629 == _4631))
                          {
                            {
                              int _9017 = _ptr__4564[safe_add( _4554,_4627 )];
                              int _9018 = _ptr__4564[safe_add( safe_add( _4554,_4627 ),(int)1 )];
                              for (int _4633 = _9017; _4633 < _9018; ++_4633)
                              {
                                {
                                  _ptr__4623[safe_add( _4619,_4625 )] = _ptr__4565[safe_add( _4556,_4633 )];
                                  _ptr__4624[safe_add( _4620,_4625 )] = _ptr__4566[safe_add( _4558,_4633 )];
                                  ++ _4625;
                                }
                              }
                              _ptr__4624[safe_add( _4621,_4626 )] = _ptr__4566[safe_add( _4557,_4628 )];
                              _ptr__4622[safe_add( safe_add( _4617,_4626 ),(int)1 )] = _4625;
                              ++ _4627;
                            }
                          }
                          else
                          {
                            {
                              long long _4634 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4628,_ptr__4563[(int)0] ),safe_mul( _4631,_ptr__4563[(int)1] ) ),safe_mul( _4630,_ptr__4563[(int)2] ) ),safe_mul( _4629,_ptr__4563[(int)3] ) ),_4632 );
                              int _9019 = _ptr__4564[safe_add( _4554,_4627 )];
                              int _9020 = _ptr__4564[safe_add( safe_add( _4554,_4627 ),(int)1 )];
                              for (int _4635 = _9019; _4635 < _9020; ++_4635)
                              {
                                {
                                  _ptr__4623[safe_add( _4619,_4625 )] = _ptr__4565[safe_add( _4556,_4635 )];
                                  _ptr__4624[safe_add( _4620,_4625 )] = (_ptr__4566[safe_add( _4558,_4635 )] * 0.5);
                                  ++ _4625;
                                }
                              }
                              int _9021 = _ptr__4564[safe_add( _4554,_4634 )];
                              int _9022 = _ptr__4564[safe_add( safe_add( _4554,_4634 ),(int)1 )];
                              for (int _4636 = _9021; _4636 < _9022; ++_4636)
                              {
                                {
                                  _ptr__4623[safe_add( _4619,_4625 )] = _ptr__4565[safe_add( _4556,_4636 )];
                                  _ptr__4624[safe_add( _4620,_4625 )] = (_ptr__4566[safe_add( _4558,_4636 )] * 0.5);
                                  ++ _4625;
                                }
                              }
                              _ptr__4624[safe_add( _4621,_4626 )] = (0.5 * (_ptr__4566[safe_add( _4557,_4627 )] + _ptr__4566[safe_add( _4557,_4634 )]));
                              _ptr__4622[safe_add( safe_add( _4617,_4626 ),(int)1 )] = _4625;
                              ++ _4627;
                            }
                          }
                          ++ _4626;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprSymmetrize::destroy(){expr.reset();}void mosek::fusion::ExprSymmetrize::destroy() { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->destroy(); }mosek::fusion::ExprCompress::ExprCompress(mosek::fusion::p_ExprCompress *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCompress()" << this << std::endl; */ }mosek::fusion::ExprCompress::~ExprCompress() {  /* std::cout << "~ExprCompress()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCompress::p_ExprCompress  (::mosek::fusion::ExprCompress * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4637){ return new mosek::fusion::ExprCompress(_4637); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4637) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4637); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4637){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4637->getShape());
    eps = 0.0;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4637;
  }
}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4638,    double _4639){ return new mosek::fusion::ExprCompress(_4638,_4639); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4638,    double _4639) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4638,_4639); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4638,    double _4639){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4638->getShape());
    eps = _4639;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4638;
  }
}void mosek::fusion::ExprCompress :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4640,monty::rc_ptr< ::mosek::fusion::WorkStack > _4641,monty::rc_ptr< ::mosek::fusion::WorkStack > _4642) { mosek::fusion::p_ExprCompress::_get_impl(this)->eval(_4640,_4641,_4642); }void mosek::fusion::p_ExprCompress::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4640,monty::rc_ptr< ::mosek::fusion::WorkStack > _4641,monty::rc_ptr< ::mosek::fusion::WorkStack > _4642){
  expr->eval(_4641,_4640,_4642);
  _4641->pop_expr();
  int _4643 = mosek::fusion::p_WorkStack::_get_impl(_4641)->nd;
  int _4644 = mosek::fusion::p_WorkStack::_get_impl(_4641)->shape_base;
  int _4645 = mosek::fusion::p_WorkStack::_get_impl(_4641)->nelem;
  int _4646 = mosek::fusion::p_WorkStack::_get_impl(_4641)->nnz;
  bool _4647 = mosek::fusion::p_WorkStack::_get_impl(_4641)->hassp;
  int _4648 = mosek::fusion::p_WorkStack::_get_impl(_4641)->ptr_base;
  int _4649 = mosek::fusion::p_WorkStack::_get_impl(_4641)->sp_base;
  int _4650 = mosek::fusion::p_WorkStack::_get_impl(_4641)->nidxs_base;
  int _4651 = mosek::fusion::p_WorkStack::_get_impl(_4641)->bfix_base;
  int _4652 = mosek::fusion::p_WorkStack::_get_impl(_4641)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4653 = mosek::fusion::p_WorkStack::_get_impl(_4641)->i32;
  _checked_ptr_1<int> _ptr__4653(_4653 ? _4653->raw() : nullptr,_4653 ? _4653->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4654 = mosek::fusion::p_WorkStack::_get_impl(_4641)->i64;
  _checked_ptr_1<long long> _ptr__4654(_4654 ? _4654->raw() : nullptr,_4654 ? _4654->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4655 = mosek::fusion::p_WorkStack::_get_impl(_4641)->f64;
  _checked_ptr_1<double> _ptr__4655(_4655 ? _4655->raw() : nullptr,_4655 ? _4655->size(0) : 0);
  std::vector<int> _9023;
  for (int _4657 = (int)0, _9024 = _4643; _4657 < _9024 ; ++_4657)
  {
    _9023.push_back(_ptr__4653[safe_add( _4644,_4657 )]);
  }
  auto _9025 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9023.size()),_9023.begin(),_9023.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4656 = _9025;
  _checked_ptr_1<int> _ptr__4656(_4656 ? _4656->raw() : nullptr,_4656 ? _4656->size(0) : 0);
  bool _4658 = true;
  int _9026 = (int)0;
  int _9027 = _4645;
  for (int _4659 = _9026; _4659 < _9027; ++_4659)
  {
    {
      int _9028 = safe_add( _ptr__4653[safe_add( _4648,_4659 )],(int)1 );
      int _9029 = _ptr__4653[safe_add( safe_add( _4648,_4659 ),(int)1 )];
      for (int _4660 = _9028; _4660 < _9029; ++_4660)
      {
        {
          _4658 = (_4658 && (_ptr__4654[(safe_add( _4650,_4660 ) - (int)1)] < _ptr__4654[safe_add( _4650,_4660 )]));
        }
      }
    }
  }
  if (_4658)
  {
    {
      int _9030 = (int)0;
      int _9031 = _4646;
      for (int _4661 = _9030; _4661 < _9031; ++_4661)
      {
        {
          _4658 = (_4658 && ((_ptr__4655[safe_add( _4652,_4661 )] <= (0.0 - eps)) || ((0.0 + eps) <= _ptr__4655[safe_add( _4652,_4661 )])));
        }
      }
    }
  }
  {}
  if (_4658)
  {
    {
      _4640->alloc_expr(_4643,_4645,_4646,_4647);
      int _4662 = mosek::fusion::p_WorkStack::_get_impl(_4640)->ptr_base;
      int _4663 = mosek::fusion::p_WorkStack::_get_impl(_4640)->nidxs_base;
      int _4664 = mosek::fusion::p_WorkStack::_get_impl(_4640)->sp_base;
      int _4665 = mosek::fusion::p_WorkStack::_get_impl(_4640)->cof_base;
      int _4666 = mosek::fusion::p_WorkStack::_get_impl(_4640)->bfix_base;
      int _4667 = mosek::fusion::p_WorkStack::_get_impl(_4640)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4668 = mosek::fusion::p_WorkStack::_get_impl(_4640)->i32;
      _checked_ptr_1<int> _ptr__4668(_4668 ? _4668->raw() : nullptr,_4668 ? _4668->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4669 = mosek::fusion::p_WorkStack::_get_impl(_4640)->i64;
      _checked_ptr_1<long long> _ptr__4669(_4669 ? _4669->raw() : nullptr,_4669 ? _4669->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4670 = mosek::fusion::p_WorkStack::_get_impl(_4640)->f64;
      _checked_ptr_1<double> _ptr__4670(_4670 ? _4670->raw() : nullptr,_4670 ? _4670->size(0) : 0);
      {
        int _9032 = (int)0;
        int _9033 = _4643;
        for (int _4671 = _9032; _4671 < _9033; ++_4671)
        {
          {
            _ptr__4668[safe_add( _4667,_4671 )] = _ptr__4656[_4671];
          }
        }
        int _9034 = (int)0;
        int _9035 = safe_add( _4645,(int)1 );
        for (int _4672 = _9034; _4672 < _9035; ++_4672)
        {
          {
            _ptr__4668[safe_add( _4662,_4672 )] = _ptr__4653[safe_add( _4648,_4672 )];
          }
        }
        if (_4647)
        {
          {
            int _9036 = (int)0;
            int _9037 = _4645;
            for (int _4673 = _9036; _4673 < _9037; ++_4673)
            {
              {
                _ptr__4669[safe_add( _4664,_4673 )] = _ptr__4654[safe_add( _4649,_4673 )];
              }
            }
          }
        }
        {}
        int _9038 = (int)0;
        int _9039 = _4645;
        for (int _4674 = _9038; _4674 < _9039; ++_4674)
        {
          {
            _ptr__4670[safe_add( _4666,_4674 )] = _ptr__4655[safe_add( _4651,_4674 )];
          }
        }
        int _9040 = (int)0;
        int _9041 = _4646;
        for (int _4675 = _9040; _4675 < _9041; ++_4675)
        {
          {
            _ptr__4669[safe_add( _4663,_4675 )] = _ptr__4654[safe_add( _4650,_4675 )];
          }
        }
        int _9042 = (int)0;
        int _9043 = _4646;
        for (int _4676 = _9042; _4676 < _9043; ++_4676)
        {
          {
            _ptr__4670[safe_add( _4665,_4676 )] = _ptr__4655[safe_add( _4652,_4676 )];
          }
        }
      }
    }
  }
  else
  {
    {
      int _4677 = _4642->alloci32(_4646);
      ::mosek::fusion::p_ExprCompress::arg_sort(_4641,_4642,_4677,_4645,_4646,_4648,_4650);
      std::shared_ptr< monty::ndarray< int,1 > > _4678 = mosek::fusion::p_WorkStack::_get_impl(_4642)->i32;
      _checked_ptr_1<int> _ptr__4678(_4678 ? _4678->raw() : nullptr,_4678 ? _4678->size(0) : 0);
      int _4679 = (int)0;
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4680 = mosek::fusion::p_WorkStack::_get_impl(_4640)->i32;
        _checked_ptr_1<int> _ptr__4680(_4680 ? _4680->raw() : nullptr,_4680 ? _4680->size(0) : 0);
        {
          int _9044 = (int)0;
          int _9045 = _4645;
          for (int _4681 = _9044; _4681 < _9045; ++_4681)
          {
            {
              int _4682 = _ptr__4653[safe_add( safe_add( _4648,_4681 ),(int)1 )];
              int _4683 = _ptr__4653[safe_add( _4648,_4681 )];
              if ((_4683 < _4682))
              {
                {
                  int _4684 = _4683;
                  while ( (_4684 < _4682) )
                  {
                    {
                      double _4685 = 0.0;
                      long long _4686 = _ptr__4654[safe_add( _4650,_ptr__4678[safe_add( _4677,_4684 )] )];
                      while ( ((_4684 < _4682) && (_ptr__4654[safe_add( _4650,_ptr__4678[safe_add( _4677,_4684 )] )] == _4686)) )
                      {
                        {
                          _4685 += _ptr__4655[safe_add( _4652,_ptr__4678[safe_add( _4677,_4684 )] )];
                          ++ _4684;
                        }
                      }
                      {
                      }
                      if (((_4686 != (int)0) && ((_4685 < (-eps)) || (eps < _4685))))
                      {
                        {
                          ++ _4679;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
            }
          }
        }
      }
      _4640->alloc_expr(_4643,_4645,_4679,_4647);
      int _4687 = mosek::fusion::p_WorkStack::_get_impl(_4640)->nidxs_base;
      int _4688 = mosek::fusion::p_WorkStack::_get_impl(_4640)->shape_base;
      int _4689 = mosek::fusion::p_WorkStack::_get_impl(_4640)->sp_base;
      int _4690 = mosek::fusion::p_WorkStack::_get_impl(_4640)->cof_base;
      int _4691 = mosek::fusion::p_WorkStack::_get_impl(_4640)->bfix_base;
      int _4692 = mosek::fusion::p_WorkStack::_get_impl(_4640)->ptr_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4693 = mosek::fusion::p_WorkStack::_get_impl(_4640)->i32;
      _checked_ptr_1<int> _ptr__4693(_4693 ? _4693->raw() : nullptr,_4693 ? _4693->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4694 = mosek::fusion::p_WorkStack::_get_impl(_4640)->i64;
      _checked_ptr_1<long long> _ptr__4694(_4694 ? _4694->raw() : nullptr,_4694 ? _4694->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4695 = mosek::fusion::p_WorkStack::_get_impl(_4640)->f64;
      _checked_ptr_1<double> _ptr__4695(_4695 ? _4695->raw() : nullptr,_4695 ? _4695->size(0) : 0);
      int _9046 = (int)0;
      int _9047 = _4643;
      for (int _4696 = _9046; _4696 < _9047; ++_4696)
      {
        {
          _ptr__4693[safe_add( _4688,_4696 )] = _ptr__4656[_4696];
        }
      }
      {
        int _9048 = (int)0;
        int _9049 = _4645;
        for (int _4697 = _9048; _4697 < _9049; ++_4697)
        {
          {
            _ptr__4695[safe_add( _4690,_4697 )] = 0.0;
          }
        }
        int _9050 = (int)0;
        int _9051 = _4645;
        for (int _4698 = _9050; _4698 < _9051; ++_4698)
        {
          {
            _ptr__4695[safe_add( _4691,_4698 )] = _ptr__4655[safe_add( _4651,_4698 )];
          }
        }
        if (_4647)
        {
          {
            int _9052 = (int)0;
            int _9053 = _4645;
            for (int _4699 = _9052; _4699 < _9053; ++_4699)
            {
              {
                _ptr__4694[safe_add( _4689,_4699 )] = _ptr__4654[safe_add( _4689,_4699 )];
              }
            }
          }
        }
        {}
        int _4700 = (int)0;
        {
          int _4701 = (_4690 - _4687);
          _ptr__4693[_4692] = (int)0;
          int _9054 = (int)0;
          int _9055 = _4645;
          for (int _4702 = _9054; _4702 < _9055; ++_4702)
          {
            {
              int _4703 = _ptr__4653[safe_add( safe_add( _4648,_4702 ),(int)1 )];
              int _4704 = _ptr__4653[safe_add( _4648,_4702 )];
              if ((_4704 < _4703))
              {
                {
                  int _4705 = _4704;
                  while ( (_4705 < _4703) )
                  {
                    {
                      double _4706 = 0.0;
                      long long _4707 = _ptr__4654[safe_add( _4650,_ptr__4678[safe_add( _4677,_4705 )] )];
                      while ( ((_4705 < _4703) && (_ptr__4654[safe_add( _4650,_ptr__4678[safe_add( _4677,_4705 )] )] == _4707)) )
                      {
                        {
                          _4706 += _ptr__4655[safe_add( _4652,_ptr__4678[safe_add( _4677,_4705 )] )];
                          ++ _4705;
                        }
                      }
                      {
                      }
                      if (((_4707 != (int)0) && ((_4706 < (-eps)) || (eps < _4706))))
                      {
                        {
                          _ptr__4694[safe_add( _4687,_4700 )] = _4707;
                          _ptr__4695[safe_add( _4690,_4700 )] = _4706;
                          ++ _4700;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
              _ptr__4693[safe_add( safe_add( _4692,_4702 ),(int)1 )] = _4700;
            }
          }
        }
      }
    }
  }
  _4642->clear();
}
void mosek::fusion::ExprCompress::arg_sort  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4708,    monty::rc_ptr< ::mosek::fusion::WorkStack > _4709,    int _4710,    int _4711,    int _4712,    int _4713,    int _4714) { mosek::fusion::p_ExprCompress::arg_sort(_4708,_4709,_4710,_4711,_4712,_4713,_4714); }void mosek::fusion::p_ExprCompress::arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4708,monty::rc_ptr< ::mosek::fusion::WorkStack > _4709,int _4710,int _4711,int _4712,int _4713,int _4714){
  int _4715 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4716 = mosek::fusion::p_WorkStack::_get_impl(_4708)->i32;
  _checked_ptr_1<int> _ptr__4716(_4716 ? _4716->raw() : nullptr,_4716 ? _4716->size(0) : 0);
  int _9056 = (int)0;
  int _9057 = _4711;
  for (int _4717 = _9056; _4717 < _9057; ++_4717)
  {
    {
      if (((_ptr__4716[safe_add( safe_add( _4713,_4717 ),(int)1 )] - _ptr__4716[safe_add( _4713,_4717 )]) > _4715))
      {
        {
          _4715 = (_ptr__4716[safe_add( safe_add( _4713,_4717 ),(int)1 )] - _ptr__4716[safe_add( _4713,_4717 )]);
        }
      }
      {}
    }
  }
  int _9058;
  bool _9059 = (_4715 > (int)2);
  if (_9059)
  {
    _9058 = _4709->alloci32(safe_mul( _4715,(int)2 ));
  }
  else
  {
    _9058 = (int)99999;
  }
  int _4718 = _9058;
  std::shared_ptr< monty::ndarray< int,1 > > _4719 = mosek::fusion::p_WorkStack::_get_impl(_4709)->i32;
  _checked_ptr_1<int> _ptr__4719(_4719 ? _4719->raw() : nullptr,_4719 ? _4719->size(0) : 0);
  _4716 = mosek::fusion::p_WorkStack::_get_impl(_4708)->i32;
  _ptr__4716.update(_4716 ? _4716->raw() : nullptr, _4716 ? _4716->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4720 = mosek::fusion::p_WorkStack::_get_impl(_4708)->i64;
  _checked_ptr_1<long long> _ptr__4720(_4720 ? _4720->raw() : nullptr,_4720 ? _4720->size(0) : 0);
  int _9060 = (int)0;
  int _9061 = _4711;
  for (int _4721 = _9060; _4721 < _9061; ++_4721)
  {
    {
      int _4722 = _ptr__4716[safe_add( _4713,_4721 )];
      int _4723 = _ptr__4716[safe_add( safe_add( _4713,_4721 ),(int)1 )];
      int _4724 = (_4723 - _4722);
      if ((_4724 == (int)0))
      {
        {
        }
      }
      else if((_4724 == (int)1))
      {
        {
          _ptr__4719[safe_add( _4710,_4722 )] = _4722;
        }
      }
      else if((_4724 == (int)2))
      {
        {
          if ((_ptr__4720[safe_add( _4714,_4722 )] <= _ptr__4720[safe_add( safe_add( _4714,_4722 ),(int)1 )]))
          {
            {
              _ptr__4719[safe_add( _4710,_4722 )] = _4722;
              _ptr__4719[safe_add( safe_add( _4710,_4722 ),(int)1 )] = safe_add( _4722,(int)1 );
            }
          }
          else
          {
            {
              _ptr__4719[safe_add( _4710,_4722 )] = safe_add( _4722,(int)1 );
              _ptr__4719[safe_add( safe_add( _4710,_4722 ),(int)1 )] = _4722;
            }
          }
        }
      }
      else
      {
        {
          long long _4725 = _ptr__4720[safe_add( _4714,_4722 )];
          long long _4726 = _ptr__4720[safe_add( _4714,_4722 )];
          bool _4727 = false;
          int _9062 = safe_add( _4722,(int)1 );
          int _9063 = _4723;
          for (int _4728 = _9062; _4728 < _9063; ++_4728)
          {
            {
              _4727 = (_4727 && (_ptr__4720[(safe_add( _4714,_4728 ) - (int)1)] <= _ptr__4720[safe_add( _4714,_4728 )]));
              if ((_4725 > _ptr__4720[safe_add( _4714,_4728 )]))
              {
                {
                  _4725 = _ptr__4720[safe_add( _4714,_4728 )];
                }
              }
              {}
              if ((_4726 < _ptr__4720[safe_add( _4714,_4728 )]))
              {
                {
                  _4726 = _ptr__4720[safe_add( _4714,_4728 )];
                }
              }
              {}
            }
          }
          if (_4727)
          {
            {
              int _9064 = _4722;
              int _9065 = _4723;
              for (int _4729 = _9064; _4729 < _9065; ++_4729)
              {
                {
                  _ptr__4719[safe_add( _4710,_4729 )] = _4729;
                }
              }
            }
          }
          else if((safe_add( (_4726 - _4725),(int)1 ) <= _4724))
          {
            {
              long long _4730 = safe_add( (_4726 - _4725),(int)1 );
              int _9066 = (int)0;
              long long _9067 = safe_add( _4730,(int)1 );
              for (long long _4731 = _9066; _4731 < _9067; ++_4731)
              {
                {
                  _ptr__4719[safe_add( _4718,_4731 )] = (int)0;
                }
              }
              int _9068 = _4722;
              int _9069 = _4723;
              for (int _4732 = _9068; _4732 < _9069; ++_4732)
              {
                {
                  ++ _ptr__4719[safe_add( (safe_add( _4718,_ptr__4720[safe_add( _4714,_4732 )] ) - _4725),(int)1 )];
                }
              }
              int _9070 = (int)0;
              long long _9071 = _4730;
              for (long long _4733 = _9070; _4733 < _9071; ++_4733)
              {
                {
                  _ptr__4719[safe_add( safe_add( _4718,_4733 ),(int)1 )] += _ptr__4719[safe_add( _4718,_4733 )];
                }
              }
              int _9072 = _4722;
              int _9073 = _4723;
              for (int _4734 = _9072; _4734 < _9073; ++_4734)
              {
                {
                  _ptr__4719[safe_add( safe_add( _4710,_4722 ),_ptr__4719[(safe_add( _4718,_ptr__4720[safe_add( _4714,_4734 )] ) - _4725)] )] = _4734;
                  ++ _ptr__4719[(safe_add( _4718,_ptr__4720[safe_add( _4714,_4734 )] ) - _4725)];
                }
              }
            }
          }
          else
          {
            {
              int _4735 = (int)1;
              int _4736 = _4718;
              int _4737 = safe_add( _4718,_4724 );
              int _9074 = (int)0;
              int _9075 = _4724;
              for (int _4738 = _9074; _4738 < _9075; ++_4738)
              {
                {
                  _ptr__4719[safe_add( _4736,_4738 )] = _4738;
                }
              }
              while ( (_4735 < _4724) )
              {
                {
                  int _4739 = safe_mul( _4735,(int)2 );
                  int _4740 = (_4724 / _4739);
                  if ((safe_add( safe_mul( _4740,_4739 ),_4735 ) < _4724))
                  {
                    {
                      ++ _4740;
                    }
                  }
                  {}
                  int _4741 = (int)0;
                  int _9076 = (int)0;
                  int _9077 = _4740;
                  for (int _4742 = _9076; _4742 < _9077; ++_4742)
                  {
                    {
                      int _4743 = safe_mul( _4742,_4739 );
                      int _4744 = safe_add( _4743,_4735 );
                      int _4745 = _4744;
                      int _4746 = safe_add( _4745,_4735 );
                      if ((_4746 > _4724))
                      {
                        {
                          _4746 = _4724;
                        }
                      }
                      {}
                      while ( ((_4743 < _4744) && (_4745 < _4746)) )
                      {
                        {
                          if ((_ptr__4720[safe_add( safe_add( _4714,_ptr__4719[safe_add( _4736,_4743 )] ),_4722 )] <= _ptr__4720[safe_add( safe_add( _4714,_ptr__4719[safe_add( _4736,_4745 )] ),_4722 )]))
                          {
                            {
                              _ptr__4719[safe_add( _4737,_4741 )] = _ptr__4719[safe_add( _4736,_4743 )];
                              ++ _4741;
                              ++ _4743;
                            }
                          }
                          else
                          {
                            {
                              _ptr__4719[safe_add( _4737,_4741 )] = _ptr__4719[safe_add( _4736,_4745 )];
                              ++ _4741;
                              ++ _4745;
                            }
                          }
                        }
                      }
                      while ( (_4743 < _4744) )
                      {
                        {
                          _ptr__4719[safe_add( _4737,_4741 )] = _ptr__4719[safe_add( _4736,_4743 )];
                          ++ _4741;
                          ++ _4743;
                        }
                      }
                      while ( (_4745 < _4746) )
                      {
                        {
                          _ptr__4719[safe_add( _4737,_4741 )] = _ptr__4719[safe_add( _4736,_4745 )];
                          ++ _4741;
                          ++ _4745;
                        }
                      }
                    }
                  }
                  if ((safe_mul( _4740,_4739 ) < _4724))
                  {
                    {
                      int _4747 = safe_mul( _4740,_4739 );
                      while ( (_4747 < _4724) )
                      {
                        {
                          _ptr__4719[safe_add( _4737,_4741 )] = _ptr__4719[safe_add( _4736,_4747 )];
                          ++ _4747;
                          ++ _4741;
                        }
                      }
                    }
                  }
                  {}
                  int _4748 = _4736;
                  _4736 = _4737;
                  _4737 = _4748;
                  _4735 *= (int)2;
                }
              }
              int _9078 = (int)0;
              int _9079 = _4724;
              for (int _4749 = _9078; _4749 < _9079; ++_4749)
              {
                {
                  _ptr__4719[safe_add( safe_add( _4710,_4722 ),_4749 )] = safe_add( _ptr__4719[safe_add( _4736,_4749 )],_4722 );
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress::merge_sort  ( int _4750,    int _4751,    int _4752,    int _4753,    int _4754,    int _4755,    std::shared_ptr< monty::ndarray< int,1 > > _4756,    std::shared_ptr< monty::ndarray< long long,1 > > _4757) { mosek::fusion::p_ExprCompress::merge_sort(_4750,_4751,_4752,_4753,_4754,_4755,_4756,_4757); }void mosek::fusion::p_ExprCompress::merge_sort(int _4750,int _4751,int _4752,int _4753,int _4754,int _4755,std::shared_ptr< monty::ndarray< int,1 > > _4756,std::shared_ptr< monty::ndarray< long long,1 > > _4757){
  _checked_ptr_1<int> _ptr__4756(_4756 ? _4756->raw() : nullptr, _4756 ? _4756->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4757(_4757 ? _4757->raw() : nullptr, _4757 ? _4757->size(0) : 0);
  int _4758 = _4750;
  int _4759 = _4751;
  int _9080 = (int)0;
  int _9081 = _4753;
  for (int _4760 = _9080; _4760 < _9081; ++_4760)
  {
    {
      _ptr__4756[safe_add( _4758,_4760 )] = _4760;
    }
  }
  int _9082 = (int)0;
  int _9083 = _4752;
  for (int _4761 = _9082; _4761 < _9083; ++_4761)
  {
    {
      _4758 = _4750;
      _4759 = _4751;
      int _4762 = _ptr__4756[safe_add( safe_add( _4754,_4761 ),(int)1 )];
      int _4763 = _ptr__4756[safe_add( _4754,_4761 )];
      if ((safe_add( _4763,(int)1 ) < _4762))
      {
        {
          int _4764 = (_4762 - _4763);
          int _4765 = (int)0;
          while ( (_4764 > (int)1) )
          {
            {
              ++ _4765;
              _4764 /= (int)2;
            }
          }
          _4764 = (_4762 - _4763);
          int _4766 = (int)1;
          int _9084 = (int)0;
          int _9085 = safe_add( _4765,(int)1 );
          for (int _4767 = _9084; _4767 < _9085; ++_4767)
          {
            {
              int _4768 = ((safe_add( _4764,_4766 ) - (int)1) / _4766);
              int _4769 = (_4768 / (int)2);
              int _4770 = _4763;
              int _9086 = (int)0;
              int _9087 = _4769;
              for (int _4771 = _9086; _4771 < _9087; ++_4771)
              {
                {
                  int _4772 = safe_mul( safe_mul( _4771,_4766 ),(int)2 );
                  int _9088;
                  bool _9089 = (safe_add( safe_add( _4763,_4772 ),safe_mul( (int)2,_4766 ) ) < _4762);
                  if (_9089)
                  {
                    _9088 = safe_add( safe_add( _4763,_4772 ),safe_mul( (int)2,_4766 ) );
                  }
                  else
                  {
                    _9088 = _4762;
                  }
                  int _4773 = _9088;
                  int _4774 = safe_add( safe_add( _4763,_4772 ),_4766 );
                  int _4775 = safe_add( safe_add( _4763,_4772 ),_4766 );
                  int _4776 = safe_add( _4763,_4772 );
                  while ( ((_4776 < _4775) && (_4774 < _4773)) )
                  {
                    {
                      if ((_ptr__4757[safe_add( _4755,_ptr__4756[safe_add( _4758,_4776 )] )] <= _ptr__4757[safe_add( _4755,_ptr__4756[safe_add( _4758,_4774 )] )]))
                      {
                        {
                          _ptr__4756[safe_add( _4759,_4770 )] = _ptr__4756[safe_add( _4758,_4776 )];
                          ++ _4770;
                          ++ _4776;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4756[safe_add( _4759,_4770 )] = _ptr__4756[safe_add( _4758,_4774 )];
                          ++ _4770;
                          ++ _4774;
                        }
                      }
                    }
                  }
                  while ( (_4776 < _4775) )
                  {
                    {
                      _ptr__4756[safe_add( _4759,_4770 )] = _ptr__4756[safe_add( _4758,_4776 )];
                      ++ _4770;
                      ++ _4776;
                    }
                  }
                  while ( (_4774 < _4773) )
                  {
                    {
                      _ptr__4756[safe_add( _4759,_4770 )] = _ptr__4756[safe_add( _4758,_4774 )];
                      ++ _4770;
                      ++ _4774;
                    }
                  }
                }
              }
              int _9090 = _4770;
              int _9091 = _4762;
              for (int _4777 = _9090; _4777 < _9091; ++_4777)
              {
                {
                  _ptr__4756[safe_add( _4759,_4777 )] = _ptr__4756[safe_add( _4758,_4777 )];
                }
              }
              int _4778 = _4758;
              _4758 = _4759;
              _4759 = _4778;
              _4766 *= (int)2;
            }
          }
        }
      }
      {}
      int _9092 = _4763;
      int _9093 = _4762;
      for (int _4779 = _9092; _4779 < _9093; ++_4779)
      {
        {
          _ptr__4756[safe_add( _4750,_4779 )] = _ptr__4756[safe_add( _4758,_4779 )];
        }
      }
    }
  }
}
std::string mosek::fusion::ExprCompress :: toString() { return mosek::fusion::p_ExprCompress::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCompress::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCompress("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCompress::destroy(){expr.reset();}void mosek::fusion::ExprCompress::destroy() { mosek::fusion::p_ExprCompress::_get_impl(this)->destroy(); }mosek::fusion::ExprCondense::ExprCondense(mosek::fusion::p_ExprCondense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCondense()" << this << std::endl; */ }mosek::fusion::ExprCondense::~ExprCondense() {  /* std::cout << "~ExprCondense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCondense::p_ExprCondense  (::mosek::fusion::ExprCondense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCondense::t mosek::fusion::p_ExprCondense::_new_ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4780){ return new mosek::fusion::ExprCondense(_4780); }mosek::fusion::ExprCondense::ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4780) :    ExprCondense(new mosek::fusion::p_ExprCondense(this)){ mosek::fusion::p_ExprCondense::_get_impl(this)->_initialize(_4780); }void mosek::fusion::p_ExprCondense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4780){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4780->getShape());
    mosek::fusion::p_ExprCondense::_get_impl(::mosek::fusion::ExprCondense::t(_pubthis))->expr = _4780;
  }
}void mosek::fusion::ExprCondense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4781,monty::rc_ptr< ::mosek::fusion::WorkStack > _4782,monty::rc_ptr< ::mosek::fusion::WorkStack > _4783) { mosek::fusion::p_ExprCondense::_get_impl(this)->eval(_4781,_4782,_4783); }void mosek::fusion::p_ExprCondense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4781,monty::rc_ptr< ::mosek::fusion::WorkStack > _4782,monty::rc_ptr< ::mosek::fusion::WorkStack > _4783){
  expr->eval(_4781,_4782,_4783);
  int _4784 = _4781->popi32();
  long long _4785 = (int)1;
  int _9094 = (int)0;
  int _9095 = _4784;
  for (int _4786 = _9094; _4786 < _9095; ++_4786)
  {
    {
      _4785 *= _4781->popi32();
    }
  }
  int _4787 = _4781->popi32();
  int _4788 = _4781->popi32();
  bool _4789 = (_4781->popi32() != (int)0);
  if (_4789)
  {
    {
      _4781->popi64(_4787);
    }
  }
  {}
  _4781->pushi32((int)0);
  _4781->pushi32(_4788);
  _4781->pushi32(_4787);
  _4781->pushi32(_4787);
  _4781->pushi32((int)1);
}
void mosek::fusion::p_ExprCondense::destroy(){expr.reset();}void mosek::fusion::ExprCondense::destroy() { mosek::fusion::p_ExprCondense::_get_impl(this)->destroy(); }mosek::fusion::ExprFromVar::ExprFromVar(mosek::fusion::p_ExprFromVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprFromVar()" << this << std::endl; */ }mosek::fusion::ExprFromVar::~ExprFromVar() {  /* std::cout << "~ExprFromVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprFromVar::p_ExprFromVar  (::mosek::fusion::ExprFromVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprFromVar::t mosek::fusion::p_ExprFromVar::_new_ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4790){ return new mosek::fusion::ExprFromVar(_4790); }mosek::fusion::ExprFromVar::ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4790) :    ExprFromVar(new mosek::fusion::p_ExprFromVar(this)){ mosek::fusion::p_ExprFromVar::_get_impl(this)->_initialize(_4790); }void mosek::fusion::p_ExprFromVar::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4790){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4790->getShape());
    mosek::fusion::p_ExprFromVar::_get_impl(::mosek::fusion::ExprFromVar::t(_pubthis))->x = _4790;
  }
}void mosek::fusion::ExprFromVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4791,monty::rc_ptr< ::mosek::fusion::WorkStack > _4792,monty::rc_ptr< ::mosek::fusion::WorkStack > _4793) { mosek::fusion::p_ExprFromVar::_get_impl(this)->eval(_4791,_4792,_4793); }void mosek::fusion::p_ExprFromVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4791,monty::rc_ptr< ::mosek::fusion::WorkStack > _4792,monty::rc_ptr< ::mosek::fusion::WorkStack > _4793){
  std::shared_ptr< monty::ndarray< int,1 > > _4794 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4794(_4794 ? _4794->raw() : nullptr,_4794 ? _4794->size(0) : 0);
  long long _4795 = ::mosek::fusion::p_Set::size(_4794);
  int _4796 = x->numInst();
  int _4797 = _4796;
  bool _4798 = (_4795 > _4796);
  int _4799 = _4791->alloci32(safe_add( _4796,(int)1 ));
  int _4800 = _4791->alloci64(_4797);
  int _9096;
  bool _9097 = _4798;
  if (_9097)
  {
    _9096 = _4791->alloci64(_4796);
  }
  else
  {
    _9096 = (-(int)1);
  }
  int _4801 = _9096;
  int _4802 = _4791->allocf64(_4797);
  int _4803 = _4791->allocf64(_4796);
  int _9098;
  bool _9099 = _4798;
  if (_9099)
  {
    _9098 = (int)1;
  }
  else
  {
    _9098 = (int)0;
  }
  _4791->pushi32(_9098);
  _4791->pushi32(_4797);
  _4791->pushi32(_4796);
  int _9100 = (int)0;
  int _9101 = (int)((_4794)->size(0));
  for (int _4804 = _9100; _4804 < _9101; ++_4804)
  {
    {
      _4791->pushi32(_ptr__4794[_4804]);
    }
  }
  _4791->pushi32((int)((_4794)->size(0)));
  std::shared_ptr< monty::ndarray< int,1 > > _4805 = mosek::fusion::p_WorkStack::_get_impl(_4791)->i32;
  _checked_ptr_1<int> _ptr__4805(_4805 ? _4805->raw() : nullptr,_4805 ? _4805->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4806 = mosek::fusion::p_WorkStack::_get_impl(_4791)->i64;
  _checked_ptr_1<long long> _ptr__4806(_4806 ? _4806->raw() : nullptr,_4806 ? _4806->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4807 = mosek::fusion::p_WorkStack::_get_impl(_4791)->f64;
  _checked_ptr_1<double> _ptr__4807(_4807 ? _4807->raw() : nullptr,_4807 ? _4807->size(0) : 0);
  int _9102 = (int)0;
  int _9103 = safe_add( _4796,(int)1 );
  for (int _4808 = _9102; _4808 < _9103; ++_4808)
  {
    {
      _ptr__4805[safe_add( _4799,_4808 )] = _4808;
    }
  }
  int _9104 = (int)0;
  int _9105 = _4796;
  for (int _4809 = _9104; _4809 < _9105; ++_4809)
  {
    {
      _ptr__4807[safe_add( _4803,_4809 )] = 0.0;
    }
  }
  int _9106 = (int)0;
  int _9107 = _4797;
  for (int _4810 = _9106; _4810 < _9107; ++_4810)
  {
    {
      _ptr__4807[safe_add( _4802,_4810 )] = 1.0;
    }
  }
  if (_4798)
  {
    {
      x->inst(_4801,_4806,_4800,_4806);
    }
  }
  else
  {
    {
      x->inst(_4800,_4806);
    }
  }
}
std::string mosek::fusion::ExprFromVar :: toString() { return mosek::fusion::p_ExprFromVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprFromVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Expr("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprFromVar::destroy(){x.reset();}void mosek::fusion::ExprFromVar::destroy() { mosek::fusion::p_ExprFromVar::_get_impl(this)->destroy(); }mosek::fusion::ExprReshape::ExprReshape(mosek::fusion::p_ExprReshape *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprReshape()" << this << std::endl; */ }mosek::fusion::ExprReshape::~ExprReshape() {  /* std::cout << "~ExprReshape()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprReshape::p_ExprReshape  (::mosek::fusion::ExprReshape * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprReshape::t mosek::fusion::p_ExprReshape::_new_ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4811,    monty::rc_ptr< ::mosek::fusion::Expression > _4812){ return new mosek::fusion::ExprReshape(_4811,_4812); }mosek::fusion::ExprReshape::ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4811,    monty::rc_ptr< ::mosek::fusion::Expression > _4812) :    ExprReshape(new mosek::fusion::p_ExprReshape(this)){ mosek::fusion::p_ExprReshape::_get_impl(this)->_initialize(_4811,_4812); }void mosek::fusion::p_ExprReshape::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4811,    monty::rc_ptr< ::mosek::fusion::Expression > _4812){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4811(_4811 ? _4811->raw() : nullptr, _4811 ? _4811->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4811));
    long long _4813 = _4812->getSize();
    if ((::mosek::fusion::p_Set::size(_4811) != _4812->getSize()))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Cannot reshape to mismatching shape"));
      }
    }
    {}
    mosek::fusion::p_ExprReshape::_get_impl(::mosek::fusion::ExprReshape::t(_pubthis))->e = _4812;
  }
}void mosek::fusion::ExprReshape :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4814,monty::rc_ptr< ::mosek::fusion::WorkStack > _4815,monty::rc_ptr< ::mosek::fusion::WorkStack > _4816) { mosek::fusion::p_ExprReshape::_get_impl(this)->eval(_4814,_4815,_4816); }void mosek::fusion::p_ExprReshape::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4814,monty::rc_ptr< ::mosek::fusion::WorkStack > _4815,monty::rc_ptr< ::mosek::fusion::WorkStack > _4816){
  std::shared_ptr< monty::ndarray< int,1 > > _4817 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4817(_4817 ? _4817->raw() : nullptr,_4817 ? _4817->size(0) : 0);
  e->eval(_4814,_4815,_4816);
  _4814->peek_expr();
  int _4818 = _4814->popi32();
  long long _4819 = (int)1;
  int _9108 = (int)0;
  int _9109 = _4818;
  for (int _4820 = _9108; _4820 < _9109; ++_4820)
  {
    {
      _4819 *= _4814->popi32();
    }
  }
  if ((_4819 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("The two shapes have different sizes"));
    }
  }
  {}
  int _9110 = (int)0;
  int _9111 = (int)((_4817)->size(0));
  for (int _4821 = _9110; _4821 < _9111; ++_4821)
  {
    {
      _4814->pushi32(_ptr__4817[_4821]);
    }
  }
  _4814->pushi32((int)((_4817)->size(0)));
}
std::string mosek::fusion::ExprReshape :: toString() { return mosek::fusion::p_ExprReshape::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprReshape::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4822 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprReshape(("));
  if ((_pubthis->getND() > (int)0))
  {
    {
      _4822->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim((int)0));
      int _9112 = (int)1;
      int _9113 = _pubthis->getND();
      for (int _4823 = _9112; _4823 < _9113; ++_4823)
      {
        {
          _4822->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim(_4823));
        }
      }
    }
  }
  {}
  _4822->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4822->toString();
}
void mosek::fusion::p_ExprReshape::destroy(){e.reset();}void mosek::fusion::ExprReshape::destroy() { mosek::fusion::p_ExprReshape::_get_impl(this)->destroy(); }mosek::fusion::BaseExpression::BaseExpression(mosek::fusion::p_BaseExpression *_impl) : _impl(_impl) { /*std::cout << "BaseExpression() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseExpression::~BaseExpression() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseExpression::p_BaseExpression  (::mosek::fusion::BaseExpression * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseExpression::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4824){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4824(_4824 ? _4824->raw() : nullptr, _4824 ? _4824->size(0) : 0);
    mosek::fusion::p_BaseExpression::_get_impl(::mosek::fusion::BaseExpression::t(_pubthis))->shape = _4824;
  }
}std::string mosek::fusion::BaseExpression :: toString() { return mosek::fusion::p_BaseExpression::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseExpression::toString(){
  return std::string ("Expression()");
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__eval() { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::eval() { return __mosek_2fusion_2BaseExpression__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__eval(){
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4825 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4826 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4827 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  _pubthis->eval(_4825,_4826,_4827);
  int _4828 = _4825->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4829 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4828)));
  _checked_ptr_1<int> _ptr__4829(_4829 ? _4829->raw() : nullptr,_4829 ? _4829->size(0) : 0);
  _4825->popi32(_4828,_4829,(int)0);
  int _4830 = _4825->popi32();
  int _4831 = _4825->popi32();
  int _4832 = (int)1;
  int _9114 = (int)0;
  int _9115 = _4828;
  for (int _4833 = _9114; _4833 < _9115; ++_4833)
  {
    {
      _4832 *= _ptr__4829[_4833];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4834 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4831)));
  _checked_ptr_1<long long> _ptr__4834(_4834 ? _4834->raw() : nullptr,_4834 ? _4834->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4835 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _4830,(int)1 ))));
  _checked_ptr_1<int> _ptr__4835(_4835 ? _4835->raw() : nullptr,_4835 ? _4835->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4836 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4830)));
  _checked_ptr_1<double> _ptr__4836(_4836 ? _4836->raw() : nullptr,_4836 ? _4836->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4837 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4831)));
  _checked_ptr_1<double> _ptr__4837(_4837 ? _4837->raw() : nullptr,_4837 ? _4837->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4838 = nullptr;
  _checked_ptr_1<long long> _ptr__4838(_4838 ? _4838->raw() : nullptr,_4838 ? _4838->size(0) : 0);
  if ((_4832 < _4830))
  {
    {
      _4838 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4830)));
      _ptr__4838.update(_4838 ? _4838->raw() : nullptr, _4838 ? _4838->size(0) : 0);
      _4825->popi64(_4830,_4838,(int)0);
    }
  }
  {}
  _4825->popi32(_4830,_4835,(int)1);
  _4825->popi64(_4831,_4834,(int)0);
  _4825->popf64(_4830,_4836,(int)0);
  _4825->popf64(_4831,_4837,(int)0);
  std::vector<long long> _9116;
  for (int _4839 = (int)0, _9117 = safe_add( _4830,(int)1 ); _4839 < _9117 ; ++_4839)
  {
    _9116.push_back(_ptr__4835[_4839]);
  }
  auto _9118 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9116.size()),_9116.begin(),_9116.end()));
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4836,_9118,_4834,_4837,_4829,_4838);
}
void mosek::fusion::BaseExpression::storeexpr  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4840,    std::shared_ptr< monty::ndarray< int,1 > > _4841,    std::shared_ptr< monty::ndarray< int,1 > > _4842,    std::shared_ptr< monty::ndarray< long long,1 > > _4843,    std::shared_ptr< monty::ndarray< long long,1 > > _4844,    std::shared_ptr< monty::ndarray< double,1 > > _4845,    std::shared_ptr< monty::ndarray< double,1 > > _4846) { mosek::fusion::p_BaseExpression::storeexpr(_4840,_4841,_4842,_4843,_4844,_4845,_4846); }void mosek::fusion::p_BaseExpression::storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4840,std::shared_ptr< monty::ndarray< int,1 > > _4841,std::shared_ptr< monty::ndarray< int,1 > > _4842,std::shared_ptr< monty::ndarray< long long,1 > > _4843,std::shared_ptr< monty::ndarray< long long,1 > > _4844,std::shared_ptr< monty::ndarray< double,1 > > _4845,std::shared_ptr< monty::ndarray< double,1 > > _4846){
  _checked_ptr_1<int> _ptr__4841(_4841 ? _4841->raw() : nullptr, _4841 ? _4841->size(0) : 0);
  _checked_ptr_1<int> _ptr__4842(_4842 ? _4842->raw() : nullptr, _4842 ? _4842->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4843(_4843 ? _4843->raw() : nullptr, _4843 ? _4843->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4844(_4844 ? _4844->raw() : nullptr, _4844 ? _4844->size(0) : 0);
  _checked_ptr_1<double> _ptr__4845(_4845 ? _4845->raw() : nullptr, _4845 ? _4845->size(0) : 0);
  _checked_ptr_1<double> _ptr__4846(_4846 ? _4846->raw() : nullptr, _4846 ? _4846->size(0) : 0);
  int _4847 = _ptr__4842[((int)((_4842)->size(0)) - (int)1)];
  int _4848 = ((int)((_4842)->size(0)) - (int)1);
  int _4849 = (int)((_4841)->size(0));
  {
    int _4850 = _4840->alloci32(safe_add( _4848,(int)1 ));
    ::mosek::fusion::Utils::Tools::arraycopy(_4842,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4840)->i32,_4850,safe_add( _4848,(int)1 ));
  }
  int _9119;
  bool _9120 = (NULL != _4843.get());
  if (_9120)
  {
    _9119 = (int)1;
  }
  else
  {
    _9119 = (int)0;
  }
  _4840->pushi32(_9119);
  _4840->pushi32(_4847);
  _4840->pushi32(_4848);
  {
    int _4851 = _4840->alloci32(_4849);
    ::mosek::fusion::Utils::Tools::arraycopy(_4841,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4840)->i32,_4851,_4849);
  }
  _4840->pushi32(_4849);
  {
    int _4852 = _4840->alloci64(_4847);
    ::mosek::fusion::Utils::Tools::arraycopy(_4844,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4840)->i64,_4852,_4847);
  }
  if ((NULL != _4843.get()))
  {
    {
      int _4853 = _4840->alloci64(_4848);
      ::mosek::fusion::Utils::Tools::arraycopy(_4843,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4840)->i64,_4853,_4848);
    }
  }
  {}
  {
    int _4854 = _4840->allocf64(_4847);
    ::mosek::fusion::Utils::Tools::arraycopy(_4845,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4840)->f64,_4854,_4847);
  }
  {
    int _4855 = _4840->allocf64(_4848);
    if ((NULL != _4846.get()))
    {
      {
        ::mosek::fusion::Utils::Tools::arraycopy(_4846,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4840)->f64,_4855,_4848);
      }
    }
    else
    {
      {
        int _9121 = (int)0;
        int _9122 = _4848;
        for (int _4856 = _9121; _4856 < _9122; ++_4856)
        {
          {
            ((*mosek::fusion::p_WorkStack::_get_impl(_4840)->f64)(safe_add( _4855,_4856 ))) = (int)0;
          }
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4860) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4860); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,2 > > _4860) { return __mosek_2fusion_2BaseExpression__pick(_4860); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4860) { return __mosek_2fusion_2BaseExpression__pick(_4860); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4860){
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4860)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4861) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4861); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,1 > > _4861) { return __mosek_2fusion_2BaseExpression__pick(_4861); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4861) { return __mosek_2fusion_2BaseExpression__pick(_4861); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4861){
  _checked_ptr_1<int> _ptr__4861(_4861 ? _4861->raw() : nullptr, _4861 ? _4861->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4862 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_4861)->size(0)),(int)1)));
  int _9123 = (int)0;
  int _9124 = (int)((_4861)->size(0));
  for (int _4863 = _9123; _4863 < _9124; ++_4863)
  {
    {
      ((*_4862)(_4863,(int)0)) = _ptr__4861[_4863];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4862)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4864) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4864); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(std::shared_ptr< monty::ndarray< int,1 > > _4864) { return __mosek_2fusion_2BaseExpression__index(_4864); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4864) { return __mosek_2fusion_2BaseExpression__index(_4864); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4864){
  _checked_ptr_1<int> _ptr__4864(_4864 ? _4864->raw() : nullptr, _4864 ? _4864->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4865 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_4864)->size(0)))));
  int _9125 = (int)0;
  int _9126 = (int)((_4864)->size(0));
  for (int _4866 = _9125; _4866 < _9126; ++_4866)
  {
    {
      ((*_4865)((int)0,_4866)) = _ptr__4864[_4866];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4865)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(int _4867) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4867); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(int _4867) { return __mosek_2fusion_2BaseExpression__index(_4867); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(int _4867) { return __mosek_2fusion_2BaseExpression__index(_4867); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(int _4867){
  std::shared_ptr< monty::ndarray< int,2 > > _4868 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)1)));
  ((*_4868)((int)0,(int)0)) = _4867;
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4868)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4869,std::shared_ptr< monty::ndarray< int,1 > > _4870) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4869,_4870); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(std::shared_ptr< monty::ndarray< int,1 > > _4869,std::shared_ptr< monty::ndarray< int,1 > > _4870) { return __mosek_2fusion_2BaseExpression__slice(_4869,_4870); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4869,std::shared_ptr< monty::ndarray< int,1 > > _4870) { return __mosek_2fusion_2BaseExpression__slice(_4869,_4870); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4869,std::shared_ptr< monty::ndarray< int,1 > > _4870){
  _checked_ptr_1<int> _ptr__4869(_4869 ? _4869->raw() : nullptr, _4869 ? _4869->size(0) : 0);
  _checked_ptr_1<int> _ptr__4870(_4870 ? _4870->raw() : nullptr, _4870 ? _4870->size(0) : 0);
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4869,_4870)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(int _4871,int _4872) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4871,_4872); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(int _4871,int _4872) { return __mosek_2fusion_2BaseExpression__slice(_4871,_4872); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(int _4871,int _4872) { return __mosek_2fusion_2BaseExpression__slice(_4871,_4872); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(int _4871,int _4872){
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4871)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4872)}))).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::BaseExpression :: getSize() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseExpression::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::BaseExpression :: getND() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getND(); }int mosek::fusion::p_BaseExpression::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseExpression :: getDim(int _4873) { return mosek::fusion::p_BaseExpression::_get_impl(this)->getDim(_4873); }int mosek::fusion::p_BaseExpression::getDim(int _4873){
  return ((*shape)(_4873));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseExpression :: getShape() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseExpression::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::p_BaseExpression::destroy(){shape.reset();}void mosek::fusion::BaseExpression::destroy() { mosek::fusion::p_BaseExpression::_get_impl(this)->destroy(); }mosek::fusion::WorkStack::WorkStack(mosek::fusion::p_WorkStack *_impl) : _impl(_impl) { /*std::cout << "WorkStack() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::WorkStack::~WorkStack() { delete _impl; _impl = nullptr; }mosek::fusion::p_WorkStack::p_WorkStack  (::mosek::fusion::WorkStack * _pubthis) :     _pubthis(_pubthis){}int mosek::fusion::WorkStack::get_cof_base() { return _impl->cof_base; }
void mosek::fusion::WorkStack::set_cof_base(int _val) { _impl->cof_base = _val; }
int mosek::fusion::WorkStack::get_bfix_base() { return _impl->bfix_base; }
void mosek::fusion::WorkStack::set_bfix_base(int _val) { _impl->bfix_base = _val; }
int mosek::fusion::WorkStack::get_nidxs_base() { return _impl->nidxs_base; }
void mosek::fusion::WorkStack::set_nidxs_base(int _val) { _impl->nidxs_base = _val; }
int mosek::fusion::WorkStack::get_sp_base() { return _impl->sp_base; }
void mosek::fusion::WorkStack::set_sp_base(int _val) { _impl->sp_base = _val; }
int mosek::fusion::WorkStack::get_shape_base() { return _impl->shape_base; }
void mosek::fusion::WorkStack::set_shape_base(int _val) { _impl->shape_base = _val; }
int mosek::fusion::WorkStack::get_ptr_base() { return _impl->ptr_base; }
void mosek::fusion::WorkStack::set_ptr_base(int _val) { _impl->ptr_base = _val; }
bool mosek::fusion::WorkStack::get_hassp() { return _impl->hassp; }
void mosek::fusion::WorkStack::set_hassp(bool _val) { _impl->hassp = _val; }
int mosek::fusion::WorkStack::get_nelem() { return _impl->nelem; }
void mosek::fusion::WorkStack::set_nelem(int _val) { _impl->nelem = _val; }
int mosek::fusion::WorkStack::get_nnz() { return _impl->nnz; }
void mosek::fusion::WorkStack::set_nnz(int _val) { _impl->nnz = _val; }
int mosek::fusion::WorkStack::get_nd() { return _impl->nd; }
void mosek::fusion::WorkStack::set_nd(int _val) { _impl->nd = _val; }
int mosek::fusion::WorkStack::get_pf64() { return _impl->pf64; }
void mosek::fusion::WorkStack::set_pf64(int _val) { _impl->pf64 = _val; }
int mosek::fusion::WorkStack::get_pi64() { return _impl->pi64; }
void mosek::fusion::WorkStack::set_pi64(int _val) { _impl->pi64 = _val; }
int mosek::fusion::WorkStack::get_pi32() { return _impl->pi32; }
void mosek::fusion::WorkStack::set_pi32(int _val) { _impl->pi32 = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::WorkStack::get_f64() { return _impl->f64; }
void mosek::fusion::WorkStack::set_f64(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->f64 = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::WorkStack::get_i64() { return _impl->i64; }
void mosek::fusion::WorkStack::set_i64(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->i64 = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::WorkStack::get_i32() { return _impl->i32; }
void mosek::fusion::WorkStack::set_i32(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->i32 = _val; }
mosek::fusion::WorkStack::t mosek::fusion::p_WorkStack::_new_WorkStack  (){ return new mosek::fusion::WorkStack(); }mosek::fusion::WorkStack::WorkStack  () :    WorkStack(new mosek::fusion::p_WorkStack(this)){ mosek::fusion::p_WorkStack::_get_impl(this)->_initialize(); }void mosek::fusion::p_WorkStack::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    i32 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)256)));
    i64 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)256)));
    f64 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)256)));
    pi32 = (int)0;
    pi64 = (int)0;
    pf64 = (int)0;
    nd = (int)0;
    nnz = (int)0;
    nelem = (int)0;
    hassp = false;
    ptr_base = (int)0;
    shape_base = (int)0;
    sp_base = (int)0;
    nidxs_base = (int)0;
    bfix_base = (int)0;
    cof_base = (int)0;
  }
}bool mosek::fusion::WorkStack :: peek_hassp() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_hassp(); }bool mosek::fusion::p_WorkStack::peek_hassp(){
  return (_pubthis->peeki32(safe_add( (int)3,_pubthis->peek_nd() )) != (int)0);
}
int mosek::fusion::WorkStack :: peek_nnz() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nnz(); }int mosek::fusion::p_WorkStack::peek_nnz(){
  return _pubthis->peeki32(safe_add( (int)2,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_nelem() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nelem(); }int mosek::fusion::p_WorkStack::peek_nelem(){
  return _pubthis->peeki32(safe_add( (int)1,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_dim(int _4874) { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_dim(_4874); }int mosek::fusion::p_WorkStack::peek_dim(int _4874){
  return _pubthis->peeki32(safe_add( _4874,(int)1 ));
}
int mosek::fusion::WorkStack :: peek_nd() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nd(); }int mosek::fusion::p_WorkStack::peek_nd(){
  return _pubthis->peeki32();
}
void mosek::fusion::WorkStack :: alloc_expr(int _4875,int _4876,int _4877,bool _4878) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_4875,_4876,_4877,_4878); }void mosek::fusion::p_WorkStack::alloc_expr(int _4875,int _4876,int _4877,bool _4878){
  cof_base = _pubthis->allocf64(_4877);
  bfix_base = _pubthis->allocf64(_4876);
  nidxs_base = _pubthis->alloci64(_4877);
  int _9127;
  bool _9128 = _4878;
  if (_9128)
  {
    _9127 = _pubthis->alloci64(_4876);
  }
  else
  {
    _9127 = (-(int)9999);
  }
  sp_base = _9127;
  ptr_base = _pubthis->alloci32(safe_add( _4876,(int)1 ));
  int _9129;
  bool _9130 = _4878;
  if (_9130)
  {
    _9129 = (int)1;
  }
  else
  {
    _9129 = (int)0;
  }
  _pubthis->pushi32(_9129);
  _pubthis->pushi32(_4877);
  _pubthis->pushi32(_4876);
  shape_base = _pubthis->alloci32(_4875);
  _pubthis->pushi32(_4875);
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nd = _4875;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nelem = _4876;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nnz = _4877;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->hassp = _4878;
}
void mosek::fusion::WorkStack :: move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4879) { mosek::fusion::p_WorkStack::_get_impl(this)->move_expr(_4879); }void mosek::fusion::p_WorkStack::move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4879){
  int _4880 = pi32;
  int _4881 = pi64;
  int _4882 = pf64;
  _pubthis->pop_expr();
  int _4883 = _4879->alloci32((_4880 - pi32));
  int _4884 = _4879->alloci64((_4881 - pi64));
  int _4885 = _4879->allocf64((_4882 - pf64));
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,mosek::fusion::p_WorkStack::_get_impl(_4879)->i32,_4883,(_4880 - pi32));
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,mosek::fusion::p_WorkStack::_get_impl(_4879)->i64,_4884,(_4881 - pi64));
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,mosek::fusion::p_WorkStack::_get_impl(_4879)->f64,_4885,(_4882 - pf64));
}
void mosek::fusion::WorkStack :: peek_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->peek_expr(); }void mosek::fusion::p_WorkStack::peek_expr(){
  int _4886 = pi32;
  int _4887 = pi64;
  int _4888 = pf64;
  _pubthis->pop_expr();
  pi32 = _4886;
  pi64 = _4887;
  pf64 = _4888;
}
void mosek::fusion::WorkStack :: pop_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->pop_expr(); }void mosek::fusion::p_WorkStack::pop_expr(){
  nd = _pubthis->popi32();
  shape_base = _pubthis->popi32(nd);
  nelem = _pubthis->popi32();
  nnz = _pubthis->popi32();
  hassp = (_pubthis->popi32() != (int)0);
  ptr_base = _pubthis->popi32(safe_add( nelem,(int)1 ));
  int _9131;
  bool _9132 = hassp;
  if (_9132)
  {
    _9131 = _pubthis->popi64(nelem);
  }
  else
  {
    _9131 = (-(int)9999);
  }
  sp_base = _9131;
  nidxs_base = _pubthis->popi64(nnz);
  bfix_base = _pubthis->popf64(nelem);
  cof_base = _pubthis->popf64(nnz);
}
void mosek::fusion::WorkStack :: ensure_sparsity() { mosek::fusion::p_WorkStack::_get_impl(this)->ensure_sparsity(); }void mosek::fusion::p_WorkStack::ensure_sparsity(){
  int _4889 = ((*i32)((pi32 - (int)1)));
  bool _4890 = (((*i32)(((pi32 - _4889) - (int)3))) != (int)0);
  int _4891 = ((*i32)(((pi32 - _4889) - (int)1)));
  if ((!_4890))
  {
    {
      ((*i32)(((pi32 - _4889) - (int)3))) = (int)1;
      int _4892 = _pubthis->alloci64(_4891);
      int _9133 = (int)0;
      int _9134 = _4891;
      for (int _4893 = _9133; _4893 < _9134; ++_4893)
      {
        {
          ((*i64)(_4892)) = _4893;
        }
      }
    }
  }
  {}
}
void mosek::fusion::WorkStack :: clear() { mosek::fusion::p_WorkStack::_get_impl(this)->clear(); }void mosek::fusion::p_WorkStack::clear(){
  pi32 = (int)0;
  pi64 = (int)0;
  pf64 = (int)0;
}
int mosek::fusion::WorkStack :: allocf64(int _4894) { return mosek::fusion::p_WorkStack::_get_impl(this)->allocf64(_4894); }int mosek::fusion::p_WorkStack::allocf64(int _4894){
  _pubthis->ensuref64(_4894);
  int _4895 = pf64;
  int _9135 = pf64;
  int _9136 = safe_add( pf64,_4894 );
  for (int _4896 = _9135; _4896 < _9136; ++_4896)
  {
    {
      ((*f64)(_4896)) = (int)99997;
    }
  }
  pf64 += _4894;
  return _4895;
}
int mosek::fusion::WorkStack :: alloci64(int _4897) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci64(_4897); }int mosek::fusion::p_WorkStack::alloci64(int _4897){
  _pubthis->ensurei64(_4897);
  int _4898 = pi64;
  int _9137 = pi64;
  int _9138 = safe_add( pi64,_4897 );
  for (int _4899 = _9137; _4899 < _9138; ++_4899)
  {
    {
      ((*i64)(_4899)) = (int)99998;
    }
  }
  pi64 += _4897;
  return _4898;
}
int mosek::fusion::WorkStack :: alloci32(int _4900) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci32(_4900); }int mosek::fusion::p_WorkStack::alloci32(int _4900){
  if ((_4900 > (int)0))
  {
    {
      _pubthis->ensurei32(_4900);
      int _4901 = pi32;
      int _9139 = pi32;
      int _9140 = safe_add( pi32,_4900 );
      for (int _4902 = _9139; _4902 < _9140; ++_4902)
      {
        {
          ((*i32)(_4902)) = (int)99999;
        }
      }
      pi32 += _4900;
      return _4901;
    }
  }
  else
  {
    {
      return (int)0;
    }
  }
}
void mosek::fusion::WorkStack :: pushf64(double _4903) { mosek::fusion::p_WorkStack::_get_impl(this)->pushf64(_4903); }void mosek::fusion::p_WorkStack::pushf64(double _4903){
  _pubthis->ensuref64((int)1);
  ((*f64)(pf64)) = _4903;
  ++ pf64;
}
void mosek::fusion::WorkStack :: pushi64(long long _4904) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi64(_4904); }void mosek::fusion::p_WorkStack::pushi64(long long _4904){
  _pubthis->ensurei64((int)1);
  ((*i64)(pi64)) = _4904;
  ++ pi64;
}
void mosek::fusion::WorkStack :: pushi32(int _4905) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi32(_4905); }void mosek::fusion::p_WorkStack::pushi32(int _4905){
  _pubthis->ensurei32((int)1);
  ((*i32)(pi32)) = _4905;
  ++ pi32;
}
void mosek::fusion::WorkStack :: ensuref64(int _4906) { mosek::fusion::p_WorkStack::_get_impl(this)->ensuref64(_4906); }void mosek::fusion::p_WorkStack::ensuref64(int _4906){
  if ((safe_add( pf64,_4906 ) > (int)((f64)->size(0))))
  {
    {
      int _9141;
      bool _9142 = (_4906 < (int)((f64)->size(0)));
      if (_9142)
      {
        _9141 = safe_mul( (int)((f64)->size(0)),(int)2 );
      }
      else
      {
        _9141 = safe_add( (int)((f64)->size(0)),_4906 );
      }
      int _4907 = _9141;
      std::shared_ptr< monty::ndarray< double,1 > > _4908 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4907)));
      _checked_ptr_1<double> _ptr__4908(_4908 ? _4908->raw() : nullptr,_4908 ? _4908->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(f64,(int)0,_4908,(int)0,pf64);
      f64 = _4908;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei64(int _4909) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei64(_4909); }void mosek::fusion::p_WorkStack::ensurei64(int _4909){
  if ((safe_add( pi64,_4909 ) > (int)((i64)->size(0))))
  {
    {
      int _9143;
      bool _9144 = (_4909 < (int)((i64)->size(0)));
      if (_9144)
      {
        _9143 = (int)((i64)->size(0));
      }
      else
      {
        _9143 = _4909;
      }
      int _4910 = safe_add( (int)((i64)->size(0)),_9143 );
      std::shared_ptr< monty::ndarray< long long,1 > > _4911 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4910)));
      _checked_ptr_1<long long> _ptr__4911(_4911 ? _4911->raw() : nullptr,_4911 ? _4911->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i64,(int)0,_4911,(int)0,pi64);
      i64 = _4911;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei32(int _4912) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei32(_4912); }void mosek::fusion::p_WorkStack::ensurei32(int _4912){
  if ((safe_add( pi32,_4912 ) > (int)((i32)->size(0))))
  {
    {
      int _9145;
      bool _9146 = (_4912 < (int)((i32)->size(0)));
      if (_9146)
      {
        _9145 = safe_mul( (int)((i32)->size(0)),(int)2 );
      }
      else
      {
        _9145 = safe_add( (int)((i32)->size(0)),_4912 );
      }
      int _4913 = _9145;
      std::shared_ptr< monty::ndarray< int,1 > > _4914 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4913)));
      _checked_ptr_1<int> _ptr__4914(_4914 ? _4914->raw() : nullptr,_4914 ? _4914->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i32,(int)0,_4914,(int)0,pi32);
      i32 = _4914;
    }
  }
  {}
}
int mosek::fusion::WorkStack :: popf64(int _4915) { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4915); }int mosek::fusion::p_WorkStack::popf64(int _4915){
  pf64 -= _4915;
  return pf64;
}
int mosek::fusion::WorkStack :: popi64(int _4916) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4916); }int mosek::fusion::p_WorkStack::popi64(int _4916){
  pi64 -= _4916;
  return pi64;
}
int mosek::fusion::WorkStack :: popi32(int _4917) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4917); }int mosek::fusion::p_WorkStack::popi32(int _4917){
  pi32 -= _4917;
  return pi32;
}
void mosek::fusion::WorkStack :: popf64(int _4918,std::shared_ptr< monty::ndarray< double,1 > > _4919,int _4920) { mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4918,_4919,_4920); }void mosek::fusion::p_WorkStack::popf64(int _4918,std::shared_ptr< monty::ndarray< double,1 > > _4919,int _4920){
  _checked_ptr_1<double> _ptr__4919(_4919 ? _4919->raw() : nullptr, _4919 ? _4919->size(0) : 0);
  pf64 -= _4918;
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,_4919,_4920,_4918);
}
void mosek::fusion::WorkStack :: popi64(int _4921,std::shared_ptr< monty::ndarray< long long,1 > > _4922,int _4923) { mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4921,_4922,_4923); }void mosek::fusion::p_WorkStack::popi64(int _4921,std::shared_ptr< monty::ndarray< long long,1 > > _4922,int _4923){
  _checked_ptr_1<long long> _ptr__4922(_4922 ? _4922->raw() : nullptr, _4922 ? _4922->size(0) : 0);
  pi64 -= _4921;
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,_4922,_4923,_4921);
}
void mosek::fusion::WorkStack :: popi32(int _4924,std::shared_ptr< monty::ndarray< int,1 > > _4925,int _4926) { mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4924,_4925,_4926); }void mosek::fusion::p_WorkStack::popi32(int _4924,std::shared_ptr< monty::ndarray< int,1 > > _4925,int _4926){
  _checked_ptr_1<int> _ptr__4925(_4925 ? _4925->raw() : nullptr, _4925 ? _4925->size(0) : 0);
  pi32 -= _4924;
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,_4925,_4926,_4924);
}
double mosek::fusion::WorkStack :: popf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(); }double mosek::fusion::p_WorkStack::popf64(){
  -- pf64;
  return ((*f64)(pf64));
}
long long mosek::fusion::WorkStack :: popi64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(); }long long mosek::fusion::p_WorkStack::popi64(){
  -- pi64;
  return ((*i64)(pi64));
}
int mosek::fusion::WorkStack :: popi32() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(); }int mosek::fusion::p_WorkStack::popi32(){
  -- pi32;
  return ((*i32)(pi32));
}
double mosek::fusion::WorkStack :: peekf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(); }double mosek::fusion::p_WorkStack::peekf64(){
  return ((*f64)((pf64 - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(); }long long mosek::fusion::p_WorkStack::peeki64(){
  return ((*i64)((pi64 - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(); }int mosek::fusion::p_WorkStack::peeki32(){
  return ((*i32)((pi32 - (int)1)));
}
double mosek::fusion::WorkStack :: peekf64(int _4927) { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(_4927); }double mosek::fusion::p_WorkStack::peekf64(int _4927){
  return ((*f64)(((pf64 - _4927) - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64(int _4928) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(_4928); }long long mosek::fusion::p_WorkStack::peeki64(int _4928){
  return ((*i64)(((pi64 - _4928) - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32(int _4929) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(_4929); }int mosek::fusion::p_WorkStack::peeki32(int _4929){
  return ((*i32)(((pi32 - _4929) - (int)1)));
}
void mosek::fusion::p_WorkStack::destroy(){f64.reset();i64.reset();i32.reset();}void mosek::fusion::WorkStack::destroy() { mosek::fusion::p_WorkStack::_get_impl(this)->destroy(); }mosek::fusion::SymmetricExpr::SymmetricExpr(mosek::fusion::p_SymmetricExpr *_impl) : _impl(_impl) { /*std::cout << "SymmetricExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricExpr::~SymmetricExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricExpr::p_SymmetricExpr  (::mosek::fusion::SymmetricExpr * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricExpr::t mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr  (int _4930,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4931,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4932,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4933){ return new mosek::fusion::SymmetricExpr(_4930,_4931,_4932,_4933); }mosek::fusion::SymmetricExpr::SymmetricExpr  (int _4930,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4931,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4932,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4933) :    SymmetricExpr(new mosek::fusion::p_SymmetricExpr(this)){ mosek::fusion::p_SymmetricExpr::_get_impl(this)->_initialize(_4930,_4931,_4932,_4933); }void mosek::fusion::p_SymmetricExpr::_initialize  (int _4930,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4931,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4932,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4933){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->n = _4930;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->Ms = _4931;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->xs = _4932;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->b = _4933;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4934,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4935){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4934)->n != _4935->getdim()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimension does not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9147;
  bool _9148 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4934)->b.get());
  if (_9148)
  {
    _9147 = mosek::fusion::p_SymmetricExpr::_get_impl(_4934)->b->__mosek_2fusion_2SymmetricMatrix__add(_4935);
  }
  else
  {
    _9147 = _4935;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4934)->n,mosek::fusion::p_SymmetricExpr::_get_impl(_4934)->Ms,mosek::fusion::p_SymmetricExpr::_get_impl(_4934)->xs,_9147);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4936,double _4937){
  std::vector<monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >> _9149;
  for (int _4938 = (int)0, _9150 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->Ms)->size(0)); _4938 < _9150 ; ++_4938)
  {
    _9149.push_back(((*mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->Ms)(_4938))->__mosek_2fusion_2SymmetricMatrix__mul(_4937));
  }
  auto _9151 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(_9149.size()),_9149.begin(),_9149.end()));
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9152;
  bool _9153 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->b.get());
  if (_9153)
  {
    _9152 = mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->b->__mosek_2fusion_2SymmetricMatrix__mul(_4937);
  }
  else
  {
    _9152 = nullptr;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->n,_9151,mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->xs,_9152);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4939,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4940){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->n != mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->n))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4941 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->Ms)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->Ms)->size(0)) ))));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4942 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->xs)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->xs)->size(0)) ))));
  int _4943 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->Ms)->size(0));
  int _9154 = (int)0;
  int _9155 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->Ms)->size(0));
  for (int _4944 = _9154; _4944 < _9155; ++_4944)
  {
    {
      ((*_4941)(_4944)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->Ms)(_4944));
    }
  }
  int _9156 = (int)0;
  int _9157 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->Ms)->size(0));
  for (int _4945 = _9156; _4945 < _9157; ++_4945)
  {
    {
      ((*_4941)(safe_add( _4945,_4943 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->Ms)(_4945));
    }
  }
  int _4946 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->xs)->size(0));
  int _9158 = (int)0;
  int _9159 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->xs)->size(0));
  for (int _4947 = _9158; _4947 < _9159; ++_4947)
  {
    {
      ((*_4942)(_4947)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->xs)(_4947));
    }
  }
  int _9160 = (int)0;
  int _9161 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->xs)->size(0));
  for (int _4948 = _9160; _4948 < _9161; ++_4948)
  {
    {
      ((*_4942)(safe_add( _4948,_4946 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->xs)(_4948));
    }
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9162;
  bool _9163 = ((NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->b.get()) && (NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->b.get()));
  if (_9163)
  {
    _9162 = nullptr;
  }
  else
  {
    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9164;
    bool _9165 = ((NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->b.get()) && (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->b.get()));
    if (_9165)
    {
      _9164 = mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->b->__mosek_2fusion_2SymmetricMatrix__add(mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->b);
    }
    else
    {
      monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9166;
      bool _9167 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->b.get());
      if (_9167)
      {
        _9166 = mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->b;
      }
      else
      {
        _9166 = mosek::fusion::p_SymmetricExpr::_get_impl(_4940)->b;
      }
      _9164 = _9166;
    }
    _9162 = _9164;
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4949 = _9162;
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4939)->n,_4941,_4942,_4949);
}
std::string mosek::fusion::SymmetricExpr :: toString() { return mosek::fusion::p_SymmetricExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_SymmetricExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4950 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _4950->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SymmetricExpr( ("))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _4950->toString();
}
void mosek::fusion::p_SymmetricExpr::destroy(){xs.reset();b.reset();Ms.reset();}void mosek::fusion::SymmetricExpr::destroy() { mosek::fusion::p_SymmetricExpr::_get_impl(this)->destroy(); }mosek::fusion::Expr::Expr(mosek::fusion::p_Expr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "Expr()" << this << std::endl; */ }mosek::fusion::Expr::~Expr() {  /* std::cout << "~Expr()" << this << std::endl << std::flush; */ }mosek::fusion::p_Expr::p_Expr  (::mosek::fusion::Expr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4951,    std::shared_ptr< monty::ndarray< long long,1 > > _4952,    std::shared_ptr< monty::ndarray< double,1 > > _4953,    std::shared_ptr< monty::ndarray< double,1 > > _4954,    std::shared_ptr< monty::ndarray< int,1 > > _4955,    std::shared_ptr< monty::ndarray< long long,1 > > _4956){ return new mosek::fusion::Expr(_4951,_4952,_4953,_4954,_4955,_4956); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4951,    std::shared_ptr< monty::ndarray< long long,1 > > _4952,    std::shared_ptr< monty::ndarray< double,1 > > _4953,    std::shared_ptr< monty::ndarray< double,1 > > _4954,    std::shared_ptr< monty::ndarray< int,1 > > _4955,    std::shared_ptr< monty::ndarray< long long,1 > > _4956) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4951,_4952,_4953,_4954,_4955,_4956); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4951,    std::shared_ptr< monty::ndarray< long long,1 > > _4952,    std::shared_ptr< monty::ndarray< double,1 > > _4953,    std::shared_ptr< monty::ndarray< double,1 > > _4954,    std::shared_ptr< monty::ndarray< int,1 > > _4955,    std::shared_ptr< monty::ndarray< long long,1 > > _4956){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4951(_4951 ? _4951->raw() : nullptr, _4951 ? _4951->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4952(_4952 ? _4952->raw() : nullptr, _4952 ? _4952->size(0) : 0);
    _checked_ptr_1<double> _ptr__4953(_4953 ? _4953->raw() : nullptr, _4953 ? _4953->size(0) : 0);
    _checked_ptr_1<double> _ptr__4954(_4954 ? _4954->raw() : nullptr, _4954 ? _4954->size(0) : 0);
    _checked_ptr_1<int> _ptr__4955(_4955 ? _4955->raw() : nullptr, _4955 ? _4955->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4956(_4956 ? _4956->raw() : nullptr, _4956 ? _4956->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _9168;
    bool _9169 = (NULL != _4955.get());
    if (_9169)
    {
      _9168 = ::mosek::fusion::Utils::Tools::arraycopy(_4955);
    }
    else
    {
      _9168 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((int)((_4951)->size(0)) - (int)1))});
    }
    std::shared_ptr< monty::ndarray< long long,1 > > _9170;
    bool _9171 = (NULL != _4956.get());
    if (_9171)
    {
      _9170 = ::mosek::fusion::Utils::Tools::arraycopy(_4956);
    }
    else
    {
      _9170 = nullptr;
    }
    mosek::fusion::p_Expr::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4951),::mosek::fusion::Utils::Tools::arraycopy(_4952),::mosek::fusion::Utils::Tools::arraycopy(_4953),::mosek::fusion::Utils::Tools::arraycopy(_4954),_9168,_9170,(int)1);
    int _4957 = ((int)((_4951)->size(0)) - (int)1);
    if ((_4957 < (int)0))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    long long _4958 = _ptr__4951[_4957];
    if (((_4958 < (int)0) || ((_4958 != (int)((_4953)->size(0))) || (_4958 != (int)((_4952)->size(0))))))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb construction"));
      }
    }
    {}
    bool _4959 = true;
    bool _4960 = true;
    bool _4961 = true;
    std::shared_ptr< monty::ndarray< int,1 > > _4962 = mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape;
    _checked_ptr_1<int> _ptr__4962(_4962 ? _4962->raw() : nullptr,_4962 ? _4962->size(0) : 0);
    long long _4963 = ::mosek::fusion::p_Set::size(_4962);
    {
      int _9172 = (int)0;
      int _9173 = (int)((_4962)->size(0));
      for (int _4964 = _9172; _4964 < _9173; ++_4964)
      {
        {
          _4960 = (_4960 && (_ptr__4962[_4964] >= (int)0));
        }
      }
      int _9174 = (int)0;
      int _9175 = _4957;
      for (int _4965 = _9174; _4965 < _9175; ++_4965)
      {
        {
          _4959 = (_4959 && (_ptr__4951[_4965] <= _ptr__4951[safe_add( _4965,(int)1 )]));
        }
      }
      if (((NULL != _4956.get()) && ((int)((_4956)->size(0)) > (int)0)))
      {
        {
          _4961 = ((_ptr__4956[(int)0] >= (int)0) && (_ptr__4956[(_4957 - (int)1)] < _4963));
          int _9176 = (int)0;
          int _9177 = (_4957 - (int)1);
          for (int _4966 = _9176; _4966 < _9177; ++_4966)
          {
            {
              _4961 = (_4961 && (_ptr__4956[_4966] < _ptr__4956[safe_add( _4966,(int)1 )]));
            }
          }
        }
      }
      {}
    }
    if ((!_4960))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid shape"));
      }
    }
    {}
    if ((!_4959))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    if ((!_4961))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid sparsity pattern"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4967,    std::shared_ptr< monty::ndarray< long long,1 > > _4968,    std::shared_ptr< monty::ndarray< double,1 > > _4969,    std::shared_ptr< monty::ndarray< double,1 > > _4970,    std::shared_ptr< monty::ndarray< int,1 > > _4971,    std::shared_ptr< monty::ndarray< long long,1 > > _4972,    int _4973){ return new mosek::fusion::Expr(_4967,_4968,_4969,_4970,_4971,_4972,_4973); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4967,    std::shared_ptr< monty::ndarray< long long,1 > > _4968,    std::shared_ptr< monty::ndarray< double,1 > > _4969,    std::shared_ptr< monty::ndarray< double,1 > > _4970,    std::shared_ptr< monty::ndarray< int,1 > > _4971,    std::shared_ptr< monty::ndarray< long long,1 > > _4972,    int _4973) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4967,_4968,_4969,_4970,_4971,_4972,_4973); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4967,    std::shared_ptr< monty::ndarray< long long,1 > > _4968,    std::shared_ptr< monty::ndarray< double,1 > > _4969,    std::shared_ptr< monty::ndarray< double,1 > > _4970,    std::shared_ptr< monty::ndarray< int,1 > > _4971,    std::shared_ptr< monty::ndarray< long long,1 > > _4972,    int _4973){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4967(_4967 ? _4967->raw() : nullptr, _4967 ? _4967->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4968(_4968 ? _4968->raw() : nullptr, _4968 ? _4968->size(0) : 0);
    _checked_ptr_1<double> _ptr__4969(_4969 ? _4969->raw() : nullptr, _4969 ? _4969->size(0) : 0);
    _checked_ptr_1<double> _ptr__4970(_4970 ? _4970->raw() : nullptr, _4970 ? _4970->size(0) : 0);
    _checked_ptr_1<int> _ptr__4971(_4971 ? _4971->raw() : nullptr, _4971 ? _4971->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4972(_4972 ? _4972->raw() : nullptr, _4972 ? _4972->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_4971);
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape = _4971;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->ptrb = _4967;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->subj = _4968;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->cof_v = _4969;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->bfix = _4970;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->inst = _4972;
    if ((NULL == mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4974){ return new mosek::fusion::Expr(_4974); }mosek::fusion::Expr::Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4974) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4974); }void mosek::fusion::p_Expr::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4974){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4974->getShape());
    monty::rc_ptr< ::mosek::fusion::Expression > _9178 = _4974;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::Expr*>(_9178.get()))
    {
      ::mosek::fusion::Expr::t _4975 (dynamic_cast<::mosek::fusion::Expr*>(_9178.get()));
      {
        shape = mosek::fusion::p_Expr::_get_impl(_4975)->shape;
        ptrb = mosek::fusion::p_Expr::_get_impl(_4975)->ptrb;
        subj = mosek::fusion::p_Expr::_get_impl(_4975)->subj;
        cof_v = mosek::fusion::p_Expr::_get_impl(_4975)->cof_v;
        bfix = mosek::fusion::p_Expr::_get_impl(_4975)->bfix;
        inst = mosek::fusion::p_Expr::_get_impl(_4975)->inst;
      }
    }
    else
    {
      mosek::fusion::Expression::t _4976 = _9178;
      {
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4977 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4978 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4979 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        _4976->eval(_4979,_4978,_4977);
        int _4980 = _4979->popi32();
        int _4981 = _4979->popi32(_4980);
        int _4982 = _4979->popi32();
        int _4983 = _4979->popi32();
        bool _4984 = (_4979->popi32() != (int)0);
        int _4985 = _4979->popi32(safe_add( _4982,(int)1 ));
        int _9179;
        bool _9180 = _4984;
        if (_9180)
        {
          _9179 = _4979->popi64(_4982);
        }
        else
        {
          _9179 = (int)0;
        }
        int _4986 = _9179;
        int _4987 = _4979->popi64(_4983);
        int _4988 = _4979->popf64(_4982);
        int _4989 = _4979->popf64(_4983);
        std::shared_ptr< monty::ndarray< int,1 > > _4990 = mosek::fusion::p_WorkStack::_get_impl(_4979)->i32;
        _checked_ptr_1<int> _ptr__4990(_4990 ? _4990->raw() : nullptr,_4990 ? _4990->size(0) : 0);
        std::shared_ptr< monty::ndarray< long long,1 > > _4991 = mosek::fusion::p_WorkStack::_get_impl(_4979)->i64;
        _checked_ptr_1<long long> _ptr__4991(_4991 ? _4991->raw() : nullptr,_4991 ? _4991->size(0) : 0);
        std::shared_ptr< monty::ndarray< double,1 > > _4992 = mosek::fusion::p_WorkStack::_get_impl(_4979)->f64;
        _checked_ptr_1<double> _ptr__4992(_4992 ? _4992->raw() : nullptr,_4992 ? _4992->size(0) : 0);
        std::vector<int> _9181;
        for (int _4993 = (int)0, _9182 = _4980; _4993 < _9182 ; ++_4993)
        {
          _9181.push_back(_ptr__4990[safe_add( _4981,_4993 )]);
        }
        auto _9183 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9181.size()),_9181.begin(),_9181.end()));
        shape = _9183;
        std::vector<long long> _9184;
        for (int _4994 = (int)0, _9185 = safe_add( _4982,(int)1 ); _4994 < _9185 ; ++_4994)
        {
          _9184.push_back(_ptr__4990[safe_add( _4985,_4994 )]);
        }
        auto _9186 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9184.size()),_9184.begin(),_9184.end()));
        ptrb = _9186;
        std::vector<long long> _9187;
        for (int _4995 = (int)0, _9188 = _4983; _4995 < _9188 ; ++_4995)
        {
          _9187.push_back(_ptr__4991[safe_add( _4987,_4995 )]);
        }
        auto _9189 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9187.size()),_9187.begin(),_9187.end()));
        subj = _9189;
        std::vector<double> _9190;
        for (int _4996 = (int)0, _9191 = _4983; _4996 < _9191 ; ++_4996)
        {
          _9190.push_back(_ptr__4992[safe_add( _4989,_4996 )]);
        }
        auto _9192 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9190.size()),_9190.begin(),_9190.end()));
        cof_v = _9192;
        std::vector<double> _9193;
        for (int _4997 = (int)0, _9194 = _4983; _4997 < _9194 ; ++_4997)
        {
          _9193.push_back(_ptr__4992[safe_add( _4988,_4997 )]);
        }
        auto _9195 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9193.size()),_9193.begin(),_9193.end()));
        bfix = _9195;
        std::shared_ptr< monty::ndarray< long long,1 > > _9196;
        bool _9197 = _4984;
        if (_9197)
        {
          std::vector<long long> _9198;
          for (int _4998 = (int)0, _9199 = _4983; _4998 < _9199 ; ++_4998)
          {
            _9198.push_back(_ptr__4991[safe_add( _4986,_4998 )]);
          }
          auto _9200 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9198.size()),_9198.begin(),_9198.end()));
          _9196 = _9200;
        }
        else
        {
          _9196 = nullptr;
        }
        inst = _9196;
      }
    }
    if ((NULL == shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}long long mosek::fusion::p_Expr::prod(std::shared_ptr< monty::ndarray< int,1 > > _4999){
  _checked_ptr_1<int> _ptr__4999(_4999 ? _4999->raw() : nullptr, _4999 ? _4999->size(0) : 0);
  int _5000 = (int)1;
  int _9201 = (int)0;
  int _9202 = (int)((_4999)->size(0));
  for (int _5001 = _9201; _5001 < _9202; ++_5001)
  {
    {
      _5000 *= _ptr__4999[_5001];
    }
  }
  return _5000;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _5002){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _9203;
  for (int _5003 = (int)0, _9204 = (int)((_5002)->size(0)); _5003 < _9204 ; ++_5003)
  {
    for (int _5004 = (int)0, _9205 = (int)((((*_5002)(_5003)))->size(0)); _5004 < _9205 ; ++_5004)
    {
      _9203.push_back(((*((*_5002)(_5003)))(_5004)));
    }
  }
  auto _9206 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_9203.size()),_9203.begin(),_9203.end()));
  return _9206;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5005,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5006){
  if ((NULL == _5005.get()))
  {
    {
      return _5006;
    }
  }
  else if((NULL == _5006.get()))
  {
    {
      return _5005;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5007 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((_5005)->size(0)),(int)((_5006)->size(0)) ))));
      int _9207 = (int)0;
      int _9208 = (int)((_5005)->size(0));
      for (int _5008 = _9207; _5008 < _9208; ++_5008)
      {
        {
          ((*_5007)(_5008)) = ((*_5005)(_5008));
        }
      }
      int _9209 = (int)0;
      int _9210 = (int)((_5006)->size(0));
      for (int _5009 = _9209; _5009 < _9210; ++_5009)
      {
        {
          ((*_5007)(safe_add( _5009,(int)((_5005)->size(0)) ))) = ((*_5006)(_5009));
        }
      }
      return _5007;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::condense  ( monty::rc_ptr< ::mosek::fusion::Expression > _5010) { return mosek::fusion::p_Expr::condense(_5010); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::condense(monty::rc_ptr< ::mosek::fusion::Expression > _5010){
  return (::mosek::fusion::p_ExprCondense::_new_ExprCondense(_5010)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::flatten  ( monty::rc_ptr< ::mosek::fusion::Expression > _5011) { return mosek::fusion::p_Expr::flatten(_5011); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::flatten(monty::rc_ptr< ::mosek::fusion::Expression > _5011){
  if ((NULL == _5011.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for flatten may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5011,(int)_5011->getSize());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5012,    int _5013,    int _5014) { return mosek::fusion::p_Expr::reshape(_5012,_5013,_5014); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5012,int _5013,int _5014){
  if ((NULL == _5012.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5012,::mosek::fusion::p_Set::make(_5013,_5014));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5015,    int _5016) { return mosek::fusion::p_Expr::reshape(_5015,_5016); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5015,int _5016){
  if ((NULL == _5015.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5015,::mosek::fusion::p_Set::make(_5016));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5017,    std::shared_ptr< monty::ndarray< int,1 > > _5018) { return mosek::fusion::p_Expr::reshape(_5017,_5018); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5017,std::shared_ptr< monty::ndarray< int,1 > > _5018){
  _checked_ptr_1<int> _ptr__5018(_5018 ? _5018->raw() : nullptr, _5018 ? _5018->size(0) : 0);
  return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5018,_5017)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: size() { return mosek::fusion::p_Expr::_get_impl(this)->size(); }long long mosek::fusion::p_Expr::size(){
  return ((long long)((ptrb)->size(0)) - (int)1);
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr :: __mosek_2fusion_2Expr__eval() { return mosek::fusion::p_Expr::_get_impl(this)->__mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::eval() { return __mosek_2fusion_2Expr__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::__mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_Expr::__mosek_2fusion_2Expr__eval(){
  std::shared_ptr< monty::ndarray< double,1 > > _9211;
  bool _9212 = (NULL == bfix.get());
  if (_9212)
  {
    _9211 = nullptr;
  }
  else
  {
    _9211 = ::mosek::fusion::Utils::Tools::arraycopy(bfix);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5019 = _9211;
  _checked_ptr_1<double> _ptr__5019(_5019 ? _5019->raw() : nullptr,_5019 ? _5019->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9213;
  bool _9214 = (NULL == inst.get());
  if (_9214)
  {
    _9213 = nullptr;
  }
  else
  {
    _9213 = ::mosek::fusion::Utils::Tools::arraycopy(inst);
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5020 = _9213;
  _checked_ptr_1<long long> _ptr__5020(_5020 ? _5020->raw() : nullptr,_5020 ? _5020->size(0) : 0);
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_5019,::mosek::fusion::Utils::Tools::arraycopy(ptrb),::mosek::fusion::Utils::Tools::arraycopy(subj),::mosek::fusion::Utils::Tools::arraycopy(cof_v),shape,inst);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( std::shared_ptr< monty::ndarray< int,1 > > _5021) { return mosek::fusion::p_Expr::zeros(_5021); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(std::shared_ptr< monty::ndarray< int,1 > > _5021){
  _checked_ptr_1<int> _ptr__5021(_5021 ? _5021->raw() : nullptr, _5021 ? _5021->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5021,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( int _5022) { return mosek::fusion::p_Expr::zeros(_5022); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(int _5022){
  return ::mosek::fusion::p_Expr::constTerm(_5022,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( ) { return mosek::fusion::p_Expr::ones(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(){
  return ::mosek::fusion::p_Expr::constTerm((double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5023,    std::shared_ptr< monty::ndarray< int,2 > > _5024) { return mosek::fusion::p_Expr::ones(_5023,_5024); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5023,std::shared_ptr< monty::ndarray< int,2 > > _5024){
  _checked_ptr_1<int> _ptr__5023(_5023 ? _5023->raw() : nullptr, _5023 ? _5023->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5023,_5024,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5025) { return mosek::fusion::p_Expr::ones(_5025); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5025){
  _checked_ptr_1<int> _ptr__5025(_5025 ? _5025->raw() : nullptr, _5025 ? _5025->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5025,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( int _5026) { return mosek::fusion::p_Expr::ones(_5026); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(int _5026){
  return ::mosek::fusion::p_Expr::constTerm(_5026,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5027) { return mosek::fusion::p_Expr::constTerm(_5027); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5027){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(mosek::fusion::p_NDSparseArray::_get_impl(_5027)->dims,mosek::fusion::p_NDSparseArray::_get_impl(_5027)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5027)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5028) { return mosek::fusion::p_Expr::constTerm(_5028); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _5028){
  int _5029 = _5028->numRows();
  int _5030 = _5028->numColumns();
  std::shared_ptr< monty::ndarray< int,1 > > _5031 = ::mosek::fusion::p_Set::make(_5029,_5030);
  _checked_ptr_1<int> _ptr__5031(_5031 ? _5031->raw() : nullptr,_5031 ? _5031->size(0) : 0);
  if (_5028->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5032 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5028->numNonzeros())));
      _checked_ptr_1<double> _ptr__5032(_5032 ? _5032->raw() : nullptr,_5032 ? _5032->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5033 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5028->numNonzeros())));
      _checked_ptr_1<int> _ptr__5033(_5033 ? _5033->raw() : nullptr,_5033 ? _5033->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5034 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5028->numNonzeros())));
      _checked_ptr_1<int> _ptr__5034(_5034 ? _5034->raw() : nullptr,_5034 ? _5034->size(0) : 0);
      _5028->getDataAsTriplets(_5034,_5033,_5032);
      std::vector<long long> _9215;
      for (int _5036 = (int)0, _9216 = (int)((_5033)->size(0)); _5036 < _9216 ; ++_5036)
      {
        _9215.push_back(safe_add( safe_mul( _ptr__5034[_5036],_5030 ),_ptr__5033[_5036] ));
      }
      auto _9217 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9215.size()),_9215.begin(),_9215.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _5035 = _9217;
      _checked_ptr_1<long long> _ptr__5035(_5035 ? _5035->raw() : nullptr,_5035 ? _5035->size(0) : 0);
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5031,_5035,_5032)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5031,nullptr,_5028->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( double _5037) { return mosek::fusion::p_Expr::constTerm(_5037); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(double _5037){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,_5037)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5038,    std::shared_ptr< monty::ndarray< int,2 > > _5039,    double _5040) { return mosek::fusion::p_Expr::constTerm(_5038,_5039,_5040); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5038,std::shared_ptr< monty::ndarray< int,2 > > _5039,double _5040){
  _checked_ptr_1<int> _ptr__5038(_5038 ? _5038->raw() : nullptr, _5038 ? _5038->size(0) : 0);
  int _5041 = (int)((_5039)->size(0));
  int _5042 = (int)((_5038)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5043 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5041)));
  _checked_ptr_1<long long> _ptr__5043(_5043 ? _5043->raw() : nullptr,_5043 ? _5043->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5044 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5042)));
  _checked_ptr_1<long long> _ptr__5044(_5044 ? _5044->raw() : nullptr,_5044 ? _5044->size(0) : 0);
  _ptr__5044[(_5042 - (int)1)] = (int)1;
  int _9218 = (int)1;
  int _9219 = _5042;
  for (int _5045 = _9218; _5045 < _9219; ++_5045)
  {
    {
      _ptr__5044[((_5042 - _5045) - (int)1)] = safe_mul( _ptr__5044[(_5042 - _5045)],_ptr__5038[(_5042 - _5045)] );
    }
  }
  int _9220 = (int)0;
  int _9221 = _5041;
  for (int _5046 = _9220; _5046 < _9221; ++_5046)
  {
    {
      int _9222 = (int)0;
      int _9223 = _5042;
      for (int _5047 = _9222; _5047 < _9223; ++_5047)
      {
        {
          _ptr__5043[_5046] += safe_mul( _ptr__5044[_5047],((*_5039)(_5046,_5047)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5038,_5043,_5040)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5048,    std::shared_ptr< monty::ndarray< int,2 > > _5049,    std::shared_ptr< monty::ndarray< double,1 > > _5050) { return mosek::fusion::p_Expr::constTerm(_5048,_5049,_5050); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5048,std::shared_ptr< monty::ndarray< int,2 > > _5049,std::shared_ptr< monty::ndarray< double,1 > > _5050){
  _checked_ptr_1<int> _ptr__5048(_5048 ? _5048->raw() : nullptr, _5048 ? _5048->size(0) : 0);
  _checked_ptr_1<double> _ptr__5050(_5050 ? _5050->raw() : nullptr, _5050 ? _5050->size(0) : 0);
  int _5051 = (int)((_5049)->size(0));
  int _5052 = (int)((_5048)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5053 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5051)));
  _checked_ptr_1<long long> _ptr__5053(_5053 ? _5053->raw() : nullptr,_5053 ? _5053->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5054 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5052)));
  _checked_ptr_1<long long> _ptr__5054(_5054 ? _5054->raw() : nullptr,_5054 ? _5054->size(0) : 0);
  _ptr__5054[(_5052 - (int)1)] = (int)1;
  int _9224 = (int)1;
  int _9225 = _5052;
  for (int _5055 = _9224; _5055 < _9225; ++_5055)
  {
    {
      _ptr__5054[((_5052 - _5055) - (int)1)] = safe_mul( _ptr__5054[(_5052 - _5055)],_ptr__5048[(_5052 - _5055)] );
    }
  }
  int _9226 = (int)0;
  int _9227 = _5051;
  for (int _5056 = _9226; _5056 < _9227; ++_5056)
  {
    {
      int _9228 = (int)0;
      int _9229 = _5052;
      for (int _5057 = _9228; _5057 < _9229; ++_5057)
      {
        {
          _ptr__5053[_5056] += safe_mul( _ptr__5054[_5057],((*_5049)(_5056,_5057)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5048,_5053,_5050)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5058,    double _5059) { return mosek::fusion::p_Expr::constTerm(_5058,_5059); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5058,double _5059){
  _checked_ptr_1<int> _ptr__5058(_5058 ? _5058->raw() : nullptr, _5058 ? _5058->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5058,nullptr,_5059)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( int _5060,    double _5061) { return mosek::fusion::p_Expr::constTerm(_5060,_5061); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(int _5060,double _5061){
  std::vector<double> _9230;
  for (int _5062 = (int)0, _9231 = _5060; _5062 < _9231 ; ++_5062)
  {
    _9230.push_back(_5061);
  }
  auto _9232 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9230.size()),_9230.begin(),_9230.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5060)}),nullptr,_9232)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,2 > > _5063) { return mosek::fusion::p_Expr::constTerm(_5063); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5063){
  std::vector<double> _9233;
  for (int _5064 = (int)0, _9234 = (int)((_5063)->size(0)); _5064 < _9234 ; ++_5064)
  {
    for (int _5065 = (int)0, _9235 = (int)((_5063)->size(1)); _5065 < _9235 ; ++_5065)
    {
      _9233.push_back(((*_5063)(_5064,_5065)));
    }
  }
  auto _9236 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9233.size()),_9233.begin(),_9233.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5063)->size(0))),(int)((int)((_5063)->size(1)))}),nullptr,_9236)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,1 > > _5066) { return mosek::fusion::p_Expr::constTerm(_5066); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5066){
  _checked_ptr_1<double> _ptr__5066(_5066 ? _5066->raw() : nullptr, _5066 ? _5066->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5066)->size(0)))}),nullptr,_5066)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: numNonzeros() { return mosek::fusion::p_Expr::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_Expr::numNonzeros(){
  return (long long)((cof_v)->size(0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5067,    int _5068) { return mosek::fusion::p_Expr::sum(_5067,_5068); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5067,int _5068){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce(_5068,_5067)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5069) { return mosek::fusion::p_Expr::sum(_5069); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5069){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce((int)0,::mosek::fusion::p_Expr::flatten(_5069))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::neg  ( monty::rc_ptr< ::mosek::fusion::Expression > _5070) { return mosek::fusion::p_Expr::neg(_5070); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::neg(monty::rc_ptr< ::mosek::fusion::Expression > _5070){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst((double)((-(int)1)),_5070)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(bool _5071,monty::rc_ptr< ::mosek::fusion::Matrix > _5072,monty::rc_ptr< ::mosek::fusion::Expression > _5073){
  long long _5074 = _5072->numNonzeros();
  int _5075 = _5072->numRows();
  int _5076 = _5072->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5077 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5074)));
  _checked_ptr_1<double> _ptr__5077(_5077 ? _5077->raw() : nullptr,_5077 ? _5077->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5078 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5074)));
  _checked_ptr_1<int> _ptr__5078(_5078 ? _5078->raw() : nullptr,_5078 ? _5078->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5079 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5074)));
  _checked_ptr_1<int> _ptr__5079(_5079 ? _5079->raw() : nullptr,_5079 ? _5079->size(0) : 0);
  _5072->getDataAsTriplets(_5079,_5078,_5077);
  if (_5071)
  {
    {
      return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft(_5075,_5076,_5079,_5078,_5077,_5073)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight(_5075,_5076,_5079,_5078,_5077,_5073)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5080,    monty::rc_ptr< ::mosek::fusion::Matrix > _5081) { return mosek::fusion::p_Expr::mulDiag(_5080,_5081); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5080,monty::rc_ptr< ::mosek::fusion::Matrix > _5081){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5081,_5080->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5082,    monty::rc_ptr< ::mosek::fusion::Variable > _5083) { return mosek::fusion::p_Expr::mulDiag(_5082,_5083); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5082,monty::rc_ptr< ::mosek::fusion::Variable > _5083){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5082,_5083->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5084,    monty::rc_ptr< ::mosek::fusion::Matrix > _5085) { return mosek::fusion::p_Expr::mulDiag(_5084,_5085); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5084,monty::rc_ptr< ::mosek::fusion::Matrix > _5085){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5085,_5084);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5086,    monty::rc_ptr< ::mosek::fusion::Expression > _5087) { return mosek::fusion::p_Expr::mulDiag(_5086,_5087); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5086,monty::rc_ptr< ::mosek::fusion::Expression > _5087){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5086,_5087);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5088,    std::shared_ptr< monty::ndarray< double,2 > > _5089) { return mosek::fusion::p_Expr::mulDiag(_5088,_5089); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5088,std::shared_ptr< monty::ndarray< double,2 > > _5089){
  std::vector<int> _9237;
  for (int _5090 = (int)0, _9238 = (int)((_5089)->size(0)); _5090 < _9238 ; ++_5090)
  {
    for (int _5091 = (int)0, _9239 = (int)((_5089)->size(1)); _5091 < _9239 ; ++_5091)
    {
      _9237.push_back(_5090);
    }
  }
  auto _9240 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9237.size()),_9237.begin(),_9237.end()));
  std::vector<int> _9241;
  for (int _5092 = (int)0, _9242 = (int)((_5089)->size(0)); _5092 < _9242 ; ++_5092)
  {
    for (int _5093 = (int)0, _9243 = (int)((_5089)->size(1)); _5093 < _9243 ; ++_5093)
    {
      _9241.push_back(_5093);
    }
  }
  auto _9244 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9241.size()),_9241.begin(),_9241.end()));
  std::vector<double> _9245;
  for (int _5094 = (int)0, _9246 = (int)((_5089)->size(0)); _5094 < _9246 ; ++_5094)
  {
    for (int _5095 = (int)0, _9247 = (int)((_5089)->size(1)); _5095 < _9247 ; ++_5095)
    {
      _9245.push_back(((*_5089)(_5094,_5095)));
    }
  }
  auto _9248 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9245.size()),_9245.begin(),_9245.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5089)->size(0)),(int)((_5089)->size(1)),_9240,_9244,_9248,_5088->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5096,    std::shared_ptr< monty::ndarray< double,2 > > _5097) { return mosek::fusion::p_Expr::mulDiag(_5096,_5097); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5096,std::shared_ptr< monty::ndarray< double,2 > > _5097){
  std::vector<int> _9249;
  for (int _5098 = (int)0, _9250 = (int)((_5097)->size(0)); _5098 < _9250 ; ++_5098)
  {
    for (int _5099 = (int)0, _9251 = (int)((_5097)->size(1)); _5099 < _9251 ; ++_5099)
    {
      _9249.push_back(_5098);
    }
  }
  auto _9252 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9249.size()),_9249.begin(),_9249.end()));
  std::vector<int> _9253;
  for (int _5100 = (int)0, _9254 = (int)((_5097)->size(0)); _5100 < _9254 ; ++_5100)
  {
    for (int _5101 = (int)0, _9255 = (int)((_5097)->size(1)); _5101 < _9255 ; ++_5101)
    {
      _9253.push_back(_5101);
    }
  }
  auto _9256 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9253.size()),_9253.begin(),_9253.end()));
  std::vector<double> _9257;
  for (int _5102 = (int)0, _9258 = (int)((_5097)->size(0)); _5102 < _9258 ; ++_5102)
  {
    for (int _5103 = (int)0, _9259 = (int)((_5097)->size(1)); _5103 < _9259 ; ++_5103)
    {
      _9257.push_back(((*_5097)(_5102,_5103)));
    }
  }
  auto _9260 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9257.size()),_9257.begin(),_9257.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5097)->size(0)),(int)((_5097)->size(1)),_9252,_9256,_9260,_5096)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5104,    monty::rc_ptr< ::mosek::fusion::Variable > _5105) { return mosek::fusion::p_Expr::mulDiag(_5104,_5105); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5104,monty::rc_ptr< ::mosek::fusion::Variable > _5105){
  std::vector<int> _9261;
  for (int _5106 = (int)0, _9262 = (int)((_5104)->size(0)); _5106 < _9262 ; ++_5106)
  {
    for (int _5107 = (int)0, _9263 = (int)((_5104)->size(1)); _5107 < _9263 ; ++_5107)
    {
      _9261.push_back(_5106);
    }
  }
  auto _9264 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9261.size()),_9261.begin(),_9261.end()));
  std::vector<int> _9265;
  for (int _5108 = (int)0, _9266 = (int)((_5104)->size(0)); _5108 < _9266 ; ++_5108)
  {
    for (int _5109 = (int)0, _9267 = (int)((_5104)->size(1)); _5109 < _9267 ; ++_5109)
    {
      _9265.push_back(_5109);
    }
  }
  auto _9268 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9265.size()),_9265.begin(),_9265.end()));
  std::vector<double> _9269;
  for (int _5110 = (int)0, _9270 = (int)((_5104)->size(0)); _5110 < _9270 ; ++_5110)
  {
    for (int _5111 = (int)0, _9271 = (int)((_5104)->size(1)); _5111 < _9271 ; ++_5111)
    {
      _9269.push_back(((*_5104)(_5110,_5111)));
    }
  }
  auto _9272 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9269.size()),_9269.begin(),_9269.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5104)->size(0)),(int)((_5104)->size(1)),_9264,_9268,_9272,_5105->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5112,    monty::rc_ptr< ::mosek::fusion::Expression > _5113) { return mosek::fusion::p_Expr::mulDiag(_5112,_5113); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5112,monty::rc_ptr< ::mosek::fusion::Expression > _5113){
  std::vector<int> _9273;
  for (int _5114 = (int)0, _9274 = (int)((_5112)->size(0)); _5114 < _9274 ; ++_5114)
  {
    for (int _5115 = (int)0, _9275 = (int)((_5112)->size(1)); _5115 < _9275 ; ++_5115)
    {
      _9273.push_back(_5114);
    }
  }
  auto _9276 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9273.size()),_9273.begin(),_9273.end()));
  std::vector<int> _9277;
  for (int _5116 = (int)0, _9278 = (int)((_5112)->size(0)); _5116 < _9278 ; ++_5116)
  {
    for (int _5117 = (int)0, _9279 = (int)((_5112)->size(1)); _5117 < _9279 ; ++_5117)
    {
      _9277.push_back(_5117);
    }
  }
  auto _9280 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9277.size()),_9277.begin(),_9277.end()));
  std::vector<double> _9281;
  for (int _5118 = (int)0, _9282 = (int)((_5112)->size(0)); _5118 < _9282 ; ++_5118)
  {
    for (int _5119 = (int)0, _9283 = (int)((_5112)->size(1)); _5119 < _9283 ; ++_5119)
    {
      _9281.push_back(((*_5112)(_5118,_5119)));
    }
  }
  auto _9284 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9281.size()),_9281.begin(),_9281.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5112)->size(0)),(int)((_5112)->size(1)),_9276,_9280,_9284,_5113)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5120,monty::rc_ptr< ::mosek::fusion::Expression > _5121){
  std::shared_ptr< monty::ndarray< int,1 > > _5122 = _5121->getShape();
  _checked_ptr_1<int> _ptr__5122(_5122 ? _5122->raw() : nullptr,_5122 ? _5122->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Expression > _5123 = _5121;
  if (((int)((_5122)->size(0)) == (int)1))
  {
    {
      _5122 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5122[(int)0]),(int)((int)1)});
      _ptr__5122.update(_5122 ? _5122->raw() : nullptr, _5122 ? _5122->size(0) : 0);
      _5123 = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5122,_5121)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5122)->size(0)) != (int)2) || ((_5120->numRows() != _ptr__5122[(int)0]) || (_5120->numColumns() != _ptr__5122[(int)1]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  {}
  int _5124 = _5120->numColumns();
  long long _5125 = _5120->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5126 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5125)));
  _checked_ptr_1<int> _ptr__5126(_5126 ? _5126->raw() : nullptr,_5126 ? _5126->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5127 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5125)));
  _checked_ptr_1<int> _ptr__5127(_5127 ? _5127->raw() : nullptr,_5127 ? _5127->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5128 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5125)));
  _checked_ptr_1<double> _ptr__5128(_5128 ? _5128->raw() : nullptr,_5128 ? _5128->size(0) : 0);
  _5120->getDataAsTriplets(_5126,_5127,_5128);
  std::vector<long long> _9285;
  for (long long _5129 = (int)0, _9286 = _5125; _5129 < _9286 ; ++_5129)
  {
    _9285.push_back(safe_add( safe_mul( _ptr__5126[_5129],_5124 ),_ptr__5127[_5129] ));
  }
  auto _9287 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9285.size()),_9285.begin(),_9285.end()));
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5128,_9287,_5123,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5130,monty::rc_ptr< ::mosek::fusion::Expression > _5131){
  _checked_ptr_1<double> _ptr__5130(_5130 ? _5130->raw() : nullptr, _5130 ? _5130->size(0) : 0);
  if (((NULL == _5130.get()) || (NULL == _5131.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  if (((_5131->getND() == (int)0) && ((int)((_5130)->size(0)) == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_ptr__5130[(int)0],_5131)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_5131->getND() != (int)1) || (_5131->getDim((int)0) != (int)((_5130)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  else
  {
    {
      std::vector<long long> _9288;
      for (int _5132 = (int)0, _9289 = (int)((_5130)->size(0)); _5132 < _9289 ; ++_5132)
      {
        _9288.push_back(_5132);
      }
      auto _9290 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9288.size()),_9288.begin(),_9288.end()));
      return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5130,_9290,_5131)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5133,monty::rc_ptr< ::mosek::fusion::Expression > _5134){
  if (((NULL == _5133.get()) || (NULL == _5134.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _5135 = _5134->getShape();
  _checked_ptr_1<int> _ptr__5135(_5135 ? _5135->raw() : nullptr,_5135 ? _5135->size(0) : 0);
  if (((int)((_5135)->size(0)) != (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5133)->dims)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Dimension mismatch"));
    }
  }
  {}
  int _9291 = (int)0;
  int _9292 = (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5133)->dims)->size(0));
  for (int _5136 = _9291; _5136 < _9292; ++_5136)
  {
    {
      if ((((*mosek::fusion::p_NDSparseArray::_get_impl(_5133)->dims)(_5136)) != _ptr__5135[_5136]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(mosek::fusion::p_NDSparseArray::_get_impl(_5133)->cof,mosek::fusion::p_NDSparseArray::_get_impl(_5133)->inst,_5134)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5137,    double _5138) { return mosek::fusion::p_Expr::mul(_5137,_5138); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5137,double _5138){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5138,_5137)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( double _5139,    monty::rc_ptr< ::mosek::fusion::Expression > _5140) { return mosek::fusion::p_Expr::mul(_5139,_5140); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(double _5139,monty::rc_ptr< ::mosek::fusion::Expression > _5140){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5139,_5140)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5141,    std::shared_ptr< monty::ndarray< double,1 > > _5142) { return mosek::fusion::p_Expr::mul(_5141,_5142); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5141,std::shared_ptr< monty::ndarray< double,1 > > _5142){
  _checked_ptr_1<double> _ptr__5142(_5142 ? _5142->raw() : nullptr, _5142 ? _5142->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(false,_5142,_5141);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,1 > > _5143,    monty::rc_ptr< ::mosek::fusion::Expression > _5144) { return mosek::fusion::p_Expr::mul(_5143,_5144); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,1 > > _5143,monty::rc_ptr< ::mosek::fusion::Expression > _5144){
  _checked_ptr_1<double> _ptr__5143(_5143 ? _5143->raw() : nullptr, _5143 ? _5143->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(true,_5143,_5144);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5145,    std::shared_ptr< monty::ndarray< double,2 > > _5146) { return mosek::fusion::p_Expr::mul(_5145,_5146); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5145,std::shared_ptr< monty::ndarray< double,2 > > _5146){
  return ::mosek::fusion::p_Expr::mul(false,_5146,_5145);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,2 > > _5147,    monty::rc_ptr< ::mosek::fusion::Expression > _5148) { return mosek::fusion::p_Expr::mul(_5147,_5148); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,2 > > _5147,monty::rc_ptr< ::mosek::fusion::Expression > _5148){
  return ::mosek::fusion::p_Expr::mul(true,_5147,_5148);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5149,    monty::rc_ptr< ::mosek::fusion::Matrix > _5150) { return mosek::fusion::p_Expr::mul(_5149,_5150); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5149,monty::rc_ptr< ::mosek::fusion::Matrix > _5150){
  return ::mosek::fusion::p_Expr::mul(false,_5150,_5149);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5151,    monty::rc_ptr< ::mosek::fusion::Expression > _5152) { return mosek::fusion::p_Expr::mul(_5151,_5152); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5151,monty::rc_ptr< ::mosek::fusion::Expression > _5152){
  return ::mosek::fusion::p_Expr::mul(true,_5151,_5152);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5153,std::shared_ptr< monty::ndarray< double,1 > > _5154,monty::rc_ptr< ::mosek::fusion::Expression > _5155){
  _checked_ptr_1<double> _ptr__5154(_5154 ? _5154->raw() : nullptr, _5154 ? _5154->size(0) : 0);
  int _5156 = (int)((_5154)->size(0));
  int _5157 = _5156;
  std::shared_ptr< monty::ndarray< double,1 > > _5158 = ::mosek::fusion::Utils::Tools::arraycopy(_5154);
  _checked_ptr_1<double> _ptr__5158(_5158 ? _5158->raw() : nullptr,_5158 ? _5158->size(0) : 0);
  int _5159 = _5155->getND();
  if ((_5159 == (int)0))
  {
    {
      std::vector<int> _9293;
      for (int _5160 = (int)0, _9294 = _5156; _5160 < _9294 ; ++_5160)
      {
        _9293.push_back(_5160);
      }
      auto _9295 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9293.size()),_9293.begin(),_9293.end()));
      std::vector<int> _9296;
      for (int _5161 = (int)0, _9297 = _5156; _5161 < _9297 ; ++_5161)
      {
        _9296.push_back((int)0);
      }
      auto _9298 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9296.size()),_9296.begin(),_9296.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5156)}),(::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5156,(int)1,_9295,_9298,_5158,_5155,(int)1)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5159 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else if((_5153 && (_5155->getDim((int)0) == (int)((_5154)->size(0)))))
  {
    {
      std::vector<int> _9299;
      for (int _5162 = (int)0, _9300 = _5156; _5162 < _9300 ; ++_5162)
      {
        _9299.push_back((int)0);
      }
      auto _9301 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9299.size()),_9299.begin(),_9299.end()));
      std::vector<int> _9302;
      for (int _5163 = (int)0, _9303 = _5156; _5163 < _9303 ; ++_5163)
      {
        _9302.push_back(_5163);
      }
      auto _9304 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9302.size()),_9302.begin(),_9302.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5155->getDim((int)1))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft((int)1,_5156,_9301,_9304,_5158,_5155)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5153 && (_5155->getDim((int)0) == (int)1)))
  {
    {
      std::vector<int> _9305;
      for (int _5164 = (int)0, _9306 = _5156; _5164 < _9306 ; ++_5164)
      {
        _9305.push_back(_5164);
      }
      auto _9307 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9305.size()),_9305.begin(),_9305.end()));
      std::vector<int> _9308;
      for (int _5165 = (int)0, _9309 = _5156; _5165 < _9309 ; ++_5165)
      {
        _9308.push_back((int)0);
      }
      auto _9310 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9308.size()),_9308.begin(),_9308.end()));
      return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5156,(int)1,_9307,_9310,_5158,_5155,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5153) && (_5155->getDim((int)1) == _5156)))
  {
    {
      std::vector<int> _9311;
      for (int _5166 = (int)0, _9312 = _5156; _5166 < _9312 ; ++_5166)
      {
        _9311.push_back(_5166);
      }
      auto _9313 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9311.size()),_9311.begin(),_9311.end()));
      std::vector<int> _9314;
      for (int _5167 = (int)0, _9315 = _5156; _5167 < _9315 ; ++_5167)
      {
        _9314.push_back((int)0);
      }
      auto _9316 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9314.size()),_9314.begin(),_9314.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5155->getDim((int)0))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5156,(int)1,_9313,_9316,_5158,_5155)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5153) && (_5155->getDim((int)1) == (int)1)))
  {
    {
      std::vector<int> _9317;
      for (int _5168 = (int)0, _9318 = _5156; _5168 < _9318 ; ++_5168)
      {
        _9317.push_back((int)0);
      }
      auto _9319 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9317.size()),_9317.begin(),_9317.end()));
      std::vector<int> _9320;
      for (int _5169 = (int)0, _9321 = _5156; _5169 < _9321 ; ++_5169)
      {
        _9320.push_back(_5169);
      }
      auto _9322 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9320.size()),_9320.begin(),_9320.end()));
      return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((int)1,_5156,_9319,_9322,_5158,_5155,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5170,std::shared_ptr< monty::ndarray< double,2 > > _5171,monty::rc_ptr< ::mosek::fusion::Expression > _5172){
  int _5173 = (int)((_5171)->size(0));
  int _5174 = (int)((_5171)->size(1));
  int _5175 = safe_mul( _5173,_5174 );
  std::vector<int> _9323;
  for (int _5177 = (int)0, _9324 = _5173; _5177 < _9324 ; ++_5177)
  {
    for (int _5178 = (int)0, _9325 = _5174; _5178 < _9325 ; ++_5178)
    {
      _9323.push_back(_5177);
    }
  }
  auto _9326 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9323.size()),_9323.begin(),_9323.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5176 = _9326;
  _checked_ptr_1<int> _ptr__5176(_5176 ? _5176->raw() : nullptr,_5176 ? _5176->size(0) : 0);
  std::vector<int> _9327;
  for (int _5180 = (int)0, _9328 = _5173; _5180 < _9328 ; ++_5180)
  {
    for (int _5181 = (int)0, _9329 = _5174; _5181 < _9329 ; ++_5181)
    {
      _9327.push_back(_5181);
    }
  }
  auto _9330 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9327.size()),_9327.begin(),_9327.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5179 = _9330;
  _checked_ptr_1<int> _ptr__5179(_5179 ? _5179->raw() : nullptr,_5179 ? _5179->size(0) : 0);
  std::vector<double> _9331;
  for (int _5183 = (int)0, _9332 = _5173; _5183 < _9332 ; ++_5183)
  {
    for (int _5184 = (int)0, _9333 = _5174; _5184 < _9333 ; ++_5184)
    {
      _9331.push_back(((*_5171)(_5183,_5184)));
    }
  }
  auto _9334 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9331.size()),_9331.begin(),_9331.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5182 = _9334;
  _checked_ptr_1<double> _ptr__5182(_5182 ? _5182->raw() : nullptr,_5182 ? _5182->size(0) : 0);
  long long _5185 = _5172->getSize();
  std::shared_ptr< monty::ndarray< int,1 > > _5186 = _5172->getShape();
  _checked_ptr_1<int> _ptr__5186(_5186 ? _5186->raw() : nullptr,_5186 ? _5186->size(0) : 0);
  if (((int)((_5186)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5173,_5174,_5176,_5179,_5182,_5172,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(_5170)
  {
    {
      if (((int)((_5186)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5171)->size(0)))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5173,_5174,_5176,_5179,_5182,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5186[(int)0]),(int)((int)1)}),_5172)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5186)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5173,_5174,_5176,_5179,_5182,_5172)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_5186)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5171)->size(1)))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5173,_5174,_5176,_5179,_5182,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5186[(int)0])}),_5172)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5186)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5173,_5174,_5176,_5179,_5182,_5172)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5187,monty::rc_ptr< ::mosek::fusion::Matrix > _5188,monty::rc_ptr< ::mosek::fusion::Expression > _5189){
  long long _5190 = _5188->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5191 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5190)));
  _checked_ptr_1<int> _ptr__5191(_5191 ? _5191->raw() : nullptr,_5191 ? _5191->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5192 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5190)));
  _checked_ptr_1<int> _ptr__5192(_5192 ? _5192->raw() : nullptr,_5192 ? _5192->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5193 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5190)));
  _checked_ptr_1<double> _ptr__5193(_5193 ? _5193->raw() : nullptr,_5193 ? _5193->size(0) : 0);
  int _5194 = _5188->numRows();
  int _5195 = _5188->numColumns();
  _5188->getDataAsTriplets(_5191,_5192,_5193);
  int _5196 = _5189->getND();
  if ((_5196 == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5194,_5195,_5191,_5192,_5193,_5189)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5196 == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5197 = _5189->getShape();
      _checked_ptr_1<int> _ptr__5197(_5197 ? _5197->raw() : nullptr,_5197 ? _5197->size(0) : 0);
      if (_5187)
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5194)}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5194,_5195,_5191,_5192,_5193,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5197[(int)0]),(int)((int)1)}),_5189)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5195)}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5194,_5195,_5191,_5192,_5193,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5197[(int)0])}),_5189)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else if((_5196 == (int)2))
  {
    {
      if (_5187)
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5194,_5195,_5191,_5192,_5193,_5189)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5194,_5195,_5191,_5192,_5193,_5189)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Variable > _5198,    monty::rc_ptr< ::mosek::fusion::Matrix > _5199) { return mosek::fusion::p_Expr::mul(_5198,_5199); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Variable > _5198,monty::rc_ptr< ::mosek::fusion::Matrix > _5199){
  int _5200 = _5199->numRows();
  int _5201 = _5199->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5202 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5199->numNonzeros())));
  _checked_ptr_1<double> _ptr__5202(_5202 ? _5202->raw() : nullptr,_5202 ? _5202->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5203 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5199->numNonzeros())));
  _checked_ptr_1<int> _ptr__5203(_5203 ? _5203->raw() : nullptr,_5203 ? _5203->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5199->numNonzeros())));
  _checked_ptr_1<int> _ptr__5204(_5204 ? _5204->raw() : nullptr,_5204 ? _5204->size(0) : 0);
  _5199->getDataAsTriplets(_5204,_5203,_5202);
  return ::mosek::fusion::p_Expr::mul(false,_5200,_5201,_5204,_5203,_5202,_5198);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5205,    monty::rc_ptr< ::mosek::fusion::Variable > _5206) { return mosek::fusion::p_Expr::mul(_5205,_5206); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5205,monty::rc_ptr< ::mosek::fusion::Variable > _5206){
  int _5207 = _5205->numRows();
  int _5208 = _5205->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5209 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5205->numNonzeros())));
  _checked_ptr_1<double> _ptr__5209(_5209 ? _5209->raw() : nullptr,_5209 ? _5209->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5210 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5205->numNonzeros())));
  _checked_ptr_1<int> _ptr__5210(_5210 ? _5210->raw() : nullptr,_5210 ? _5210->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5211 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5205->numNonzeros())));
  _checked_ptr_1<int> _ptr__5211(_5211 ? _5211->raw() : nullptr,_5211 ? _5211->size(0) : 0);
  _5205->getDataAsTriplets(_5211,_5210,_5209);
  return ::mosek::fusion::p_Expr::mul(true,_5207,_5208,_5211,_5210,_5209,_5206);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5212,int _5213,int _5214,std::shared_ptr< monty::ndarray< int,1 > > _5215,std::shared_ptr< monty::ndarray< int,1 > > _5216,std::shared_ptr< monty::ndarray< double,1 > > _5217,monty::rc_ptr< ::mosek::fusion::Variable > _5218){
  _checked_ptr_1<int> _ptr__5215(_5215 ? _5215->raw() : nullptr, _5215 ? _5215->size(0) : 0);
  _checked_ptr_1<int> _ptr__5216(_5216 ? _5216->raw() : nullptr, _5216 ? _5216->size(0) : 0);
  _checked_ptr_1<double> _ptr__5217(_5217 ? _5217->raw() : nullptr, _5217 ? _5217->size(0) : 0);
  if ((_5218->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar(_5213,_5214,_5215,_5216,_5217,_5218)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5218->getND() == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5219 = _5218->getShape();
      _checked_ptr_1<int> _ptr__5219(_5219 ? _5219->raw() : nullptr,_5219 ? _5219->size(0) : 0);
      int _9335;
      bool _9336 = _5212;
      if (_9336)
      {
        _9335 = _5213;
      }
      else
      {
        _9335 = _5214;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _9337;
      bool _9338 = _5212;
      if (_9338)
      {
        _9337 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5219[(int)0]),(int)((int)1)});
      }
      else
      {
        _9337 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5219[(int)0])});
      }
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_9335)}),(::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5212,_5213,_5214,_5215,_5216,_5217,::mosek::fusion::p_Var::reshape(_5218,_9337))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5212,_5213,_5214,_5215,_5216,_5217,_5218)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5220,    monty::rc_ptr< ::mosek::fusion::Matrix > _5221) { return mosek::fusion::p_Expr::dot(_5220,_5221); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5220,monty::rc_ptr< ::mosek::fusion::Matrix > _5221){
  long long _5222 = _5221->numNonzeros();
  if ((!_5221->isSparse()))
  {
    {
      std::vector<long long> _9339;
      for (long long _5223 = (int)0, _9340 = _5222; _5223 < _9340 ; ++_5223)
      {
        _9339.push_back(_5223);
      }
      auto _9341 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9339.size()),_9339.begin(),_9339.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5220,_9341,_5221->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5224 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5222)));
      _checked_ptr_1<int> _ptr__5224(_5224 ? _5224->raw() : nullptr,_5224 ? _5224->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5225 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5222)));
      _checked_ptr_1<int> _ptr__5225(_5225 ? _5225->raw() : nullptr,_5225 ? _5225->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5226 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5222)));
      _checked_ptr_1<double> _ptr__5226(_5226 ? _5226->raw() : nullptr,_5226 ? _5226->size(0) : 0);
      int _5227 = _5221->numColumns();
      _5221->getDataAsTriplets(_5224,_5225,_5226);
      std::vector<long long> _9342;
      for (int _5228 = (int)0, _9343 = (int)((_5224)->size(0)); _5228 < _9343 ; ++_5228)
      {
        _9342.push_back(safe_add( safe_mul( _ptr__5224[_5228],_5227 ),_ptr__5225[_5228] ));
      }
      auto _9344 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9342.size()),_9342.begin(),_9342.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5220,_9344,_5226)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5229,    std::shared_ptr< monty::ndarray< double,2 > > _5230) { return mosek::fusion::p_Expr::dot(_5229,_5230); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5229,std::shared_ptr< monty::ndarray< double,2 > > _5230){
  std::vector<long long> _9345;
  for (int _5231 = (int)0, _9346 = safe_mul( (int)((_5230)->size(0)),(int)((_5230)->size(1)) ); _5231 < _9346 ; ++_5231)
  {
    _9345.push_back(_5231);
  }
  auto _9347 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9345.size()),_9345.begin(),_9345.end()));
  std::vector<double> _9348;
  for (int _5232 = (int)0, _9349 = (int)((_5230)->size(0)); _5232 < _9349 ; ++_5232)
  {
    for (int _5233 = (int)0, _9350 = (int)((_5230)->size(1)); _5233 < _9350 ; ++_5233)
    {
      _9348.push_back(((*_5230)(_5232,_5233)));
    }
  }
  auto _9351 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9348.size()),_9348.begin(),_9348.end()));
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5229,_9347,_9351)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5234,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5235) { return mosek::fusion::p_Expr::dot(_5234,_5235); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5234,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5235){
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5234,mosek::fusion::p_NDSparseArray::_get_impl(_5235)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5235)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5236,    std::shared_ptr< monty::ndarray< double,1 > > _5237) { return mosek::fusion::p_Expr::dot(_5236,_5237); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5236,std::shared_ptr< monty::ndarray< double,1 > > _5237){
  _checked_ptr_1<double> _ptr__5237(_5237 ? _5237->raw() : nullptr, _5237 ? _5237->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5238 = _5236->getShape();
  _checked_ptr_1<int> _ptr__5238(_5238 ? _5238->raw() : nullptr,_5238 ? _5238->size(0) : 0);
  if (((_5236->getSize() == (int)((_5237)->size(0))) && ((int)((_5238)->size(0)) > (int)1)))
  {
    {
      int _5239 = (int)0;
      int _9352 = (int)0;
      int _9353 = (int)((_5238)->size(0));
      for (int _5240 = _9352; _5240 < _9353; ++_5240)
      {
        {
          if ((_ptr__5238[_5240] > (int)1))
          {
            {
              ++ _5239;
            }
          }
          {}
        }
      }
      if ((_5239 > (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5241 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)_5236->getSize())});
          _checked_ptr_1<int> _ptr__5241(_5241 ? _5241->raw() : nullptr,_5241 ? _5241->size(0) : 0);
          return (::mosek::fusion::p_ExprInner::_new_ExprInner((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5241,_5236)).as<::mosek::fusion::Expression>(),_5237)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5236,_5237)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5242,    monty::rc_ptr< ::mosek::fusion::Expression > _5243) { return mosek::fusion::p_Expr::dot(_5242,_5243); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5242,monty::rc_ptr< ::mosek::fusion::Expression > _5243){
  return ::mosek::fusion::p_Expr::dot(_5243,_5242);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5244,    monty::rc_ptr< ::mosek::fusion::Expression > _5245) { return mosek::fusion::p_Expr::dot(_5244,_5245); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5244,monty::rc_ptr< ::mosek::fusion::Expression > _5245){
  return ::mosek::fusion::p_Expr::dot(_5245,_5244);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,2 > > _5246,    monty::rc_ptr< ::mosek::fusion::Expression > _5247) { return mosek::fusion::p_Expr::dot(_5246,_5247); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,2 > > _5246,monty::rc_ptr< ::mosek::fusion::Expression > _5247){
  return ::mosek::fusion::p_Expr::dot(_5247,_5246);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,1 > > _5248,    monty::rc_ptr< ::mosek::fusion::Expression > _5249) { return mosek::fusion::p_Expr::dot(_5248,_5249); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,1 > > _5248,monty::rc_ptr< ::mosek::fusion::Expression > _5249){
  _checked_ptr_1<double> _ptr__5248(_5248 ? _5248->raw() : nullptr, _5248 ? _5248->size(0) : 0);
  return ::mosek::fusion::p_Expr::dot(_5249,_5248);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5250,    monty::rc_ptr< ::mosek::fusion::Expression > _5251) { return mosek::fusion::p_Expr::outer(_5250,_5251); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5250,monty::rc_ptr< ::mosek::fusion::Expression > _5251){
  _checked_ptr_1<double> _ptr__5250(_5250 ? _5250->raw() : nullptr, _5250 ? _5250->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5252 = _5251->getShape();
  _checked_ptr_1<int> _ptr__5252(_5252 ? _5252->raw() : nullptr,_5252 ? _5252->size(0) : 0);
  if (((int)((_5252)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  if ((_ptr__5252[(int)0] != (int)((_5250)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Argument lengths do not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5253 = _5251->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9354;
  for (int _5254 = (int)0, _9355 = (int)((_5250)->size(0)); _5254 < _9355 ; ++_5254)
  {
    _9354.push_back(_5254);
  }
  auto _9356 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9354.size()),_9354.begin(),_9354.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5253)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5253)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5253)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5253)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5253)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5253)->inst,_5250,_9356,(int)((_5250)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Expression > _5255,    std::shared_ptr< monty::ndarray< double,1 > > _5256) { return mosek::fusion::p_Expr::outer(_5255,_5256); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Expression > _5255,std::shared_ptr< monty::ndarray< double,1 > > _5256){
  _checked_ptr_1<double> _ptr__5256(_5256 ? _5256->raw() : nullptr, _5256 ? _5256->size(0) : 0);
  if (((_5255->getND() != (int)1) || (_5255->getND() != (int)1)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5257 = _5255->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9357;
  for (int _5258 = (int)0, _9358 = (int)((_5256)->size(0)); _5258 < _9358 ; ++_5258)
  {
    _9357.push_back(_5258);
  }
  auto _9359 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9357.size()),_9357.begin(),_9357.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5257)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5257)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5257)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5257)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5257)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5257)->inst,_5256,_9359,(int)((_5256)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5259,    monty::rc_ptr< ::mosek::fusion::Variable > _5260) { return mosek::fusion::p_Expr::outer(_5259,_5260); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5259,monty::rc_ptr< ::mosek::fusion::Variable > _5260){
  std::shared_ptr< monty::ndarray< int,1 > > _5261 = _5260->getShape();
  _checked_ptr_1<int> _ptr__5261(_5261 ? _5261->raw() : nullptr,_5261 ? _5261->size(0) : 0);
  if ((!(((int)((_5261)->size(0)) == (int)1) || (((int)((_5261)->size(0)) == (int)2) && (_ptr__5261[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5259)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9360 = _5259;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9360.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5262 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9360.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5260,_ptr__5261[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5262)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5262)->data)->size(0)),true);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5263 = _9360;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5264 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5263->numNonzeros())));
      _checked_ptr_1<double> _ptr__5264(_5264 ? _5264->raw() : nullptr,_5264 ? _5264->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5265 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5263->numNonzeros())));
      _checked_ptr_1<int> _ptr__5265(_5265 ? _5265->raw() : nullptr,_5265 ? _5265->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5266 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5263->numNonzeros())));
      _checked_ptr_1<int> _ptr__5266(_5266 ? _5266->raw() : nullptr,_5266 ? _5266->size(0) : 0);
      _5263->getDataAsTriplets(_5266,_5265,_5264);
      return ::mosek::fusion::p_Expr::outer_(_5260,_ptr__5261[(int)0],_5264,_5266,mosek::fusion::p_Matrix::_get_impl(_5263)->dimi,true);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5267,    monty::rc_ptr< ::mosek::fusion::Matrix > _5268) { return mosek::fusion::p_Expr::outer(_5267,_5268); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5267,monty::rc_ptr< ::mosek::fusion::Matrix > _5268){
  std::shared_ptr< monty::ndarray< int,1 > > _5269 = _5267->getShape();
  _checked_ptr_1<int> _ptr__5269(_5269 ? _5269->raw() : nullptr,_5269 ? _5269->size(0) : 0);
  if ((!((_5267->getND() == (int)1) || ((_5267->getND() == (int)2) && (_ptr__5269[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5268)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9361 = _5268;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9361.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5270 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9361.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5267,_ptr__5269[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5270)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5270)->data)->size(0)),false);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5271 = _9361;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5272 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5271->numNonzeros())));
      _checked_ptr_1<double> _ptr__5272(_5272 ? _5272->raw() : nullptr,_5272 ? _5272->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5273 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5271->numNonzeros())));
      _checked_ptr_1<int> _ptr__5273(_5273 ? _5273->raw() : nullptr,_5273 ? _5273->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5274 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5268->numNonzeros())));
      _checked_ptr_1<int> _ptr__5274(_5274 ? _5274->raw() : nullptr,_5274 ? _5274->size(0) : 0);
      _5271->getDataAsTriplets(_5274,_5273,_5272);
      return ::mosek::fusion::p_Expr::outer_(_5267,((*_5267->getShape())((int)0)),_5272,_5274,mosek::fusion::p_Matrix::_get_impl(_5271)->dimi,false);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5275,    monty::rc_ptr< ::mosek::fusion::Variable > _5276) { return mosek::fusion::p_Expr::outer(_5275,_5276); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5275,monty::rc_ptr< ::mosek::fusion::Variable > _5276){
  _checked_ptr_1<double> _ptr__5275(_5275 ? _5275->raw() : nullptr, _5275 ? _5275->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5277 = _5276->getShape();
  _checked_ptr_1<int> _ptr__5277(_5277 ? _5277->raw() : nullptr,_5277 ? _5277->size(0) : 0);
  if ((!((_5276->getND() == (int)1) || ((_5276->getND() == (int)2) && (_ptr__5277[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5276,_ptr__5277[(int)0],_5275,nullptr,(int)((_5275)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5278,    std::shared_ptr< monty::ndarray< double,1 > > _5279) { return mosek::fusion::p_Expr::outer(_5278,_5279); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5278,std::shared_ptr< monty::ndarray< double,1 > > _5279){
  _checked_ptr_1<double> _ptr__5279(_5279 ? _5279->raw() : nullptr, _5279 ? _5279->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5280 = _5278->getShape();
  _checked_ptr_1<int> _ptr__5280(_5280 ? _5280->raw() : nullptr,_5280 ? _5280->size(0) : 0);
  if ((!((_5278->getND() == (int)1) || ((_5278->getND() == (int)2) && (_ptr__5280[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5278,_ptr__5280[(int)0],_5279,nullptr,(int)((_5279)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(int _5281,std::shared_ptr< monty::ndarray< long long,1 > > _5282,std::shared_ptr< monty::ndarray< long long,1 > > _5283,std::shared_ptr< monty::ndarray< double,1 > > _5284,std::shared_ptr< monty::ndarray< double,1 > > _5285,std::shared_ptr< monty::ndarray< long long,1 > > _5286,std::shared_ptr< monty::ndarray< double,1 > > _5287,std::shared_ptr< monty::ndarray< int,1 > > _5288,int _5289,bool _5290){
  _checked_ptr_1<long long> _ptr__5282(_5282 ? _5282->raw() : nullptr, _5282 ? _5282->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5283(_5283 ? _5283->raw() : nullptr, _5283 ? _5283->size(0) : 0);
  _checked_ptr_1<double> _ptr__5284(_5284 ? _5284->raw() : nullptr, _5284 ? _5284->size(0) : 0);
  _checked_ptr_1<double> _ptr__5285(_5285 ? _5285->raw() : nullptr, _5285 ? _5285->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5286(_5286 ? _5286->raw() : nullptr, _5286 ? _5286->size(0) : 0);
  _checked_ptr_1<double> _ptr__5287(_5287 ? _5287->raw() : nullptr, _5287 ? _5287->size(0) : 0);
  _checked_ptr_1<int> _ptr__5288(_5288 ? _5288->raw() : nullptr, _5288 ? _5288->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9362;
  bool _9363 = (!_5290);
  if (_9363)
  {
    _9362 = ::mosek::fusion::p_Set::make(_5281,_5289);
  }
  else
  {
    _9362 = ::mosek::fusion::p_Set::make(_5289,_5281);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5291 = _9362;
  _checked_ptr_1<int> _ptr__5291(_5291 ? _5291->raw() : nullptr,_5291 ? _5291->size(0) : 0);
  int _5292 = safe_mul( (int)((_5287)->size(0)),(int)((_5286)->size(0)) );
  int _5293 = safe_mul( (int)((_5287)->size(0)),(int)((_5283)->size(0)) );
  std::shared_ptr< monty::ndarray< long long,1 > > _5294 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5292)));
  _checked_ptr_1<long long> _ptr__5294(_5294 ? _5294->raw() : nullptr,_5294 ? _5294->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9364;
  bool _9365 = (NULL != _5285.get());
  if (_9365)
  {
    _9364 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5292)));
  }
  else
  {
    _9364 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5295 = _9364;
  _checked_ptr_1<double> _ptr__5295(_5295 ? _5295->raw() : nullptr,_5295 ? _5295->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5296 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5293)));
  _checked_ptr_1<double> _ptr__5296(_5296 ? _5296->raw() : nullptr,_5296 ? _5296->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5297 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5293)));
  _checked_ptr_1<long long> _ptr__5297(_5297 ? _5297->raw() : nullptr,_5297 ? _5297->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5298 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5292,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5298(_5298 ? _5298->raw() : nullptr,_5298 ? _5298->size(0) : 0);
  int _5299 = (int)_ptr__5298[((int)((_5298)->size(0)) - (int)1)];
  if ((!_5290))
  {
    {
      long long _5300 = (long long)0;
      long long _5301 = (long long)0;
      int _9366 = (int)0;
      int _9367 = (int)((_5286)->size(0));
      for (int _5302 = _9366; _5302 < _9367; ++_5302)
      {
        {
          long long _5303 = (_ptr__5282[safe_add( _5302,(int)1 )] - _ptr__5282[_5302]);
          int _9368 = (int)0;
          int _9369 = (int)((_5287)->size(0));
          for (int _5304 = _9368; _5304 < _9369; ++_5304)
          {
            {
              _ptr__5286[_5300] = safe_add( safe_mul( _ptr__5286[_5302],_5289 ),_ptr__5288[_5304] );
              _ptr__5298[safe_add( _5300,(int)1 )] = safe_add( _ptr__5298[_5300],_5303 );
              ++ _5300;
              long long _9370 = _ptr__5282[_5302];
              long long _9371 = _ptr__5282[safe_add( _5302,(int)1 )];
              for (long long _5305 = _9370; _5305 < _9371; ++_5305)
              {
                {
                  _ptr__5297[_5301] = _ptr__5283[_5305];
                  _ptr__5296[_5301] = (_ptr__5284[_5305] * _ptr__5287[_5304]);
                  ++ _5301;
                }
              }
            }
          }
        }
      }
      if ((NULL != _5295.get()))
      {
        {
          int _5306 = (int)0;
          int _9372 = (int)0;
          int _9373 = (int)((_5286)->size(0));
          for (int _5307 = _9372; _5307 < _9373; ++_5307)
          {
            {
              int _9374 = (int)0;
              int _9375 = (int)((_5287)->size(0));
              for (int _5308 = _9374; _5308 < _9375; ++_5308)
              {
                {
                  _ptr__5295[_5306] = (_ptr__5287[_5308] * _ptr__5285[_5307]);
                  ++ _5306;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      long long _5309 = (long long)0;
      long long _5310 = (long long)0;
      int _9376 = (int)0;
      int _9377 = (int)((_5287)->size(0));
      for (int _5311 = _9376; _5311 < _9377; ++_5311)
      {
        {
          double _5312 = _ptr__5287[_5311];
          ::mosek::fusion::Utils::Tools::arraycopy(_5283,(long long)((int)0),_5297,_5310,(long long)(_5299));
          int _9378 = (int)0;
          int _9379 = _5299;
          for (int _5313 = _9378; _5313 < _9379; ++_5313)
          {
            {
              _ptr__5296[safe_add( _5310,_5313 )] = (_ptr__5284[_5313] * _ptr__5287[_5311]);
            }
          }
          int _9380 = (int)0;
          int _9381 = (int)((_5286)->size(0));
          for (int _5314 = _9380; _5314 < _9381; ++_5314)
          {
            {
              long long _5315 = (_ptr__5282[safe_add( _5314,(int)1 )] - _ptr__5282[_5314]);
              _ptr__5286[_5309] = safe_add( safe_mul( _ptr__5286[_5314],_5289 ),_ptr__5288[_5311] );
              _ptr__5298[safe_add( _5309,(int)1 )] = safe_add( _ptr__5298[_5309],_5315 );
              ++ _5309;
            }
          }
          _5310 += _5299;
        }
      }
      if ((NULL != _5295.get()))
      {
        {
          int _5316 = (int)0;
          int _9382 = (int)0;
          int _9383 = (int)((_5287)->size(0));
          for (int _5317 = _9382; _5317 < _9383; ++_5317)
          {
            {
              double _5318 = _ptr__5287[_5317];
              int _9384 = (int)0;
              int _9385 = (int)((_5286)->size(0));
              for (int _5319 = _9384; _5319 < _9385; ++_5319)
              {
                {
                  _ptr__5295[_5316] = (_ptr__5285[_5319] * _5318);
                  ++ _5316;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5298,_5297,_5296,_5295,_5291,_5294)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5320,int _5321,std::shared_ptr< monty::ndarray< double,1 > > _5322,std::shared_ptr< monty::ndarray< int,1 > > _5323,int _5324,bool _5325){
  _checked_ptr_1<double> _ptr__5322(_5322 ? _5322->raw() : nullptr, _5322 ? _5322->size(0) : 0);
  _checked_ptr_1<int> _ptr__5323(_5323 ? _5323->raw() : nullptr, _5323 ? _5323->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9386;
  bool _9387 = (!_5325);
  if (_9387)
  {
    _9386 = ::mosek::fusion::p_Set::make(_5321,_5324);
  }
  else
  {
    _9386 = ::mosek::fusion::p_Set::make(_5324,_5321);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5326 = _9386;
  _checked_ptr_1<int> _ptr__5326(_5326 ? _5326->raw() : nullptr,_5326 ? _5326->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9388;
  bool _9389 = (_5324 == (int)((_5322)->size(0)));
  if (_9389)
  {
    _9388 = nullptr;
  }
  else
  {
    _9388 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5322)->size(0)),_5321 ))));
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5327 = _9388;
  _checked_ptr_1<long long> _ptr__5327(_5327 ? _5327->raw() : nullptr,_5327 ? _5327->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5328 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5322)->size(0)),_5321 ))));
  _checked_ptr_1<double> _ptr__5328(_5328 ? _5328->raw() : nullptr,_5328 ? _5328->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5329 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5322)->size(0)),_5321 ))));
  _checked_ptr_1<double> _ptr__5329(_5329 ? _5329->raw() : nullptr,_5329 ? _5329->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5330 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5322)->size(0)),_5321 ))));
  _checked_ptr_1<long long> _ptr__5330(_5330 ? _5330->raw() : nullptr,_5330 ? _5330->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5331 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( safe_mul( (int)((_5322)->size(0)),_5321 ),(int)1 ))));
  _checked_ptr_1<long long> _ptr__5331(_5331 ? _5331->raw() : nullptr,_5331 ? _5331->size(0) : 0);
  if ((_5324 == (int)((_5322)->size(0))))
  {
    {
      long long _5332 = (long long)0;
      if ((!_5325))
      {
        {
          int _9390 = (int)0;
          int _9391 = _5321;
          for (int _5333 = _9390; _5333 < _9391; ++_5333)
          {
            {
              int _9392 = (int)0;
              int _9393 = _5324;
              for (int _5334 = _9392; _5334 < _9393; ++_5334)
              {
                {
                  _ptr__5331[safe_add( _5332,(int)1 )] = safe_add( _5332,(int)1 );
                  _ptr__5330[_5332] = (long long)_5333;
                  _ptr__5329[_5332] = _ptr__5322[_5334];
                  ++ _5332;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9394 = (int)0;
          int _9395 = _5324;
          for (int _5335 = _9394; _5335 < _9395; ++_5335)
          {
            {
              int _9396 = (int)0;
              int _9397 = _5321;
              for (int _5336 = _9396; _5336 < _9397; ++_5336)
              {
                {
                  _ptr__5331[safe_add( _5332,(int)1 )] = safe_add( _5332,(int)1 );
                  _ptr__5330[_5332] = (long long)_5336;
                  _ptr__5329[_5332] = _ptr__5322[_5335];
                  ++ _5332;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      long long _5337 = (long long)0;
      if ((!_5325))
      {
        {
          int _9398 = (int)0;
          int _9399 = _5321;
          for (int _5338 = _9398; _5338 < _9399; ++_5338)
          {
            {
              int _9400 = (int)0;
              int _9401 = (int)((_5322)->size(0));
              for (int _5339 = _9400; _5339 < _9401; ++_5339)
              {
                {
                  _ptr__5331[safe_add( _5337,(int)1 )] = safe_add( _5337,(int)1 );
                  _ptr__5330[_5337] = (long long)_5338;
                  _ptr__5329[_5337] = _ptr__5322[_5339];
                  _ptr__5327[_5337] = safe_add( safe_mul( _5338,_5324 ),_ptr__5323[_5339] );
                  ++ _5337;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9402 = (int)0;
          int _9403 = (int)((_5322)->size(0));
          for (int _5340 = _9402; _5340 < _9403; ++_5340)
          {
            {
              int _9404 = (int)0;
              int _9405 = _5321;
              for (int _5341 = _9404; _5341 < _9405; ++_5341)
              {
                {
                  _ptr__5331[safe_add( _5337,(int)1 )] = safe_add( _5337,(int)1 );
                  _ptr__5330[_5337] = (long long)_5341;
                  _ptr__5329[_5337] = _ptr__5322[_5340];
                  _ptr__5327[_5337] = safe_add( safe_mul( _ptr__5323[_5340],_5321 ),_5341 );
                  ++ _5337;
                }
              }
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5331,_5330,_5329,_5328,_5326,_5327)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5342) { return mosek::fusion::p_Expr::stack(_5342); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5342){
  if ((NULL == _5342.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9406 = (int)0;
  int _9407 = (int)((_5342)->size(0));
  for (int _5343 = _9406; _5343 < _9407; ++_5343)
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5344 = ((*_5342)(_5343));
      if ((NULL == _5344.get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
        }
      }
      {}
      int _9408 = (int)0;
      int _9409 = (int)((_5344)->size(0));
      for (int _5345 = _9408; _5345 < _9409; ++_5345)
      {
        {
          if ((NULL == ((*_5344)(_5345)).get()))
          {
            {
              throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9410;
  for (int _5347 = (int)0, _9411 = (int)((_5342)->size(0)); _5347 < _9411 ; ++_5347)
  {
    _9410.push_back(::mosek::fusion::p_Expr::stack_(((*_5342)(_5347)),(int)1));
  }
  auto _9412 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9410.size()),_9410.begin(),_9410.end()));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5346 = _9412;
  return ::mosek::fusion::p_Expr::stack_(_5346,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5348,    double _5349,    double _5350) { return mosek::fusion::p_Expr::vstack(_5348,_5349,_5350); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5348,double _5349,double _5350){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5348).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5349).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5350).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5351,    double _5352,    monty::rc_ptr< ::mosek::fusion::Expression > _5353) { return mosek::fusion::p_Expr::vstack(_5351,_5352,_5353); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5351,double _5352,monty::rc_ptr< ::mosek::fusion::Expression > _5353){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5351).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5352).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5353.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5354,    monty::rc_ptr< ::mosek::fusion::Expression > _5355,    double _5356) { return mosek::fusion::p_Expr::vstack(_5354,_5355,_5356); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5354,monty::rc_ptr< ::mosek::fusion::Expression > _5355,double _5356){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5354).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5355.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5356).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5357,    monty::rc_ptr< ::mosek::fusion::Expression > _5358,    monty::rc_ptr< ::mosek::fusion::Expression > _5359) { return mosek::fusion::p_Expr::vstack(_5357,_5358,_5359); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5357,monty::rc_ptr< ::mosek::fusion::Expression > _5358,monty::rc_ptr< ::mosek::fusion::Expression > _5359){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5357).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5358.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5359.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5360,    double _5361,    double _5362) { return mosek::fusion::p_Expr::vstack(_5360,_5361,_5362); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5360,double _5361,double _5362){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5360.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5361).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5362).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5363,    double _5364,    monty::rc_ptr< ::mosek::fusion::Expression > _5365) { return mosek::fusion::p_Expr::vstack(_5363,_5364,_5365); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5363,double _5364,monty::rc_ptr< ::mosek::fusion::Expression > _5365){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5363.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5364).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5365.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5366,    monty::rc_ptr< ::mosek::fusion::Expression > _5367,    double _5368) { return mosek::fusion::p_Expr::vstack(_5366,_5367,_5368); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5366,monty::rc_ptr< ::mosek::fusion::Expression > _5367,double _5368){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5366.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5367.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5368).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5369,    monty::rc_ptr< ::mosek::fusion::Expression > _5370,    monty::rc_ptr< ::mosek::fusion::Expression > _5371) { return mosek::fusion::p_Expr::vstack(_5369,_5370,_5371); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5369,monty::rc_ptr< ::mosek::fusion::Expression > _5370,monty::rc_ptr< ::mosek::fusion::Expression > _5371){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5369.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5370.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5371.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5372,    monty::rc_ptr< ::mosek::fusion::Expression > _5373) { return mosek::fusion::p_Expr::vstack(_5372,_5373); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5372,monty::rc_ptr< ::mosek::fusion::Expression > _5373){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5372).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5373.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5374,    double _5375) { return mosek::fusion::p_Expr::vstack(_5374,_5375); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5374,double _5375){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5374.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5375).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5376,    monty::rc_ptr< ::mosek::fusion::Expression > _5377) { return mosek::fusion::p_Expr::vstack(_5376,_5377); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5376,monty::rc_ptr< ::mosek::fusion::Expression > _5377){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5376.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5377.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5378) { return mosek::fusion::p_Expr::vstack(_5378); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5378){
  if ((NULL == _5378.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9413 = (int)0;
  int _9414 = (int)((_5378)->size(0));
  for (int _5379 = _9413; _5379 < _9414; ++_5379)
  {
    {
      if ((NULL == ((*_5378)(_5379)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for vstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5378,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5380,    monty::rc_ptr< ::mosek::fusion::Expression > _5381,    monty::rc_ptr< ::mosek::fusion::Expression > _5382) { return mosek::fusion::p_Expr::hstack(_5380,_5381,_5382); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5380,monty::rc_ptr< ::mosek::fusion::Expression > _5381,monty::rc_ptr< ::mosek::fusion::Expression > _5382){
  if (((NULL == _5380.get()) || ((NULL == _5381.get()) || (NULL == _5382.get()))))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments e1, e2 and e3 may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5380.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5381.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5382.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5383,    monty::rc_ptr< ::mosek::fusion::Expression > _5384,    double _5385) { return mosek::fusion::p_Expr::hstack(_5383,_5384,_5385); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5383,monty::rc_ptr< ::mosek::fusion::Expression > _5384,double _5385){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5383.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5384.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5385).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5386,    double _5387,    monty::rc_ptr< ::mosek::fusion::Expression > _5388) { return mosek::fusion::p_Expr::hstack(_5386,_5387,_5388); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5386,double _5387,monty::rc_ptr< ::mosek::fusion::Expression > _5388){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5386.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5387).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5388.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5389,    double _5390,    double _5391) { return mosek::fusion::p_Expr::hstack(_5389,_5390,_5391); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5389,double _5390,double _5391){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5389.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5390).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5391).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5392,    monty::rc_ptr< ::mosek::fusion::Expression > _5393,    monty::rc_ptr< ::mosek::fusion::Expression > _5394) { return mosek::fusion::p_Expr::hstack(_5392,_5393,_5394); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5392,monty::rc_ptr< ::mosek::fusion::Expression > _5393,monty::rc_ptr< ::mosek::fusion::Expression > _5394){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5392).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5393.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5394.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5395,    monty::rc_ptr< ::mosek::fusion::Expression > _5396,    double _5397) { return mosek::fusion::p_Expr::hstack(_5395,_5396,_5397); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5395,monty::rc_ptr< ::mosek::fusion::Expression > _5396,double _5397){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5395).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5396.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5397).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5398,    double _5399,    monty::rc_ptr< ::mosek::fusion::Expression > _5400) { return mosek::fusion::p_Expr::hstack(_5398,_5399,_5400); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5398,double _5399,monty::rc_ptr< ::mosek::fusion::Expression > _5400){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5398).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5399).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5400.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5401,    monty::rc_ptr< ::mosek::fusion::Expression > _5402) { return mosek::fusion::p_Expr::hstack(_5401,_5402); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5401,monty::rc_ptr< ::mosek::fusion::Expression > _5402){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5401).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5402.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5403,    double _5404) { return mosek::fusion::p_Expr::hstack(_5403,_5404); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5403,double _5404){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5403.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5404).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5405,    monty::rc_ptr< ::mosek::fusion::Expression > _5406) { return mosek::fusion::p_Expr::hstack(_5405,_5406); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5405,monty::rc_ptr< ::mosek::fusion::Expression > _5406){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5405.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5406.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5407) { return mosek::fusion::p_Expr::hstack(_5407); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5407){
  if ((NULL == _5407.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9415 = (int)0;
  int _9416 = (int)((_5407)->size(0));
  for (int _5408 = _9415; _5408 < _9416; ++_5408)
  {
    {
      if ((NULL == ((*_5407)(_5408)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for hstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5407,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5409,    monty::rc_ptr< ::mosek::fusion::Expression > _5410,    monty::rc_ptr< ::mosek::fusion::Expression > _5411,    monty::rc_ptr< ::mosek::fusion::Expression > _5412) { return mosek::fusion::p_Expr::stack(_5409,_5410,_5411,_5412); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5409,monty::rc_ptr< ::mosek::fusion::Expression > _5410,monty::rc_ptr< ::mosek::fusion::Expression > _5411,monty::rc_ptr< ::mosek::fusion::Expression > _5412){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5410.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5411.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5412.get())}),_5409);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5413,    monty::rc_ptr< ::mosek::fusion::Expression > _5414,    monty::rc_ptr< ::mosek::fusion::Expression > _5415,    double _5416) { return mosek::fusion::p_Expr::stack(_5413,_5414,_5415,_5416); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5413,monty::rc_ptr< ::mosek::fusion::Expression > _5414,monty::rc_ptr< ::mosek::fusion::Expression > _5415,double _5416){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5414.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5415.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5416).get())}),_5413);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5417,    monty::rc_ptr< ::mosek::fusion::Expression > _5418,    double _5419,    monty::rc_ptr< ::mosek::fusion::Expression > _5420) { return mosek::fusion::p_Expr::stack(_5417,_5418,_5419,_5420); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5417,monty::rc_ptr< ::mosek::fusion::Expression > _5418,double _5419,monty::rc_ptr< ::mosek::fusion::Expression > _5420){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5418.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5419).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5420.get())}),_5417);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5421,    monty::rc_ptr< ::mosek::fusion::Expression > _5422,    double _5423,    double _5424) { return mosek::fusion::p_Expr::stack(_5421,_5422,_5423,_5424); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5421,monty::rc_ptr< ::mosek::fusion::Expression > _5422,double _5423,double _5424){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5422.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5423).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5424).get())}),_5421);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5425,    double _5426,    monty::rc_ptr< ::mosek::fusion::Expression > _5427,    monty::rc_ptr< ::mosek::fusion::Expression > _5428) { return mosek::fusion::p_Expr::stack(_5425,_5426,_5427,_5428); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5425,double _5426,monty::rc_ptr< ::mosek::fusion::Expression > _5427,monty::rc_ptr< ::mosek::fusion::Expression > _5428){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5426).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5427.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5428.get())}),_5425);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5429,    double _5430,    monty::rc_ptr< ::mosek::fusion::Expression > _5431,    double _5432) { return mosek::fusion::p_Expr::stack(_5429,_5430,_5431,_5432); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5429,double _5430,monty::rc_ptr< ::mosek::fusion::Expression > _5431,double _5432){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5430).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5431.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5432).get())}),_5429);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5433,    double _5434,    double _5435,    monty::rc_ptr< ::mosek::fusion::Expression > _5436) { return mosek::fusion::p_Expr::stack(_5433,_5434,_5435,_5436); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5433,double _5434,double _5435,monty::rc_ptr< ::mosek::fusion::Expression > _5436){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5434).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5435).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5436.get())}),_5433);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5437,    double _5438,    monty::rc_ptr< ::mosek::fusion::Expression > _5439) { return mosek::fusion::p_Expr::stack(_5437,_5438,_5439); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5437,double _5438,monty::rc_ptr< ::mosek::fusion::Expression > _5439){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5438).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5439.get())}),_5437);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5440,    monty::rc_ptr< ::mosek::fusion::Expression > _5441,    double _5442) { return mosek::fusion::p_Expr::stack(_5440,_5441,_5442); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441,double _5442){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5441.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5442).get())}),_5440);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5443,    monty::rc_ptr< ::mosek::fusion::Expression > _5444,    monty::rc_ptr< ::mosek::fusion::Expression > _5445) { return mosek::fusion::p_Expr::stack(_5443,_5444,_5445); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5443,monty::rc_ptr< ::mosek::fusion::Expression > _5444,monty::rc_ptr< ::mosek::fusion::Expression > _5445){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5444.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5445.get())}),_5443);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5446,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5447) { return mosek::fusion::p_Expr::stack(_5446,_5447); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5446,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5447){
  return ::mosek::fusion::p_Expr::stack_(_5447,_5446);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5448,int _5449){
  if (((int)((_5448)->size(0)) == (int)1))
  {
    {
      return ((*_5448)((int)0));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprStack::_new_ExprStack(::mosek::fusion::p_Expr::promote(_5448,_5449),_5449)).as<::mosek::fusion::Expression>();
    }
  }
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > mosek::fusion::p_Expr::promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5450,int _5451){
  int _5452 = (int)((_5450)->size(0));
  std::vector<int> _9417;
  for (int _5454 = (int)0, _9418 = _5452; _5454 < _9418 ; ++_5454)
  {
    _9417.push_back(((*_5450)(_5454))->getND());
  }
  auto _9419 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9417.size()),_9417.begin(),_9417.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5453 = _9419;
  _checked_ptr_1<int> _ptr__5453(_5453 ? _5453->raw() : nullptr,_5453 ? _5453->size(0) : 0);
  int _5455 = _ptr__5453[(int)0];
  int _5456 = _ptr__5453[(int)0];
  int _9420 = (int)1;
  int _9421 = _5452;
  for (int _5457 = _9420; _5457 < _9421; ++_5457)
  {
    {
      if ((_ptr__5453[_5457] < _5456))
      {
        {
          _5456 = _ptr__5453[_5457];
        }
      }
      {}
      if ((_ptr__5453[_5457] > _5455))
      {
        {
          _5455 = _ptr__5453[_5457];
        }
      }
      {}
    }
  }
  if ((_5455 < _5451))
  {
    {
      _5455 = _5451;
    }
  }
  {}
  if ((_5456 < _5455))
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5458 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_5452)));
      std::shared_ptr< monty::ndarray< int,1 > > _5459 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5455)));
      _checked_ptr_1<int> _ptr__5459(_5459 ? _5459->raw() : nullptr,_5459 ? _5459->size(0) : 0);
      int _9422 = (int)0;
      int _9423 = _5452;
      for (int _5460 = _9422; _5460 < _9423; ++_5460)
      {
        {
          if ((((*_5450)(_5460))->getND() == _5455))
          {
            {
              ((*_5458)(_5460)) = ((*_5450)(_5460));
            }
          }
          else
          {
            {
              std::shared_ptr< monty::ndarray< int,1 > > _5461 = ((*_5450)(_5460))->getShape();
              _checked_ptr_1<int> _ptr__5461(_5461 ? _5461->raw() : nullptr,_5461 ? _5461->size(0) : 0);
              int _9424 = (int)0;
              int _9425 = (int)((_5461)->size(0));
              for (int _5462 = _9424; _5462 < _9425; ++_5462)
              {
                {
                  _ptr__5459[_5462] = _ptr__5461[_5462];
                }
              }
              int _9426 = (int)((_5461)->size(0));
              int _9427 = _5455;
              for (int _5463 = _9426; _5463 < _9427; ++_5463)
              {
                {
                  _ptr__5459[_5463] = (int)1;
                }
              }
              ((*_5458)(_5460)) = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5459,((*_5450)(_5460)))).as<::mosek::fusion::Expression>();
            }
          }
        }
      }
      return _5458;
    }
  }
  else
  {
    {
      return _5450;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Expression > _5464,    int _5465,    int _5466) { return mosek::fusion::p_Expr::repeat(_5464,_5465,_5466); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5464,int _5465,int _5466){
  if ((_5465 <= (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Cannot repeat Expression 0 or less times"));
    }
  }
  {}
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9428;
  for (int _5467 = (int)0, _9429 = _5465; _5467 < _9429 ; ++_5467)
  {
    _9428.push_back(_5464);
  }
  auto _9430 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9428.size()),_9428.begin(),_9428.end()));
  return ::mosek::fusion::p_Expr::stack_(_9430,_5466);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5468) { return mosek::fusion::p_Expr::add(_5468); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5468){
  std::vector<double> _9431;
  for (int _5469 = (int)0, _9432 = (int)((_5468)->size(0)); _5469 < _9432 ; ++_5469)
  {
    _9431.push_back(1.0);
  }
  auto _9433 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9431.size()),_9431.begin(),_9431.end()));
  return (::mosek::fusion::p_ExprWSum::_new_ExprWSum(_5468,_9433)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5470) { return mosek::fusion::p_Expr::add(_5470); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5470){
  if ((NULL == _5470.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may not be null"));
    }
  }
  {}
  if (((int)((_5470)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_Expr::_new_Expr(std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >{(long long)((int)0)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),nullptr,::mosek::fusion::p_Set::make((int)0),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5470)->size(0)) > (int)0) && (NULL == ((*_5470)((int)0)).get())))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may contain null"));
    }
  }
  {}
  int _5471 = ((*_5470)((int)0))->getND();
  int _9434 = (int)1;
  int _9435 = (int)((_5470)->size(0));
  for (int _5472 = _9434; _5472 < _9435; ++_5472)
  {
    {
      if ((_5471 < ((*_5470)(_5472))->getND()))
      {
        {
          _5471 = ((*_5470)(_5472))->getND();
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,2 > > _5473 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_5470)->size(0)),_5471)));
  int _9436 = (int)0;
  int _9437 = (int)((_5470)->size(0));
  for (int _5474 = _9436; _5474 < _9437; ++_5474)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5475 = ((*_5470)(_5474))->getShape();
      _checked_ptr_1<int> _ptr__5475(_5475 ? _5475->raw() : nullptr,_5475 ? _5475->size(0) : 0);
      int _9438 = (int)0;
      int _9439 = (int)((_5475)->size(0));
      for (int _5476 = _9438; _5476 < _9439; ++_5476)
      {
        {
          ((*_5473)(_5474,_5476)) = _ptr__5475[_5476];
        }
      }
      int _9440 = (int)((_5475)->size(0));
      int _9441 = _5471;
      for (int _5477 = _9440; _5477 < _9441; ++_5477)
      {
        {
          ((*_5473)(_5474,_5477)) = (int)1;
        }
      }
    }
  }
  int _9442 = (int)1;
  int _9443 = (int)((_5470)->size(0));
  for (int _5478 = _9442; _5478 < _9443; ++_5478)
  {
    {
      int _9444 = (int)0;
      int _9445 = _5471;
      for (int _5479 = _9444; _5479 < _9445; ++_5479)
      {
        {
          if ((((*_5473)((int)0,_5479)) != ((*_5473)(_5478,_5479))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _9446;
  for (int _5481 = (int)0, _9447 = _5471; _5481 < _9447 ; ++_5481)
  {
    _9446.push_back(((*_5473)((int)0,_5481)));
  }
  auto _9448 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9446.size()),_9446.begin(),_9446.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5480 = _9448;
  _checked_ptr_1<int> _ptr__5480(_5480 ? _5480->raw() : nullptr,_5480 ? _5480->size(0) : 0);
  int _5482 = (int)1;
  int _9449 = (int)0;
  int _9450 = _5471;
  for (int _5483 = _9449; _5483 < _9450; ++_5483)
  {
    {
      _5482 *= _ptr__5480[_5483];
    }
  }
  int _5484 = (int)0;
  int _5485 = (int)0;
  int _9451 = (int)0;
  int _9452 = (int)((_5470)->size(0));
  for (int _5486 = _9451; _5486 < _9452; ++_5486)
  {
    {
      int _5487 = ((*_5470)(_5486))->numInst();
      _5484 += _5487;
      int _9453;
      bool _9454 = (_5485 > _5487);
      if (_9454)
      {
        _9453 = _5485;
      }
      else
      {
        _9453 = _5487;
      }
      _5485 = _9453;
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5488 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5482,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5488(_5488 ? _5488->raw() : nullptr,_5488 ? _5488->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5489 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5484)));
  _checked_ptr_1<long long> _ptr__5489(_5489 ? _5489->raw() : nullptr,_5489 ? _5489->size(0) : 0);
  std::vector<double> _9455;
  for (int _5491 = (int)0, _9456 = _5484; _5491 < _9456 ; ++_5491)
  {
    _9455.push_back(1.0);
  }
  auto _9457 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9455.size()),_9455.begin(),_9455.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5490 = _9457;
  _checked_ptr_1<double> _ptr__5490(_5490 ? _5490->raw() : nullptr,_5490 ? _5490->size(0) : 0);
  {
    std::shared_ptr< monty::ndarray< long long,1 > > _5492 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5485)));
    _checked_ptr_1<long long> _ptr__5492(_5492 ? _5492->raw() : nullptr,_5492 ? _5492->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5493 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5485)));
    _checked_ptr_1<long long> _ptr__5493(_5493 ? _5493->raw() : nullptr,_5493 ? _5493->size(0) : 0);
    int _9458 = (int)0;
    int _9459 = (int)((_5470)->size(0));
    for (int _5494 = _9458; _5494 < _9459; ++_5494)
    {
      {
        int _5495 = ((*_5470)(_5494))->inst((int)0,_5492,(int)0,_5493);
        int _9460 = (int)0;
        int _9461 = _5495;
        for (int _5496 = _9460; _5496 < _9461; ++_5496)
        {
          {
            _ptr__5488[safe_add( _ptr__5492[_5496],(int)1 )] += (int)1;
          }
        }
      }
    }
    int _9462 = (int)0;
    int _9463 = _5482;
    for (int _5497 = _9462; _5497 < _9463; ++_5497)
    {
      {
        _ptr__5488[safe_add( _5497,(int)1 )] += _ptr__5488[_5497];
      }
    }
    int _9464 = (int)0;
    int _9465 = (int)((_5470)->size(0));
    for (int _5498 = _9464; _5498 < _9465; ++_5498)
    {
      {
        int _5499 = ((*_5470)(_5498))->inst((int)0,_5492,(int)0,_5493);
        int _9466 = (int)0;
        int _9467 = _5499;
        for (int _5500 = _9466; _5500 < _9467; ++_5500)
        {
          {
            _ptr__5489[_ptr__5488[_ptr__5492[_5500]]] = _ptr__5493[_5500];
            ++ _ptr__5488[_ptr__5492[_5500]];
          }
        }
      }
    }
    int _9468 = (int)0;
    int _9469 = _5482;
    for (int _5501 = _9468; _5501 < _9469; ++_5501)
    {
      {
        _ptr__5488[(_5482 - _5501)] = _ptr__5488[((_5482 - _5501) - (int)1)];
      }
    }
    _ptr__5488[(int)0] = (int)0;
  }
  std::vector<double> _9470;
  for (int _5502 = (int)0, _9471 = _5482; _5502 < _9471 ; ++_5502)
  {
    _9470.push_back(0.0);
  }
  auto _9472 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9470.size()),_9470.begin(),_9470.end()));
  return (::mosek::fusion::p_Expr::_new_Expr(_5488,_5489,_5490,_9472,_5480,nullptr,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add_(monty::rc_ptr< ::mosek::fusion::Expression > _5503,double _5504,monty::rc_ptr< ::mosek::fusion::Expression > _5505,double _5506){
  int _5507 = _5503->getND();
  int _5508 = _5505->getND();
  if ((_5507 == _5508))
  {
    {
      return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5503,_5505,_5504,_5506)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _9473;
      bool _9474 = (_5507 > _5508);
      if (_9474)
      {
        _9473 = _5507;
      }
      else
      {
        _9473 = _5508;
      }
      int _5509 = _9473;
      std::shared_ptr< monty::ndarray< int,1 > > _5510 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5509)));
      _checked_ptr_1<int> _ptr__5510(_5510 ? _5510->raw() : nullptr,_5510 ? _5510->size(0) : 0);
      if ((_5507 < _5508))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5511 = _5503->getShape();
          _checked_ptr_1<int> _ptr__5511(_5511 ? _5511->raw() : nullptr,_5511 ? _5511->size(0) : 0);
          int _9475 = (int)0;
          int _9476 = _5507;
          for (int _5512 = _9475; _5512 < _9476; ++_5512)
          {
            {
              _ptr__5510[_5512] = _ptr__5511[_5512];
            }
          }
          int _9477 = _5507;
          int _9478 = _5509;
          for (int _5513 = _9477; _5513 < _9478; ++_5513)
          {
            {
              _ptr__5510[_5513] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5510,_5503)).as<::mosek::fusion::Expression>(),_5505,_5504,_5506)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5514 = _5505->getShape();
          _checked_ptr_1<int> _ptr__5514(_5514 ? _5514->raw() : nullptr,_5514 ? _5514->size(0) : 0);
          int _9479 = (int)0;
          int _9480 = _5508;
          for (int _5515 = _9479; _5515 < _9480; ++_5515)
          {
            {
              _ptr__5510[_5515] = _ptr__5514[_5515];
            }
          }
          int _9481 = _5508;
          int _9482 = _5509;
          for (int _5516 = _9481; _5516 < _9482; ++_5516)
          {
            {
              _ptr__5510[_5516] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5503,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5510,_5505)).as<::mosek::fusion::Expression>(),_5504,_5506)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::transpose  ( monty::rc_ptr< ::mosek::fusion::Expression > _5517) { return mosek::fusion::p_Expr::transpose(_5517); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5517){
  if ((_5517->getND() == (int)0))
  {
    {
      return _5517;
    }
  }
  else if((_5517->getND() == (int)1))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_5517->getDim((int)0))}),_5517)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5517->getND() == (int)2))
  {
    {
      return (::mosek::fusion::p_ExprTranspose::_new_ExprTranspose(_5517)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incorrect number of dimensions for transpose"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5518,    monty::rc_ptr< ::mosek::fusion::Expression > _5519) { return mosek::fusion::p_Expr::mulElm(_5518,_5519); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5518,monty::rc_ptr< ::mosek::fusion::Expression > _5519){
  return ::mosek::fusion::p_Expr::mulElm_(_5518,_5519);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5520,    monty::rc_ptr< ::mosek::fusion::Expression > _5521) { return mosek::fusion::p_Expr::mulElm(_5520,_5521); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5520,monty::rc_ptr< ::mosek::fusion::Expression > _5521){
  return ::mosek::fusion::p_Expr::mulElm_(_5520,_5521);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,2 > > _5522,    monty::rc_ptr< ::mosek::fusion::Expression > _5523) { return mosek::fusion::p_Expr::mulElm(_5522,_5523); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5522,monty::rc_ptr< ::mosek::fusion::Expression > _5523){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5522),_5523);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,1 > > _5524,    monty::rc_ptr< ::mosek::fusion::Expression > _5525) { return mosek::fusion::p_Expr::mulElm(_5524,_5525); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5524,monty::rc_ptr< ::mosek::fusion::Expression > _5525){
  _checked_ptr_1<double> _ptr__5524(_5524 ? _5524->raw() : nullptr, _5524 ? _5524->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5524,_5525);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5526,    monty::rc_ptr< ::mosek::fusion::Matrix > _5527) { return mosek::fusion::p_Expr::mulElm(_5526,_5527); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5526,monty::rc_ptr< ::mosek::fusion::Matrix > _5527){
  return ::mosek::fusion::p_Expr::mulElm_(_5527,_5526);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5528,    std::shared_ptr< monty::ndarray< double,2 > > _5529) { return mosek::fusion::p_Expr::mulElm(_5528,_5529); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5528,std::shared_ptr< monty::ndarray< double,2 > > _5529){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5529),_5528);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5530,    std::shared_ptr< monty::ndarray< double,1 > > _5531) { return mosek::fusion::p_Expr::mulElm(_5530,_5531); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5530,std::shared_ptr< monty::ndarray< double,1 > > _5531){
  _checked_ptr_1<double> _ptr__5531(_5531 ? _5531->raw() : nullptr, _5531 ? _5531->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5531,_5530);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5532,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5533) { return mosek::fusion::p_Expr::mulElm(_5532,_5533); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5532,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5533){
  return ::mosek::fusion::p_Expr::mulElm_(_5533,_5532);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5534,    monty::rc_ptr< ::mosek::fusion::Expression > _5535) { return mosek::fusion::p_Expr::sub(_5534,_5535); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5534,monty::rc_ptr< ::mosek::fusion::Expression > _5535){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5534),1.0,_5535,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5536,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5537) { return mosek::fusion::p_Expr::sub(_5536,_5537); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5536,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5537){
  return ::mosek::fusion::p_Expr::add_(_5536,1.0,::mosek::fusion::p_Expr::constTerm(_5537),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5538,    monty::rc_ptr< ::mosek::fusion::Expression > _5539) { return mosek::fusion::p_Expr::sub(_5538,_5539); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5538,monty::rc_ptr< ::mosek::fusion::Expression > _5539){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5538),1.0,_5539,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5540,    monty::rc_ptr< ::mosek::fusion::Matrix > _5541) { return mosek::fusion::p_Expr::sub(_5540,_5541); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5540,monty::rc_ptr< ::mosek::fusion::Matrix > _5541){
  return ::mosek::fusion::p_Expr::add_(_5540,1.0,::mosek::fusion::p_Expr::constTerm(_5541),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( double _5542,    monty::rc_ptr< ::mosek::fusion::Expression > _5543) { return mosek::fusion::p_Expr::sub(_5542,_5543); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(double _5542,monty::rc_ptr< ::mosek::fusion::Expression > _5543){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5543->getShape(),_5542),1.0,_5543,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5544,    double _5545) { return mosek::fusion::p_Expr::sub(_5544,_5545); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5544,double _5545){
  return ::mosek::fusion::p_Expr::add_(_5544,1.0,::mosek::fusion::p_Expr::constTerm(_5544->getShape(),_5545),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,2 > > _5546,    monty::rc_ptr< ::mosek::fusion::Expression > _5547) { return mosek::fusion::p_Expr::sub(_5546,_5547); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,2 > > _5546,monty::rc_ptr< ::mosek::fusion::Expression > _5547){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5546),1.0,_5547,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,1 > > _5548,    monty::rc_ptr< ::mosek::fusion::Expression > _5549) { return mosek::fusion::p_Expr::sub(_5548,_5549); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,1 > > _5548,monty::rc_ptr< ::mosek::fusion::Expression > _5549){
  _checked_ptr_1<double> _ptr__5548(_5548 ? _5548->raw() : nullptr, _5548 ? _5548->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5548),1.0,_5549,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5550,    std::shared_ptr< monty::ndarray< double,2 > > _5551) { return mosek::fusion::p_Expr::sub(_5550,_5551); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5550,std::shared_ptr< monty::ndarray< double,2 > > _5551){
  return ::mosek::fusion::p_Expr::add_(_5550,1.0,::mosek::fusion::p_Expr::constTerm(_5551),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5552,    std::shared_ptr< monty::ndarray< double,1 > > _5553) { return mosek::fusion::p_Expr::sub(_5552,_5553); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5552,std::shared_ptr< monty::ndarray< double,1 > > _5553){
  _checked_ptr_1<double> _ptr__5553(_5553 ? _5553->raw() : nullptr, _5553 ? _5553->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5552,1.0,::mosek::fusion::p_Expr::constTerm(_5553),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5554,    monty::rc_ptr< ::mosek::fusion::Expression > _5555) { return mosek::fusion::p_Expr::sub(_5554,_5555); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5554,monty::rc_ptr< ::mosek::fusion::Expression > _5555){
  return ::mosek::fusion::p_Expr::add_(_5554,1.0,_5555,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5556,    monty::rc_ptr< ::mosek::fusion::Expression > _5557) { return mosek::fusion::p_Expr::add(_5556,_5557); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5556,monty::rc_ptr< ::mosek::fusion::Expression > _5557){
  return ::mosek::fusion::p_Expr::add_(_5557,1.0,::mosek::fusion::p_Expr::constTerm(_5556),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5558,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5559) { return mosek::fusion::p_Expr::add(_5558,_5559); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5558,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5559){
  return ::mosek::fusion::p_Expr::add_(_5558,1.0,::mosek::fusion::p_Expr::constTerm(_5559),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5560,    monty::rc_ptr< ::mosek::fusion::Expression > _5561) { return mosek::fusion::p_Expr::add(_5560,_5561); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Matrix > _5560,monty::rc_ptr< ::mosek::fusion::Expression > _5561){
  return ::mosek::fusion::p_Expr::add_(_5561,1.0,::mosek::fusion::p_Expr::constTerm(_5560),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5562,    monty::rc_ptr< ::mosek::fusion::Matrix > _5563) { return mosek::fusion::p_Expr::add(_5562,_5563); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5562,monty::rc_ptr< ::mosek::fusion::Matrix > _5563){
  return ::mosek::fusion::p_Expr::add_(_5562,1.0,::mosek::fusion::p_Expr::constTerm(_5563),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( double _5564,    monty::rc_ptr< ::mosek::fusion::Expression > _5565) { return mosek::fusion::p_Expr::add(_5564,_5565); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(double _5564,monty::rc_ptr< ::mosek::fusion::Expression > _5565){
  return ::mosek::fusion::p_Expr::add_(_5565,1.0,::mosek::fusion::p_Expr::constTerm(_5565->getShape(),_5564),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5566,    double _5567) { return mosek::fusion::p_Expr::add(_5566,_5567); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5566,double _5567){
  return ::mosek::fusion::p_Expr::add_(_5566,1.0,::mosek::fusion::p_Expr::constTerm(_5566->getShape(),_5567),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,2 > > _5568,    monty::rc_ptr< ::mosek::fusion::Expression > _5569) { return mosek::fusion::p_Expr::add(_5568,_5569); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,2 > > _5568,monty::rc_ptr< ::mosek::fusion::Expression > _5569){
  return ::mosek::fusion::p_Expr::add_(_5569,1.0,::mosek::fusion::p_Expr::constTerm(_5568),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,1 > > _5570,    monty::rc_ptr< ::mosek::fusion::Expression > _5571) { return mosek::fusion::p_Expr::add(_5570,_5571); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,1 > > _5570,monty::rc_ptr< ::mosek::fusion::Expression > _5571){
  _checked_ptr_1<double> _ptr__5570(_5570 ? _5570->raw() : nullptr, _5570 ? _5570->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5571,1.0,::mosek::fusion::p_Expr::constTerm(_5570),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5572,    std::shared_ptr< monty::ndarray< double,2 > > _5573) { return mosek::fusion::p_Expr::add(_5572,_5573); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5572,std::shared_ptr< monty::ndarray< double,2 > > _5573){
  return ::mosek::fusion::p_Expr::add_(_5572,1.0,::mosek::fusion::p_Expr::constTerm(_5573),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5574,    std::shared_ptr< monty::ndarray< double,1 > > _5575) { return mosek::fusion::p_Expr::add(_5574,_5575); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5574,std::shared_ptr< monty::ndarray< double,1 > > _5575){
  _checked_ptr_1<double> _ptr__5575(_5575 ? _5575->raw() : nullptr, _5575 ? _5575->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5574,1.0,::mosek::fusion::p_Expr::constTerm(_5575),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5576,    monty::rc_ptr< ::mosek::fusion::Expression > _5577) { return mosek::fusion::p_Expr::add(_5576,_5577); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5576,monty::rc_ptr< ::mosek::fusion::Expression > _5577){
  return ::mosek::fusion::p_Expr::add_(_5576,1.0,_5577,1.0);
}
int mosek::fusion::Expr :: getND() { return mosek::fusion::p_Expr::_get_impl(this)->getND(); }int mosek::fusion::p_Expr::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Expr :: getShape() { return mosek::fusion::p_Expr::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Expr::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::Expr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5578,monty::rc_ptr< ::mosek::fusion::WorkStack > _5579,monty::rc_ptr< ::mosek::fusion::WorkStack > _5580) { mosek::fusion::p_Expr::_get_impl(this)->eval(_5578,_5579,_5580); }void mosek::fusion::p_Expr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5578,monty::rc_ptr< ::mosek::fusion::WorkStack > _5579,monty::rc_ptr< ::mosek::fusion::WorkStack > _5580){
  std::vector<int> _9483;
  for (int _5581 = (int)0, _9484 = (int)((ptrb)->size(0)); _5581 < _9484 ; ++_5581)
  {
    _9483.push_back((int)((*ptrb)(_5581)));
  }
  auto _9485 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9483.size()),_9483.begin(),_9483.end()));
  ::mosek::fusion::p_BaseExpression::storeexpr(_5578,shape,_9485,inst,subj,cof_v,bfix);
}
void mosek::fusion::p_Expr::validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5582,std::shared_ptr< monty::ndarray< long long,1 > > _5583,std::shared_ptr< monty::ndarray< double,1 > > _5584,std::shared_ptr< monty::ndarray< double,1 > > _5585,std::shared_ptr< monty::ndarray< int,1 > > _5586,std::shared_ptr< monty::ndarray< long long,1 > > _5587){
  _checked_ptr_1<long long> _ptr__5582(_5582 ? _5582->raw() : nullptr, _5582 ? _5582->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5583(_5583 ? _5583->raw() : nullptr, _5583 ? _5583->size(0) : 0);
  _checked_ptr_1<double> _ptr__5584(_5584 ? _5584->raw() : nullptr, _5584 ? _5584->size(0) : 0);
  _checked_ptr_1<double> _ptr__5585(_5585 ? _5585->raw() : nullptr, _5585 ? _5585->size(0) : 0);
  _checked_ptr_1<int> _ptr__5586(_5586 ? _5586->raw() : nullptr, _5586 ? _5586->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5587(_5587 ? _5587->raw() : nullptr, _5587 ? _5587->size(0) : 0);
  if ((NULL == _5586.get()))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'shape' in expression is null"));
    }
  }
  {}
  int _5588 = ((int)((_5582)->size(0)) - (int)1);
  long long _5589 = _ptr__5582[((int)((_5582)->size(0)) - (int)1)];
  int _5590 = (int)((_5586)->size(0));
  long long _5591 = (long long)1;
  int _9486 = (int)0;
  int _9487 = _5590;
  for (int _5592 = _9486; _5592 < _9487; ++_5592)
  {
    {
      _5591 *= _ptr__5586[_5592];
    }
  }
  if (((int)((_5582)->size(0)) < (int)1))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong size"));
    }
  }
  {}
  if ((_5589 != (int)((_5583)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'subj' in expression has wrong size"));
    }
  }
  {}
  if ((_5589 != (int)((_5584)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'cof' in expression has wrong size"));
    }
  }
  {}
  if (((NULL == _5585.get()) || (_5588 != (int)((_5585)->size(0)))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'bfix' in expression has wrong length"));
    }
  }
  {}
  if (((NULL != _5587.get()) && ((int)((_5587)->size(0)) < _5591)))
  {
    {
      if (((int)((_5587)->size(0)) != ((int)((_5582)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' in expression has wrong length"));
        }
      }
      {}
      if (((int)((_5587)->size(0)) > (int)0))
      {
        {
          if (((_ptr__5587[(int)0] < (int)0) || (_ptr__5587[(int)0] >= _5591)))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' contains an invalid index"));
            }
          }
          {}
          bool _5593 = true;
          long long _5594 = _5591;
          int _9488 = (int)1;
          int _9489 = (int)((_5587)->size(0));
          for (int _5595 = _9488; _5595 < _9489; ++_5595)
          {
            {
              _5593 = (_5593 && ((_ptr__5587[_5595] >= (int)0) && ((_ptr__5587[_5595] < _5594) && (_ptr__5587[_5595] > _ptr__5587[(_5595 - (int)1)]))));
            }
          }
          if ((!_5593))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Invalid array 'inst'"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      if ((_5591 != ((long long)((_5582)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong length"));
        }
      }
      {}
    }
  }
  bool _5596 = false;
  bool _5597 = false;
  if ((_ptr__5582[(int)0] != (long long)0))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
  bool _5598 = true;
  int _9490 = (int)0;
  int _9491 = _5588;
  for (int _5599 = _9490; _5599 < _9491; ++_5599)
  {
    {
      _5598 = (_5598 && (_ptr__5582[_5599] <= _ptr__5582[safe_add( _5599,(int)1 )]));
    }
  }
  if ((!_5598))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Expr::extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5600){
  monty::rc_ptr< ::mosek::fusion::Model > _9492;
  bool _9493 = ((NULL == _5600.get()) || ((int)((_5600)->size(0)) == (int)0));
  if (_9493)
  {
    _9492 = nullptr;
  }
  else
  {
    _9492 = ((*_5600)((int)0))->__mosek_2fusion_2Variable__getModel();
  }
  return _9492;
}
void mosek::fusion::p_Expr::destroy(){inst.reset();cof_v.reset();subj.reset();ptrb.reset();bfix.reset();shape.reset();}void mosek::fusion::Expr::destroy() { mosek::fusion::p_Expr::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,2 > > _5601) { return __mosek_2fusion_2Expression__pick(_5601); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,1 > > _5602) { return __mosek_2fusion_2Expression__pick(_5602); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(std::shared_ptr< monty::ndarray< int,1 > > _5603) { return __mosek_2fusion_2Expression__index(_5603); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(int _5604) { return __mosek_2fusion_2Expression__index(_5604); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(std::shared_ptr< monty::ndarray< int,1 > > _5605,std::shared_ptr< monty::ndarray< int,1 > > _5606) { return __mosek_2fusion_2Expression__slice(_5605,_5606); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(int _5607,int _5608) { return __mosek_2fusion_2Expression__slice(_5607,_5608); }
monty::rc_ptr< mosek::fusion::FlatExpr > mosek::fusion::Expression::eval() { return __mosek_2fusion_2Expression__eval(); }
mosek::fusion::FlatExpr::FlatExpr(mosek::fusion::p_FlatExpr *_impl) : _impl(_impl) { /*std::cout << "FlatExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::FlatExpr::~FlatExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_FlatExpr::p_FlatExpr  (::mosek::fusion::FlatExpr * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_inst() { return _impl->inst; }
void mosek::fusion::FlatExpr::set_inst(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->inst = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::FlatExpr::get_shape() { return _impl->shape; }
void mosek::fusion::FlatExpr::set_shape(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->shape = _val; }
long long mosek::fusion::FlatExpr::get_nnz() { return _impl->nnz; }
void mosek::fusion::FlatExpr::set_nnz(long long _val) { _impl->nnz = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_cof() { return _impl->cof; }
void mosek::fusion::FlatExpr::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_subj() { return _impl->subj; }
void mosek::fusion::FlatExpr::set_subj(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::FlatExpr::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_bfix() { return _impl->bfix; }
void mosek::fusion::FlatExpr::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5613){ return new mosek::fusion::FlatExpr(_5613); }mosek::fusion::FlatExpr::FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5613) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5613); }void mosek::fusion::p_FlatExpr::_initialize  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5613){monty::rc_reserve __reserve_this(_pubthis);   {
    bfix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5613)->bfix);
    ptrb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5613)->ptrb);
    subj = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5613)->subj);
    cof = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5613)->cof);
    nnz = mosek::fusion::p_FlatExpr::_get_impl(_5613)->nnz;
    shape = mosek::fusion::p_FlatExpr::_get_impl(_5613)->shape;
    inst = mosek::fusion::p_FlatExpr::_get_impl(_5613)->inst;
  }
}mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5614,    std::shared_ptr< monty::ndarray< long long,1 > > _5615,    std::shared_ptr< monty::ndarray< long long,1 > > _5616,    std::shared_ptr< monty::ndarray< double,1 > > _5617,    std::shared_ptr< monty::ndarray< int,1 > > _5618,    std::shared_ptr< monty::ndarray< long long,1 > > _5619){ return new mosek::fusion::FlatExpr(_5614,_5615,_5616,_5617,_5618,_5619); }mosek::fusion::FlatExpr::FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5614,    std::shared_ptr< monty::ndarray< long long,1 > > _5615,    std::shared_ptr< monty::ndarray< long long,1 > > _5616,    std::shared_ptr< monty::ndarray< double,1 > > _5617,    std::shared_ptr< monty::ndarray< int,1 > > _5618,    std::shared_ptr< monty::ndarray< long long,1 > > _5619) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5614,_5615,_5616,_5617,_5618,_5619); }void mosek::fusion::p_FlatExpr::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5614,    std::shared_ptr< monty::ndarray< long long,1 > > _5615,    std::shared_ptr< monty::ndarray< long long,1 > > _5616,    std::shared_ptr< monty::ndarray< double,1 > > _5617,    std::shared_ptr< monty::ndarray< int,1 > > _5618,    std::shared_ptr< monty::ndarray< long long,1 > > _5619){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5614(_5614 ? _5614->raw() : nullptr, _5614 ? _5614->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5615(_5615 ? _5615->raw() : nullptr, _5615 ? _5615->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5616(_5616 ? _5616->raw() : nullptr, _5616 ? _5616->size(0) : 0);
    _checked_ptr_1<double> _ptr__5617(_5617 ? _5617->raw() : nullptr, _5617 ? _5617->size(0) : 0);
    _checked_ptr_1<int> _ptr__5618(_5618 ? _5618->raw() : nullptr, _5618 ? _5618->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5619(_5619 ? _5619->raw() : nullptr, _5619 ? _5619->size(0) : 0);
    if (((NULL != _5614.get()) && ((int)((_5614)->size(0)) != ((int)((_5615)->size(0)) - (int)1))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of bfix and ptrb"));
      }
    }
    {}
    if (((NULL == _5617.get()) || ((NULL == _5616.get()) || ((int)((_5616)->size(0)) != (int)((_5617)->size(0))))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of subj and cof"));
      }
    }
    {}
    if ((NULL != _5618.get()))
    {
      {
        if ((NULL != _5619.get()))
        {
          {
            if (((int)((_5619)->size(0)) != ((int)((_5615)->size(0)) - (int)1)))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of inst and ptrb"));
              }
            }
            {}
          }
        }
        else if((::mosek::fusion::p_Set::size(_5618) != ((long long)((_5615)->size(0)) - (int)1)))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching shape and ptrb"));
          }
        }
        {}
      }
    }
    {}
    bfix = _5614;
    ptrb = _5615;
    subj = _5616;
    cof = _5617;
    nnz = ((*ptrb)(((int)((ptrb)->size(0)) - (int)1)));
    shape = _5618;
    inst = _5619;
  }
}std::string mosek::fusion::FlatExpr :: toString() { return mosek::fusion::p_FlatExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_FlatExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5620 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5620->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("FlatExpr:"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| ptrb["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((ptrb)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(ptrb)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| subj["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((subj)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(subj)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| cof ["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((cof)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(cof)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| bfix["));
  if ((NULL != bfix.get()))
  {
    {
      _5620->__mosek_2fusion_2Utils_2StringBuffer__a((int)((bfix)->size(0)));
    }
  }
  {}
  _5620->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(bfix)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| inst["));
  if ((NULL != inst.get()))
  {
    {
      _5620->__mosek_2fusion_2Utils_2StringBuffer__a((int)((inst)->size(0)));
    }
  }
  {}
  _5620->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(inst)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"));
  return _5620->toString();
}
int mosek::fusion::FlatExpr :: size() { return mosek::fusion::p_FlatExpr::_get_impl(this)->size(); }int mosek::fusion::p_FlatExpr::size(){
  return ((int)((ptrb)->size(0)) - (int)1);
}
void mosek::fusion::p_FlatExpr::destroy(){inst.reset();shape.reset();cof.reset();subj.reset();ptrb.reset();bfix.reset();}void mosek::fusion::FlatExpr::destroy() { mosek::fusion::p_FlatExpr::_get_impl(this)->destroy(); }mosek::fusion::SymmetricMatrix::SymmetricMatrix(mosek::fusion::p_SymmetricMatrix *_impl) : _impl(_impl) { /*std::cout << "SymmetricMatrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricMatrix::~SymmetricMatrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricMatrix::p_SymmetricMatrix  (::mosek::fusion::SymmetricMatrix * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricMatrix::t mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix  (int _5621,    int _5622,    std::shared_ptr< monty::ndarray< int,1 > > _5623,    std::shared_ptr< monty::ndarray< int,1 > > _5624,    std::shared_ptr< monty::ndarray< double,1 > > _5625,    std::shared_ptr< monty::ndarray< int,1 > > _5626,    std::shared_ptr< monty::ndarray< int,1 > > _5627,    std::shared_ptr< monty::ndarray< double,1 > > _5628,    double _5629){ return new mosek::fusion::SymmetricMatrix(_5621,_5622,_5623,_5624,_5625,_5626,_5627,_5628,_5629); }mosek::fusion::SymmetricMatrix::SymmetricMatrix  (int _5621,    int _5622,    std::shared_ptr< monty::ndarray< int,1 > > _5623,    std::shared_ptr< monty::ndarray< int,1 > > _5624,    std::shared_ptr< monty::ndarray< double,1 > > _5625,    std::shared_ptr< monty::ndarray< int,1 > > _5626,    std::shared_ptr< monty::ndarray< int,1 > > _5627,    std::shared_ptr< monty::ndarray< double,1 > > _5628,    double _5629) :    SymmetricMatrix(new mosek::fusion::p_SymmetricMatrix(this)){ mosek::fusion::p_SymmetricMatrix::_get_impl(this)->_initialize(_5621,_5622,_5623,_5624,_5625,_5626,_5627,_5628,_5629); }void mosek::fusion::p_SymmetricMatrix::_initialize  (int _5621,    int _5622,    std::shared_ptr< monty::ndarray< int,1 > > _5623,    std::shared_ptr< monty::ndarray< int,1 > > _5624,    std::shared_ptr< monty::ndarray< double,1 > > _5625,    std::shared_ptr< monty::ndarray< int,1 > > _5626,    std::shared_ptr< monty::ndarray< int,1 > > _5627,    std::shared_ptr< monty::ndarray< double,1 > > _5628,    double _5629){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5623(_5623 ? _5623->raw() : nullptr, _5623 ? _5623->size(0) : 0);
    _checked_ptr_1<int> _ptr__5624(_5624 ? _5624->raw() : nullptr, _5624 ? _5624->size(0) : 0);
    _checked_ptr_1<double> _ptr__5625(_5625 ? _5625->raw() : nullptr, _5625 ? _5625->size(0) : 0);
    _checked_ptr_1<int> _ptr__5626(_5626 ? _5626->raw() : nullptr, _5626 ? _5626->size(0) : 0);
    _checked_ptr_1<int> _ptr__5627(_5627 ? _5627->raw() : nullptr, _5627 ? _5627->size(0) : 0);
    _checked_ptr_1<double> _ptr__5628(_5628 ? _5628->raw() : nullptr, _5628 ? _5628->size(0) : 0);
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d0 = _5621;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d1 = _5622;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubi = _5623;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubj = _5624;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->uval = _5625;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubi = _5626;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubj = _5627;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vval = _5628;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->scale = _5629;
    nnz = (-(int)1);
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( int _5630,    std::shared_ptr< monty::ndarray< int,1 > > _5631,    std::shared_ptr< monty::ndarray< double,1 > > _5632) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5630,_5631,_5632); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(int _5630,std::shared_ptr< monty::ndarray< int,1 > > _5631,std::shared_ptr< monty::ndarray< double,1 > > _5632){
  _checked_ptr_1<int> _ptr__5631(_5631 ? _5631->raw() : nullptr, _5631 ? _5631->size(0) : 0);
  _checked_ptr_1<double> _ptr__5632(_5632 ? _5632->raw() : nullptr, _5632 ? _5632->size(0) : 0);
  if (((int)((_5631)->size(0)) != (int)((_5632)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching array lengths"));
    }
  }
  {}
  int _9494 = (int)0;
  int _9495 = (int)((_5631)->size(0));
  for (int _5633 = _9494; _5633 < _9495; ++_5633)
  {
    {
      if (((_ptr__5631[_5633] < (int)0) || (_ptr__5631[_5633] >= _5630)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid index in argument 'sub'"));
        }
      }
      {}
    }
  }
  std::vector<int> _9496;
  for (int _5635 = (int)0, _9497 = (int)((_5631)->size(0)); _5635 < _9497 ; ++_5635)
  {
    _9496.push_back(_ptr__5631[_5635]);
  }
  auto _9498 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9496.size()),_9496.begin(),_9496.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5634 = _9498;
  _checked_ptr_1<int> _ptr__5634(_5634 ? _5634->raw() : nullptr,_5634 ? _5634->size(0) : 0);
  std::vector<int> _9499;
  for (int _5637 = (int)0, _9500 = (int)((_5631)->size(0)); _5637 < _9500 ; ++_5637)
  {
    _9499.push_back((int)1);
  }
  auto _9501 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9499.size()),_9499.begin(),_9499.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5636 = _9501;
  _checked_ptr_1<int> _ptr__5636(_5636 ? _5636->raw() : nullptr,_5636 ? _5636->size(0) : 0);
  std::vector<double> _9502;
  for (int _5639 = (int)0, _9503 = (int)((_5632)->size(0)); _5639 < _9503 ; ++_5639)
  {
    _9502.push_back(_ptr__5632[_5639]);
  }
  auto _9504 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9502.size()),_9502.begin(),_9502.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5638 = _9504;
  _checked_ptr_1<double> _ptr__5638(_5638 ? _5638->raw() : nullptr,_5638 ? _5638->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5630,(int)1,_5634,_5636,_5638,_5634,_5636,_5638,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( std::shared_ptr< monty::ndarray< double,1 > > _5640) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5640); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5640){
  _checked_ptr_1<double> _ptr__5640(_5640 ? _5640->raw() : nullptr, _5640 ? _5640->size(0) : 0);
  int _5641 = (int)((_5640)->size(0));
  std::vector<int> _9505;
  for (int _5643 = (int)0, _9506 = _5641; _5643 < _9506 ; ++_5643)
  {
    _9505.push_back(_5643);
  }
  auto _9507 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9505.size()),_9505.begin(),_9505.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5642 = _9507;
  _checked_ptr_1<int> _ptr__5642(_5642 ? _5642->raw() : nullptr,_5642 ? _5642->size(0) : 0);
  std::vector<int> _9508;
  for (int _5645 = (int)0, _9509 = _5641; _5645 < _9509 ; ++_5645)
  {
    _9508.push_back((int)1);
  }
  auto _9510 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9508.size()),_9508.begin(),_9508.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5644 = _9510;
  _checked_ptr_1<int> _ptr__5644(_5644 ? _5644->raw() : nullptr,_5644 ? _5644->size(0) : 0);
  std::vector<double> _9511;
  for (int _5647 = (int)0, _9512 = _5641; _5647 < _9512 ; ++_5647)
  {
    _9511.push_back(_ptr__5640[_5647]);
  }
  auto _9513 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9511.size()),_9511.begin(),_9511.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5646 = _9513;
  _checked_ptr_1<double> _ptr__5646(_5646 ? _5646->raw() : nullptr,_5646 ? _5646->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5641,(int)1,_5642,_5644,_5646,_5642,_5644,_5646,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::antiDiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5648) { return mosek::fusion::p_SymmetricMatrix::antiDiag(_5648); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5648){
  _checked_ptr_1<double> _ptr__5648(_5648 ? _5648->raw() : nullptr, _5648 ? _5648->size(0) : 0);
  int _5649 = (int)((_5648)->size(0));
  std::vector<int> _9514;
  for (int _5651 = (int)0, _9515 = _5649; _5651 < _9515 ; ++_5651)
  {
    _9514.push_back(_5651);
  }
  auto _9516 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9514.size()),_9514.begin(),_9514.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5650 = _9516;
  _checked_ptr_1<int> _ptr__5650(_5650 ? _5650->raw() : nullptr,_5650 ? _5650->size(0) : 0);
  std::vector<int> _9517;
  for (int _5652 = (int)0, _9518 = _5649; _5652 < _9518 ; ++_5652)
  {
    _9517.push_back((_5649 - _5652));
  }
  auto _9519 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9517.size()),_9517.begin(),_9517.end()));
  std::vector<double> _9520;
  for (int _5653 = (int)0, _9521 = _5649; _5653 < _9521 ; ++_5653)
  {
    _9520.push_back(_ptr__5648[_5653]);
  }
  auto _9522 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9520.size()),_9520.begin(),_9520.end()));
  std::vector<double> _9523;
  for (int _5654 = (int)0, _9524 = _5649; _5654 < _9524 ; ++_5654)
  {
    _9523.push_back(1.0);
  }
  auto _9525 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9523.size()),_9523.begin(),_9523.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5649,_5649,_5650,_9519,_9522,_5650,_5650,_9525,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5655) { return mosek::fusion::p_SymmetricMatrix::diag(_5655); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5655){
  _checked_ptr_1<double> _ptr__5655(_5655 ? _5655->raw() : nullptr, _5655 ? _5655->size(0) : 0);
  int _5656 = (int)((_5655)->size(0));
  std::vector<int> _9526;
  for (int _5658 = (int)0, _9527 = _5656; _5658 < _9527 ; ++_5658)
  {
    _9526.push_back(_5658);
  }
  auto _9528 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9526.size()),_9526.begin(),_9526.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5657 = _9528;
  _checked_ptr_1<int> _ptr__5657(_5657 ? _5657->raw() : nullptr,_5657 ? _5657->size(0) : 0);
  std::vector<double> _9529;
  for (int _5659 = (int)0, _9530 = _5656; _5659 < _9530 ; ++_5659)
  {
    _9529.push_back(_ptr__5655[_5659]);
  }
  auto _9531 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9529.size()),_9529.begin(),_9529.end()));
  std::vector<double> _9532;
  for (int _5660 = (int)0, _9533 = _5656; _5660 < _9533 ; ++_5660)
  {
    _9532.push_back(1.0);
  }
  auto _9534 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9532.size()),_9532.begin(),_9532.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5656,_5656,_5657,_5657,_9531,_5657,_5657,_9534,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5661) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__add(_5661); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5661) { return __mosek_2fusion_2SymmetricMatrix__add(_5661); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5661){
  int _5662 = _pubthis->getdim();
  if ((_5661->getdim() != _5662))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  int _5663 = (int)((usubi)->size(0));
  int _5664 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->usubi)->size(0));
  int _5665 = safe_add( _5663,_5664 );
  int _5666 = (int)((vsubi)->size(0));
  int _5667 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->vsubi)->size(0));
  int _5668 = safe_add( _5666,_5667 );
  std::shared_ptr< monty::ndarray< double,1 > > _5669 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5668)));
  _checked_ptr_1<double> _ptr__5669(_5669 ? _5669->raw() : nullptr,_5669 ? _5669->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5670 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5668)));
  _checked_ptr_1<int> _ptr__5670(_5670 ? _5670->raw() : nullptr,_5670 ? _5670->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5671 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5668)));
  _checked_ptr_1<int> _ptr__5671(_5671 ? _5671->raw() : nullptr,_5671 ? _5671->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5672 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5665)));
  _checked_ptr_1<double> _ptr__5672(_5672 ? _5672->raw() : nullptr,_5672 ? _5672->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5673 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5665)));
  _checked_ptr_1<int> _ptr__5673(_5673 ? _5673->raw() : nullptr,_5673 ? _5673->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5674 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5665)));
  _checked_ptr_1<int> _ptr__5674(_5674 ? _5674->raw() : nullptr,_5674 ? _5674->size(0) : 0);
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5674,(int)0,_5663);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->usubi,(int)0,_5674,_5663,_5664);
  ::mosek::fusion::Utils::Tools::arraycopy(usubj,(int)0,_5673,(int)0,_5663);
  int _9535 = (int)0;
  int _9536 = _5664;
  for (int _5675 = _9535; _5675 < _9536; ++_5675)
  {
    {
      _ptr__5673[safe_add( _5675,_5663 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->usubj)(_5675)),d1 );
    }
  }
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(uval,(int)0,_5672,(int)0,_5663);
    }
  }
  else
  {
    {
      int _9537 = (int)0;
      int _9538 = _5663;
      for (int _5676 = _9537; _5676 < _9538; ++_5676)
      {
        {
          _ptr__5672[_5676] = (scale * ((*uval)(_5676)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->uval,(int)0,_5672,_5663,_5664);
    }
  }
  else
  {
    {
      int _9539 = (int)0;
      int _9540 = _5664;
      for (int _5677 = _9539; _5677 < _9540; ++_5677)
      {
        {
          _ptr__5672[safe_add( _5677,_5663 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->uval)(_5677)));
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5674,(int)0,_5663);
  int _9541 = (int)0;
  int _9542 = _5667;
  for (int _5678 = _9541; _5678 < _9542; ++_5678)
  {
    {
      _ptr__5671[safe_add( _5678,_5666 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->vsubi)(_5678)),mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->d1 );
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(vsubj,(int)0,_5670,(int)0,_5666);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->vsubj,_5666,_5670,_5666,_5667);
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(vval,(int)0,_5669,(int)0,_5666);
    }
  }
  else
  {
    {
      int _9543 = (int)0;
      int _9544 = _5666;
      for (int _5679 = _9543; _5679 < _9544; ++_5679)
      {
        {
          _ptr__5669[_5679] = (scale * ((*vval)(_5679)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->vval,(int)0,_5669,_5666,_5667);
    }
  }
  else
  {
    {
      int _9545 = (int)0;
      int _9546 = _5667;
      for (int _5680 = _9545; _5680 < _9546; ++_5680)
      {
        {
          _ptr__5669[safe_add( _5680,_5666 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->vval)(_5680)));
        }
      }
    }
  }
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,safe_add( d1,mosek::fusion::p_SymmetricMatrix::_get_impl(_5661)->d1 ),_5674,_5673,_5672,_5671,_5670,_5669,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5681) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__sub(_5681); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5681) { return __mosek_2fusion_2SymmetricMatrix__sub(_5681); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5681){
  return _pubthis->__mosek_2fusion_2SymmetricMatrix__add(_5681->__mosek_2fusion_2SymmetricMatrix__mul((-1.0)));
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__mul(double _5682) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__mul(_5682); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::mul(double _5682) { return __mosek_2fusion_2SymmetricMatrix__mul(_5682); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__mul(double _5682){
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,d1,usubi,usubj,uval,vsubi,vsubj,vval,(scale * _5682));
}
int mosek::fusion::SymmetricMatrix :: getdim() { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->getdim(); }int mosek::fusion::p_SymmetricMatrix::getdim(){
  return d0;
}
void mosek::fusion::p_SymmetricMatrix::destroy(){vval.reset();vsubj.reset();vsubi.reset();uval.reset();usubj.reset();usubi.reset();}void mosek::fusion::SymmetricMatrix::destroy() { mosek::fusion::p_SymmetricMatrix::_get_impl(this)->destroy(); }mosek::fusion::NDSparseArray::NDSparseArray(mosek::fusion::p_NDSparseArray *_impl) : _impl(_impl) { /*std::cout << "NDSparseArray() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::NDSparseArray::~NDSparseArray() { delete _impl; _impl = nullptr; }mosek::fusion::p_NDSparseArray::p_NDSparseArray  (::mosek::fusion::NDSparseArray * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5683,    std::shared_ptr< monty::ndarray< int,2 > > _5684,    std::shared_ptr< monty::ndarray< double,1 > > _5685){ return new mosek::fusion::NDSparseArray(_5683,_5684,_5685); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5683,    std::shared_ptr< monty::ndarray< int,2 > > _5684,    std::shared_ptr< monty::ndarray< double,1 > > _5685) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5683,_5684,_5685); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5683,    std::shared_ptr< monty::ndarray< int,2 > > _5684,    std::shared_ptr< monty::ndarray< double,1 > > _5685){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5683(_5683 ? _5683->raw() : nullptr, _5683 ? _5683->size(0) : 0);
    _checked_ptr_1<double> _ptr__5685(_5685 ? _5685->raw() : nullptr, _5685 ? _5685->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5686 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_5684)->size(0)))));
    _checked_ptr_1<long long> _ptr__5686(_5686 ? _5686->raw() : nullptr,_5686 ? _5686->size(0) : 0);
    size = (long long)1;
    int _9547 = (int)0;
    int _9548 = (int)((_5683)->size(0));
    for (int _5687 = _9547; _5687 < _9548; ++_5687)
    {
      {
        size = safe_mul( size,_ptr__5683[_5687] );
      }
    }
    int _5688 = (int)((_5683)->size(0));
    if (((int)((_5684)->size(0)) != (int)((_5685)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    if (((int)((_5684)->size(1)) != _5688))
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index key in sub has wrong length"));
      }
    }
    {}
    int _9549 = (int)0;
    int _9550 = (int)((_5684)->size(0));
    for (int _5689 = _9549; _5689 < _9550; ++_5689)
    {
      {
        int _9551 = (int)0;
        int _9552 = (int)((_5684)->size(1));
        for (int _5690 = _9551; _5690 < _9552; ++_5690)
        {
          {
            if (((((*_5684)(_5689,_5690)) < (int)0) || (((*_5684)(_5689,_5690)) >= _ptr__5683[_5690])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("An index in sub is out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    int _9553 = (int)0;
    int _9554 = (int)((_5684)->size(0));
    for (int _5691 = _9553; _5691 < _9554; ++_5691)
    {
      {
        long long _5692 = (long long)0;
        int _9555 = (int)0;
        int _9556 = (int)((_5684)->size(1));
        for (int _5693 = _9555; _5693 < _9556; ++_5693)
        {
          {
            _5692 = safe_add( safe_mul( _5692,_ptr__5683[_5693] ),((*_5684)(_5691,_5693)) );
          }
        }
        _ptr__5686[_5691] = _5692;
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5683);
    bool _5694 = true;
    int _9557 = (int)1;
    int _9558 = (int)((_5686)->size(0));
    for (int _5695 = _9557; _5695 < _9558; ++_5695)
    {
      {
        _5694 = (_5694 && (_ptr__5686[_5695] >= _ptr__5686[(_5695 - (int)1)]));
      }
    }
    if (_5694)
    {
      {
        int _5696 = (int)1;
        int _9559 = (int)1;
        int _9560 = (int)((_5686)->size(0));
        for (int _5697 = _9559; _5697 < _9560; ++_5697)
        {
          {
            if ((_ptr__5686[(_5697 - (int)1)] < _ptr__5686[_5697]))
            {
              {
                ++ _5696;
              }
            }
            {}
          }
        }
        if ((_5696 == (int)((_5686)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5686);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5685);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5696)));
            ((*inst)((int)0)) = _ptr__5686[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5696)));
            ((*cof)((int)0)) = _ptr__5685[(int)0];
            int _5698 = (int)0;
            int _9561 = (int)1;
            int _9562 = (int)((_5686)->size(0));
            for (int _5699 = _9561; _5699 < _9562; ++_5699)
            {
              {
                if ((_ptr__5686[_5699] > _ptr__5686[(_5699 - (int)1)]))
                {
                  {
                    ++ _5698;
                    ((*inst)(_5698)) = _ptr__5686[_5699];
                    ((*cof)(_5698)) = _ptr__5685[_5699];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5698)) = (((*cof)(_5698)) + _ptr__5685[_5699]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5700 = ::mosek::fusion::Utils::Tools::range((long long)((_5686)->size(0)));
        _checked_ptr_1<long long> _ptr__5700(_5700 ? _5700->raw() : nullptr,_5700 ? _5700->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5700,_5686,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5686)->size(0)));
        int _5701 = (int)1;
        int _9563 = (int)1;
        int _9564 = (int)((_5686)->size(0));
        for (int _5702 = _9563; _5702 < _9564; ++_5702)
        {
          {
            if ((_ptr__5686[_ptr__5700[(_5702 - (int)1)]] < _ptr__5686[_ptr__5700[_5702]]))
            {
              {
                ++ _5701;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5701)));
        ((*inst)((int)0)) = _ptr__5686[_ptr__5700[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5701)));
        ((*cof)((int)0)) = _ptr__5685[_ptr__5700[(int)0]];
        int _5703 = (int)0;
        int _9565 = (int)1;
        int _9566 = (int)((_5686)->size(0));
        for (int _5704 = _9565; _5704 < _9566; ++_5704)
        {
          {
            if ((_ptr__5686[_ptr__5700[_5704]] > _ptr__5686[_ptr__5700[(_5704 - (int)1)]]))
            {
              {
                ++ _5703;
                ((*inst)(_5703)) = _ptr__5686[_ptr__5700[_5704]];
                ((*cof)(_5703)) = _ptr__5685[_ptr__5700[_5704]];
              }
            }
            else
            {
              {
                ((*cof)(_5703)) = (((*cof)(_5703)) + _ptr__5685[_ptr__5700[_5704]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5705,    std::shared_ptr< monty::ndarray< long long,1 > > _5706,    std::shared_ptr< monty::ndarray< double,1 > > _5707){ return new mosek::fusion::NDSparseArray(_5705,_5706,_5707); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5705,    std::shared_ptr< monty::ndarray< long long,1 > > _5706,    std::shared_ptr< monty::ndarray< double,1 > > _5707) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5705,_5706,_5707); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5705,    std::shared_ptr< monty::ndarray< long long,1 > > _5706,    std::shared_ptr< monty::ndarray< double,1 > > _5707){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5705(_5705 ? _5705->raw() : nullptr, _5705 ? _5705->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5706(_5706 ? _5706->raw() : nullptr, _5706 ? _5706->size(0) : 0);
    _checked_ptr_1<double> _ptr__5707(_5707 ? _5707->raw() : nullptr, _5707 ? _5707->size(0) : 0);
    size = (long long)1;
    int _9567 = (int)0;
    int _9568 = (int)((_5705)->size(0));
    for (int _5708 = _9567; _5708 < _9568; ++_5708)
    {
      {
        size = safe_mul( size,_ptr__5705[_5708] );
      }
    }
    if (((int)((_5706)->size(0)) != (int)((_5707)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    int _9569 = (int)0;
    int _9570 = (int)((_5706)->size(0));
    for (int _5709 = _9569; _5709 < _9570; ++_5709)
    {
      {
        if (((_ptr__5706[_5709] < (int)0) || (_ptr__5706[_5709] >= size)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("An index in inst is out of bounds"));
          }
        }
        {}
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5705);
    bool _5710 = true;
    int _9571 = (int)1;
    int _9572 = (int)((_5706)->size(0));
    for (int _5711 = _9571; _5711 < _9572; ++_5711)
    {
      {
        _5710 = (_5710 && (_ptr__5706[_5711] >= _ptr__5706[(_5711 - (int)1)]));
      }
    }
    if (_5710)
    {
      {
        int _5712 = (int)1;
        int _9573 = (int)1;
        int _9574 = (int)((_5706)->size(0));
        for (int _5713 = _9573; _5713 < _9574; ++_5713)
        {
          {
            if ((_ptr__5706[(_5713 - (int)1)] < _ptr__5706[_5713]))
            {
              {
                ++ _5712;
              }
            }
            {}
          }
        }
        if ((_5712 == (int)((_5706)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5706);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5707);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5712)));
            ((*inst)((int)0)) = _ptr__5706[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5712)));
            ((*cof)((int)0)) = _ptr__5707[(int)0];
            int _5714 = (int)0;
            int _9575 = (int)1;
            int _9576 = (int)((_5706)->size(0));
            for (int _5715 = _9575; _5715 < _9576; ++_5715)
            {
              {
                if ((_ptr__5706[_5715] > _ptr__5706[(_5715 - (int)1)]))
                {
                  {
                    ++ _5714;
                    ((*inst)(_5714)) = _ptr__5706[_5715];
                    ((*cof)(_5714)) = _ptr__5707[_5715];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5714)) = (((*cof)(_5714)) + _ptr__5707[_5715]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5716 = ::mosek::fusion::Utils::Tools::range((long long)((_5706)->size(0)));
        _checked_ptr_1<long long> _ptr__5716(_5716 ? _5716->raw() : nullptr,_5716 ? _5716->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5716,_5706,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5706)->size(0)));
        int _5717 = (int)1;
        int _9577 = (int)1;
        int _9578 = (int)((_5706)->size(0));
        for (int _5718 = _9577; _5718 < _9578; ++_5718)
        {
          {
            if ((_ptr__5706[_ptr__5716[(_5718 - (int)1)]] < _ptr__5706[_ptr__5716[_5718]]))
            {
              {
                ++ _5717;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5717)));
        ((*inst)((int)0)) = _ptr__5706[_ptr__5716[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5717)));
        ((*cof)((int)0)) = _ptr__5707[_ptr__5716[(int)0]];
        int _5719 = (int)0;
        int _9579 = (int)1;
        int _9580 = (int)((_5706)->size(0));
        for (int _5720 = _9579; _5720 < _9580; ++_5720)
        {
          {
            if ((_ptr__5706[_ptr__5716[_5720]] > ((*inst)(_ptr__5716[(_5720 - (int)1)]))))
            {
              {
                ++ _5719;
                ((*inst)(_5719)) = _ptr__5706[_ptr__5716[_5720]];
                ((*cof)(_5719)) = _ptr__5707[_ptr__5716[_5720]];
              }
            }
            else
            {
              {
                ((*cof)(_5719)) = (((*cof)(_5719)) + _ptr__5707[_ptr__5716[_5720]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5721){ return new mosek::fusion::NDSparseArray(_5721); }mosek::fusion::NDSparseArray::NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5721) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5721); }void mosek::fusion::p_NDSparseArray::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5721){monty::rc_reserve __reserve_this(_pubthis);   {
    long long _5722 = _5721->numNonzeros();
    int _5723 = _5721->numColumns();
    int _5724 = _5721->numRows();
    std::shared_ptr< monty::ndarray< double,1 > > _5725 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5722)));
    _checked_ptr_1<double> _ptr__5725(_5725 ? _5725->raw() : nullptr,_5725 ? _5725->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5726 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5722)));
    _checked_ptr_1<int> _ptr__5726(_5726 ? _5726->raw() : nullptr,_5726 ? _5726->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5727 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5722)));
    _checked_ptr_1<int> _ptr__5727(_5727 ? _5727->raw() : nullptr,_5727 ? _5727->size(0) : 0);
    _5721->getDataAsTriplets(_5727,_5726,_5725);
    size = safe_mul( (long long)_5721->numRows(),(long long)_5721->numColumns() );
    dims = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5724),(int)(_5723)});
    std::vector<long long> _9581;
    for (long long _5728 = (long long)0, _9582 = _5722; _5728 < _9582 ; ++_5728)
    {
      _9581.push_back(safe_add( safe_mul( (long long)_ptr__5727[_5728],_5723 ),(long long)_ptr__5726[_5728] ));
    }
    auto _9583 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9581.size()),_9581.begin(),_9581.end()));
    inst = _9583;
    cof = _5725;
  }
}monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5729) { return mosek::fusion::p_NDSparseArray::make(_5729); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(monty::rc_ptr< ::mosek::fusion::Matrix > _5729){
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5729);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5730,    std::shared_ptr< monty::ndarray< long long,1 > > _5731,    std::shared_ptr< monty::ndarray< double,1 > > _5732) { return mosek::fusion::p_NDSparseArray::make(_5730,_5731,_5732); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5730,std::shared_ptr< monty::ndarray< long long,1 > > _5731,std::shared_ptr< monty::ndarray< double,1 > > _5732){
  _checked_ptr_1<int> _ptr__5730(_5730 ? _5730->raw() : nullptr, _5730 ? _5730->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5731(_5731 ? _5731->raw() : nullptr, _5731 ? _5731->size(0) : 0);
  _checked_ptr_1<double> _ptr__5732(_5732 ? _5732->raw() : nullptr, _5732 ? _5732->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5730,_5731,_5732);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5733,    std::shared_ptr< monty::ndarray< int,2 > > _5734,    std::shared_ptr< monty::ndarray< double,1 > > _5735) { return mosek::fusion::p_NDSparseArray::make(_5733,_5734,_5735); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5733,std::shared_ptr< monty::ndarray< int,2 > > _5734,std::shared_ptr< monty::ndarray< double,1 > > _5735){
  _checked_ptr_1<int> _ptr__5733(_5733 ? _5733->raw() : nullptr, _5733 ? _5733->size(0) : 0);
  _checked_ptr_1<double> _ptr__5735(_5735 ? _5735->raw() : nullptr, _5735 ? _5735->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5733,_5734,_5735);
}
void mosek::fusion::p_NDSparseArray::destroy(){cof.reset();inst.reset();dims.reset();}void mosek::fusion::NDSparseArray::destroy() { mosek::fusion::p_NDSparseArray::_get_impl(this)->destroy(); }mosek::fusion::DenseMatrix::DenseMatrix(mosek::fusion::p_DenseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "DenseMatrix()" << this << std::endl; */ }mosek::fusion::DenseMatrix::~DenseMatrix() {  /* std::cout << "~DenseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_DenseMatrix::p_DenseMatrix  (::mosek::fusion::DenseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5736,    int _5737,    std::shared_ptr< monty::ndarray< double,1 > > _5738){ return new mosek::fusion::DenseMatrix(_5736,_5737,_5738); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5736,    int _5737,    std::shared_ptr< monty::ndarray< double,1 > > _5738) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5736,_5737,_5738); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5736,    int _5737,    std::shared_ptr< monty::ndarray< double,1 > > _5738){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5738(_5738 ? _5738->raw() : nullptr, _5738 ? _5738->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5736,_5737);
    nnz = (long long)safe_mul( _5736,_5737 );
    data = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( _5736,_5737 ))));
    ::mosek::fusion::Utils::Tools::arraycopy(_5738,(int)0,data,(int)0,safe_mul( _5736,_5737 ));
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5739){ return new mosek::fusion::DenseMatrix(_5739); }mosek::fusion::DenseMatrix::DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5739) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5739); }void mosek::fusion::p_DenseMatrix::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5739){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(mosek::fusion::p_Matrix::_get_impl(_5739)->dimi,mosek::fusion::p_Matrix::_get_impl(_5739)->dimj);
    monty::rc_ptr< ::mosek::fusion::Matrix > _9584 = _5739;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9584.get()))
    {
      ::mosek::fusion::DenseMatrix::t _5740 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9584.get()));
      {
        data = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_DenseMatrix::_get_impl(_5740)->data);
      }
    }
    else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9584.get()))
    {
      ::mosek::fusion::SparseMatrix::t _5741 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9584.get()));
      {
        data = ::mosek::fusion::Utils::Tools::zeros(safe_mul( mosek::fusion::p_Matrix::_get_impl(_5741)->dimi,mosek::fusion::p_Matrix::_get_impl(_5741)->dimj ));
        long long _9585 = (long long)0;
        long long _9586 = mosek::fusion::p_SparseMatrix::_get_impl(_5741)->nnz;
        for (long long _5743 = _9585; _5743 < _9586; ++_5743)
        {
          {
            ((*data)(safe_add( safe_mul( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5741)->subi)(_5743)),dimj ),((*mosek::fusion::p_SparseMatrix::_get_impl(_5741)->subj)(_5743)) ))) = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5741)->val)(_5743));
          }
        }
      }
    }
    else
    {
      mosek::fusion::Matrix::t _5742 = _9584;
      {
        throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
      }
    }
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5744){ return new mosek::fusion::DenseMatrix(_5744); }mosek::fusion::DenseMatrix::DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5744) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5744); }void mosek::fusion::p_DenseMatrix::_initialize  (std::shared_ptr< monty::ndarray< double,2 > > _5744){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize((int)((_5744)->size(0)),(int)((_5744)->size(1)));
    std::vector<double> _9587;
    for (int _5745 = (int)0, _9588 = dimi; _5745 < _9588 ; ++_5745)
    {
      for (int _5746 = (int)0, _9589 = dimj; _5746 < _9589 ; ++_5746)
      {
        _9587.push_back(((*_5744)(_5745,_5746)));
      }
    }
    auto _9590 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9587.size()),_9587.begin(),_9587.end()));
    data = _9590;
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5747,    int _5748,    double _5749){ return new mosek::fusion::DenseMatrix(_5747,_5748,_5749); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5747,    int _5748,    double _5749) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5747,_5748,_5749); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5747,    int _5748,    double _5749){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(_5747,_5748);
    std::vector<double> _9591;
    for (int _5750 = (int)0, _9592 = _5747; _5750 < _9592 ; ++_5750)
    {
      for (int _5751 = (int)0, _9593 = _5748; _5751 < _9593 ; ++_5751)
      {
        _9591.push_back(_5749);
      }
    }
    auto _9594 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9591.size()),_9591.begin(),_9591.end()));
    data = _9594;
    nnz = (long long)safe_mul( _5747,_5748 );
  }
}std::string mosek::fusion::DenseMatrix :: toString() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_DenseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5752 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DenseMatrix("));
  _5752->__mosek_2fusion_2Utils_2StringBuffer__a(dimi);
  _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
  _5752->__mosek_2fusion_2Utils_2StringBuffer__a(dimj);
  _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (": "));
  int _5753 = (int)0;
  {
    int _5754 = (int)0;
    for(;(_5754 < dimi);++ _5754)
    {
      {
        if ((_5754 > (int)0))
        {
          {
            _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
          }
        }
        {}
        _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("[ "));
        _5752->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5753)));
        ++ _5753;
        {
          int _5755 = (int)1;
          for(;(_5755 < dimj);++ _5755)
          {
            {
              _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
              _5752->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5753)));
              ++ _5753;
            }
          }
        }
        _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ]"));
      }
    }
  }
  _5752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _5752->toString();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix :: __mosek_2fusion_2DenseMatrix__transpose() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->__mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_DenseMatrix::__mosek_2fusion_2DenseMatrix__transpose(){
  std::shared_ptr< monty::ndarray< double,1 > > _5756 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5756(_5756 ? _5756->raw() : nullptr,_5756 ? _5756->size(0) : 0);
  int _5757 = (int)0;
  int _5758 = dimi;
  int _9595 = (int)0;
  int _9596 = dimi;
  for (int _5759 = _9595; _5759 < _9596; ++_5759)
  {
    {
      int _5760 = _5759;
      int _9597 = (int)0;
      int _9598 = dimj;
      for (int _5761 = _9597; _5761 < _9598; ++_5761)
      {
        {
          _ptr__5756[_5760] = ((*data)(_5757));
          _5760 = safe_add( _5760,_5758 );
          ++ _5757;
        }
      }
    }
  }
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(dimj,dimi,_5756)).as<::mosek::fusion::Matrix>();
}
bool mosek::fusion::DenseMatrix :: isSparse() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_DenseMatrix::isSparse(){
  return false;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::DenseMatrix :: getDataAsArray() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_DenseMatrix::getDataAsArray(){
  return ::mosek::fusion::Utils::Tools::arraycopy(data);
}
void mosek::fusion::DenseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5762,std::shared_ptr< monty::ndarray< int,1 > > _5763,std::shared_ptr< monty::ndarray< double,1 > > _5764) { mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsTriplets(_5762,_5763,_5764); }void mosek::fusion::p_DenseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5762,std::shared_ptr< monty::ndarray< int,1 > > _5763,std::shared_ptr< monty::ndarray< double,1 > > _5764){
  _checked_ptr_1<int> _ptr__5762(_5762 ? _5762->raw() : nullptr, _5762 ? _5762->size(0) : 0);
  _checked_ptr_1<int> _ptr__5763(_5763 ? _5763->raw() : nullptr, _5763 ? _5763->size(0) : 0);
  _checked_ptr_1<double> _ptr__5764(_5764 ? _5764->raw() : nullptr, _5764 ? _5764->size(0) : 0);
  if ((((int)((_5762)->size(0)) < nnz) || (((int)((_5763)->size(0)) < nnz) || ((int)((_5764)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(data,(int)0,_5764,(int)0,(int)((data)->size(0)));
  int _5765 = (int)0;
  int _9599 = (int)0;
  int _9600 = dimi;
  for (int _5766 = _9599; _5766 < _9600; ++_5766)
  {
    {
      int _9601 = (int)0;
      int _9602 = dimj;
      for (int _5767 = _9601; _5767 < _9602; ++_5767)
      {
        {
          _ptr__5762[_5765] = _5766;
          _ptr__5763[_5765] = _5767;
          ++ _5765;
        }
      }
    }
  }
}
double mosek::fusion::DenseMatrix :: get(int _5768,int _5769) { return mosek::fusion::p_DenseMatrix::_get_impl(this)->get(_5768,_5769); }double mosek::fusion::p_DenseMatrix::get(int _5768,int _5769){
  return ((*data)(safe_add( safe_mul( _5768,dimj ),_5769 )));
}
long long mosek::fusion::DenseMatrix :: numNonzeros() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_DenseMatrix::numNonzeros(){
  return (long long)safe_mul( dimi,dimj );
}
void mosek::fusion::p_DenseMatrix::destroy(){data.reset();}void mosek::fusion::DenseMatrix::destroy() { mosek::fusion::p_DenseMatrix::_get_impl(this)->destroy(); }mosek::fusion::SparseMatrix::SparseMatrix(mosek::fusion::p_SparseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "SparseMatrix()" << this << std::endl; */ }mosek::fusion::SparseMatrix::~SparseMatrix() {  /* std::cout << "~SparseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_SparseMatrix::p_SparseMatrix  (::mosek::fusion::SparseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5770,    int _5771,    std::shared_ptr< monty::ndarray< int,1 > > _5772,    std::shared_ptr< monty::ndarray< int,1 > > _5773,    std::shared_ptr< monty::ndarray< double,1 > > _5774,    long long _5775){ return new mosek::fusion::SparseMatrix(_5770,_5771,_5772,_5773,_5774,_5775); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5770,    int _5771,    std::shared_ptr< monty::ndarray< int,1 > > _5772,    std::shared_ptr< monty::ndarray< int,1 > > _5773,    std::shared_ptr< monty::ndarray< double,1 > > _5774,    long long _5775) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5770,_5771,_5772,_5773,_5774,_5775); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5770,    int _5771,    std::shared_ptr< monty::ndarray< int,1 > > _5772,    std::shared_ptr< monty::ndarray< int,1 > > _5773,    std::shared_ptr< monty::ndarray< double,1 > > _5774,    long long _5775){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5772(_5772 ? _5772->raw() : nullptr, _5772 ? _5772->size(0) : 0);
    _checked_ptr_1<int> _ptr__5773(_5773 ? _5773->raw() : nullptr, _5773 ? _5773->size(0) : 0);
    _checked_ptr_1<double> _ptr__5774(_5774 ? _5774->raw() : nullptr, _5774 ? _5774->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5770,_5771);
    if ((_5775 > (int)0))
    {
      {
        if ((((int)((_5772)->size(0)) < _5775) || (((int)((_5773)->size(0)) < _5775) || ((int)((_5774)->size(0)) < _5775))))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching arrays in sparse data."));
          }
        }
        {}
        long long _9603 = (long long)0;
        long long _9604 = _5775;
        for (long long _5776 = _9603; _5776 < _9604; ++_5776)
        {
          {
            if (((_ptr__5772[_5776] < (int)0) || ((_ptr__5772[_5776] >= dimi) || ((_ptr__5773[_5776] < (int)0) || (_ptr__5773[_5776] >= dimj)))))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Subscript out of bounds."));
              }
            }
            {}
          }
        }
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5777 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5778 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _5779 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 >(monty::shape((int)1)));
        ::mosek::fusion::p_CommonTools::tripletSort(_5772,_5773,_5774,_5777,_5778,_5779,_5775,dimi,dimj);
        subi = ((*_5777)((int)0));
        subj = ((*_5778)((int)0));
        val = ((*_5779)((int)0));
        nnz = (long long)((val)->size(0));
      }
    }
    else
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
        nnz = (long long)0;
      }
    }
  }
}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5780,    int _5781,    std::shared_ptr< monty::ndarray< int,1 > > _5782,    std::shared_ptr< monty::ndarray< int,1 > > _5783,    std::shared_ptr< monty::ndarray< double,1 > > _5784){ return new mosek::fusion::SparseMatrix(_5780,_5781,_5782,_5783,_5784); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5780,    int _5781,    std::shared_ptr< monty::ndarray< int,1 > > _5782,    std::shared_ptr< monty::ndarray< int,1 > > _5783,    std::shared_ptr< monty::ndarray< double,1 > > _5784) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5780,_5781,_5782,_5783,_5784); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5780,    int _5781,    std::shared_ptr< monty::ndarray< int,1 > > _5782,    std::shared_ptr< monty::ndarray< int,1 > > _5783,    std::shared_ptr< monty::ndarray< double,1 > > _5784){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5782(_5782 ? _5782->raw() : nullptr, _5782 ? _5782->size(0) : 0);
    _checked_ptr_1<int> _ptr__5783(_5783 ? _5783->raw() : nullptr, _5783 ? _5783->size(0) : 0);
    _checked_ptr_1<double> _ptr__5784(_5784 ? _5784->raw() : nullptr, _5784 ? _5784->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5780,_5781);
    int _5785 = (int)0;
    int _9605 = (int)0;
    int _9606 = (int)((_5784)->size(0));
    for (int _5786 = _9605; _5786 < _9606; ++_5786)
    {
      {
        if (((_ptr__5784[_5786] > (int)0) || (_ptr__5784[_5786] < (int)0)))
        {
          {
            ++ _5785;
          }
        }
        {}
      }
    }
    if (((_5785 > (int)0) && (_5785 < (int)((_5782)->size(0)))))
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5785)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5785)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5785)));
        nnz = _5785;
        int _5787 = (int)0;
        int _9607 = (int)0;
        int _9608 = (int)((_5784)->size(0));
        for (int _5788 = _9607; _5788 < _9608; ++_5788)
        {
          {
            if (((_ptr__5784[_5788] < (int)0) || (_ptr__5784[_5788] > (int)0)))
            {
              {
                ((*val)(_5787)) = _ptr__5784[_5788];
                ((*subj)(_5787)) = _ptr__5783[_5788];
                ((*subi)(_5787)) = _ptr__5782[_5788];
                ++ _5787;
              }
            }
            {}
          }
        }
      }
    }
    else
    {
      {
        subi = _5782;
        subj = _5783;
        val = _5784;
        if ((NULL == _5782.get()))
        {
          {
            nnz = (long long)0;
          }
        }
        else
        {
          {
            nnz = (long long)((subi)->size(0));
          }
        }
      }
    }
  }
}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SparseMatrix::formPtrb(){
  std::shared_ptr< monty::ndarray< long long,1 > > _5789 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( dimi,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5789(_5789 ? _5789->raw() : nullptr,_5789 ? _5789->size(0) : 0);
  long long _5790 = (long long)0;
  int _9609 = (int)0;
  int _9610 = dimi;
  for (int _5791 = _9609; _5791 < _9610; ++_5791)
  {
    {
      _ptr__5789[_5791] = _5790;
      {
        for(;((_5790 < nnz) && (((*subi)(_5790)) == _5791));++ _5790)
        {
          {
          }
        }
      }
    }
  }
  _ptr__5789[dimi] = _5790;
  return _5789;
}
std::string mosek::fusion::SparseMatrix :: toString() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_SparseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5792 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5792->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SparseMatrix("))->__mosek_2fusion_2Utils_2StringBuffer__a(dimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (", ["));
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      _5792->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
      int _9611 = (int)1;
      int _9612 = (int)((subi)->size(0));
      for (int _5793 = _9611; _5793 < _9612; ++_5793)
      {
        {
          _5792->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)(_5793)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)(_5793)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)(_5793)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
        }
      }
    }
  }
  {}
  _5792->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ])"));
  return _5792->toString();
}
long long mosek::fusion::SparseMatrix :: numNonzeros() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_SparseMatrix::numNonzeros(){
  return nnz;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix :: __mosek_2fusion_2SparseMatrix__transpose() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->__mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_SparseMatrix::__mosek_2fusion_2SparseMatrix__transpose(){
  return ::mosek::fusion::p_Matrix::sparse(dimj,dimi,subj,subi,val);
}
bool mosek::fusion::SparseMatrix :: isSparse() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_SparseMatrix::isSparse(){
  return true;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SparseMatrix :: getDataAsArray() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_SparseMatrix::getDataAsArray(){
  std::shared_ptr< monty::ndarray< double,1 > > _5794 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5794(_5794 ? _5794->raw() : nullptr,_5794 ? _5794->size(0) : 0);
  int _9613 = (int)0;
  int _9614 = (int)((subi)->size(0));
  for (int _5795 = _9613; _5795 < _9614; ++_5795)
  {
    {
      _ptr__5794[safe_add( safe_mul( ((*subi)(_5795)),dimj ),((*subj)(_5795)) )] = ((*val)(_5795));
    }
  }
  return _5794;
}
void mosek::fusion::SparseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5796,std::shared_ptr< monty::ndarray< int,1 > > _5797,std::shared_ptr< monty::ndarray< double,1 > > _5798) { mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsTriplets(_5796,_5797,_5798); }void mosek::fusion::p_SparseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5796,std::shared_ptr< monty::ndarray< int,1 > > _5797,std::shared_ptr< monty::ndarray< double,1 > > _5798){
  _checked_ptr_1<int> _ptr__5796(_5796 ? _5796->raw() : nullptr, _5796 ? _5796->size(0) : 0);
  _checked_ptr_1<int> _ptr__5797(_5797 ? _5797->raw() : nullptr, _5797 ? _5797->size(0) : 0);
  _checked_ptr_1<double> _ptr__5798(_5798 ? _5798->raw() : nullptr, _5798 ? _5798->size(0) : 0);
  if ((((long long)((_5796)->size(0)) < nnz) || (((long long)((_5797)->size(0)) < nnz) || ((long long)((_5798)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(subi,(long long)0,_5796,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(subj,(long long)0,_5797,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(val,(long long)0,_5798,(long long)0,nnz);
    }
  }
  {}
}
double mosek::fusion::SparseMatrix :: get(int _5799,int _5800) { return mosek::fusion::p_SparseMatrix::_get_impl(this)->get(_5799,_5800); }double mosek::fusion::p_SparseMatrix::get(int _5799,int _5800){
  if (((_5799 < (int)0) || ((_5799 >= dimi) || ((_5800 < (int)0) || (_5800 >= dimj)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out if bounds"));
    }
  }
  {}
  int _5801 = (int)((subi)->size(0));
  int _5802 = (int)0;
  while ( ((_5801 - _5802) > (int)1) )
  {
    {
      int _5803 = (safe_add( _5802,_5801 ) / (int)2);
      if (((((*subi)(_5803)) < _5799) || ((((*subi)(_5803)) == _5799) && (((*subj)(_5803)) < _5800))))
      {
        {
          _5802 = _5803;
        }
      }
      else if(((((*subi)(_5803)) > _5799) || ((((*subi)(_5803)) == _5799) && (((*subj)(_5803)) > _5800))))
      {
        {
          _5801 = _5803;
        }
      }
      else
      {
        {
          return ((*val)(_5803));
        }
      }
    }
  }
  if (((((*subi)(_5802)) == _5799) && (((*subj)(_5802)) == _5800)))
  {
    {
      return ((*val)(_5802));
    }
  }
  else
  {
    {
      return 0.0;
    }
  }
}
void mosek::fusion::p_SparseMatrix::destroy(){val.reset();subj.reset();subi.reset();}void mosek::fusion::SparseMatrix::destroy() { mosek::fusion::p_SparseMatrix::_get_impl(this)->destroy(); }mosek::fusion::Matrix::Matrix(mosek::fusion::p_Matrix *_impl) : _impl(_impl) { /*std::cout << "Matrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Matrix::~Matrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_Matrix::p_Matrix  (::mosek::fusion::Matrix * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Matrix::_initialize  (int _5804,    int _5805){monty::rc_reserve __reserve_this(_pubthis);   {
    if (((_5804 < (int)0) || (_5805 < (int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimensions"));
      }
    }
    {}
    dimi = _5804;
    dimj = _5805;
  }
}std::string mosek::fusion::Matrix :: toString() { return mosek::fusion::p_Matrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_Matrix::toString(){
  return std::string ("");
}
void mosek::fusion::p_Matrix::switchDims(){
  int _5806 = dimi;
  dimi = dimj;
  dimj = _5806;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5807,    monty::rc_ptr< ::mosek::fusion::Matrix > _5808) { return mosek::fusion::p_Matrix::diag(_5807,_5808); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5807,monty::rc_ptr< ::mosek::fusion::Matrix > _5808){
  std::vector<monty::rc_ptr< ::mosek::fusion::Matrix >> _9615;
  for (int _5809 = (int)0, _9616 = _5807; _5809 < _9616 ; ++_5809)
  {
    _9615.push_back(_5808);
  }
  auto _9617 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 >(monty::shape(_9615.size()),_9615.begin(),_9615.end()));
  return ::mosek::fusion::p_Matrix::diag(_9617);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5810) { return mosek::fusion::p_Matrix::diag(_5810); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5810){
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5811 = _5810;
  long long _5812 = (long long)0;
  int _5813 = (int)0;
  int _5814 = (int)0;
  int _9618 = (int)0;
  int _9619 = (int)((_5810)->size(0));
  for (int _5815 = _9618; _5815 < _9619; ++_5815)
  {
    {
      _5814 = safe_add( _5814,mosek::fusion::p_Matrix::_get_impl(((*_5810)(_5815)))->dimi );
      _5813 = safe_add( _5813,mosek::fusion::p_Matrix::_get_impl(((*_5810)(_5815)))->dimj );
      _5812 = safe_add( _5812,((*_5810)(_5815))->numNonzeros() );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5816 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5812)));
  _checked_ptr_1<int> _ptr__5816(_5816 ? _5816->raw() : nullptr,_5816 ? _5816->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5817 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5812)));
  _checked_ptr_1<int> _ptr__5817(_5817 ? _5817->raw() : nullptr,_5817 ? _5817->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5818 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5812)));
  _checked_ptr_1<double> _ptr__5818(_5818 ? _5818->raw() : nullptr,_5818 ? _5818->size(0) : 0);
  {
    int _5819 = (int)0;
    int _5820 = (int)0;
    long long _5821 = (long long)0;
    int _9620 = (int)0;
    int _9621 = (int)((_5810)->size(0));
    for (int _5822 = _9620; _5822 < _9621; ++_5822)
    {
      {
        long long _5823 = ((*_5810)(_5822))->numNonzeros();
        std::shared_ptr< monty::ndarray< double,1 > > _5824 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5823)));
        _checked_ptr_1<double> _ptr__5824(_5824 ? _5824->raw() : nullptr,_5824 ? _5824->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5825 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5823)));
        _checked_ptr_1<int> _ptr__5825(_5825 ? _5825->raw() : nullptr,_5825 ? _5825->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5826 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5823)));
        _checked_ptr_1<int> _ptr__5826(_5826 ? _5826->raw() : nullptr,_5826 ? _5826->size(0) : 0);
        ((*_5810)(_5822))->getDataAsTriplets(_5826,_5825,_5824);
        ::mosek::fusion::Utils::Tools::arraycopy(_5824,(long long)0,_5818,_5821,_5823);
        long long _9622 = (long long)0;
        long long _9623 = _5823;
        for (long long _5827 = _9622; _5827 < _9623; ++_5827)
        {
          {
            _ptr__5816[safe_add( _5821,_5827 )] = safe_add( _ptr__5826[_5827],_5820 );
            _ptr__5817[safe_add( _5821,_5827 )] = safe_add( _ptr__5826[_5827],_5819 );
          }
        }
        _5821 = safe_add( _5821,_5823 );
        _5820 = safe_add( _5820,mosek::fusion::p_Matrix::_get_impl(((*_5810)(_5822)))->dimi );
        _5819 = safe_add( _5819,mosek::fusion::p_Matrix::_get_impl(((*_5810)(_5822)))->dimj );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5814,_5813,_5816,_5817,_5818)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5828,    double _5829,    int _5830) { return mosek::fusion::p_Matrix::antidiag(_5828,_5829,_5830); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5828,double _5829,int _5830){
  if (((_5830 < _5828) && (_5830 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5829,(_5828 - _5830)),_5830);
    }
  }
  else if(((_5830 > (-_5828)) && (_5830 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5829,safe_add( _5828,_5830 )),_5830);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5831,    double _5832) { return mosek::fusion::p_Matrix::antidiag(_5831,_5832); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5831,double _5832){
  return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5832,_5831),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5833,    double _5834,    int _5835) { return mosek::fusion::p_Matrix::diag(_5833,_5834,_5835); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5833,double _5834,int _5835){
  if (((_5835 < _5833) && (_5835 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5834,(_5833 - _5835)),_5835);
    }
  }
  else if(((_5835 > (-_5833)) && (_5835 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5834,safe_add( _5833,_5835 )),_5835);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5836,    double _5837) { return mosek::fusion::p_Matrix::diag(_5836,_5837); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5836,double _5837){
  return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5837,_5836),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5838,    int _5839) { return mosek::fusion::p_Matrix::antidiag(_5838,_5839); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5838,int _5839){
  _checked_ptr_1<double> _ptr__5838(_5838 ? _5838->raw() : nullptr, _5838 ? _5838->size(0) : 0);
  int _9624;
  bool _9625 = (_5839 > (int)0);
  if (_9625)
  {
    _9624 = _5839;
  }
  else
  {
    _9624 = (-_5839);
  }
  int _5840 = _9624;
  int _5841 = safe_add( (int)((_5838)->size(0)),_5840 );
  int _5842 = (int)((_5838)->size(0));
  if ((_5839 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5843 = ::mosek::fusion::Utils::Tools::range(_5839,safe_add( _5842,_5839 ));
      _checked_ptr_1<int> _ptr__5843(_5843 ? _5843->raw() : nullptr,_5843 ? _5843->size(0) : 0);
      std::vector<int> _9626;
      for (int _5845 = (int)1, _9627 = safe_add( _5842,(int)1 ); _5845 < _9627 ; ++_5845)
      {
        _9626.push_back((safe_add( _5842,_5839 ) - _5845));
      }
      auto _9628 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9626.size()),_9626.begin(),_9626.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5844 = _9628;
      _checked_ptr_1<int> _ptr__5844(_5844 ? _5844->raw() : nullptr,_5844 ? _5844->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5841,_5841,_5843,_5844,_5838)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5846 = ::mosek::fusion::Utils::Tools::range((int)0,_5842);
      _checked_ptr_1<int> _ptr__5846(_5846 ? _5846->raw() : nullptr,_5846 ? _5846->size(0) : 0);
      std::vector<int> _9629;
      for (int _5848 = (int)1, _9630 = safe_add( _5842,(int)1 ); _5848 < _9630 ; ++_5848)
      {
        _9629.push_back((_5842 - _5848));
      }
      auto _9631 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9629.size()),_9629.begin(),_9629.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5847 = _9631;
      _checked_ptr_1<int> _ptr__5847(_5847 ? _5847->raw() : nullptr,_5847 ? _5847->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5841,_5841,_5846,_5847,_5838)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5849) { return mosek::fusion::p_Matrix::antidiag(_5849); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5849){
  _checked_ptr_1<double> _ptr__5849(_5849 ? _5849->raw() : nullptr, _5849 ? _5849->size(0) : 0);
  return ::mosek::fusion::p_Matrix::antidiag(_5849,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5850,    int _5851) { return mosek::fusion::p_Matrix::diag(_5850,_5851); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5850,int _5851){
  _checked_ptr_1<double> _ptr__5850(_5850 ? _5850->raw() : nullptr, _5850 ? _5850->size(0) : 0);
  int _9632;
  bool _9633 = (_5851 > (int)0);
  if (_9633)
  {
    _9632 = _5851;
  }
  else
  {
    _9632 = (-_5851);
  }
  int _5852 = _9632;
  int _5853 = safe_add( (int)((_5850)->size(0)),_5852 );
  int _5854 = (int)((_5850)->size(0));
  if ((_5851 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5855 = ::mosek::fusion::Utils::Tools::range((int)0,_5854);
      _checked_ptr_1<int> _ptr__5855(_5855 ? _5855->raw() : nullptr,_5855 ? _5855->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5856 = ::mosek::fusion::Utils::Tools::range(_5852,safe_add( _5854,_5852 ));
      _checked_ptr_1<int> _ptr__5856(_5856 ? _5856->raw() : nullptr,_5856 ? _5856->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5853,_5853,_5855,_5856,_5850)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5857 = ::mosek::fusion::Utils::Tools::range(_5852,safe_add( _5854,_5852 ));
      _checked_ptr_1<int> _ptr__5857(_5857 ? _5857->raw() : nullptr,_5857 ? _5857->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5858 = ::mosek::fusion::Utils::Tools::range((int)0,_5854);
      _checked_ptr_1<int> _ptr__5858(_5858 ? _5858->raw() : nullptr,_5858 ? _5858->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5853,_5853,_5857,_5858,_5850)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5859) { return mosek::fusion::p_Matrix::diag(_5859); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5859){
  _checked_ptr_1<double> _ptr__5859(_5859 ? _5859->raw() : nullptr, _5859 ? _5859->size(0) : 0);
  return ::mosek::fusion::p_Matrix::diag(_5859,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::ones  ( int _5860,    int _5861) { return mosek::fusion::p_Matrix::ones(_5860,_5861); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::ones(int _5860,int _5861){
  return ::mosek::fusion::p_Matrix::dense(_5860,_5861,1.0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::eye  ( int _5862) { return mosek::fusion::p_Matrix::eye(_5862); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::eye(int _5862){
  std::vector<double> _9634;
  for (int _5863 = (int)0, _9635 = _5862; _5863 < _9635 ; ++_5863)
  {
    _9634.push_back(1.0);
  }
  auto _9636 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9634.size()),_9634.begin(),_9634.end()));
  return ::mosek::fusion::p_Matrix::diag(_9636);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5864) { return mosek::fusion::p_Matrix::dense(_5864); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5864){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5864)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5865,    int _5866,    double _5867) { return mosek::fusion::p_Matrix::dense(_5865,_5866,_5867); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5865,int _5866,double _5867){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5865,_5866,_5867)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5868,    int _5869,    std::shared_ptr< monty::ndarray< double,1 > > _5870) { return mosek::fusion::p_Matrix::dense(_5868,_5869,_5870); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5868,int _5869,std::shared_ptr< monty::ndarray< double,1 > > _5870){
  _checked_ptr_1<double> _ptr__5870(_5870 ? _5870->raw() : nullptr, _5870 ? _5870->size(0) : 0);
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5868,_5869,_5870)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( std::shared_ptr< monty::ndarray< double,2 > > _5871) { return mosek::fusion::p_Matrix::dense(_5871); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(std::shared_ptr< monty::ndarray< double,2 > > _5871){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5871)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5872) { return mosek::fusion::p_Matrix::sparse(_5872); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5872){
  std::shared_ptr< monty::ndarray< int,1 > > _5873 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5872->numNonzeros())));
  _checked_ptr_1<int> _ptr__5873(_5873 ? _5873->raw() : nullptr,_5873 ? _5873->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5874 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5872->numNonzeros())));
  _checked_ptr_1<int> _ptr__5874(_5874 ? _5874->raw() : nullptr,_5874 ? _5874->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5875 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5872->numNonzeros())));
  _checked_ptr_1<double> _ptr__5875(_5875 ? _5875->raw() : nullptr,_5875 ? _5875->size(0) : 0);
  _5872->getDataAsTriplets(_5873,_5874,_5875);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5872->numRows(),_5872->numColumns(),_5873,_5874,_5875)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5876) { return mosek::fusion::p_Matrix::sparse(_5876); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5876){
  int _5877 = (int)((_5876)->size(0));
  int _5878 = (int)((((*_5876)((int)0)))->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _5879 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5877)));
  _checked_ptr_1<int> _ptr__5879(_5879 ? _5879->raw() : nullptr,_5879 ? _5879->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5880 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5878)));
  _checked_ptr_1<int> _ptr__5880(_5880 ? _5880->raw() : nullptr,_5880 ? _5880->size(0) : 0);
  long long _5881 = (long long)0;
  int _5882 = (int)0;
  {
    int _5883 = (int)0;
    for(;(_5883 < _5877);++ _5883)
    {
      {
        {
          int _5884 = (int)0;
          for(;(_5884 < _5878);++ _5884)
          {
            {
              monty::rc_ptr< ::mosek::fusion::Matrix > _5885 = ((*((*_5876)(_5883)))(_5884));
              if ((NULL != _5885.get()))
              {
                {
                  if ((_ptr__5880[_5884] == (int)0))
                  {
                    {
                      _ptr__5880[_5884] = mosek::fusion::p_Matrix::_get_impl(_5885)->dimj;
                    }
                  }
                  else if((_ptr__5880[_5884] != mosek::fusion::p_Matrix::_get_impl(_5885)->dimj))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  if ((_ptr__5879[_5883] == (int)0))
                  {
                    {
                      _ptr__5879[_5883] = mosek::fusion::p_Matrix::_get_impl(_5885)->dimi;
                    }
                  }
                  else if((_ptr__5879[_5883] != mosek::fusion::p_Matrix::_get_impl(_5885)->dimi))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  _5881 = safe_add( _5881,_5885->numNonzeros() );
                }
              }
              {}
              ++ _5882;
            }
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5886 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5881)));
  _checked_ptr_1<double> _ptr__5886(_5886 ? _5886->raw() : nullptr,_5886 ? _5886->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5887 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5881)));
  _checked_ptr_1<int> _ptr__5887(_5887 ? _5887->raw() : nullptr,_5887 ? _5887->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5888 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5881)));
  _checked_ptr_1<int> _ptr__5888(_5888 ? _5888->raw() : nullptr,_5888 ? _5888->size(0) : 0);
  int _5889 = (int)0;
  int _5890 = (int)0;
  {
    int _5891 = (int)0;
    for(;(_5891 < _5877);++ _5891)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _5892 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5878)));
        _checked_ptr_1<int> _ptr__5892(_5892 ? _5892->raw() : nullptr,_5892 ? _5892->size(0) : 0);
        {
          int _5893 = (int)0;
          for(;(_5893 < _ptr__5879[_5891]);++ _5893)
          {
            {
              int _5894 = (int)0;
              {
                int _5895 = (int)0;
                for(;(_5895 < _5878);++ _5895)
                {
                  {
                    monty::rc_ptr< ::mosek::fusion::Matrix > _5896 = ((*((*_5876)(_5891)))(_5895));
                    if ((NULL != _5896.get()))
                    {
                      {
                        monty::rc_ptr< ::mosek::fusion::Matrix > _9637 = _5896;
                        if (false) {}
                        else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9637.get()))
                        {
                          ::mosek::fusion::DenseMatrix::t _5897 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9637.get()));
                          {
                            int _5900 = _ptr__5892[_5895];
                            {
                              int _5901 = (int)0;
                              for(;(_5901 < mosek::fusion::p_Matrix::_get_impl(_5897)->dimj);++ _5901)
                              {
                                {
                                  _ptr__5886[_5889] = ((*mosek::fusion::p_DenseMatrix::_get_impl(_5897)->data)(_5900));
                                  _ptr__5887[_5889] = safe_add( _5890,_5893 );
                                  _ptr__5888[_5889] = safe_add( _5894,_5901 );
                                  ++ _5900;
                                  ++ _5889;
                                }
                              }
                            }
                            _ptr__5892[_5895] = _5900;
                          }
                        }
                        else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9637.get()))
                        {
                          ::mosek::fusion::SparseMatrix::t _5898 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9637.get()));
                          {
                            int _5902;
                            {
                              _5902 = _ptr__5892[_5895];
                              for(;((_5902 < mosek::fusion::p_SparseMatrix::_get_impl(_5898)->nnz) && (((*mosek::fusion::p_SparseMatrix::_get_impl(_5898)->subi)(_5902)) == _5893));++ _5902)
                              {
                                {
                                  _ptr__5886[_5889] = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5898)->val)(_5902));
                                  _ptr__5888[_5889] = safe_add( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5898)->subj)(_5902)),_5894 );
                                  _ptr__5887[_5889] = safe_add( _5890,_5893 );
                                  ++ _5889;
                                }
                              }
                            }
                            _ptr__5892[_5895] = _5902;
                          }
                        }
                        else
                        {
                          mosek::fusion::Matrix::t _5899 = _9637;
                          {
                            throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
                          }
                        }
                      }
                    }
                    {}
                    _5894 = safe_add( _5894,_ptr__5880[_5895] );
                  }
                }
              }
            }
          }
        }
        _5890 = safe_add( _5890,_ptr__5879[_5891] );
      }
    }
  }
  int _5903 = (int)0;
  int _5904 = (int)0;
  {
    int _5905 = (int)0;
    for(;(_5905 < _5877);++ _5905)
    {
      {
        _5903 = safe_add( _5903,_ptr__5879[_5905] );
      }
    }
  }
  {
    int _5906 = (int)0;
    for(;(_5906 < _5878);++ _5906)
    {
      {
        _5904 = safe_add( _5904,_ptr__5880[_5906] );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5903,_5904,_5887,_5888,_5886)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< double,2 > > _5907) { return mosek::fusion::p_Matrix::sparse(_5907); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< double,2 > > _5907){
  int _5908 = (int)((_5907)->size(0));
  int _5909 = (int)((_5907)->size(1));
  long long _5910 = (long long)safe_mul( _5908,_5909 );
  std::vector<int> _9638;
  for (int _5912 = (int)0, _9639 = _5908; _5912 < _9639 ; ++_5912)
  {
    for (int _5913 = (int)0, _9640 = _5909; _5913 < _9640 ; ++_5913)
    {
      _9638.push_back(_5912);
    }
  }
  auto _9641 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9638.size()),_9638.begin(),_9638.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5911 = _9641;
  _checked_ptr_1<int> _ptr__5911(_5911 ? _5911->raw() : nullptr,_5911 ? _5911->size(0) : 0);
  std::vector<int> _9642;
  for (int _5915 = (int)0, _9643 = _5908; _5915 < _9643 ; ++_5915)
  {
    for (int _5916 = (int)0, _9644 = _5909; _5916 < _9644 ; ++_5916)
    {
      _9642.push_back(_5916);
    }
  }
  auto _9645 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9642.size()),_9642.begin(),_9642.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5914 = _9645;
  _checked_ptr_1<int> _ptr__5914(_5914 ? _5914->raw() : nullptr,_5914 ? _5914->size(0) : 0);
  std::vector<double> _9646;
  for (int _5918 = (int)0, _9647 = _5908; _5918 < _9647 ; ++_5918)
  {
    for (int _5919 = (int)0, _9648 = _5909; _5919 < _9648 ; ++_5919)
    {
      _9646.push_back(((*_5907)(_5918,_5919)));
    }
  }
  auto _9649 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9646.size()),_9646.begin(),_9646.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5917 = _9649;
  _checked_ptr_1<double> _ptr__5917(_5917 ? _5917->raw() : nullptr,_5917 ? _5917->size(0) : 0);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5908,_5909,_5911,_5914,_5917)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5920,    int _5921) { return mosek::fusion::p_Matrix::sparse(_5920,_5921); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5920,int _5921){
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5920,_5921,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),(long long)0)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5922,    int _5923,    std::shared_ptr< monty::ndarray< int,1 > > _5924,    std::shared_ptr< monty::ndarray< int,1 > > _5925,    double _5926) { return mosek::fusion::p_Matrix::sparse(_5922,_5923,_5924,_5925,_5926); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5922,int _5923,std::shared_ptr< monty::ndarray< int,1 > > _5924,std::shared_ptr< monty::ndarray< int,1 > > _5925,double _5926){
  _checked_ptr_1<int> _ptr__5924(_5924 ? _5924->raw() : nullptr, _5924 ? _5924->size(0) : 0);
  _checked_ptr_1<int> _ptr__5925(_5925 ? _5925->raw() : nullptr, _5925 ? _5925->size(0) : 0);
  int _5927 = (int)0;
  if ((NULL != _5924.get()))
  {
    {
      _5927 = (int)((_5924)->size(0));
    }
  }
  else if((NULL != _5925.get()))
  {
    {
      _5927 = (int)((_5925)->size(0));
    }
  }
  {}
  return ::mosek::fusion::p_Matrix::sparse(_5922,_5923,_5924,_5925,::mosek::fusion::Utils::Tools::makevector(_5926,_5927));
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5928,    std::shared_ptr< monty::ndarray< int,1 > > _5929,    double _5930) { return mosek::fusion::p_Matrix::sparse(_5928,_5929,_5930); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5928,std::shared_ptr< monty::ndarray< int,1 > > _5929,double _5930){
  _checked_ptr_1<int> _ptr__5928(_5928 ? _5928->raw() : nullptr, _5928 ? _5928->size(0) : 0);
  _checked_ptr_1<int> _ptr__5929(_5929 ? _5929->raw() : nullptr, _5929 ? _5929->size(0) : 0);
  int _5931 = (int)0;
  int _5932 = (int)0;
  int _5933 = (int)((_5928)->size(0));
  if ((_5933 > (int)((_5929)->size(0))))
  {
    {
      _5933 = (int)((_5929)->size(0));
    }
  }
  {}
  int _9650 = (int)0;
  int _9651 = _5933;
  for (int _5934 = _9650; _5934 < _9651; ++_5934)
  {
    {
      if ((_5932 < _ptr__5928[_5934]))
      {
        {
          _5932 = _ptr__5928[_5934];
        }
      }
      {}
      if ((_5931 < _ptr__5929[_5934]))
      {
        {
          _5931 = _ptr__5929[_5934];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5932,(int)1 ),safe_add( _5931,(int)1 ),_5928,_5929,_5930);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5935,    std::shared_ptr< monty::ndarray< int,1 > > _5936,    std::shared_ptr< monty::ndarray< double,1 > > _5937) { return mosek::fusion::p_Matrix::sparse(_5935,_5936,_5937); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5935,std::shared_ptr< monty::ndarray< int,1 > > _5936,std::shared_ptr< monty::ndarray< double,1 > > _5937){
  _checked_ptr_1<int> _ptr__5935(_5935 ? _5935->raw() : nullptr, _5935 ? _5935->size(0) : 0);
  _checked_ptr_1<int> _ptr__5936(_5936 ? _5936->raw() : nullptr, _5936 ? _5936->size(0) : 0);
  _checked_ptr_1<double> _ptr__5937(_5937 ? _5937->raw() : nullptr, _5937 ? _5937->size(0) : 0);
  int _5938 = (int)0;
  int _5939 = (int)0;
  int _5940 = (int)((_5935)->size(0));
  if ((_5940 > (int)((_5936)->size(0))))
  {
    {
      _5940 = (int)((_5936)->size(0));
    }
  }
  {}
  if ((_5940 > (int)((_5937)->size(0))))
  {
    {
      _5940 = (int)((_5937)->size(0));
    }
  }
  {}
  int _9652 = (int)0;
  int _9653 = _5940;
  for (int _5941 = _9652; _5941 < _9653; ++_5941)
  {
    {
      if ((_5939 < _ptr__5935[_5941]))
      {
        {
          _5939 = _ptr__5935[_5941];
        }
      }
      {}
      if ((_5938 < _ptr__5936[_5941]))
      {
        {
          _5938 = _ptr__5936[_5941];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5939,(int)1 ),safe_add( _5938,(int)1 ),_5935,_5936,_5937);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5942,    int _5943,    std::shared_ptr< monty::ndarray< int,1 > > _5944,    std::shared_ptr< monty::ndarray< int,1 > > _5945,    std::shared_ptr< monty::ndarray< double,1 > > _5946) { return mosek::fusion::p_Matrix::sparse(_5942,_5943,_5944,_5945,_5946); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5942,int _5943,std::shared_ptr< monty::ndarray< int,1 > > _5944,std::shared_ptr< monty::ndarray< int,1 > > _5945,std::shared_ptr< monty::ndarray< double,1 > > _5946){
  _checked_ptr_1<int> _ptr__5944(_5944 ? _5944->raw() : nullptr, _5944 ? _5944->size(0) : 0);
  _checked_ptr_1<int> _ptr__5945(_5945 ? _5945->raw() : nullptr, _5945 ? _5945->size(0) : 0);
  _checked_ptr_1<double> _ptr__5946(_5946 ? _5946->raw() : nullptr, _5946 ? _5946->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9654;
  bool _9655 = (NULL != _5946.get());
  if (_9655)
  {
    _9654 = _5946;
  }
  else
  {
    _9654 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5947 = _9654;
  _checked_ptr_1<double> _ptr__5947(_5947 ? _5947->raw() : nullptr,_5947 ? _5947->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9656;
  bool _9657 = (NULL != _5945.get());
  if (_9657)
  {
    _9656 = _5945;
  }
  else
  {
    _9656 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5948 = _9656;
  _checked_ptr_1<int> _ptr__5948(_5948 ? _5948->raw() : nullptr,_5948 ? _5948->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9658;
  bool _9659 = (NULL != _5944.get());
  if (_9659)
  {
    _9658 = _5944;
  }
  else
  {
    _9658 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5949 = _9658;
  _checked_ptr_1<int> _ptr__5949(_5949 ? _5949->raw() : nullptr,_5949 ? _5949->size(0) : 0);
  long long _5950 = (long long)((_5949)->size(0));
  if ((((long long)((_5948)->size(0)) != _5950) || ((long long)((_5947)->size(0)) != _5950)))
  {
    {
      throw ::mosek::fusion::SparseFormatError(std::string ("Arrays defining sparse data have different lengths"));
    }
  }
  {}
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5942,_5943,_5949,_5948,_5947,_5950)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix :: transpose() { return __mosek_2fusion_2Matrix__transpose(); }
int mosek::fusion::Matrix :: numColumns() { return mosek::fusion::p_Matrix::_get_impl(this)->numColumns(); }int mosek::fusion::p_Matrix::numColumns(){
  return dimj;
}
int mosek::fusion::Matrix :: numRows() { return mosek::fusion::p_Matrix::_get_impl(this)->numRows(); }int mosek::fusion::p_Matrix::numRows(){
  return dimi;
}
void mosek::fusion::p_Matrix::destroy(){}void mosek::fusion::Matrix::destroy() { mosek::fusion::p_Matrix::_get_impl(this)->destroy(); }mosek::fusion::UnimplementedError::UnimplementedError  ( const std::string &  _5956) : RuntimeException(_5956)  {
  }
mosek::fusion::FatalError::FatalError  ( const std::string &  _5957) : RuntimeException(_5957)  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( ::mosek::fusion::FusionException _5958) : RuntimeException(_5958.toString())  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( const std::string &  _5959) : RuntimeException(_5959)  {
  }
mosek::fusion::SparseFormatError::SparseFormatError  ( const std::string &  _5960) : mosek::fusion::FusionRuntimeException(_5960)  {
  }
mosek::fusion::SolutionError::SolutionError  ( ) : mosek::fusion::FusionException(std::string ("Solution is invalid or undefined"))  {
  }
mosek::fusion::SolutionError::SolutionError  ( const std::string &  _5961) : mosek::fusion::FusionException(_5961)  {
  }
mosek::fusion::SliceError::SliceError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Invalid slice range"))  {
  }
mosek::fusion::SliceError::SliceError  ( const std::string &  _5962) : mosek::fusion::FusionRuntimeException(_5962)  {
  }
mosek::fusion::SetDefinitionError::SetDefinitionError  ( const std::string &  _5963) : mosek::fusion::FusionRuntimeException(_5963)  {
  }
mosek::fusion::OptimizeError::OptimizeError  ( const std::string &  _5964) : mosek::fusion::FusionRuntimeException(_5964)  {
  }
mosek::fusion::NameError::NameError  ( const std::string &  _5965) : mosek::fusion::FusionRuntimeException(_5965)  {
  }
mosek::fusion::ModelError::ModelError  ( const std::string &  _5966) : mosek::fusion::FusionRuntimeException(_5966)  {
  }
mosek::fusion::MatrixError::MatrixError  ( const std::string &  _5967) : mosek::fusion::FusionRuntimeException(_5967)  {
  }
mosek::fusion::DimensionError::DimensionError  ( const std::string &  _5968) : mosek::fusion::FusionRuntimeException(_5968)  {
  }
mosek::fusion::LengthError::LengthError  ( const std::string &  _5969) : mosek::fusion::FusionRuntimeException(_5969)  {
  }
mosek::fusion::RangeError::RangeError  ( const std::string &  _5970) : mosek::fusion::FusionRuntimeException(_5970)  {
  }
mosek::fusion::IndexError::IndexError  ( const std::string &  _5971) : mosek::fusion::FusionRuntimeException(_5971)  {
  }
mosek::fusion::DomainError::DomainError  ( const std::string &  _5972) : mosek::fusion::FusionRuntimeException(_5972)  {
  }
mosek::fusion::ValueConversionError::ValueConversionError  ( const std::string &  _5973) : mosek::fusion::FusionRuntimeException(_5973)  {
  }
mosek::fusion::ParameterError::ParameterError  ( const std::string &  _5974) : mosek::fusion::FusionRuntimeException(_5974)  {
  }
mosek::fusion::ExpressionError::ExpressionError  ( const std::string &  _5975) : mosek::fusion::FusionRuntimeException(_5975)  {
  }
mosek::fusion::IOError::IOError  ( const std::string &  _5976) : mosek::fusion::FusionRuntimeException(_5976)  {
  }
mosek::fusion::FusionRuntimeException::FusionRuntimeException  ( const std::string &  _5977) : RuntimeException(_5977)  {
    msg = _5977;
  }
std::string mosek::fusion::FusionRuntimeException::toString(){
  return msg;
}
mosek::fusion::FusionException::FusionException  ( const std::string &  _5978) : Exception(_5978)  {
    msg = _5978;
  }
std::string mosek::fusion::FusionException::toString(){
  return msg;
}
mosek::fusion::LinkedBlocks::LinkedBlocks(mosek::fusion::p_LinkedBlocks *_impl) : _impl(_impl) { /*std::cout << "LinkedBlocks() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedBlocks::~LinkedBlocks() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedBlocks::p_LinkedBlocks  (::mosek::fusion::LinkedBlocks * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (){ return new mosek::fusion::LinkedBlocks(); }mosek::fusion::LinkedBlocks::LinkedBlocks  () :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedBlocks::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedBlocks::_initialize((int)0);
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (int _5979){ return new mosek::fusion::LinkedBlocks(_5979); }mosek::fusion::LinkedBlocks::LinkedBlocks  (int _5979) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5979); }void mosek::fusion::p_LinkedBlocks::_initialize  (int _5979){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(_5979);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts((int)128);
    bsize = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
    bfirst = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5980){ return new mosek::fusion::LinkedBlocks(_5980); }mosek::fusion::LinkedBlocks::LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5980) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5980); }void mosek::fusion::p_LinkedBlocks::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5980){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5980)->ints);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5980)->blocks);
    bsize = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5980)->bsize);
    bfirst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5980)->bfirst);
  }
}void mosek::fusion::LinkedBlocks :: free(int _5981) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->free(_5981); }void mosek::fusion::p_LinkedBlocks::free(int _5981){
  int _5982 = ((*bfirst)(_5981));
  ints->free(_5981,((*bsize)(_5981)));
  ((*bsize)(_5981)) = (-(int)1);
  ((*bfirst)(_5981)) = (-(int)1);
  blocks->free(_5982,(int)1);
}
int mosek::fusion::LinkedBlocks :: alloc(int _5983) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->alloc(_5983); }int mosek::fusion::p_LinkedBlocks::alloc(int _5983){
  int _9660;
  bool _9661 = (_5983 > (int)0);
  if (_9661)
  {
    _9660 = ints->alloc(_5983);
  }
  else
  {
    _9660 = (-(int)1);
  }
  int _5984 = _9660;
  int _5985 = blocks->alloc();
  if ((blocks->capacity() > (int)((bsize)->size(0))))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5986 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5986(_5986 ? _5986->raw() : nullptr,_5986 ? _5986->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5987 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5987(_5987 ? _5987->raw() : nullptr,_5987 ? _5987->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(bsize,(int)0,_5986,(int)0,(int)((bsize)->size(0)));
      ::mosek::fusion::Utils::Tools::arraycopy(bfirst,(int)0,_5987,(int)0,(int)((bfirst)->size(0)));
      bsize = _5986;
      bfirst = _5987;
    }
  }
  {}
  ((*bfirst)(_5985)) = _5984;
  ((*bsize)(_5985)) = _5983;
  return _5985;
}
int mosek::fusion::LinkedBlocks :: maxidx(int _5988) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->maxidx(_5988); }int mosek::fusion::p_LinkedBlocks::maxidx(int _5988){
  return ints->maxidx(((*bfirst)(_5988)),((*bsize)(_5988)));
}
void mosek::fusion::LinkedBlocks :: get(int _5989,std::shared_ptr< monty::ndarray< int,1 > > _5990,int _5991) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->get(_5989,_5990,_5991); }void mosek::fusion::p_LinkedBlocks::get(int _5989,std::shared_ptr< monty::ndarray< int,1 > > _5990,int _5991){
  _checked_ptr_1<int> _ptr__5990(_5990 ? _5990->raw() : nullptr, _5990 ? _5990->size(0) : 0);
  ints->get(((*bfirst)(_5989)),((*bsize)(_5989)),_5990,_5991);
}
int mosek::fusion::LinkedBlocks :: numblocks() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->numblocks(); }int mosek::fusion::p_LinkedBlocks::numblocks(){
  return (int)((bsize)->size(0));
}
int mosek::fusion::LinkedBlocks :: blocksize(int _5992) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->blocksize(_5992); }int mosek::fusion::p_LinkedBlocks::blocksize(int _5992){
  return ((*bsize)(_5992));
}
int mosek::fusion::LinkedBlocks :: capacity() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedBlocks::capacity(){
  return ints->capacity();
}
bool mosek::fusion::LinkedBlocks :: validate() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedBlocks::validate(){
  return (ints->validate() && blocks->validate());
}
void mosek::fusion::p_LinkedBlocks::destroy(){bfirst.reset();bsize.reset();blocks.reset();ints.reset();}void mosek::fusion::LinkedBlocks::destroy() { mosek::fusion::p_LinkedBlocks::_get_impl(this)->destroy(); }mosek::fusion::LinkedInts::LinkedInts(mosek::fusion::p_LinkedInts *_impl) : _impl(_impl) { /*std::cout << "LinkedInts() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedInts::~LinkedInts() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedInts::p_LinkedInts  (::mosek::fusion::LinkedInts * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (int _5993){ return new mosek::fusion::LinkedInts(_5993); }mosek::fusion::LinkedInts::LinkedInts  (int _5993) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5993); }void mosek::fusion::p_LinkedInts::_initialize  (int _5993){monty::rc_reserve __reserve_this(_pubthis);   {
    int _9662;
    bool _9663 = (_5993 > (int)0);
    if (_9663)
    {
      _9662 = _5993;
    }
    else
    {
      _9662 = (int)128;
    }
    int _5994 = _9662;
    next = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5994)));
    prev = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5994)));
    first_used = (-(int)1);
    first_free = (int)0;
    last_free = (_5994 - (int)1);
    int _9664 = (int)1;
    int _9665 = _5994;
    for (int _5995 = _9664; _5995 < _9665; ++_5995)
    {
      {
        ((*prev)(_5995)) = (_5995 - (int)1);
        ((*next)((_5995 - (int)1))) = _5995;
      }
    }
    ((*prev)((int)0)) = (-(int)1);
    ((*next)((_5994 - (int)1))) = (-(int)1);
    nfree = _5994;
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (){ return new mosek::fusion::LinkedInts(); }mosek::fusion::LinkedInts::LinkedInts  () :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedInts::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedInts::_initialize((int)128);
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5996){ return new mosek::fusion::LinkedInts(_5996); }mosek::fusion::LinkedInts::LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5996) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5996); }void mosek::fusion::p_LinkedInts::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5996){monty::rc_reserve __reserve_this(_pubthis);   {
    next = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5996)->next);
    prev = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5996)->prev);
    first_used = mosek::fusion::p_LinkedInts::_get_impl(_5996)->first_used;
    first_free = mosek::fusion::p_LinkedInts::_get_impl(_5996)->first_free;
    last_free = mosek::fusion::p_LinkedInts::_get_impl(_5996)->last_free;
    nfree = mosek::fusion::p_LinkedInts::_get_impl(_5996)->nfree;
  }
}void mosek::fusion::LinkedInts :: free(int _5997,int _5998) { mosek::fusion::p_LinkedInts::_get_impl(this)->free(_5997,_5998); }void mosek::fusion::p_LinkedInts::free(int _5997,int _5998){
  int _5999 = _5997;
  int _6000 = _5999;
  int _9666 = (int)0;
  int _9667 = (_5998 - (int)1);
  for (int _6001 = _9666; _6001 < _9667; ++_6001)
  {
    {
      _6000 = ((*next)(_6000));
    }
  }
  int _6002 = ((*prev)(_5999));
  int _6003 = ((*next)(_6000));
  if ((_6002 >= (int)0))
  {
    {
      ((*next)(_6002)) = _6003;
    }
  }
  {}
  if ((_6003 >= (int)0))
  {
    {
      ((*prev)(_6003)) = _6002;
    }
  }
  {}
  ((*prev)(_5999)) = (-(int)1);
  ((*next)(_6000)) = first_free;
  if ((first_free >= (int)0))
  {
    {
      ((*prev)(first_free)) = _6000;
    }
  }
  {}
  first_free = _5999;
  nfree += _5998;
}
int mosek::fusion::LinkedInts :: alloc() { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(); }int mosek::fusion::p_LinkedInts::alloc(){
  return allocblock((int)1);
}
int mosek::fusion::LinkedInts :: alloc(int _6004) { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6004); }int mosek::fusion::p_LinkedInts::alloc(int _6004){
  return allocblock(_6004);
}
void mosek::fusion::LinkedInts :: alloc(int _6005,std::shared_ptr< monty::ndarray< int,1 > > _6006,int _6007) { mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6005,_6006,_6007); }void mosek::fusion::p_LinkedInts::alloc(int _6005,std::shared_ptr< monty::ndarray< int,1 > > _6006,int _6007){
  _checked_ptr_1<int> _ptr__6006(_6006 ? _6006->raw() : nullptr, _6006 ? _6006->size(0) : 0);
  int _6008 = allocblock(_6005);
  int _9668 = (int)0;
  int _9669 = _6005;
  for (int _6009 = _9668; _6009 < _9669; ++_6009)
  {
    {
      _ptr__6006[safe_add( _6009,_6007 )] = _6008;
      _6008 = ((*next)(_6008));
    }
  }
}
void mosek::fusion::LinkedInts :: get(int _6010,int _6011,std::shared_ptr< monty::ndarray< int,1 > > _6012,int _6013) { mosek::fusion::p_LinkedInts::_get_impl(this)->get(_6010,_6011,_6012,_6013); }void mosek::fusion::p_LinkedInts::get(int _6010,int _6011,std::shared_ptr< monty::ndarray< int,1 > > _6012,int _6013){
  _checked_ptr_1<int> _ptr__6012(_6012 ? _6012->raw() : nullptr, _6012 ? _6012->size(0) : 0);
  int _6014 = _6010;
  int _9670 = (int)0;
  int _9671 = _6011;
  for (int _6015 = _9670; _6015 < _9671; ++_6015)
  {
    {
      _ptr__6012[safe_add( _6015,_6013 )] = _6014;
      _6014 = ((*next)(_6014));
    }
  }
}
int mosek::fusion::LinkedInts :: maxidx(int _6016,int _6017) { return mosek::fusion::p_LinkedInts::_get_impl(this)->maxidx(_6016,_6017); }int mosek::fusion::p_LinkedInts::maxidx(int _6016,int _6017){
  int _6018 = _6016;
  int _6019 = _6016;
  int _9672 = (int)1;
  int _9673 = _6017;
  for (int _6020 = _9672; _6020 < _9673; ++_6020)
  {
    {
      _6019 = ((*next)(_6019));
      if ((_6018 < _6019))
      {
        {
          _6018 = _6019;
        }
      }
      {}
    }
  }
  return _6018;
}
int mosek::fusion::p_LinkedInts::allocblock(int _6021){
  int _6022 = (int)((next)->size(0));
  if ((nfree < _6021))
  {
    {
      int _6023 = (_6021 - nfree);
      if ((_6023 < _6022))
      {
        {
          _6023 = _6022;
        }
      }
      {}
      recap(safe_add( _6023,_6022 ));
    }
  }
  {}
  int _6024 = first_free;
  int _6025 = _6024;
  int _9674 = (int)0;
  int _9675 = (_6021 - (int)1);
  for (int _6026 = _9674; _6026 < _9675; ++_6026)
  {
    {
      _6025 = ((*next)(_6025));
    }
  }
  first_free = ((*next)(_6025));
  if ((first_free < (int)0))
  {
    {
      last_free = (-(int)1);
    }
  }
  else
  {
    {
      ((*prev)(first_free)) = (-(int)1);
    }
  }
  ((*next)(_6025)) = first_used;
  if ((first_used >= (int)0))
  {
    {
      ((*prev)(first_used)) = _6025;
    }
  }
  {}
  first_used = _6024;
  nfree -= _6021;
  return _6024;
}
void mosek::fusion::p_LinkedInts::recap(int _6027){
  int _6028 = (int)((next)->size(0));
  if ((_6027 > _6028))
  {
    {
      next = ::mosek::fusion::p_CommonTools::resize(next,_6027);
      prev = ::mosek::fusion::p_CommonTools::resize(prev,_6027);
      int _9676 = _6028;
      int _9677 = (_6027 - (int)1);
      for (int _6029 = _9676; _6029 < _9677; ++_6029)
      {
        {
          ((*next)(_6029)) = safe_add( _6029,(int)1 );
          ((*prev)(safe_add( _6029,(int)1 ))) = _6029;
        }
      }
      ((*next)((_6027 - (int)1))) = (-(int)1);
      ((*prev)(_6028)) = last_free;
      if ((last_free < (int)0))
      {
        {
          first_free = _6028;
        }
      }
      else
      {
        {
          ((*next)(last_free)) = _6028;
        }
      }
      last_free = (_6027 - (int)1);
      nfree += (_6027 - _6028);
    }
  }
  {}
}
int mosek::fusion::LinkedInts :: capacity() { return mosek::fusion::p_LinkedInts::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedInts::capacity(){
  return (int)((next)->size(0));
}
bool mosek::fusion::LinkedInts :: validate() { return mosek::fusion::p_LinkedInts::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedInts::validate(){
  std::shared_ptr< monty::ndarray< bool,1 > > _6030 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape((int)((next)->size(0)))));
  int _6031 = first_used;
  while ( (_6031 >= (int)0) )
  {
    {
      ((*_6030)(_6031)) = true;
      _6031 = ((*next)(_6031));
      if (((_6031 >= (int)0) && ((*_6030)(_6031))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("used list/next is inconsistent"));
        }
      }
      {}
    }
  }
  _6031 = first_free;
  int _6032 = (int)0;
  while ( (_6031 >= (int)0) )
  {
    {
      ++ _6032;
      ((*_6030)(_6031)) = true;
      _6031 = ((*next)(_6031));
      if (((_6031 >= (int)0) && ((*_6030)(_6031))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("free list/next is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6032 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free next list did not contain nfree elements"));
    }
  }
  {}
  int _9678 = (int)0;
  int _9679 = (int)((_6030)->size(0));
  for (int _6033 = _9678; _6033 < _9679; ++_6033)
  {
    {
      if ((!((*_6030)(_6031))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("elements missing from used+free list"));
        }
      }
      {}
    }
  }
  int _9680 = (int)0;
  int _9681 = (int)((_6030)->size(0));
  for (int _6034 = _9680; _6034 < _9681; ++_6034)
  {
    {
      ((*_6030)(_6034)) = false;
    }
  }
  _6031 = last_free;
  int _6035 = (int)0;
  while ( (_6031 >= (int)0) )
  {
    {
      ++ _6035;
      ((*_6030)(_6031)) = true;
      _6031 = ((*prev)(_6031));
      if (((_6031 >= (int)0) && ((*_6030)(_6031))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("prev list is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6035 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free prev list did not contain nfree elements"));
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinkedInts::destroy(){prev.reset();next.reset();}void mosek::fusion::LinkedInts::destroy() { mosek::fusion::p_LinkedInts::_get_impl(this)->destroy(); }mosek::fusion::Parameters::Parameters(mosek::fusion::p_Parameters *_impl) : _impl(_impl) { /*std::cout << "Parameters() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Parameters::~Parameters() { delete _impl; _impl = nullptr; }mosek::fusion::p_Parameters::p_Parameters  (::mosek::fusion::Parameters * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6036,    const std::string & _6037,    double _6038) { mosek::fusion::p_Parameters::setParameter(_6036,_6037,_6038); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6036,const std::string & _6037,double _6038){
  if (false)
  {
    {
    }
  }
  else if((_6037 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6037 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6037 == std::string ("numThreads")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6039 = _6038;
          if (((int)0 <= _6039))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6039);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6037 == std::string ("mtSpincount")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6040 = _6038;
          if ((((int)0 <= _6040) && (_6040 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6040);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6037 == std::string ("biMaxIterations")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6041 = _6038;
          if (((int)0 <= _6041))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6041);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6042 = _6038;
          if (((int)0 <= _6042))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6042);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logCutSecondOpt")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6043 = _6038;
          if (((int)0 <= _6043))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6043);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logResponse")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6044 = _6038;
          if (((int)0 <= _6044))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6044);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6037 == std::string ("logBi")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6045 = _6038;
          if (((int)0 <= _6045))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6045);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logBiFreq")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6046 = _6038;
          if (((int)0 <= _6046))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6046);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6037 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6037 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6037 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6037 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6037 == std::string ("logIntpnt")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6047 = _6038;
          if (((int)0 <= _6047))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6047);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntMaxIterations")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6048 = _6038;
          if (((int)0 <= _6048))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6048);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntOffColTrh")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6049 = _6038;
          if (((int)0 <= _6049))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6049);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_6037 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6050 = _6038;
          if (((int)0 <= _6050))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6050);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6037 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6037 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6037 == std::string ("intpntMaxNumCor")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6051 = _6038;
          if (((-(int)1) <= _6051))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6051);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6037 == std::string ("presolveLevel")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6052 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6052);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logPresolve")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6053 = _6038;
          if (((int)0 <= _6053))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6053);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6037 == std::string ("presolveMaxNumPass")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6054 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6054);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6055 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6055);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6056 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6056);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("simPrimalCrash")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6057 = _6038;
          if (((int)0 <= _6057))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6057);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logSim")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6058 = _6038;
          if (((int)0 <= _6058))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6058);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logSimMinor")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6059 = _6038;
          if (((int)0 <= _6059))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6059);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logSimFreq")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6060 = _6038;
          if (((int)0 <= _6060))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6060);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("simPrimalRestrictSelection")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6061 = _6038;
          if ((((int)0 <= _6061) && (_6061 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6061);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6037 == std::string ("simDualRestrictSelection")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6062 = _6038;
          if ((((int)0 <= _6062) && (_6062 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6062);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6037 == std::string ("simMaxIterations")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6063 = _6038;
          if (((int)0 <= _6063))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6063);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6037 == std::string ("simRefactorFreq")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6064 = _6038;
          if (((int)0 <= _6064))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6064);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("simSeed")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6065 = _6038;
          if ((((int)0 <= _6065) && (_6065 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6065);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6037 == std::string ("logMio")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6066 = _6038;
          if (((int)0 <= _6066))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6066);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logMioFreq")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6067 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6067);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioMaxNumRelaxs")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6068 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6068);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioMaxNumBranches")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6069 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6069);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6070 = _6038;
          if (((int)0 <= _6070))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6070);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioMaxNumSolutions")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6071 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6071);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6037 == std::string ("mioHeuristicLevel")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6072 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6072);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioProbingLevel")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6073 = _6038;
          if ((((-(int)1) <= _6073) && (_6073 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6073);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioCutSelectionLevel")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6074 = _6038;
          if ((((-(int)1) <= _6074) && (_6074 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6074);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioVbDetectionLevel")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6075 = _6038;
          if ((((-(int)1) <= _6075) && (_6075 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6075);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6037 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6037 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6037 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6037 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6037 == std::string ("mioSeed")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6076 = _6038;
          if (((int)0 <= _6076))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6076);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6037 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6037 == std::string ("writeLpLineWidth")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6077 = _6038;
          if (((int)40 <= _6077))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6077);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("writeLpTermsPerLine")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6078 = _6038;
          if (((int)0 <= _6078))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6078);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6037 == std::string ("logInfeasAna")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6079 = _6038;
          if (((int)0 <= _6079))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6079);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6037 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6037 == std::string ("licensePauseTime")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6080 = _6038;
          if ((((int)0 <= _6080) && (_6080 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6080);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6037 == std::string ("log")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6081 = _6038;
          if (((int)0 <= _6081))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6081);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logExpand")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6082 = _6038;
          if (((int)0 <= _6082))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6082);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logFile")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6083 = _6038;
          if (((int)0 <= _6083))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6083);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("logOrder")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6084 = _6038;
          if (((int)0 <= _6084))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6084);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6037 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6037 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6085 = _6038;
          if ((((int)0 <= _6085) && (_6085 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6085);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("simDualPhaseoneMethod")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6086 = _6038;
          if ((((int)0 <= _6086) && (_6086 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6086);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("simMaxNumSetbacks")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6087 = _6038;
          if (((int)0 <= _6087))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6087);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6037 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6037 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6037 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6037 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6037 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6037 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6037 == std::string ("simDualCrash")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6088 = _6038;
          if (((int)0 <= _6088))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6088);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6037 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6089 = _6038;
          if ((((-(int)1) <= _6089) && (_6089 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6089);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6037 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6037 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6037 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6037 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6037 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6090 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6090);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6091 = _6038;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6091);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6037 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6037 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6037 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6037 == std::string ("mioRinsMaxNodes")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6092 = _6038;
          if (((-(int)1) <= _6092))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6092);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioFeaspumpLevel")))
  {
    {
      if (((_6038 - (int)_6038) == 0.0))
      {
        {
          double _6093 = _6038;
          if ((((-(int)1) <= _6093) && (_6093 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6093);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("optimizerMaxTime")))
  {
    {
      double _6094 = _6038;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6094);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("lowerObjCut")))
  {
    {
      double _6095 = _6038;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6095);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("upperObjCut")))
  {
    {
      double _6096 = _6038;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6096);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6097 = _6038;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6097);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6098 = _6038;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6098);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolRelGap")))
  {
    {
      double _6099 = _6038;
      if ((1.000000e-14 <= _6099))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6099);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolStepSize")))
  {
    {
      double _6100 = _6038;
      if (((0.000000e+00 <= _6100) && (_6100 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6100);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6101 = _6038;
      if (((1.000000e-06 <= _6101) && (_6101 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6101);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolRelStep")))
  {
    {
      double _6102 = _6038;
      if (((1.000000e-04 <= _6102) && (_6102 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6102);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolPath")))
  {
    {
      double _6103 = _6038;
      if (((0.000000e+00 <= _6103) && (_6103 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6103);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolPfeas")))
  {
    {
      double _6104 = _6038;
      if (((0.000000e+00 <= _6104) && (_6104 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6104);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolDfeas")))
  {
    {
      double _6105 = _6038;
      if (((0.000000e+00 <= _6105) && (_6105 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6105);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolMuRed")))
  {
    {
      double _6106 = _6038;
      if (((0.000000e+00 <= _6106) && (_6106 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6106);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolInfeas")))
  {
    {
      double _6107 = _6038;
      if (((0.000000e+00 <= _6107) && (_6107 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6107);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6108 = _6038;
      if (((0.000000e+00 <= _6108) && (_6108 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6108);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6109 = _6038;
      if (((0.000000e+00 <= _6109) && (_6109 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6109);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6110 = _6038;
      if (((0.000000e+00 <= _6110) && (_6110 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6110);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6111 = _6038;
      if (((0.000000e+00 <= _6111) && (_6111 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6111);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6112 = _6038;
      if ((1.000000e+00 <= _6112))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6112);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6113 = _6038;
      if (((0.000000e+00 <= _6113) && (_6113 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6113);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolPsafe")))
  {
    {
      double _6114 = _6038;
      if ((1.000000e-04 <= _6114))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6114);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("intpntTolDsafe")))
  {
    {
      double _6115 = _6038;
      if ((1.000000e-04 <= _6115))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6115);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioMaxTime")))
  {
    {
      double _6116 = _6038;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6116);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioRelGapConst")))
  {
    {
      double _6117 = _6038;
      if ((1.000000e-15 <= _6117))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6117);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioTolRelGap")))
  {
    {
      double _6118 = _6038;
      if ((0.000000e+00 <= _6118))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6118);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioTolAbsGap")))
  {
    {
      double _6119 = _6038;
      if ((0.000000e+00 <= _6119))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6119);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6120 = _6038;
      if ((1.000000e-09 <= _6120))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6120);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("basisTolX")))
  {
    {
      double _6121 = _6038;
      if ((1.000000e-09 <= _6121))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6121);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("basisTolS")))
  {
    {
      double _6122 = _6038;
      if ((1.000000e-09 <= _6122))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6122);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("basisRelTolS")))
  {
    {
      double _6123 = _6038;
      if ((0.000000e+00 <= _6123))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6123);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveTolX")))
  {
    {
      double _6124 = _6038;
      if ((0.000000e+00 <= _6124))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6124);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveTolS")))
  {
    {
      double _6125 = _6038;
      if ((0.000000e+00 <= _6125))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6125);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveTolAij")))
  {
    {
      double _6126 = _6038;
      if ((1.000000e-15 <= _6126))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6126);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6127 = _6038;
      if ((0.000000e+00 <= _6127))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6127);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6128 = _6038;
      if ((0.000000e+00 <= _6128))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6128);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6129 = _6038;
      if ((1.000000e-12 <= _6129))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6129);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioTolFeas")))
  {
    {
      double _6130 = _6038;
      if (((1.000000e-09 <= _6130) && (_6130 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6130);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6037 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6131 = _6038;
      if (((0.000000e+00 <= _6131) && (_6131 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6036.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6131);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6037 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6037 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6037 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6037 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6037 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6037 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6132,    const std::string & _6133,    int _6134) { mosek::fusion::p_Parameters::setParameter(_6132,_6133,_6134); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6132,const std::string & _6133,int _6134){
  if (false)
  {
    {
    }
  }
  else if((_6133 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6133 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6133 == std::string ("numThreads")))
  {
    {
      int _6135 = _6134;
      if (((int)0 <= _6135))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6135);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6133 == std::string ("mtSpincount")))
  {
    {
      int _6136 = _6134;
      if ((((int)0 <= _6136) && (_6136 <= (int)1000000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6136);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6133 == std::string ("biMaxIterations")))
  {
    {
      int _6137 = _6134;
      if (((int)0 <= _6137))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6137);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      int _6138 = _6134;
      if (((int)0 <= _6138))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6138);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logCutSecondOpt")))
  {
    {
      int _6139 = _6134;
      if (((int)0 <= _6139))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6139);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logResponse")))
  {
    {
      int _6140 = _6134;
      if (((int)0 <= _6140))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6140);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6133 == std::string ("logBi")))
  {
    {
      int _6141 = _6134;
      if (((int)0 <= _6141))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6141);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logBiFreq")))
  {
    {
      int _6142 = _6134;
      if (((int)0 <= _6142))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6142);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6133 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6133 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6133 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6133 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6133 == std::string ("logIntpnt")))
  {
    {
      int _6143 = _6134;
      if (((int)0 <= _6143))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6143);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntMaxIterations")))
  {
    {
      int _6144 = _6134;
      if (((int)0 <= _6144))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6144);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntOffColTrh")))
  {
    {
      int _6145 = _6134;
      if (((int)0 <= _6145))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6145);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_6133 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      int _6146 = _6134;
      if (((int)0 <= _6146))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6146);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6133 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6133 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6133 == std::string ("intpntMaxNumCor")))
  {
    {
      int _6147 = _6134;
      if (((-(int)1) <= _6147))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6147);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6133 == std::string ("presolveLevel")))
  {
    {
      int _6148 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6148);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logPresolve")))
  {
    {
      int _6149 = _6134;
      if (((int)0 <= _6149))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6149);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6133 == std::string ("presolveMaxNumPass")))
  {
    {
      int _6150 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6150);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      int _6151 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6151);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      int _6152 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6152);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("simPrimalCrash")))
  {
    {
      int _6153 = _6134;
      if (((int)0 <= _6153))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6153);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logSim")))
  {
    {
      int _6154 = _6134;
      if (((int)0 <= _6154))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6154);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logSimMinor")))
  {
    {
      int _6155 = _6134;
      if (((int)0 <= _6155))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6155);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logSimFreq")))
  {
    {
      int _6156 = _6134;
      if (((int)0 <= _6156))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6156);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("simPrimalRestrictSelection")))
  {
    {
      int _6157 = _6134;
      if ((((int)0 <= _6157) && (_6157 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6157);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6133 == std::string ("simDualRestrictSelection")))
  {
    {
      int _6158 = _6134;
      if ((((int)0 <= _6158) && (_6158 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6158);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6133 == std::string ("simMaxIterations")))
  {
    {
      int _6159 = _6134;
      if (((int)0 <= _6159))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6159);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6133 == std::string ("simRefactorFreq")))
  {
    {
      int _6160 = _6134;
      if (((int)0 <= _6160))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6160);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("simSeed")))
  {
    {
      int _6161 = _6134;
      if ((((int)0 <= _6161) && (_6161 <= (int)32749)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6161);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6133 == std::string ("logMio")))
  {
    {
      int _6162 = _6134;
      if (((int)0 <= _6162))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6162);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logMioFreq")))
  {
    {
      int _6163 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6163);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioMaxNumRelaxs")))
  {
    {
      int _6164 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6164);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioMaxNumBranches")))
  {
    {
      int _6165 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6165);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      int _6166 = _6134;
      if (((int)0 <= _6166))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6166);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioMaxNumSolutions")))
  {
    {
      int _6167 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6167);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6133 == std::string ("mioHeuristicLevel")))
  {
    {
      int _6168 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6168);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioProbingLevel")))
  {
    {
      int _6169 = _6134;
      if ((((-(int)1) <= _6169) && (_6169 <= (int)3)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6169);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioCutSelectionLevel")))
  {
    {
      int _6170 = _6134;
      if ((((-(int)1) <= _6170) && (_6170 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6170);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioVbDetectionLevel")))
  {
    {
      int _6171 = _6134;
      if ((((-(int)1) <= _6171) && (_6171 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6171);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6133 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6133 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6133 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6133 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6133 == std::string ("mioSeed")))
  {
    {
      int _6172 = _6134;
      if (((int)0 <= _6172))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6172);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6133 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6133 == std::string ("writeLpLineWidth")))
  {
    {
      int _6173 = _6134;
      if (((int)40 <= _6173))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6173);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("writeLpTermsPerLine")))
  {
    {
      int _6174 = _6134;
      if (((int)0 <= _6174))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6174);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6133 == std::string ("logInfeasAna")))
  {
    {
      int _6175 = _6134;
      if (((int)0 <= _6175))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6175);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6133 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6133 == std::string ("licensePauseTime")))
  {
    {
      int _6176 = _6134;
      if ((((int)0 <= _6176) && (_6176 <= (int)1000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6176);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6133 == std::string ("log")))
  {
    {
      int _6177 = _6134;
      if (((int)0 <= _6177))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6177);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logExpand")))
  {
    {
      int _6178 = _6134;
      if (((int)0 <= _6178))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6178);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logFile")))
  {
    {
      int _6179 = _6134;
      if (((int)0 <= _6179))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6179);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("logOrder")))
  {
    {
      int _6180 = _6134;
      if (((int)0 <= _6180))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6180);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6133 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6133 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      int _6181 = _6134;
      if ((((int)0 <= _6181) && (_6181 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6181);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("simDualPhaseoneMethod")))
  {
    {
      int _6182 = _6134;
      if ((((int)0 <= _6182) && (_6182 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6182);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("simMaxNumSetbacks")))
  {
    {
      int _6183 = _6134;
      if (((int)0 <= _6183))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6183);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6133 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6133 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6133 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6133 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6133 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6133 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6133 == std::string ("simDualCrash")))
  {
    {
      int _6184 = _6134;
      if (((int)0 <= _6184))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6184);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6133 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      int _6185 = _6134;
      if ((((-(int)1) <= _6185) && (_6185 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6185);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6133 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6133 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6133 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6133 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6133 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      int _6186 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6186);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      int _6187 = _6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6187);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6133 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6133 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6133 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6133 == std::string ("mioRinsMaxNodes")))
  {
    {
      int _6188 = _6134;
      if (((-(int)1) <= _6188))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6188);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioFeaspumpLevel")))
  {
    {
      int _6189 = _6134;
      if ((((-(int)1) <= _6189) && (_6189 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6189);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("optimizerMaxTime")))
  {
    {
      double _6190 = (double)_6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6190);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("lowerObjCut")))
  {
    {
      double _6191 = (double)_6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6191);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("upperObjCut")))
  {
    {
      double _6192 = (double)_6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6192);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6193 = (double)_6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6193);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6194 = (double)_6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6194);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolRelGap")))
  {
    {
      double _6195 = (double)_6134;
      if ((1.000000e-14 <= _6195))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6195);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolStepSize")))
  {
    {
      double _6196 = (double)_6134;
      if (((0.000000e+00 <= _6196) && (_6196 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6196);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6197 = (double)_6134;
      if (((1.000000e-06 <= _6197) && (_6197 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6197);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolRelStep")))
  {
    {
      double _6198 = (double)_6134;
      if (((1.000000e-04 <= _6198) && (_6198 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6198);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolPath")))
  {
    {
      double _6199 = (double)_6134;
      if (((0.000000e+00 <= _6199) && (_6199 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6199);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolPfeas")))
  {
    {
      double _6200 = (double)_6134;
      if (((0.000000e+00 <= _6200) && (_6200 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6200);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolDfeas")))
  {
    {
      double _6201 = (double)_6134;
      if (((0.000000e+00 <= _6201) && (_6201 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6201);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolMuRed")))
  {
    {
      double _6202 = (double)_6134;
      if (((0.000000e+00 <= _6202) && (_6202 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6202);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolInfeas")))
  {
    {
      double _6203 = (double)_6134;
      if (((0.000000e+00 <= _6203) && (_6203 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6203);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6204 = (double)_6134;
      if (((0.000000e+00 <= _6204) && (_6204 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6204);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6205 = (double)_6134;
      if (((0.000000e+00 <= _6205) && (_6205 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6205);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6206 = (double)_6134;
      if (((0.000000e+00 <= _6206) && (_6206 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6206);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6207 = (double)_6134;
      if (((0.000000e+00 <= _6207) && (_6207 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6207);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6208 = (double)_6134;
      if ((1.000000e+00 <= _6208))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6208);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6209 = (double)_6134;
      if (((0.000000e+00 <= _6209) && (_6209 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6209);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolPsafe")))
  {
    {
      double _6210 = (double)_6134;
      if ((1.000000e-04 <= _6210))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6210);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("intpntTolDsafe")))
  {
    {
      double _6211 = (double)_6134;
      if ((1.000000e-04 <= _6211))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6211);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioMaxTime")))
  {
    {
      double _6212 = (double)_6134;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6212);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioRelGapConst")))
  {
    {
      double _6213 = (double)_6134;
      if ((1.000000e-15 <= _6213))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6213);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioTolRelGap")))
  {
    {
      double _6214 = (double)_6134;
      if ((0.000000e+00 <= _6214))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6214);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioTolAbsGap")))
  {
    {
      double _6215 = (double)_6134;
      if ((0.000000e+00 <= _6215))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6215);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6216 = (double)_6134;
      if ((1.000000e-09 <= _6216))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6216);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("basisTolX")))
  {
    {
      double _6217 = (double)_6134;
      if ((1.000000e-09 <= _6217))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6217);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("basisTolS")))
  {
    {
      double _6218 = (double)_6134;
      if ((1.000000e-09 <= _6218))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6218);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("basisRelTolS")))
  {
    {
      double _6219 = (double)_6134;
      if ((0.000000e+00 <= _6219))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6219);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveTolX")))
  {
    {
      double _6220 = (double)_6134;
      if ((0.000000e+00 <= _6220))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6220);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveTolS")))
  {
    {
      double _6221 = (double)_6134;
      if ((0.000000e+00 <= _6221))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6221);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveTolAij")))
  {
    {
      double _6222 = (double)_6134;
      if ((1.000000e-15 <= _6222))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6222);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6223 = (double)_6134;
      if ((0.000000e+00 <= _6223))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6223);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6224 = (double)_6134;
      if ((0.000000e+00 <= _6224))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6224);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6225 = (double)_6134;
      if ((1.000000e-12 <= _6225))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6225);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioTolFeas")))
  {
    {
      double _6226 = (double)_6134;
      if (((1.000000e-09 <= _6226) && (_6226 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6226);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6133 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6227 = (double)_6134;
      if (((0.000000e+00 <= _6227) && (_6227 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6132.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6227);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6133 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6133 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6133 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6133 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6133 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6133 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6228,    const std::string & _6229,    const std::string & _6230) { mosek::fusion::p_Parameters::setParameter(_6228,_6229,_6230); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6228,const std::string & _6229,const std::string & _6230){
  if (false)
  {
    {
    }
  }
  {}
  if ((_6229 == std::string ("autoUpdateSolInfo")))
  {
    {
      int _6231 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6231 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_AUTO_UPDATE_SOL_INFO"),_6231);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("removeUnusedSolutions")))
  {
    {
      int _6232 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6232 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_REMOVE_UNUSED_SOLUTIONS"),_6232);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("numThreads")))
  {
    {
      try
      {
        {
          int _6234 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6234))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6234);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6233)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntMultiThread")))
  {
    {
      int _6235 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6235 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MULTI_THREAD"),_6235);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mtSpincount")))
  {
    {
      try
      {
        {
          int _6237 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((int)0 <= _6237) && (_6237 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6237);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6236)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("optimizer")))
  {
    {
      int _6238 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6230);
      if ((_6238 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_OPTIMIZER"),_6238);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("biMaxIterations")))
  {
    {
      try
      {
        {
          int _6240 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6240))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6240);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6239)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      try
      {
        {
          int _6242 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6242))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6242);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6241)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logCutSecondOpt")))
  {
    {
      try
      {
        {
          int _6244 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6244))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6244);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6243)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logResponse")))
  {
    {
      try
      {
        {
          int _6246 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6246))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6246);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6245)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logLocalInfo")))
  {
    {
      int _6247 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6247 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_LOCAL_INFO"),_6247);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("logBi")))
  {
    {
      try
      {
        {
          int _6249 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6249))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6249);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6248)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logBiFreq")))
  {
    {
      try
      {
        {
          int _6251 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6251))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6251);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6250)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("biCleanOptimizer")))
  {
    {
      int _6252 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6230);
      if ((_6252 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_BI_CLEAN_OPTIMIZER"),_6252);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intpntStartingPoint")))
  {
    {
      int _6253 = ::mosek::fusion::p_Parameters::string_to_startpointtype_value(_6230);
      if ((_6253 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_STARTING_POINT"),_6253);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intpntDiffStep")))
  {
    {
      int _6254 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6254 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_DIFF_STEP"),_6254);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intpntScaling")))
  {
    {
      int _6255 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6230);
      if ((_6255 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SCALING"),_6255);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intpntSolveForm")))
  {
    {
      int _6256 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6230);
      if ((_6256 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SOLVE_FORM"),_6256);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("logIntpnt")))
  {
    {
      try
      {
        {
          int _6258 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6258))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6258);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6257)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntMaxIterations")))
  {
    {
      try
      {
        {
          int _6260 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6260))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6260);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6259)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntOffColTrh")))
  {
    {
      try
      {
        {
          int _6262 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6262))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6262);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6261)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntOrderMethod")))
  {
    {
      int _6263 = ::mosek::fusion::p_Parameters::string_to_orderingtype_value(_6230);
      if ((_6263 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_METHOD"),_6263);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      try
      {
        {
          int _6265 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6265))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6265);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6264)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntBasis")))
  {
    {
      int _6266 = ::mosek::fusion::p_Parameters::string_to_basindtype_value(_6230);
      if ((_6266 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_BASIS"),_6266);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("biIgnoreMaxIter")))
  {
    {
      int _6267 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6267 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_MAX_ITER"),_6267);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("biIgnoreNumError")))
  {
    {
      int _6268 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6268 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_NUM_ERROR"),_6268);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intpntMaxNumCor")))
  {
    {
      try
      {
        {
          int _6270 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((-(int)1) <= _6270))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6270);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6269)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveUse")))
  {
    {
      int _6271 = ::mosek::fusion::p_Parameters::string_to_presolvemode_value(_6230);
      if ((_6271 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_USE"),_6271);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("presolveLevel")))
  {
    {
      try
      {
        {
          int _6273 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6273);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6272)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logPresolve")))
  {
    {
      try
      {
        {
          int _6275 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6275))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6275);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6274)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveLindepUse")))
  {
    {
      int _6276 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6276 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_USE"),_6276);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("presolveMaxNumPass")))
  {
    {
      try
      {
        {
          int _6278 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6278);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6277)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      try
      {
        {
          int _6280 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6280);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6279)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      try
      {
        {
          int _6282 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6282);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6281)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simPrimalCrash")))
  {
    {
      try
      {
        {
          int _6284 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6284))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6284);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6283)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logSim")))
  {
    {
      try
      {
        {
          int _6286 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6286))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6286);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6285)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logSimMinor")))
  {
    {
      try
      {
        {
          int _6288 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6288))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6288);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6287)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logSimFreq")))
  {
    {
      try
      {
        {
          int _6290 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6290))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6290);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6289)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simPrimalRestrictSelection")))
  {
    {
      try
      {
        {
          int _6292 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((int)0 <= _6292) && (_6292 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6292);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6291)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simPrimalSelection")))
  {
    {
      int _6293 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6230);
      if ((_6293 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_SELECTION"),_6293);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simDualRestrictSelection")))
  {
    {
      try
      {
        {
          int _6295 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((int)0 <= _6295) && (_6295 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6295);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6294)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simDualSelection")))
  {
    {
      int _6296 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6230);
      if ((_6296 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_SELECTION"),_6296);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simMaxIterations")))
  {
    {
      try
      {
        {
          int _6298 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6298))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6298);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6297)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simHotstartLu")))
  {
    {
      int _6299 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6299 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART_LU"),_6299);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simRefactorFreq")))
  {
    {
      try
      {
        {
          int _6301 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6301))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6301);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6300)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simSeed")))
  {
    {
      try
      {
        {
          int _6303 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((int)0 <= _6303) && (_6303 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6303);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6302)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioMode")))
  {
    {
      int _6304 = ::mosek::fusion::p_Parameters::string_to_miomode_value(_6230);
      if ((_6304 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_MODE"),_6304);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("logMio")))
  {
    {
      try
      {
        {
          int _6306 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6306))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6306);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6305)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logMioFreq")))
  {
    {
      try
      {
        {
          int _6308 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6308);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6307)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioMaxNumRelaxs")))
  {
    {
      try
      {
        {
          int _6310 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6310);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6309)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioMaxNumBranches")))
  {
    {
      try
      {
        {
          int _6312 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6312);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6311)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      try
      {
        {
          int _6314 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6314))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6314);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6313)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioMaxNumSolutions")))
  {
    {
      try
      {
        {
          int _6316 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6316);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6315)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioNodeSelection")))
  {
    {
      int _6317 = ::mosek::fusion::p_Parameters::string_to_mionodeseltype_value(_6230);
      if ((_6317 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_SELECTION"),_6317);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioHeuristicLevel")))
  {
    {
      try
      {
        {
          int _6319 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6319);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6318)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioProbingLevel")))
  {
    {
      try
      {
        {
          int _6321 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((-(int)1) <= _6321) && (_6321 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6321);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6320)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioCutSelectionLevel")))
  {
    {
      try
      {
        {
          int _6323 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((-(int)1) <= _6323) && (_6323 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6323);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6322)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioVbDetectionLevel")))
  {
    {
      try
      {
        {
          int _6325 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((-(int)1) <= _6325) && (_6325 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6325);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6324)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioBranchDir")))
  {
    {
      int _6326 = ::mosek::fusion::p_Parameters::string_to_branchdir_value(_6230);
      if ((_6326 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_BRANCH_DIR"),_6326);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioRootOptimizer")))
  {
    {
      int _6327 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6230);
      if ((_6327 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_OPTIMIZER"),_6327);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioNodeOptimizer")))
  {
    {
      int _6328 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6230);
      if ((_6328 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_OPTIMIZER"),_6328);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioPerspectiveReformulate")))
  {
    {
      int _6329 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6329 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_PERSPECTIVE_REFORMULATE"),_6329);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      int _6330 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6330 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROPAGATE_OBJECTIVE_CONSTRAINT"),_6330);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioSeed")))
  {
    {
      try
      {
        {
          int _6332 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6332))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6332);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6331)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioConicOuterApproximation")))
  {
    {
      int _6333 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6333 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_CONIC_OUTER_APPROXIMATION"),_6333);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("writeLpQuotedNames")))
  {
    {
      int _6334 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6334 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_QUOTED_NAMES"),_6334);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("writeLpLineWidth")))
  {
    {
      try
      {
        {
          int _6336 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)40 <= _6336))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6336);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6335)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("writeLpTermsPerLine")))
  {
    {
      try
      {
        {
          int _6338 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6338))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6338);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6337)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("writeLpFullObj")))
  {
    {
      int _6339 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6339 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_FULL_OBJ"),_6339);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("logInfeasAna")))
  {
    {
      try
      {
        {
          int _6341 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6341))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6341);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6340)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("licenseWait")))
  {
    {
      int _6342 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6342 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_WAIT"),_6342);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      int _6343 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6343 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_SUPPRESS_EXPIRE_WRNS"),_6343);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("licensePauseTime")))
  {
    {
      try
      {
        {
          int _6345 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((int)0 <= _6345) && (_6345 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6345);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6344)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("licenseDebug")))
  {
    {
      int _6346 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6346 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_DEBUG"),_6346);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("log")))
  {
    {
      try
      {
        {
          int _6348 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6348))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6348);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6347)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logExpand")))
  {
    {
      try
      {
        {
          int _6350 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6350))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6350);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6349)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logFile")))
  {
    {
      try
      {
        {
          int _6352 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6352))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6352);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6351)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("logOrder")))
  {
    {
      try
      {
        {
          int _6354 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6354))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6354);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6353)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simScaling")))
  {
    {
      int _6355 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6230);
      if ((_6355 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING"),_6355);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simScalingMethod")))
  {
    {
      int _6356 = ::mosek::fusion::p_Parameters::string_to_scalingmethod_value(_6230);
      if ((_6356 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING_METHOD"),_6356);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6358 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((int)0 <= _6358) && (_6358 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6358);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6357)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simDualPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6360 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((int)0 <= _6360) && (_6360 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6360);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6359)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simMaxNumSetbacks")))
  {
    {
      try
      {
        {
          int _6362 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6362))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6362);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6361)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simHotstart")))
  {
    {
      int _6363 = ::mosek::fusion::p_Parameters::string_to_simhotstart_value(_6230);
      if ((_6363 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART"),_6363);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simBasisFactorUse")))
  {
    {
      int _6364 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6364 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_BASIS_FACTOR_USE"),_6364);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simDegen")))
  {
    {
      int _6365 = ::mosek::fusion::p_Parameters::string_to_simdegen_value(_6230);
      if ((_6365 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_DEGEN"),_6365);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simReformulation")))
  {
    {
      int _6366 = ::mosek::fusion::p_Parameters::string_to_simreform_value(_6230);
      if ((_6366 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFORMULATION"),_6366);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simExploitDupvec")))
  {
    {
      int _6367 = ::mosek::fusion::p_Parameters::string_to_simdupvec_value(_6230);
      if ((_6367 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_EXPLOIT_DUPVEC"),_6367);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simSaveLu")))
  {
    {
      int _6368 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6368 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_SAVE_LU"),_6368);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simNonSingular")))
  {
    {
      int _6369 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6369 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_NON_SINGULAR"),_6369);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simDualCrash")))
  {
    {
      try
      {
        {
          int _6371 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((int)0 <= _6371))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6371);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6370)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("infeasPreferPrimal")))
  {
    {
      int _6372 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6372 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INFEAS_PREFER_PRIMAL"),_6372);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      try
      {
        {
          int _6374 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((-(int)1) <= _6374) && (_6374 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6374);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6373)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioCutCmir")))
  {
    {
      int _6375 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6375 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CMIR"),_6375);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioCutClique")))
  {
    {
      int _6376 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6376 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CLIQUE"),_6376);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioCutImpliedBound")))
  {
    {
      int _6377 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6377 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_IMPLIED_BOUND"),_6377);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioCutKnapsackCover")))
  {
    {
      int _6378 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6378 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_KNAPSACK_COVER"),_6378);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioCutGmi")))
  {
    {
      int _6379 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6379 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_GMI"),_6379);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      try
      {
        {
          int _6381 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6381);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6380)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      try
      {
        {
          int _6383 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6383);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6382)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("cacheLicense")))
  {
    {
      int _6384 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6384 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_CACHE_LICENSE"),_6384);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intpntRegularizationUse")))
  {
    {
      int _6385 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6385 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_REGULARIZATION_USE"),_6385);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simSolveForm")))
  {
    {
      int _6386 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6230);
      if ((_6386 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_SOLVE_FORM"),_6386);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("simSwitchOptimizer")))
  {
    {
      int _6387 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6230);
      if ((_6387 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_SIM_SWITCH_OPTIMIZER"),_6387);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("mioRinsMaxNodes")))
  {
    {
      try
      {
        {
          int _6389 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if (((-(int)1) <= _6389))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6389);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6388)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioFeaspumpLevel")))
  {
    {
      try
      {
        {
          int _6391 = ::mosek::fusion::Utils::Tools::toInt(_6230);
          if ((((-(int)1) <= _6391) && (_6391 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6391);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6390)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("optimizerMaxTime")))
  {
    {
      try
      {
        {
          double _6393 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6393);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6392)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("lowerObjCut")))
  {
    {
      try
      {
        {
          double _6395 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6395);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6394)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("upperObjCut")))
  {
    {
      try
      {
        {
          double _6397 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6397);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6396)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6399 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6399);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6398)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6401 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6401);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6400)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolRelGap")))
  {
    {
      try
      {
        {
          double _6403 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-14 <= _6403))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6403);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6402)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolStepSize")))
  {
    {
      try
      {
        {
          double _6405 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6405) && (_6405 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6405);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6404)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simLuTolRelPiv")))
  {
    {
      try
      {
        {
          double _6407 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((1.000000e-06 <= _6407) && (_6407 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6407);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6406)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolRelStep")))
  {
    {
      try
      {
        {
          double _6409 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((1.000000e-04 <= _6409) && (_6409 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6409);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6408)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolPath")))
  {
    {
      try
      {
        {
          double _6411 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6411) && (_6411 <= 9.999000e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6411);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6410)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolPfeas")))
  {
    {
      try
      {
        {
          double _6413 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6413) && (_6413 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6413);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6412)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolDfeas")))
  {
    {
      try
      {
        {
          double _6415 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6415) && (_6415 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6415);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6414)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolMuRed")))
  {
    {
      try
      {
        {
          double _6417 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6417) && (_6417 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6417);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6416)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolInfeas")))
  {
    {
      try
      {
        {
          double _6419 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6419) && (_6419 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6419);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6418)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntCoTolRelGap")))
  {
    {
      try
      {
        {
          double _6421 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6421) && (_6421 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6421);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6420)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntCoTolPfeas")))
  {
    {
      try
      {
        {
          double _6423 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6423) && (_6423 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6423);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6422)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntCoTolDfeas")))
  {
    {
      try
      {
        {
          double _6425 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6425) && (_6425 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6425);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6424)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntCoTolMuRed")))
  {
    {
      try
      {
        {
          double _6427 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6427) && (_6427 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6427);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6426)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntCoTolNearRel")))
  {
    {
      try
      {
        {
          double _6429 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e+00 <= _6429))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6429);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6428)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntCoTolInfeas")))
  {
    {
      try
      {
        {
          double _6431 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6431) && (_6431 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6431);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6430)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolPsafe")))
  {
    {
      try
      {
        {
          double _6433 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-04 <= _6433))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6433);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6432)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("intpntTolDsafe")))
  {
    {
      try
      {
        {
          double _6435 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-04 <= _6435))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6435);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6434)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioMaxTime")))
  {
    {
      try
      {
        {
          double _6437 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6437);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6436)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioRelGapConst")))
  {
    {
      try
      {
        {
          double _6439 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-15 <= _6439))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6439);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6438)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioTolRelGap")))
  {
    {
      try
      {
        {
          double _6441 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((0.000000e+00 <= _6441))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6441);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6440)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioTolAbsGap")))
  {
    {
      try
      {
        {
          double _6443 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((0.000000e+00 <= _6443))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6443);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6442)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      try
      {
        {
          double _6445 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-09 <= _6445))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6445);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6444)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("basisTolX")))
  {
    {
      try
      {
        {
          double _6447 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-09 <= _6447))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6447);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6446)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("basisTolS")))
  {
    {
      try
      {
        {
          double _6449 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-09 <= _6449))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6449);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6448)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("basisRelTolS")))
  {
    {
      try
      {
        {
          double _6451 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((0.000000e+00 <= _6451))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6451);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6450)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveTolX")))
  {
    {
      try
      {
        {
          double _6453 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((0.000000e+00 <= _6453))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6453);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6452)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveTolS")))
  {
    {
      try
      {
        {
          double _6455 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((0.000000e+00 <= _6455))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6455);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6454)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveTolAij")))
  {
    {
      try
      {
        {
          double _6457 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-15 <= _6457))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6457);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6456)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveTolAbsLindep")))
  {
    {
      try
      {
        {
          double _6459 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((0.000000e+00 <= _6459))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6459);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6458)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("presolveTolRelLindep")))
  {
    {
      try
      {
        {
          double _6461 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((0.000000e+00 <= _6461))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6461);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6460)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("simplexAbsTolPiv")))
  {
    {
      try
      {
        {
          double _6463 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if ((1.000000e-12 <= _6463))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6463);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6462)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioTolFeas")))
  {
    {
      try
      {
        {
          double _6465 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((1.000000e-09 <= _6465) && (_6465 <= 1.000000e-03)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6465);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6464)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      try
      {
        {
          double _6467 = ::mosek::fusion::Utils::Tools::toDouble(_6230);
          if (((0.000000e+00 <= _6467) && (_6467 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6467);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6466)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  {}
  if ((_6229 == std::string ("dataFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_SPAR_DATA_FILE_NAME"),_6230);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("basSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_SPAR_BAS_SOL_FILE_NAME"),_6230);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("itrSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_SPAR_ITR_SOL_FILE_NAME"),_6230);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("intSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_SPAR_INT_SOL_FILE_NAME"),_6230);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("writeLpGenVarName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_SPAR_WRITE_LP_GEN_VAR_NAME"),_6230);
      return;
    }
  }
  {}
  if ((_6229 == std::string ("remoteAccessToken")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6228.get())->task_put_param(std::string ("MSK_SPAR_REMOTE_ACCESS_TOKEN"),_6230);
      return;
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
int mosek::fusion::p_Parameters::string_to_mionodeseltype_value(const std::string & _6468){
  if ((_6468 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6468 == std::string ("first")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6468 == std::string ("best")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6468 == std::string ("pseudo")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingtype_value(const std::string & _6469){
  if ((_6469 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6469 == std::string ("none")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6469 == std::string ("moderate")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6469 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_checkconvexitytype_value(const std::string & _6470){
  if ((_6470 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6470 == std::string ("simple")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6470 == std::string ("full")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_feature_value(const std::string & _6471){
  if ((_6471 == std::string ("pts")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6471 == std::string ("pton")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_stakey_value(const std::string & _6472){
  if ((_6472 == std::string ("unk")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6472 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6472 == std::string ("supbas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6472 == std::string ("low")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6472 == std::string ("upr")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6472 == std::string ("fix")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6472 == std::string ("inf")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_objsense_value(const std::string & _6473){
  if ((_6473 == std::string ("minimize")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6473 == std::string ("maximize")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miomode_value(const std::string & _6474){
  if ((_6474 == std::string ("ignored")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6474 == std::string ("satisfied")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_nametype_value(const std::string & _6475){
  if ((_6475 == std::string ("gen")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6475 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6475 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_boundkey_value(const std::string & _6476){
  if ((_6476 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6476 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6476 == std::string ("fx")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6476 == std::string ("fr")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6476 == std::string ("ra")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingmethod_value(const std::string & _6477){
  if ((_6477 == std::string ("pow2")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6477 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_inftype_value(const std::string & _6478){
  if ((_6478 == std::string ("douType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6478 == std::string ("intType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6478 == std::string ("lintType")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_transpose_value(const std::string & _6479){
  if ((_6479 == std::string ("no")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6479 == std::string ("yes")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_streamtype_value(const std::string & _6480){
  if ((_6480 == std::string ("log")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6480 == std::string ("msg")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6480 == std::string ("err")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6480 == std::string ("wrn")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_conetype_value(const std::string & _6481){
  if ((_6481 == std::string ("quad")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6481 == std::string ("rquad")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6481 == std::string ("pexp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6481 == std::string ("dexp")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6481 == std::string ("ppow")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6481 == std::string ("dpow")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6481 == std::string ("zero")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simseltype_value(const std::string & _6482){
  if ((_6482 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6482 == std::string ("full")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6482 == std::string ("ase")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6482 == std::string ("devex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6482 == std::string ("se")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6482 == std::string ("partial")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_iinf_value(const std::string & _6483){
  if ((_6483 == std::string ("versionMajor")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6483 == std::string ("versionMinor")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6483 == std::string ("versionRevision")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6483 == std::string ("presolveLindepWork")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6483 == std::string ("presolveLindepPivots")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6483 == std::string ("presolveLindepSkipped")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6483 == std::string ("presolveOutofspace")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6483 == std::string ("presolveBadPrecision")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6483 == std::string ("optObjectiveSense")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6483 == std::string ("optimizer")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFirRefIter")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumRefSteps")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFactorDim")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFactorSchurNumSingular")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFactorNumDenseA")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFactorNumDenseADup")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFactorNumDenseW")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumcon")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumvar")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumbarvar")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumblo")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumbup")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumbfr")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumbfx")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumcone")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumconevar")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumbndcone")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumrqcones")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumqcones")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumpexpcones")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6483 == std::string ("intpntNumppowcones")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6483 == std::string ("intpntMinconedim")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6483 == std::string ("intpntMaxconedim")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6483 == std::string ("intpntMaxbarvardim")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumcfr")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumcfx")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumclo")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumcup")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumcra")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumcnl")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumvfr")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumvfx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumvlo")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumvup")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumvra")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumvnl")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumnza")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumcon")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumcfr")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumcfx")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumclo")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumcup")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumcra")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumcnl")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumvar")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumvfr")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumvfx")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumvlo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumvup")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumvra")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumvnl")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6483 == std::string ("presolveFnumnza")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumElimns")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6483 == std::string ("presolveEliNumTries")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6483 == std::string ("presolveEliNumFreedCon")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6483 == std::string ("presolveEliNumFreedConTotal")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6483 == std::string ("presolveLindepNumTries")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6483 == std::string ("presolveLindepNum")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6483 == std::string ("presolveForceConNum")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6483 == std::string ("presolveForceConNumVar")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6483 == std::string ("presolveForceVarNum")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6483 == std::string ("presolveForceVarNumCon")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6483 == std::string ("presolvePivOnConNum")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumDouBlocks")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumSimplifiedDouBlocks")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6483 == std::string ("presolveSizeSimplifiedDouBlocks")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6483 == std::string ("presolveNumQuadConeOrthoTrans")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFactorNum")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6483 == std::string ("intpntFactorNumSolve")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6483 == std::string ("simPrimalHotstartNumBasics")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6483 == std::string ("simPrimalHotstartBasisRank")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6483 == std::string ("simDualHotstartNumBasics")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6483 == std::string ("simDualHotstartBasisRank")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6483 == std::string ("intpntGpOrderEmployed")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6483 == std::string ("numLuFactorizations")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6483 == std::string ("simPrimalTrust")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6483 == std::string ("simDualTrust")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6483 == std::string ("simPrimalNumSetbacks")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6483 == std::string ("simDualNumSetbacks")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6483 == std::string ("simNumDupvec")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6483 == std::string ("simNumPrimalBoundswaps")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6483 == std::string ("simNumDualBoundswaps")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6483 == std::string ("simNumDualIntegerPivots")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6483 == std::string ("biPrimalInfo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6483 == std::string ("biDualInfo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6483 == std::string ("presolveLindepNumTruncTries")))
  {
    {
      return (int)57;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_variabletype_value(const std::string & _6484){
  if ((_6484 == std::string ("typeCont")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6484 == std::string ("typeInt")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_uplo_value(const std::string & _6485){
  if ((_6485 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6485 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_language_value(const std::string & _6486){
  if ((_6486 == std::string ("eng")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6486 == std::string ("dan")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_dinf_value(const std::string & _6487){
  if ((_6487 == std::string ("sensitivityPrimalTime")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6487 == std::string ("sensitivityDualTime")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6487 == std::string ("intpntGfeas")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6487 == std::string ("intpntMu")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6487 == std::string ("intpntInitIterTime")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorTime")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6487 == std::string ("intpntInitSearchTime")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFormSearchTime")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6487 == std::string ("intpntUpdateTime")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSetupTime")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSchurTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorHatSchurTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorHatSchurPushTime")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorHatSchurPullTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorBarSchurTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorBarSchurDeTabTime")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorBarSchurSpTabTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSparseLTime")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSparseLUpdateLastTime")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSparseLFactorLastTime")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseLTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseTime")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotaTime")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotaSolveTime")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotatdotaTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotlInitTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotlFactorTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6487 == std::string ("intpntIterNonCorrectorFlops")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6487 == std::string ("intpntIterOneCorrectorFlops")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6487 == std::string ("intpntSolveTime")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6487 == std::string ("intpntIterRefTime")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6487 == std::string ("intpntSolveSparseLTime")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6487 == std::string ("intpntSolveDenseLTime")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSetupFlops")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSetupHatSchurFlops")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSchurFlops")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorHatSchurFlops")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorHatSchurPushFlops")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorHatSchurPullFlops")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorBarSchurFlops")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSparseLFlops")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorMlOrderSparseLFlops")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorGpOrderSparseLFlops")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSparseLUpdateLastFlops")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSparseLFactorLastFlops")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseLFlops")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseFlops")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotaFlops")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotatdotaFlops")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotlFactor_initFlops")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotlFactorFlops")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotl11FactorFlops")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotl21FactorFlops")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorDenseDotl22FactorFlops")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6487 == std::string ("presolveAcoltTime")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6487 == std::string ("presolveSetupTime")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6487 == std::string ("presolveCheckproTime")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6487 == std::string ("presolveDupconTime")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6487 == std::string ("presolveDupvarTime")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6487 == std::string ("presolveFinalTime")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6487 == std::string ("presolveSubDomvarTime")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6487 == std::string ("presolveSubRelaxTime")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6487 == std::string ("primalSimplexInftime")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6487 == std::string ("dualSimplexInftime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6487 == std::string ("intpntGpOrderSavedFlops")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSetupDetectDenseTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSetupMlOrderTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6487 == std::string ("intpntFactorSetupGpOrderTime")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6487 == std::string ("biCrashTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6487 == std::string ("biCrashLuTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6487 == std::string ("biFactorTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6487 == std::string ("biFactorWork")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6487 == std::string ("biPrimalDone")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6487 == std::string ("biDualDone")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6487 == std::string ("simPrimalObj")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6487 == std::string ("simPrimalFeas")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6487 == std::string ("simDualObj")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6487 == std::string ("simDualFeas")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6487 == std::string ("biPrimalObj")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6487 == std::string ("biDualObj")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6487 == std::string ("biPrimalFeas")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6487 == std::string ("biDualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6487 == std::string ("intpntPurifyTime")))
  {
    {
      return (int)63;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sensitivitytype_value(const std::string & _6488){
  if ((_6488 == std::string ("basis")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_prosta_value(const std::string & _6489){
  if ((_6489 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6489 == std::string ("primAndDualFeas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6489 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6489 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6489 == std::string ("primInfeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6489 == std::string ("dualInfeas")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6489 == std::string ("primAndDualInfeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6489 == std::string ("illPosed")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6489 == std::string ("primInfeasOrUnbounded")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sparam_value(const std::string & _6490){
  if ((_6490 == std::string ("dataFileName")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6490 == std::string ("paramReadFileName")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6490 == std::string ("paramWriteFileName")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6490 == std::string ("paramCommentSign")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6490 == std::string ("debugFileName")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6490 == std::string ("basSolFileName")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6490 == std::string ("itrSolFileName")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6490 == std::string ("intSolFileName")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6490 == std::string ("solFilterXcLow")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6490 == std::string ("solFilterXcUpr")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6490 == std::string ("solFilterXxLow")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6490 == std::string ("solFilterXxUpr")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6490 == std::string ("readMpsObjName")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6490 == std::string ("readMpsRanName")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6490 == std::string ("readMpsRhsName")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6490 == std::string ("readMpsBouName")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6490 == std::string ("statFileName")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6490 == std::string ("statName")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6490 == std::string ("statKey")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6490 == std::string ("writeLpGenVarName")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6490 == std::string ("sensitivityResFileName")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6490 == std::string ("sensitivityFileName")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6490 == std::string ("mioDebugString")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6490 == std::string ("remoteAccessToken")))
  {
    {
      return (int)13;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iomode_value(const std::string & _6491){
  if ((_6491 == std::string ("read")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6491 == std::string ("write")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6491 == std::string ("readwrite")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_branchdir_value(const std::string & _6492){
  if ((_6492 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6492 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6492 == std::string ("down")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6492 == std::string ("near")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6492 == std::string ("far")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6492 == std::string ("rootLp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6492 == std::string ("guided")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6492 == std::string ("pseudocost")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miocontsoltype_value(const std::string & _6493){
  if ((_6493 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6493 == std::string ("root")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6493 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6493 == std::string ("itgRel")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_basindtype_value(const std::string & _6494){
  if ((_6494 == std::string ("never")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6494 == std::string ("always")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6494 == std::string ("noError")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6494 == std::string ("ifFeasible")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6494 == std::string ("reservered")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_xmlwriteroutputtype_value(const std::string & _6495){
  if ((_6495 == std::string ("row")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6495 == std::string ("col")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_optimizertype_value(const std::string & _6496){
  if ((_6496 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6496 == std::string ("intpnt")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6496 == std::string ("conic")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6496 == std::string ("primalSimplex")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6496 == std::string ("dualSimplex")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6496 == std::string ("freeSimplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6496 == std::string ("mixedInt")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdegen_value(const std::string & _6497){
  if ((_6497 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6497 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6497 == std::string ("aggressive")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6497 == std::string ("moderate")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6497 == std::string ("minimum")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_orderingtype_value(const std::string & _6498){
  if ((_6498 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6498 == std::string ("appminloc")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6498 == std::string ("experimental")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6498 == std::string ("tryGraphpar")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6498 == std::string ("forceGraphpar")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6498 == std::string ("none")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemtype_value(const std::string & _6499){
  if ((_6499 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6499 == std::string ("qo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6499 == std::string ("qcqo")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6499 == std::string ("conic")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6499 == std::string ("mixed")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescodetype_value(const std::string & _6500){
  if ((_6500 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6500 == std::string ("wrn")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6500 == std::string ("trm")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6500 == std::string ("err")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6500 == std::string ("unk")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_purify_value(const std::string & _6501){
  if ((_6501 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6501 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6501 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6501 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6501 == std::string ("auto")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mpsformat_value(const std::string & _6502){
  if ((_6502 == std::string ("strict")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6502 == std::string ("relaxed")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6502 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6502 == std::string ("cplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemitem_value(const std::string & _6503){
  if ((_6503 == std::string ("var")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6503 == std::string ("con")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6503 == std::string ("cone")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_liinf_value(const std::string & _6504){
  if ((_6504 == std::string ("intpntLenbarvar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6504 == std::string ("intpntFactorNumNzBefore")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6504 == std::string ("intpntFactorNumNzAfter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6504 == std::string ("intpntFactorMlOrderSparseLNz")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6504 == std::string ("intpntFactorGpOrderSparseLNz")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6504 == std::string ("presolveStackSize")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6504 == std::string ("intpntFactorVNz")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6504 == std::string ("intpntFactorUpdatedVNz")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_onoffkey_value(const std::string & _6505){
  if ((_6505 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6505 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_liinfitem_value(const std::string & _6506){
  if ((_6506 == std::string ("mioAnz")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6506 == std::string ("mioPresolvedAnz")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6506 == std::string ("mioSimplexIter")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6506 == std::string ("mioIntpntIter")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6506 == std::string ("biPrimalIter")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6506 == std::string ("biDualIter")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6506 == std::string ("biCleanPrimalIter")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6506 == std::string ("biCleanDualIter")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6506 == std::string ("biCleanPrimalDegIter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6506 == std::string ("biCleanDualDegIter")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6506 == std::string ("intpntFactorNumNz")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6506 == std::string ("rdNumanz")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6506 == std::string ("rdNumqnz")))
  {
    {
      return (int)12;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iparam_value(const std::string & _6507){
  if ((_6507 == std::string ("autoUpdateSolInfo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6507 == std::string ("removeUnusedSolutions")))
  {
    {
      return (int)117;
    }
  }
  {}
  if ((_6507 == std::string ("intpntHotstart")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6507 == std::string ("intpntPurify")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6507 == std::string ("numThreads")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6507 == std::string ("intpntMultiThread")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6507 == std::string ("timingLevel")))
  {
    {
      return (int)151;
    }
  }
  {}
  if ((_6507 == std::string ("mtSpincount")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6507 == std::string ("maxNumWarnings")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6507 == std::string ("optimizer")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6507 == std::string ("biMaxIterations")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6507 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6507 == std::string ("logCutSecondOpt")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6507 == std::string ("logAnaPro")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6507 == std::string ("logResponse")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6507 == std::string ("logLocalInfo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6507 == std::string ("logBi")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6507 == std::string ("logBiFreq")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6507 == std::string ("biCleanOptimizer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6507 == std::string ("intpntMaxNumRefinementSteps")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6507 == std::string ("intpntStartingPoint")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6507 == std::string ("intpntDiffStep")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6507 == std::string ("intpntScaling")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6507 == std::string ("intpntSolveForm")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6507 == std::string ("logIntpnt")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6507 == std::string ("intpntMaxIterations")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6507 == std::string ("intpntOffColTrh")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6507 == std::string ("intpntOrderMethod")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6507 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6507 == std::string ("intpntBasis")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6507 == std::string ("biIgnoreMaxIter")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6507 == std::string ("biIgnoreNumError")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6507 == std::string ("intpntMaxNumCor")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6507 == std::string ("presolveUse")))
  {
    {
      return (int)107;
    }
  }
  {}
  if ((_6507 == std::string ("presolveLevel")))
  {
    {
      return (int)101;
    }
  }
  {}
  if ((_6507 == std::string ("logPresolve")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6507 == std::string ("presolveLindepUse")))
  {
    {
      return (int)104;
    }
  }
  {}
  if ((_6507 == std::string ("presolveMaxNumPass")))
  {
    {
      return (int)105;
    }
  }
  {}
  if ((_6507 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6507 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6507 == std::string ("presolveMaxNumReductions")))
  {
    {
      return (int)106;
    }
  }
  {}
  if ((_6507 == std::string ("simStabilityPriority")))
  {
    {
      return (int)144;
    }
  }
  {}
  if ((_6507 == std::string ("simPrimalCrash")))
  {
    {
      return (int)133;
    }
  }
  {}
  if ((_6507 == std::string ("logSim")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6507 == std::string ("logSimMinor")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6507 == std::string ("logSimFreq")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6507 == std::string ("simPrimalRestrictSelection")))
  {
    {
      return (int)135;
    }
  }
  {}
  if ((_6507 == std::string ("simPrimalSelection")))
  {
    {
      return (int)136;
    }
  }
  {}
  if ((_6507 == std::string ("simDualRestrictSelection")))
  {
    {
      return (int)125;
    }
  }
  {}
  if ((_6507 == std::string ("simDualSelection")))
  {
    {
      return (int)126;
    }
  }
  {}
  if ((_6507 == std::string ("simMaxIterations")))
  {
    {
      return (int)130;
    }
  }
  {}
  if ((_6507 == std::string ("simHotstartLu")))
  {
    {
      return (int)129;
    }
  }
  {}
  if ((_6507 == std::string ("simRefactorFreq")))
  {
    {
      return (int)137;
    }
  }
  {}
  if ((_6507 == std::string ("simSeed")))
  {
    {
      return (int)142;
    }
  }
  {}
  if ((_6507 == std::string ("mioMode")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6507 == std::string ("logMio")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6507 == std::string ("logMioFreq")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6507 == std::string ("mioMaxNumRelaxs")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6507 == std::string ("mioMaxNumBranches")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6507 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6507 == std::string ("mioMaxNumSolutions")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6507 == std::string ("mioNodeSelection")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6507 == std::string ("mioHeuristicLevel")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6507 == std::string ("mioProbingLevel")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6507 == std::string ("mioCutSelectionLevel")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6507 == std::string ("mioVbDetectionLevel")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6507 == std::string ("mioBranchDir")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6507 == std::string ("mioRootOptimizer")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6507 == std::string ("mioNodeOptimizer")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6507 == std::string ("mioPerspectiveReformulate")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6507 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6507 == std::string ("mioSeed")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6507 == std::string ("mioConicOuterApproximation")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6507 == std::string ("readKeepFreeCon")))
  {
    {
      return (int)111;
    }
  }
  {}
  if ((_6507 == std::string ("readMpsFormat")))
  {
    {
      return (int)114;
    }
  }
  {}
  if ((_6507 == std::string ("writeMpsFormat")))
  {
    {
      return (int)169;
    }
  }
  {}
  if ((_6507 == std::string ("readMpsWidth")))
  {
    {
      return (int)115;
    }
  }
  {}
  if ((_6507 == std::string ("readDebug")))
  {
    {
      return (int)110;
    }
  }
  {}
  if ((_6507 == std::string ("readLpQuotedNames")))
  {
    {
      return (int)113;
    }
  }
  {}
  if ((_6507 == std::string ("writeDataParam")))
  {
    {
      return (int)156;
    }
  }
  {}
  if ((_6507 == std::string ("writeFreeCon")))
  {
    {
      return (int)157;
    }
  }
  {}
  if ((_6507 == std::string ("writeGenericNames")))
  {
    {
      return (int)158;
    }
  }
  {}
  if ((_6507 == std::string ("writeGenericNamesIo")))
  {
    {
      return (int)159;
    }
  }
  {}
  if ((_6507 == std::string ("writeCompression")))
  {
    {
      return (int)155;
    }
  }
  {}
  if ((_6507 == std::string ("writeMpsInt")))
  {
    {
      return (int)170;
    }
  }
  {}
  if ((_6507 == std::string ("writeLpStrictFormat")))
  {
    {
      return (int)167;
    }
  }
  {}
  if ((_6507 == std::string ("writeLpQuotedNames")))
  {
    {
      return (int)166;
    }
  }
  {}
  if ((_6507 == std::string ("writeLpLineWidth")))
  {
    {
      return (int)165;
    }
  }
  {}
  if ((_6507 == std::string ("writeLpTermsPerLine")))
  {
    {
      return (int)168;
    }
  }
  {}
  if ((_6507 == std::string ("writeLpFullObj")))
  {
    {
      return (int)164;
    }
  }
  {}
  if ((_6507 == std::string ("writePrecision")))
  {
    {
      return (int)171;
    }
  }
  {}
  if ((_6507 == std::string ("writeSolIgnoreInvalidNames")))
  {
    {
      return (int)175;
    }
  }
  {}
  if ((_6507 == std::string ("writeSolHead")))
  {
    {
      return (int)174;
    }
  }
  {}
  if ((_6507 == std::string ("writeSolConstraints")))
  {
    {
      return (int)173;
    }
  }
  {}
  if ((_6507 == std::string ("writeSolVariables")))
  {
    {
      return (int)176;
    }
  }
  {}
  if ((_6507 == std::string ("writeSolBarvariables")))
  {
    {
      return (int)172;
    }
  }
  {}
  if ((_6507 == std::string ("writeBasHead")))
  {
    {
      return (int)153;
    }
  }
  {}
  if ((_6507 == std::string ("writeBasConstraints")))
  {
    {
      return (int)152;
    }
  }
  {}
  if ((_6507 == std::string ("writeBasVariables")))
  {
    {
      return (int)154;
    }
  }
  {}
  if ((_6507 == std::string ("writeIntHead")))
  {
    {
      return (int)162;
    }
  }
  {}
  if ((_6507 == std::string ("writeIntConstraints")))
  {
    {
      return (int)161;
    }
  }
  {}
  if ((_6507 == std::string ("writeIntVariables")))
  {
    {
      return (int)163;
    }
  }
  {}
  if ((_6507 == std::string ("solReadNameWidth")))
  {
    {
      return (int)148;
    }
  }
  {}
  if ((_6507 == std::string ("solReadWidth")))
  {
    {
      return (int)149;
    }
  }
  {}
  if ((_6507 == std::string ("infeasReportAuto")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6507 == std::string ("infeasReportLevel")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6507 == std::string ("infeasGenericNames")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6507 == std::string ("logInfeasAna")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6507 == std::string ("licenseWait")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6507 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6507 == std::string ("licensePauseTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6507 == std::string ("licenseDebug")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6507 == std::string ("solFilterKeepBasic")))
  {
    {
      return (int)146;
    }
  }
  {}
  if ((_6507 == std::string ("solFilterKeepRanged")))
  {
    {
      return (int)147;
    }
  }
  {}
  if ((_6507 == std::string ("log")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6507 == std::string ("logExpand")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6507 == std::string ("logFile")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6507 == std::string ("logOrder")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6507 == std::string ("logSensitivity")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6507 == std::string ("logSensitivityOpt")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6507 == std::string ("readTaskIgnoreParam")))
  {
    {
      return (int)116;
    }
  }
  {}
  if ((_6507 == std::string ("writeTaskIncSol")))
  {
    {
      return (int)177;
    }
  }
  {}
  if ((_6507 == std::string ("paramReadCaseName")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6507 == std::string ("paramReadIgnError")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6507 == std::string ("solutionCallback")))
  {
    {
      return (int)150;
    }
  }
  {}
  if ((_6507 == std::string ("simScaling")))
  {
    {
      return (int)140;
    }
  }
  {}
  if ((_6507 == std::string ("simScalingMethod")))
  {
    {
      return (int)141;
    }
  }
  {}
  if ((_6507 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      return (int)134;
    }
  }
  {}
  if ((_6507 == std::string ("simDualPhaseoneMethod")))
  {
    {
      return (int)124;
    }
  }
  {}
  if ((_6507 == std::string ("simMaxNumSetbacks")))
  {
    {
      return (int)131;
    }
  }
  {}
  if ((_6507 == std::string ("simHotstart")))
  {
    {
      return (int)128;
    }
  }
  {}
  if ((_6507 == std::string ("simBasisFactorUse")))
  {
    {
      return (int)121;
    }
  }
  {}
  if ((_6507 == std::string ("simDegen")))
  {
    {
      return (int)122;
    }
  }
  {}
  if ((_6507 == std::string ("simReformulation")))
  {
    {
      return (int)138;
    }
  }
  {}
  if ((_6507 == std::string ("simExploitDupvec")))
  {
    {
      return (int)127;
    }
  }
  {}
  if ((_6507 == std::string ("simSaveLu")))
  {
    {
      return (int)139;
    }
  }
  {}
  if ((_6507 == std::string ("simNonSingular")))
  {
    {
      return (int)132;
    }
  }
  {}
  if ((_6507 == std::string ("simDualCrash")))
  {
    {
      return (int)123;
    }
  }
  {}
  if ((_6507 == std::string ("logStorage")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6507 == std::string ("infeasPreferPrimal")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6507 == std::string ("readLpDropNewVarsInBou")))
  {
    {
      return (int)112;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteLineLength")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteHints")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteParameters")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteProblem")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteHeader")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteSolutions")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteSolBas")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteSolItg")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6507 == std::string ("opfWriteSolItr")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6507 == std::string ("ptfWriteTransform")))
  {
    {
      return (int)109;
    }
  }
  {}
  if ((_6507 == std::string ("primalRepairOptimizer")))
  {
    {
      return (int)108;
    }
  }
  {}
  if ((_6507 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6507 == std::string ("mioCutCmir")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6507 == std::string ("mioCutClique")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6507 == std::string ("mioCutImpliedBound")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6507 == std::string ("mioCutKnapsackCover")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6507 == std::string ("mioCutGmi")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6507 == std::string ("sensitivityType")))
  {
    {
      return (int)120;
    }
  }
  {}
  if ((_6507 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      return (int)103;
    }
  }
  {}
  if ((_6507 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      return (int)102;
    }
  }
  {}
  if ((_6507 == std::string ("sensitivityAll")))
  {
    {
      return (int)118;
    }
  }
  {}
  if ((_6507 == std::string ("logFeasRepair")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6507 == std::string ("cacheLicense")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6507 == std::string ("intpntRegularizationUse")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6507 == std::string ("simSolveForm")))
  {
    {
      return (int)143;
    }
  }
  {}
  if ((_6507 == std::string ("simSwitchOptimizer")))
  {
    {
      return (int)145;
    }
  }
  {}
  if ((_6507 == std::string ("writeIgnoreIncompatibleItems")))
  {
    {
      return (int)160;
    }
  }
  {}
  if ((_6507 == std::string ("checkConvexity")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6507 == std::string ("logCheckConvexity")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6507 == std::string ("autoSortABeforeOpt")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6507 == std::string ("sensitivityOptimizer")))
  {
    {
      return (int)119;
    }
  }
  {}
  if ((_6507 == std::string ("writeXmlMode")))
  {
    {
      return (int)178;
    }
  }
  {}
  if ((_6507 == std::string ("anaSolBasis")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6507 == std::string ("anaSolPrintViolated")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6507 == std::string ("basisSolveUsePlusOne")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6507 == std::string ("compressStatfile")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6507 == std::string ("mioRinsMaxNodes")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6507 == std::string ("mioFeaspumpLevel")))
  {
    {
      return (int)68;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_intpnthotstart_value(const std::string & _6508){
  if ((_6508 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6508 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6508 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6508 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iinfitem_value(const std::string & _6509){
  if ((_6509 == std::string ("anaProNumCon")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumConLo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumConUp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumConRa")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumConEq")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumConFr")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarLo")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarUp")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarRa")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarEq")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarFr")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarCont")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarBin")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6509 == std::string ("anaProNumVarInt")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6509 == std::string ("optimizeResponse")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6509 == std::string ("intpntIter")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6509 == std::string ("intpntFactorDimDense")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6509 == std::string ("intpntSolveDual")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6509 == std::string ("mioNodeDepth")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumbin")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumint")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumcont")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumcon")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumcone")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumqcones")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumrqcones")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumpexpcones")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumdexpcones")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumppowcones")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumdpowcones")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumconevar")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumbinconevar")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumintconevar")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumcontconevar")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumvar")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumbin")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumint")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumcont")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumcon")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumcone")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumqcones")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumrqcones")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumpexpcones")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumdexpcones")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumppowcones")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumdpowcones")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumconevar")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumbinconevar")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumintconevar")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6509 == std::string ("mioPresolvedNumcontconevar")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6509 == std::string ("mioCliqueTableSize")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6509 == std::string ("mioConstructSolution")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumIntSolutions")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6509 == std::string ("mioObjBoundDefined")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumActiveNodes")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumRelax")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumBranch")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6509 == std::string ("mioTotalNumCuts")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumCmirCuts")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumCliqueCuts")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumImpliedBoundCuts")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumKnapsackCoverCuts")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumGomoryCuts")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6509 == std::string ("mioNumRepeatedPresolve")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6509 == std::string ("mioUserObjCut")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6509 == std::string ("mioRelgapSatisfied")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6509 == std::string ("mioAbsgapSatisfied")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6509 == std::string ("rdProtype")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6509 == std::string ("rdNumcon")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6509 == std::string ("rdNumvar")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6509 == std::string ("rdNumbarvar")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6509 == std::string ("rdNumintvar")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6509 == std::string ("rdNumq")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6509 == std::string ("simDualDegIter")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6509 == std::string ("simDualInfIter")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6509 == std::string ("simDualHotstartLu")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6509 == std::string ("simPrimalIter")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6509 == std::string ("simDualIter")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6509 == std::string ("intpntNumThreads")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6509 == std::string ("simPrimalInfIter")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6509 == std::string ("simPrimalDegIter")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6509 == std::string ("simPrimalHotstart")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6509 == std::string ("simPrimalHotstartLu")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6509 == std::string ("simDualHotstart")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6509 == std::string ("solItrProsta")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6509 == std::string ("solItrSolsta")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6509 == std::string ("solBasProsta")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6509 == std::string ("solBasSolsta")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6509 == std::string ("solItgProsta")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6509 == std::string ("solItgSolsta")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6509 == std::string ("simNumcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6509 == std::string ("simNumvar")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6509 == std::string ("optNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6509 == std::string ("optNumvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6509 == std::string ("stoNumARealloc")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6509 == std::string ("rdNumcone")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6509 == std::string ("simSolveDual")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6509 == std::string ("purifyPrimalSuccess")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6509 == std::string ("purifyDualSuccess")))
  {
    {
      return (int)72;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescode_value(const std::string & _6510){
  if ((_6510 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6510 == std::string ("wrnOpenParamFile")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLargeBound")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLargeLoBound")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLargeUpBound")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLargeConFx")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLargeCj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLargeAij")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6510 == std::string ("wrnZeroAij")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6510 == std::string ("wrnNameMaxLen")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6510 == std::string ("wrnSparMaxLen")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6510 == std::string ("wrnMpsSplitRhsVector")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6510 == std::string ("wrnMpsSplitRanVector")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6510 == std::string ("wrnMpsSplitBouVector")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLpOldQuadFormat")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLpDropVariable")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6510 == std::string ("wrnNzInUprTri")))
  {
    {
      return (int)200;
    }
  }
  {}
  if ((_6510 == std::string ("wrnDroppedNzQobj")))
  {
    {
      return (int)201;
    }
  }
  {}
  if ((_6510 == std::string ("wrnIgnoreInteger")))
  {
    {
      return (int)250;
    }
  }
  {}
  if ((_6510 == std::string ("wrnNoGlobalOptimizer")))
  {
    {
      return (int)251;
    }
  }
  {}
  if ((_6510 == std::string ("wrnMioInfeasibleFinal")))
  {
    {
      return (int)270;
    }
  }
  {}
  if ((_6510 == std::string ("wrnSolFilter")))
  {
    {
      return (int)300;
    }
  }
  {}
  if ((_6510 == std::string ("wrnUndefSolFileName")))
  {
    {
      return (int)350;
    }
  }
  {}
  if ((_6510 == std::string ("wrnSolFileIgnoredCon")))
  {
    {
      return (int)351;
    }
  }
  {}
  if ((_6510 == std::string ("wrnSolFileIgnoredVar")))
  {
    {
      return (int)352;
    }
  }
  {}
  if ((_6510 == std::string ("wrnTooFewBasisVars")))
  {
    {
      return (int)400;
    }
  }
  {}
  if ((_6510 == std::string ("wrnTooManyBasisVars")))
  {
    {
      return (int)405;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLicenseExpire")))
  {
    {
      return (int)500;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLicenseServer")))
  {
    {
      return (int)501;
    }
  }
  {}
  if ((_6510 == std::string ("wrnEmptyName")))
  {
    {
      return (int)502;
    }
  }
  {}
  if ((_6510 == std::string ("wrnUsingGenericNames")))
  {
    {
      return (int)503;
    }
  }
  {}
  if ((_6510 == std::string ("wrnLicenseFeatureExpire")))
  {
    {
      return (int)505;
    }
  }
  {}
  if ((_6510 == std::string ("wrnParamNameDou")))
  {
    {
      return (int)510;
    }
  }
  {}
  if ((_6510 == std::string ("wrnParamNameInt")))
  {
    {
      return (int)511;
    }
  }
  {}
  if ((_6510 == std::string ("wrnParamNameStr")))
  {
    {
      return (int)512;
    }
  }
  {}
  if ((_6510 == std::string ("wrnParamStrValue")))
  {
    {
      return (int)515;
    }
  }
  {}
  if ((_6510 == std::string ("wrnParamIgnoredCmio")))
  {
    {
      return (int)516;
    }
  }
  {}
  if ((_6510 == std::string ("wrnZerosInSparseRow")))
  {
    {
      return (int)705;
    }
  }
  {}
  if ((_6510 == std::string ("wrnZerosInSparseCol")))
  {
    {
      return (int)710;
    }
  }
  {}
  if ((_6510 == std::string ("wrnIncompleteLinearDependencyCheck")))
  {
    {
      return (int)800;
    }
  }
  {}
  if ((_6510 == std::string ("wrnEliminatorSpace")))
  {
    {
      return (int)801;
    }
  }
  {}
  if ((_6510 == std::string ("wrnPresolveOutofspace")))
  {
    {
      return (int)802;
    }
  }
  {}
  if ((_6510 == std::string ("wrnWriteChangedNames")))
  {
    {
      return (int)803;
    }
  }
  {}
  if ((_6510 == std::string ("wrnWriteDiscardedCfix")))
  {
    {
      return (int)804;
    }
  }
  {}
  if ((_6510 == std::string ("wrnDuplicateConstraintNames")))
  {
    {
      return (int)850;
    }
  }
  {}
  if ((_6510 == std::string ("wrnDuplicateVariableNames")))
  {
    {
      return (int)851;
    }
  }
  {}
  if ((_6510 == std::string ("wrnDuplicateBarvariableNames")))
  {
    {
      return (int)852;
    }
  }
  {}
  if ((_6510 == std::string ("wrnDuplicateConeNames")))
  {
    {
      return (int)853;
    }
  }
  {}
  if ((_6510 == std::string ("wrnAnaLargeBounds")))
  {
    {
      return (int)900;
    }
  }
  {}
  if ((_6510 == std::string ("wrnAnaCZero")))
  {
    {
      return (int)901;
    }
  }
  {}
  if ((_6510 == std::string ("wrnAnaEmptyCols")))
  {
    {
      return (int)902;
    }
  }
  {}
  if ((_6510 == std::string ("wrnAnaCloseBounds")))
  {
    {
      return (int)903;
    }
  }
  {}
  if ((_6510 == std::string ("wrnAnaAlmostIntBounds")))
  {
    {
      return (int)904;
    }
  }
  {}
  if ((_6510 == std::string ("wrnQuadConesWithRootFixedAtZero")))
  {
    {
      return (int)930;
    }
  }
  {}
  if ((_6510 == std::string ("wrnRquadConesWithRootFixedAtZero")))
  {
    {
      return (int)931;
    }
  }
  {}
  if ((_6510 == std::string ("wrnExpConesWithVariablesFixedAtZero")))
  {
    {
      return (int)932;
    }
  }
  {}
  if ((_6510 == std::string ("wrnPowConesWithRootFixedAtZero")))
  {
    {
      return (int)933;
    }
  }
  {}
  if ((_6510 == std::string ("wrnNoDualizer")))
  {
    {
      return (int)950;
    }
  }
  {}
  if ((_6510 == std::string ("wrnSymMatLarge")))
  {
    {
      return (int)960;
    }
  }
  {}
  if ((_6510 == std::string ("errLicense")))
  {
    {
      return (int)1000;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseExpired")))
  {
    {
      return (int)1001;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseVersion")))
  {
    {
      return (int)1002;
    }
  }
  {}
  if ((_6510 == std::string ("errSizeLicense")))
  {
    {
      return (int)1005;
    }
  }
  {}
  if ((_6510 == std::string ("errProbLicense")))
  {
    {
      return (int)1006;
    }
  }
  {}
  if ((_6510 == std::string ("errFileLicense")))
  {
    {
      return (int)1007;
    }
  }
  {}
  if ((_6510 == std::string ("errMissingLicenseFile")))
  {
    {
      return (int)1008;
    }
  }
  {}
  if ((_6510 == std::string ("errSizeLicenseCon")))
  {
    {
      return (int)1010;
    }
  }
  {}
  if ((_6510 == std::string ("errSizeLicenseVar")))
  {
    {
      return (int)1011;
    }
  }
  {}
  if ((_6510 == std::string ("errSizeLicenseIntvar")))
  {
    {
      return (int)1012;
    }
  }
  {}
  if ((_6510 == std::string ("errOptimizerLicense")))
  {
    {
      return (int)1013;
    }
  }
  {}
  if ((_6510 == std::string ("errFlexlm")))
  {
    {
      return (int)1014;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseServer")))
  {
    {
      return (int)1015;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseMax")))
  {
    {
      return (int)1016;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseMoseklmDaemon")))
  {
    {
      return (int)1017;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseFeature")))
  {
    {
      return (int)1018;
    }
  }
  {}
  if ((_6510 == std::string ("errPlatformNotLicensed")))
  {
    {
      return (int)1019;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseCannotAllocate")))
  {
    {
      return (int)1020;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseCannotConnect")))
  {
    {
      return (int)1021;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseInvalidHostid")))
  {
    {
      return (int)1025;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseServerVersion")))
  {
    {
      return (int)1026;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseNoServerSupport")))
  {
    {
      return (int)1027;
    }
  }
  {}
  if ((_6510 == std::string ("errLicenseNoServerLine")))
  {
    {
      return (int)1028;
    }
  }
  {}
  if ((_6510 == std::string ("errOlderDll")))
  {
    {
      return (int)1035;
    }
  }
  {}
  if ((_6510 == std::string ("errNewerDll")))
  {
    {
      return (int)1036;
    }
  }
  {}
  if ((_6510 == std::string ("errLinkFileDll")))
  {
    {
      return (int)1040;
    }
  }
  {}
  if ((_6510 == std::string ("errThreadMutexInit")))
  {
    {
      return (int)1045;
    }
  }
  {}
  if ((_6510 == std::string ("errThreadMutexLock")))
  {
    {
      return (int)1046;
    }
  }
  {}
  if ((_6510 == std::string ("errThreadMutexUnlock")))
  {
    {
      return (int)1047;
    }
  }
  {}
  if ((_6510 == std::string ("errThreadCreate")))
  {
    {
      return (int)1048;
    }
  }
  {}
  if ((_6510 == std::string ("errThreadCondInit")))
  {
    {
      return (int)1049;
    }
  }
  {}
  if ((_6510 == std::string ("errUnknown")))
  {
    {
      return (int)1050;
    }
  }
  {}
  if ((_6510 == std::string ("errSpace")))
  {
    {
      return (int)1051;
    }
  }
  {}
  if ((_6510 == std::string ("errFileOpen")))
  {
    {
      return (int)1052;
    }
  }
  {}
  if ((_6510 == std::string ("errFileRead")))
  {
    {
      return (int)1053;
    }
  }
  {}
  if ((_6510 == std::string ("errFileWrite")))
  {
    {
      return (int)1054;
    }
  }
  {}
  if ((_6510 == std::string ("errDataFileExt")))
  {
    {
      return (int)1055;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFileName")))
  {
    {
      return (int)1056;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidSolFileName")))
  {
    {
      return (int)1057;
    }
  }
  {}
  if ((_6510 == std::string ("errEndOfFile")))
  {
    {
      return (int)1059;
    }
  }
  {}
  if ((_6510 == std::string ("errNullEnv")))
  {
    {
      return (int)1060;
    }
  }
  {}
  if ((_6510 == std::string ("errNullTask")))
  {
    {
      return (int)1061;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidStream")))
  {
    {
      return (int)1062;
    }
  }
  {}
  if ((_6510 == std::string ("errNoInitEnv")))
  {
    {
      return (int)1063;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidTask")))
  {
    {
      return (int)1064;
    }
  }
  {}
  if ((_6510 == std::string ("errNullPointer")))
  {
    {
      return (int)1065;
    }
  }
  {}
  if ((_6510 == std::string ("errLivingTasks")))
  {
    {
      return (int)1066;
    }
  }
  {}
  if ((_6510 == std::string ("errBlankName")))
  {
    {
      return (int)1070;
    }
  }
  {}
  if ((_6510 == std::string ("errDupName")))
  {
    {
      return (int)1071;
    }
  }
  {}
  if ((_6510 == std::string ("errFormatString")))
  {
    {
      return (int)1072;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidObjName")))
  {
    {
      return (int)1075;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidConName")))
  {
    {
      return (int)1076;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidVarName")))
  {
    {
      return (int)1077;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidConeName")))
  {
    {
      return (int)1078;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidBarvarName")))
  {
    {
      return (int)1079;
    }
  }
  {}
  if ((_6510 == std::string ("errSpaceLeaking")))
  {
    {
      return (int)1080;
    }
  }
  {}
  if ((_6510 == std::string ("errSpaceNoInfo")))
  {
    {
      return (int)1081;
    }
  }
  {}
  if ((_6510 == std::string ("errReadFormat")))
  {
    {
      return (int)1090;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsFile")))
  {
    {
      return (int)1100;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvField")))
  {
    {
      return (int)1101;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvMarker")))
  {
    {
      return (int)1102;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsNullConName")))
  {
    {
      return (int)1103;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsNullVarName")))
  {
    {
      return (int)1104;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsUndefConName")))
  {
    {
      return (int)1105;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsUndefVarName")))
  {
    {
      return (int)1106;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvConKey")))
  {
    {
      return (int)1107;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvBoundKey")))
  {
    {
      return (int)1108;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvSecName")))
  {
    {
      return (int)1109;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsNoObjective")))
  {
    {
      return (int)1110;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsSplittedVar")))
  {
    {
      return (int)1111;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsMulConName")))
  {
    {
      return (int)1112;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsMulQsec")))
  {
    {
      return (int)1113;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsMulQobj")))
  {
    {
      return (int)1114;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvSecOrder")))
  {
    {
      return (int)1115;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsMulCsec")))
  {
    {
      return (int)1116;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsConeType")))
  {
    {
      return (int)1117;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsConeOverlap")))
  {
    {
      return (int)1118;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsConeRepeat")))
  {
    {
      return (int)1119;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsNonSymmetricQ")))
  {
    {
      return (int)1120;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsDuplicateQElement")))
  {
    {
      return (int)1121;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvalidObjsense")))
  {
    {
      return (int)1122;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsTabInField2")))
  {
    {
      return (int)1125;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsTabInField3")))
  {
    {
      return (int)1126;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsTabInField5")))
  {
    {
      return (int)1127;
    }
  }
  {}
  if ((_6510 == std::string ("errMpsInvalidObjName")))
  {
    {
      return (int)1128;
    }
  }
  {}
  if ((_6510 == std::string ("errLpIncompatible")))
  {
    {
      return (int)1150;
    }
  }
  {}
  if ((_6510 == std::string ("errLpEmpty")))
  {
    {
      return (int)1151;
    }
  }
  {}
  if ((_6510 == std::string ("errLpDupSlackName")))
  {
    {
      return (int)1152;
    }
  }
  {}
  if ((_6510 == std::string ("errWriteMpsInvalidName")))
  {
    {
      return (int)1153;
    }
  }
  {}
  if ((_6510 == std::string ("errLpInvalidVarName")))
  {
    {
      return (int)1154;
    }
  }
  {}
  if ((_6510 == std::string ("errLpFreeConstraint")))
  {
    {
      return (int)1155;
    }
  }
  {}
  if ((_6510 == std::string ("errWriteOpfInvalidVarName")))
  {
    {
      return (int)1156;
    }
  }
  {}
  if ((_6510 == std::string ("errLpFileFormat")))
  {
    {
      return (int)1157;
    }
  }
  {}
  if ((_6510 == std::string ("errWriteLpFormat")))
  {
    {
      return (int)1158;
    }
  }
  {}
  if ((_6510 == std::string ("errReadLpMissingEndTag")))
  {
    {
      return (int)1159;
    }
  }
  {}
  if ((_6510 == std::string ("errLpFormat")))
  {
    {
      return (int)1160;
    }
  }
  {}
  if ((_6510 == std::string ("errWriteLpNonUniqueName")))
  {
    {
      return (int)1161;
    }
  }
  {}
  if ((_6510 == std::string ("errReadLpNonexistingName")))
  {
    {
      return (int)1162;
    }
  }
  {}
  if ((_6510 == std::string ("errLpWriteConicProblem")))
  {
    {
      return (int)1163;
    }
  }
  {}
  if ((_6510 == std::string ("errLpWriteGecoProblem")))
  {
    {
      return (int)1164;
    }
  }
  {}
  if ((_6510 == std::string ("errWritingFile")))
  {
    {
      return (int)1166;
    }
  }
  {}
  if ((_6510 == std::string ("errPtfFormat")))
  {
    {
      return (int)1167;
    }
  }
  {}
  if ((_6510 == std::string ("errOpfFormat")))
  {
    {
      return (int)1168;
    }
  }
  {}
  if ((_6510 == std::string ("errOpfNewVariable")))
  {
    {
      return (int)1169;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidNameInSolFile")))
  {
    {
      return (int)1170;
    }
  }
  {}
  if ((_6510 == std::string ("errLpInvalidConName")))
  {
    {
      return (int)1171;
    }
  }
  {}
  if ((_6510 == std::string ("errOpfPrematureEof")))
  {
    {
      return (int)1172;
    }
  }
  {}
  if ((_6510 == std::string ("errJsonSyntax")))
  {
    {
      return (int)1175;
    }
  }
  {}
  if ((_6510 == std::string ("errJsonString")))
  {
    {
      return (int)1176;
    }
  }
  {}
  if ((_6510 == std::string ("errJsonNumberOverflow")))
  {
    {
      return (int)1177;
    }
  }
  {}
  if ((_6510 == std::string ("errJsonFormat")))
  {
    {
      return (int)1178;
    }
  }
  {}
  if ((_6510 == std::string ("errJsonData")))
  {
    {
      return (int)1179;
    }
  }
  {}
  if ((_6510 == std::string ("errJsonMissingData")))
  {
    {
      return (int)1180;
    }
  }
  {}
  if ((_6510 == std::string ("errArgumentLenneq")))
  {
    {
      return (int)1197;
    }
  }
  {}
  if ((_6510 == std::string ("errArgumentType")))
  {
    {
      return (int)1198;
    }
  }
  {}
  if ((_6510 == std::string ("errNumArguments")))
  {
    {
      return (int)1199;
    }
  }
  {}
  if ((_6510 == std::string ("errInArgument")))
  {
    {
      return (int)1200;
    }
  }
  {}
  if ((_6510 == std::string ("errArgumentDimension")))
  {
    {
      return (int)1201;
    }
  }
  {}
  if ((_6510 == std::string ("errShapeIsTooLarge")))
  {
    {
      return (int)1202;
    }
  }
  {}
  if ((_6510 == std::string ("errIndexIsTooSmall")))
  {
    {
      return (int)1203;
    }
  }
  {}
  if ((_6510 == std::string ("errIndexIsTooLarge")))
  {
    {
      return (int)1204;
    }
  }
  {}
  if ((_6510 == std::string ("errParamName")))
  {
    {
      return (int)1205;
    }
  }
  {}
  if ((_6510 == std::string ("errParamNameDou")))
  {
    {
      return (int)1206;
    }
  }
  {}
  if ((_6510 == std::string ("errParamNameInt")))
  {
    {
      return (int)1207;
    }
  }
  {}
  if ((_6510 == std::string ("errParamNameStr")))
  {
    {
      return (int)1208;
    }
  }
  {}
  if ((_6510 == std::string ("errParamIndex")))
  {
    {
      return (int)1210;
    }
  }
  {}
  if ((_6510 == std::string ("errParamIsTooLarge")))
  {
    {
      return (int)1215;
    }
  }
  {}
  if ((_6510 == std::string ("errParamIsTooSmall")))
  {
    {
      return (int)1216;
    }
  }
  {}
  if ((_6510 == std::string ("errParamValueStr")))
  {
    {
      return (int)1217;
    }
  }
  {}
  if ((_6510 == std::string ("errParamType")))
  {
    {
      return (int)1218;
    }
  }
  {}
  if ((_6510 == std::string ("errInfDouIndex")))
  {
    {
      return (int)1219;
    }
  }
  {}
  if ((_6510 == std::string ("errInfIntIndex")))
  {
    {
      return (int)1220;
    }
  }
  {}
  if ((_6510 == std::string ("errIndexArrIsTooSmall")))
  {
    {
      return (int)1221;
    }
  }
  {}
  if ((_6510 == std::string ("errIndexArrIsTooLarge")))
  {
    {
      return (int)1222;
    }
  }
  {}
  if ((_6510 == std::string ("errInfLintIndex")))
  {
    {
      return (int)1225;
    }
  }
  {}
  if ((_6510 == std::string ("errArgIsTooSmall")))
  {
    {
      return (int)1226;
    }
  }
  {}
  if ((_6510 == std::string ("errArgIsTooLarge")))
  {
    {
      return (int)1227;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidWhichsol")))
  {
    {
      return (int)1228;
    }
  }
  {}
  if ((_6510 == std::string ("errInfDouName")))
  {
    {
      return (int)1230;
    }
  }
  {}
  if ((_6510 == std::string ("errInfIntName")))
  {
    {
      return (int)1231;
    }
  }
  {}
  if ((_6510 == std::string ("errInfType")))
  {
    {
      return (int)1232;
    }
  }
  {}
  if ((_6510 == std::string ("errInfLintName")))
  {
    {
      return (int)1234;
    }
  }
  {}
  if ((_6510 == std::string ("errIndex")))
  {
    {
      return (int)1235;
    }
  }
  {}
  if ((_6510 == std::string ("errWhichsol")))
  {
    {
      return (int)1236;
    }
  }
  {}
  if ((_6510 == std::string ("errSolitem")))
  {
    {
      return (int)1237;
    }
  }
  {}
  if ((_6510 == std::string ("errWhichitemNotAllowed")))
  {
    {
      return (int)1238;
    }
  }
  {}
  if ((_6510 == std::string ("errMaxnumcon")))
  {
    {
      return (int)1240;
    }
  }
  {}
  if ((_6510 == std::string ("errMaxnumvar")))
  {
    {
      return (int)1241;
    }
  }
  {}
  if ((_6510 == std::string ("errMaxnumbarvar")))
  {
    {
      return (int)1242;
    }
  }
  {}
  if ((_6510 == std::string ("errMaxnumqnz")))
  {
    {
      return (int)1243;
    }
  }
  {}
  if ((_6510 == std::string ("errTooSmallMaxNumNz")))
  {
    {
      return (int)1245;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidIdx")))
  {
    {
      return (int)1246;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidMaxNum")))
  {
    {
      return (int)1247;
    }
  }
  {}
  if ((_6510 == std::string ("errNumconlim")))
  {
    {
      return (int)1250;
    }
  }
  {}
  if ((_6510 == std::string ("errNumvarlim")))
  {
    {
      return (int)1251;
    }
  }
  {}
  if ((_6510 == std::string ("errTooSmallMaxnumanz")))
  {
    {
      return (int)1252;
    }
  }
  {}
  if ((_6510 == std::string ("errInvAptre")))
  {
    {
      return (int)1253;
    }
  }
  {}
  if ((_6510 == std::string ("errMulAElement")))
  {
    {
      return (int)1254;
    }
  }
  {}
  if ((_6510 == std::string ("errInvBk")))
  {
    {
      return (int)1255;
    }
  }
  {}
  if ((_6510 == std::string ("errInvBkc")))
  {
    {
      return (int)1256;
    }
  }
  {}
  if ((_6510 == std::string ("errInvBkx")))
  {
    {
      return (int)1257;
    }
  }
  {}
  if ((_6510 == std::string ("errInvVarType")))
  {
    {
      return (int)1258;
    }
  }
  {}
  if ((_6510 == std::string ("errSolverProbtype")))
  {
    {
      return (int)1259;
    }
  }
  {}
  if ((_6510 == std::string ("errObjectiveRange")))
  {
    {
      return (int)1260;
    }
  }
  {}
  if ((_6510 == std::string ("errUndefSolution")))
  {
    {
      return (int)1265;
    }
  }
  {}
  if ((_6510 == std::string ("errBasis")))
  {
    {
      return (int)1266;
    }
  }
  {}
  if ((_6510 == std::string ("errInvSkc")))
  {
    {
      return (int)1267;
    }
  }
  {}
  if ((_6510 == std::string ("errInvSkx")))
  {
    {
      return (int)1268;
    }
  }
  {}
  if ((_6510 == std::string ("errInvSkn")))
  {
    {
      return (int)1274;
    }
  }
  {}
  if ((_6510 == std::string ("errInvSkStr")))
  {
    {
      return (int)1269;
    }
  }
  {}
  if ((_6510 == std::string ("errInvSk")))
  {
    {
      return (int)1270;
    }
  }
  {}
  if ((_6510 == std::string ("errInvConeTypeStr")))
  {
    {
      return (int)1271;
    }
  }
  {}
  if ((_6510 == std::string ("errInvConeType")))
  {
    {
      return (int)1272;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidSurplus")))
  {
    {
      return (int)1275;
    }
  }
  {}
  if ((_6510 == std::string ("errInvNameItem")))
  {
    {
      return (int)1280;
    }
  }
  {}
  if ((_6510 == std::string ("errProItem")))
  {
    {
      return (int)1281;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFormatType")))
  {
    {
      return (int)1283;
    }
  }
  {}
  if ((_6510 == std::string ("errFirsti")))
  {
    {
      return (int)1285;
    }
  }
  {}
  if ((_6510 == std::string ("errLasti")))
  {
    {
      return (int)1286;
    }
  }
  {}
  if ((_6510 == std::string ("errFirstj")))
  {
    {
      return (int)1287;
    }
  }
  {}
  if ((_6510 == std::string ("errLastj")))
  {
    {
      return (int)1288;
    }
  }
  {}
  if ((_6510 == std::string ("errMaxLenIsTooSmall")))
  {
    {
      return (int)1289;
    }
  }
  {}
  if ((_6510 == std::string ("errNonlinearEquality")))
  {
    {
      return (int)1290;
    }
  }
  {}
  if ((_6510 == std::string ("errNonconvex")))
  {
    {
      return (int)1291;
    }
  }
  {}
  if ((_6510 == std::string ("errNonlinearRanged")))
  {
    {
      return (int)1292;
    }
  }
  {}
  if ((_6510 == std::string ("errConQNotPsd")))
  {
    {
      return (int)1293;
    }
  }
  {}
  if ((_6510 == std::string ("errConQNotNsd")))
  {
    {
      return (int)1294;
    }
  }
  {}
  if ((_6510 == std::string ("errObjQNotPsd")))
  {
    {
      return (int)1295;
    }
  }
  {}
  if ((_6510 == std::string ("errObjQNotNsd")))
  {
    {
      return (int)1296;
    }
  }
  {}
  if ((_6510 == std::string ("errArgumentPermArray")))
  {
    {
      return (int)1299;
    }
  }
  {}
  if ((_6510 == std::string ("errConeIndex")))
  {
    {
      return (int)1300;
    }
  }
  {}
  if ((_6510 == std::string ("errConeSize")))
  {
    {
      return (int)1301;
    }
  }
  {}
  if ((_6510 == std::string ("errConeOverlap")))
  {
    {
      return (int)1302;
    }
  }
  {}
  if ((_6510 == std::string ("errConeRepVar")))
  {
    {
      return (int)1303;
    }
  }
  {}
  if ((_6510 == std::string ("errMaxnumcone")))
  {
    {
      return (int)1304;
    }
  }
  {}
  if ((_6510 == std::string ("errConeType")))
  {
    {
      return (int)1305;
    }
  }
  {}
  if ((_6510 == std::string ("errConeTypeStr")))
  {
    {
      return (int)1306;
    }
  }
  {}
  if ((_6510 == std::string ("errConeOverlapAppend")))
  {
    {
      return (int)1307;
    }
  }
  {}
  if ((_6510 == std::string ("errRemoveConeVariable")))
  {
    {
      return (int)1310;
    }
  }
  {}
  if ((_6510 == std::string ("errAppendingTooBigCone")))
  {
    {
      return (int)1311;
    }
  }
  {}
  if ((_6510 == std::string ("errConeParameter")))
  {
    {
      return (int)1320;
    }
  }
  {}
  if ((_6510 == std::string ("errSolFileInvalidNumber")))
  {
    {
      return (int)1350;
    }
  }
  {}
  if ((_6510 == std::string ("errHugeC")))
  {
    {
      return (int)1375;
    }
  }
  {}
  if ((_6510 == std::string ("errHugeAij")))
  {
    {
      return (int)1380;
    }
  }
  {}
  if ((_6510 == std::string ("errDuplicateAij")))
  {
    {
      return (int)1385;
    }
  }
  {}
  if ((_6510 == std::string ("errLowerBoundIsANan")))
  {
    {
      return (int)1390;
    }
  }
  {}
  if ((_6510 == std::string ("errUpperBoundIsANan")))
  {
    {
      return (int)1391;
    }
  }
  {}
  if ((_6510 == std::string ("errInfiniteBound")))
  {
    {
      return (int)1400;
    }
  }
  {}
  if ((_6510 == std::string ("errInvQobjSubi")))
  {
    {
      return (int)1401;
    }
  }
  {}
  if ((_6510 == std::string ("errInvQobjSubj")))
  {
    {
      return (int)1402;
    }
  }
  {}
  if ((_6510 == std::string ("errInvQobjVal")))
  {
    {
      return (int)1403;
    }
  }
  {}
  if ((_6510 == std::string ("errInvQconSubk")))
  {
    {
      return (int)1404;
    }
  }
  {}
  if ((_6510 == std::string ("errInvQconSubi")))
  {
    {
      return (int)1405;
    }
  }
  {}
  if ((_6510 == std::string ("errInvQconSubj")))
  {
    {
      return (int)1406;
    }
  }
  {}
  if ((_6510 == std::string ("errInvQconVal")))
  {
    {
      return (int)1407;
    }
  }
  {}
  if ((_6510 == std::string ("errQconSubiTooSmall")))
  {
    {
      return (int)1408;
    }
  }
  {}
  if ((_6510 == std::string ("errQconSubiTooLarge")))
  {
    {
      return (int)1409;
    }
  }
  {}
  if ((_6510 == std::string ("errQobjUpperTriangle")))
  {
    {
      return (int)1415;
    }
  }
  {}
  if ((_6510 == std::string ("errQconUpperTriangle")))
  {
    {
      return (int)1417;
    }
  }
  {}
  if ((_6510 == std::string ("errFixedBoundValues")))
  {
    {
      return (int)1420;
    }
  }
  {}
  if ((_6510 == std::string ("errTooSmallATruncationValue")))
  {
    {
      return (int)1421;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidObjectiveSense")))
  {
    {
      return (int)1445;
    }
  }
  {}
  if ((_6510 == std::string ("errUndefinedObjectiveSense")))
  {
    {
      return (int)1446;
    }
  }
  {}
  if ((_6510 == std::string ("errYIsUndefined")))
  {
    {
      return (int)1449;
    }
  }
  {}
  if ((_6510 == std::string ("errNanInDoubleData")))
  {
    {
      return (int)1450;
    }
  }
  {}
  if ((_6510 == std::string ("errNanInBlc")))
  {
    {
      return (int)1461;
    }
  }
  {}
  if ((_6510 == std::string ("errNanInBuc")))
  {
    {
      return (int)1462;
    }
  }
  {}
  if ((_6510 == std::string ("errNanInC")))
  {
    {
      return (int)1470;
    }
  }
  {}
  if ((_6510 == std::string ("errNanInBlx")))
  {
    {
      return (int)1471;
    }
  }
  {}
  if ((_6510 == std::string ("errNanInBux")))
  {
    {
      return (int)1472;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidAij")))
  {
    {
      return (int)1473;
    }
  }
  {}
  if ((_6510 == std::string ("errSymMatInvalid")))
  {
    {
      return (int)1480;
    }
  }
  {}
  if ((_6510 == std::string ("errSymMatHuge")))
  {
    {
      return (int)1482;
    }
  }
  {}
  if ((_6510 == std::string ("errInvProblem")))
  {
    {
      return (int)1500;
    }
  }
  {}
  if ((_6510 == std::string ("errMixedConicAndNl")))
  {
    {
      return (int)1501;
    }
  }
  {}
  if ((_6510 == std::string ("errGlobalInvConicProblem")))
  {
    {
      return (int)1503;
    }
  }
  {}
  if ((_6510 == std::string ("errInvOptimizer")))
  {
    {
      return (int)1550;
    }
  }
  {}
  if ((_6510 == std::string ("errMioNoOptimizer")))
  {
    {
      return (int)1551;
    }
  }
  {}
  if ((_6510 == std::string ("errNoOptimizerVarType")))
  {
    {
      return (int)1552;
    }
  }
  {}
  if ((_6510 == std::string ("errFinalSolution")))
  {
    {
      return (int)1560;
    }
  }
  {}
  if ((_6510 == std::string ("errFirst")))
  {
    {
      return (int)1570;
    }
  }
  {}
  if ((_6510 == std::string ("errLast")))
  {
    {
      return (int)1571;
    }
  }
  {}
  if ((_6510 == std::string ("errSliceSize")))
  {
    {
      return (int)1572;
    }
  }
  {}
  if ((_6510 == std::string ("errNegativeSurplus")))
  {
    {
      return (int)1573;
    }
  }
  {}
  if ((_6510 == std::string ("errNegativeAppend")))
  {
    {
      return (int)1578;
    }
  }
  {}
  if ((_6510 == std::string ("errPostsolve")))
  {
    {
      return (int)1580;
    }
  }
  {}
  if ((_6510 == std::string ("errOverflow")))
  {
    {
      return (int)1590;
    }
  }
  {}
  if ((_6510 == std::string ("errNoBasisSol")))
  {
    {
      return (int)1600;
    }
  }
  {}
  if ((_6510 == std::string ("errBasisFactor")))
  {
    {
      return (int)1610;
    }
  }
  {}
  if ((_6510 == std::string ("errBasisSingular")))
  {
    {
      return (int)1615;
    }
  }
  {}
  if ((_6510 == std::string ("errFactor")))
  {
    {
      return (int)1650;
    }
  }
  {}
  if ((_6510 == std::string ("errFeasrepairCannotRelax")))
  {
    {
      return (int)1700;
    }
  }
  {}
  if ((_6510 == std::string ("errFeasrepairSolvingRelaxed")))
  {
    {
      return (int)1701;
    }
  }
  {}
  if ((_6510 == std::string ("errFeasrepairInconsistentBound")))
  {
    {
      return (int)1702;
    }
  }
  {}
  if ((_6510 == std::string ("errRepairInvalidProblem")))
  {
    {
      return (int)1710;
    }
  }
  {}
  if ((_6510 == std::string ("errRepairOptimizationFailed")))
  {
    {
      return (int)1711;
    }
  }
  {}
  if ((_6510 == std::string ("errNameMaxLen")))
  {
    {
      return (int)1750;
    }
  }
  {}
  if ((_6510 == std::string ("errNameIsNull")))
  {
    {
      return (int)1760;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidCompression")))
  {
    {
      return (int)1800;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidIomode")))
  {
    {
      return (int)1801;
    }
  }
  {}
  if ((_6510 == std::string ("errNoPrimalInfeasCer")))
  {
    {
      return (int)2000;
    }
  }
  {}
  if ((_6510 == std::string ("errNoDualInfeasCer")))
  {
    {
      return (int)2001;
    }
  }
  {}
  if ((_6510 == std::string ("errNoSolutionInCallback")))
  {
    {
      return (int)2500;
    }
  }
  {}
  if ((_6510 == std::string ("errInvMarki")))
  {
    {
      return (int)2501;
    }
  }
  {}
  if ((_6510 == std::string ("errInvMarkj")))
  {
    {
      return (int)2502;
    }
  }
  {}
  if ((_6510 == std::string ("errInvNumi")))
  {
    {
      return (int)2503;
    }
  }
  {}
  if ((_6510 == std::string ("errInvNumj")))
  {
    {
      return (int)2504;
    }
  }
  {}
  if ((_6510 == std::string ("errTaskIncompatible")))
  {
    {
      return (int)2560;
    }
  }
  {}
  if ((_6510 == std::string ("errTaskInvalid")))
  {
    {
      return (int)2561;
    }
  }
  {}
  if ((_6510 == std::string ("errTaskWrite")))
  {
    {
      return (int)2562;
    }
  }
  {}
  if ((_6510 == std::string ("errLuMaxNumTries")))
  {
    {
      return (int)2800;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidUtf8")))
  {
    {
      return (int)2900;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidWchar")))
  {
    {
      return (int)2901;
    }
  }
  {}
  if ((_6510 == std::string ("errNoDualForItgSol")))
  {
    {
      return (int)2950;
    }
  }
  {}
  if ((_6510 == std::string ("errNoSnxForBasSol")))
  {
    {
      return (int)2953;
    }
  }
  {}
  if ((_6510 == std::string ("errInternal")))
  {
    {
      return (int)3000;
    }
  }
  {}
  if ((_6510 == std::string ("errApiArrayTooSmall")))
  {
    {
      return (int)3001;
    }
  }
  {}
  if ((_6510 == std::string ("errApiCbConnect")))
  {
    {
      return (int)3002;
    }
  }
  {}
  if ((_6510 == std::string ("errApiFatalError")))
  {
    {
      return (int)3005;
    }
  }
  {}
  if ((_6510 == std::string ("errApiInternal")))
  {
    {
      return (int)3999;
    }
  }
  {}
  if ((_6510 == std::string ("errSenFormat")))
  {
    {
      return (int)3050;
    }
  }
  {}
  if ((_6510 == std::string ("errSenUndefName")))
  {
    {
      return (int)3051;
    }
  }
  {}
  if ((_6510 == std::string ("errSenIndexRange")))
  {
    {
      return (int)3052;
    }
  }
  {}
  if ((_6510 == std::string ("errSenBoundInvalidUp")))
  {
    {
      return (int)3053;
    }
  }
  {}
  if ((_6510 == std::string ("errSenBoundInvalidLo")))
  {
    {
      return (int)3054;
    }
  }
  {}
  if ((_6510 == std::string ("errSenIndexInvalid")))
  {
    {
      return (int)3055;
    }
  }
  {}
  if ((_6510 == std::string ("errSenInvalidRegexp")))
  {
    {
      return (int)3056;
    }
  }
  {}
  if ((_6510 == std::string ("errSenSolutionStatus")))
  {
    {
      return (int)3057;
    }
  }
  {}
  if ((_6510 == std::string ("errSenNumerical")))
  {
    {
      return (int)3058;
    }
  }
  {}
  if ((_6510 == std::string ("errSenUnhandledProblemType")))
  {
    {
      return (int)3080;
    }
  }
  {}
  if ((_6510 == std::string ("errUnbStepSize")))
  {
    {
      return (int)3100;
    }
  }
  {}
  if ((_6510 == std::string ("errIdenticalTasks")))
  {
    {
      return (int)3101;
    }
  }
  {}
  if ((_6510 == std::string ("errAdInvalidCodelist")))
  {
    {
      return (int)3102;
    }
  }
  {}
  if ((_6510 == std::string ("errInternalTestFailed")))
  {
    {
      return (int)3500;
    }
  }
  {}
  if ((_6510 == std::string ("errXmlInvalidProblemType")))
  {
    {
      return (int)3600;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidAmplStub")))
  {
    {
      return (int)3700;
    }
  }
  {}
  if ((_6510 == std::string ("errInt64ToInt32Cast")))
  {
    {
      return (int)3800;
    }
  }
  {}
  if ((_6510 == std::string ("errSizeLicenseNumcores")))
  {
    {
      return (int)3900;
    }
  }
  {}
  if ((_6510 == std::string ("errInfeasUndefined")))
  {
    {
      return (int)3910;
    }
  }
  {}
  if ((_6510 == std::string ("errNoBarxForSolution")))
  {
    {
      return (int)3915;
    }
  }
  {}
  if ((_6510 == std::string ("errNoBarsForSolution")))
  {
    {
      return (int)3916;
    }
  }
  {}
  if ((_6510 == std::string ("errBarVarDim")))
  {
    {
      return (int)3920;
    }
  }
  {}
  if ((_6510 == std::string ("errSymMatInvalidRowIndex")))
  {
    {
      return (int)3940;
    }
  }
  {}
  if ((_6510 == std::string ("errSymMatInvalidColIndex")))
  {
    {
      return (int)3941;
    }
  }
  {}
  if ((_6510 == std::string ("errSymMatNotLowerTringular")))
  {
    {
      return (int)3942;
    }
  }
  {}
  if ((_6510 == std::string ("errSymMatInvalidValue")))
  {
    {
      return (int)3943;
    }
  }
  {}
  if ((_6510 == std::string ("errSymMatDuplicate")))
  {
    {
      return (int)3944;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidSymMatDim")))
  {
    {
      return (int)3950;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFileFormatForSymMat")))
  {
    {
      return (int)4000;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFileFormatForCfix")))
  {
    {
      return (int)4001;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFileFormatForRangedConstraints")))
  {
    {
      return (int)4002;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFileFormatForFreeConstraints")))
  {
    {
      return (int)4003;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFileFormatForCones")))
  {
    {
      return (int)4005;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidFileFormatForNonlinear")))
  {
    {
      return (int)4010;
    }
  }
  {}
  if ((_6510 == std::string ("errDuplicateConstraintNames")))
  {
    {
      return (int)4500;
    }
  }
  {}
  if ((_6510 == std::string ("errDuplicateVariableNames")))
  {
    {
      return (int)4501;
    }
  }
  {}
  if ((_6510 == std::string ("errDuplicateBarvariableNames")))
  {
    {
      return (int)4502;
    }
  }
  {}
  if ((_6510 == std::string ("errDuplicateConeNames")))
  {
    {
      return (int)4503;
    }
  }
  {}
  if ((_6510 == std::string ("errNonUniqueArray")))
  {
    {
      return (int)5000;
    }
  }
  {}
  if ((_6510 == std::string ("errArgumentIsTooLarge")))
  {
    {
      return (int)5005;
    }
  }
  {}
  if ((_6510 == std::string ("errMioInternal")))
  {
    {
      return (int)5010;
    }
  }
  {}
  if ((_6510 == std::string ("errInvalidProblemType")))
  {
    {
      return (int)6000;
    }
  }
  {}
  if ((_6510 == std::string ("errUnhandledSolutionStatus")))
  {
    {
      return (int)6010;
    }
  }
  {}
  if ((_6510 == std::string ("errUpperTriangle")))
  {
    {
      return (int)6020;
    }
  }
  {}
  if ((_6510 == std::string ("errLauSingularMatrix")))
  {
    {
      return (int)7000;
    }
  }
  {}
  if ((_6510 == std::string ("errLauNotPositiveDefinite")))
  {
    {
      return (int)7001;
    }
  }
  {}
  if ((_6510 == std::string ("errLauInvalidLowerTriangularMatrix")))
  {
    {
      return (int)7002;
    }
  }
  {}
  if ((_6510 == std::string ("errLauUnknown")))
  {
    {
      return (int)7005;
    }
  }
  {}
  if ((_6510 == std::string ("errLauArgM")))
  {
    {
      return (int)7010;
    }
  }
  {}
  if ((_6510 == std::string ("errLauArgN")))
  {
    {
      return (int)7011;
    }
  }
  {}
  if ((_6510 == std::string ("errLauArgK")))
  {
    {
      return (int)7012;
    }
  }
  {}
  if ((_6510 == std::string ("errLauArgTransa")))
  {
    {
      return (int)7015;
    }
  }
  {}
  if ((_6510 == std::string ("errLauArgTransb")))
  {
    {
      return (int)7016;
    }
  }
  {}
  if ((_6510 == std::string ("errLauArgUplo")))
  {
    {
      return (int)7017;
    }
  }
  {}
  if ((_6510 == std::string ("errLauArgTrans")))
  {
    {
      return (int)7018;
    }
  }
  {}
  if ((_6510 == std::string ("errLauInvalidSparseSymmetricMatrix")))
  {
    {
      return (int)7019;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfParse")))
  {
    {
      return (int)7100;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfObjSense")))
  {
    {
      return (int)7101;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfNoVariables")))
  {
    {
      return (int)7102;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfTooManyConstraints")))
  {
    {
      return (int)7103;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfTooManyVariables")))
  {
    {
      return (int)7104;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfNoVersionSpecified")))
  {
    {
      return (int)7105;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfSyntax")))
  {
    {
      return (int)7106;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicateObj")))
  {
    {
      return (int)7107;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicateCon")))
  {
    {
      return (int)7108;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicateVar")))
  {
    {
      return (int)7109;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicateInt")))
  {
    {
      return (int)7110;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidVarType")))
  {
    {
      return (int)7111;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidConType")))
  {
    {
      return (int)7112;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidDomainDimension")))
  {
    {
      return (int)7113;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicateObjacoord")))
  {
    {
      return (int)7114;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicateBcoord")))
  {
    {
      return (int)7115;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicateAcoord")))
  {
    {
      return (int)7116;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfTooFewVariables")))
  {
    {
      return (int)7117;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfTooFewConstraints")))
  {
    {
      return (int)7118;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfTooFewInts")))
  {
    {
      return (int)7119;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfTooManyInts")))
  {
    {
      return (int)7120;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidIntIndex")))
  {
    {
      return (int)7121;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfUnsupported")))
  {
    {
      return (int)7122;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicatePsdvar")))
  {
    {
      return (int)7123;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidPsdvarDimension")))
  {
    {
      return (int)7124;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfTooFewPsdvar")))
  {
    {
      return (int)7125;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidExpDimension")))
  {
    {
      return (int)7126;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicatePowCones")))
  {
    {
      return (int)7130;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfDuplicatePowStarCones")))
  {
    {
      return (int)7131;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidPower")))
  {
    {
      return (int)7132;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfPowerConeIsTooLong")))
  {
    {
      return (int)7133;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidPowerConeIndex")))
  {
    {
      return (int)7134;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidPowerStarConeIndex")))
  {
    {
      return (int)7135;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfUnhandledPowerConeType")))
  {
    {
      return (int)7136;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfUnhandledPowerStarConeType")))
  {
    {
      return (int)7137;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfPowerConeMismatch")))
  {
    {
      return (int)7138;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfPowerStarConeMismatch")))
  {
    {
      return (int)7139;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidNumberOfCones")))
  {
    {
      return (int)7740;
    }
  }
  {}
  if ((_6510 == std::string ("errCbfInvalidDimensionOfCones")))
  {
    {
      return (int)7741;
    }
  }
  {}
  if ((_6510 == std::string ("errMioInvalidRootOptimizer")))
  {
    {
      return (int)7700;
    }
  }
  {}
  if ((_6510 == std::string ("errMioInvalidNodeOptimizer")))
  {
    {
      return (int)7701;
    }
  }
  {}
  if ((_6510 == std::string ("errToconicConstrQNotPsd")))
  {
    {
      return (int)7800;
    }
  }
  {}
  if ((_6510 == std::string ("errToconicConstraintFx")))
  {
    {
      return (int)7801;
    }
  }
  {}
  if ((_6510 == std::string ("errToconicConstraintRa")))
  {
    {
      return (int)7802;
    }
  }
  {}
  if ((_6510 == std::string ("errToconicConstrNotConic")))
  {
    {
      return (int)7803;
    }
  }
  {}
  if ((_6510 == std::string ("errToconicObjectiveNotPsd")))
  {
    {
      return (int)7804;
    }
  }
  {}
  if ((_6510 == std::string ("errServerConnect")))
  {
    {
      return (int)8000;
    }
  }
  {}
  if ((_6510 == std::string ("errServerProtocol")))
  {
    {
      return (int)8001;
    }
  }
  {}
  if ((_6510 == std::string ("errServerStatus")))
  {
    {
      return (int)8002;
    }
  }
  {}
  if ((_6510 == std::string ("errServerToken")))
  {
    {
      return (int)8003;
    }
  }
  {}
  if ((_6510 == std::string ("trmMaxIterations")))
  {
    {
      return (int)10000;
    }
  }
  {}
  if ((_6510 == std::string ("trmMaxTime")))
  {
    {
      return (int)10001;
    }
  }
  {}
  if ((_6510 == std::string ("trmObjectiveRange")))
  {
    {
      return (int)10002;
    }
  }
  {}
  if ((_6510 == std::string ("trmMioNumRelaxs")))
  {
    {
      return (int)10008;
    }
  }
  {}
  if ((_6510 == std::string ("trmMioNumBranches")))
  {
    {
      return (int)10009;
    }
  }
  {}
  if ((_6510 == std::string ("trmNumMaxNumIntSolutions")))
  {
    {
      return (int)10015;
    }
  }
  {}
  if ((_6510 == std::string ("trmStall")))
  {
    {
      return (int)10006;
    }
  }
  {}
  if ((_6510 == std::string ("trmUserCallback")))
  {
    {
      return (int)10007;
    }
  }
  {}
  if ((_6510 == std::string ("trmMaxNumSetbacks")))
  {
    {
      return (int)10020;
    }
  }
  {}
  if ((_6510 == std::string ("trmNumericalProblem")))
  {
    {
      return (int)10025;
    }
  }
  {}
  if ((_6510 == std::string ("trmInternal")))
  {
    {
      return (int)10030;
    }
  }
  {}
  if ((_6510 == std::string ("trmInternalStop")))
  {
    {
      return (int)10031;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simreform_value(const std::string & _6511){
  if ((_6511 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6511 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6511 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6511 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_startpointtype_value(const std::string & _6512){
  if ((_6512 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6512 == std::string ("guess")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6512 == std::string ("constant")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6512 == std::string ("satisfyBounds")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dinfitem_value(const std::string & _6513){
  if ((_6513 == std::string ("biTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6513 == std::string ("biPrimalTime")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6513 == std::string ("biDualTime")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6513 == std::string ("biCleanTime")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6513 == std::string ("biCleanPrimalTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6513 == std::string ("biCleanDualTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6513 == std::string ("intpntTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6513 == std::string ("intpntOrderTime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6513 == std::string ("intpntPrimalObj")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6513 == std::string ("intpntDualObj")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6513 == std::string ("intpntPrimalFeas")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6513 == std::string ("intpntDualFeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6513 == std::string ("intpntOptStatus")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6513 == std::string ("simTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6513 == std::string ("simPrimalTime")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6513 == std::string ("simDualTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6513 == std::string ("simObj")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6513 == std::string ("simFeas")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6513 == std::string ("mioTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6513 == std::string ("mioRootPresolveTime")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6513 == std::string ("mioRootOptimizerTime")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6513 == std::string ("toConicTime")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6513 == std::string ("mioConstructSolutionObj")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6513 == std::string ("mioObjInt")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6513 == std::string ("mioObjBound")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6513 == std::string ("mioObjRelGap")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6513 == std::string ("mioObjAbsGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6513 == std::string ("mioUserObjCut")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6513 == std::string ("mioCmirSeparationTime")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6513 == std::string ("mioCliqueSeparationTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6513 == std::string ("mioKnapsackCoverSeparationTime")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6513 == std::string ("mioGmiSeparationTime")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6513 == std::string ("mioImpliedBoundTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6513 == std::string ("mioRootCutgenTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6513 == std::string ("mioProbingTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6513 == std::string ("optimizerTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6513 == std::string ("presolveTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6513 == std::string ("mioDualBoundAfterPresolve")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6513 == std::string ("presolveEliTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6513 == std::string ("presolveLindepTime")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6513 == std::string ("rdTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6513 == std::string ("solItrPrimalObj")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6513 == std::string ("solItrPviolcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6513 == std::string ("solItrPviolvar")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6513 == std::string ("solItrPviolbarvar")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6513 == std::string ("solItrPviolcones")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6513 == std::string ("solItrDualObj")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6513 == std::string ("solItrDviolcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6513 == std::string ("solItrDviolvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6513 == std::string ("solItrDviolbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6513 == std::string ("solItrDviolcones")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmXc")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmXx")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmBarx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmY")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmSlc")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmSuc")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmSlx")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmSux")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmSnx")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6513 == std::string ("solItrNrmBars")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6513 == std::string ("solBasPrimalObj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6513 == std::string ("solBasPviolcon")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6513 == std::string ("solBasPviolvar")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6513 == std::string ("solBasDualObj")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6513 == std::string ("solBasDviolcon")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6513 == std::string ("solBasDviolvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmXc")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmXx")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmBarx")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmY")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmSlc")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmSuc")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmSlx")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6513 == std::string ("solBasNrmSux")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6513 == std::string ("solItgPrimalObj")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6513 == std::string ("solItgPviolcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6513 == std::string ("solItgPviolvar")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6513 == std::string ("solItgPviolbarvar")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6513 == std::string ("solItgPviolcones")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6513 == std::string ("solItgPviolitg")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6513 == std::string ("solItgNrmXc")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6513 == std::string ("solItgNrmXx")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6513 == std::string ("solItgNrmBarx")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6513 == std::string ("intpntFactorNumFlops")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6513 == std::string ("qcqoReformulateTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6513 == std::string ("qcqoReformulateMaxPerturbation")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6513 == std::string ("qcqoReformulateWorstCholeskyDiagScaling")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6513 == std::string ("qcqoReformulateWorstCholeskyColumnScaling")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6513 == std::string ("primalRepairPenaltyObj")))
  {
    {
      return (int)35;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_soltype_value(const std::string & _6514){
  if ((_6514 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6514 == std::string ("itr")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6514 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_presolvemode_value(const std::string & _6515){
  if ((_6515 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6515 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6515 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dparam_value(const std::string & _6516){
  if ((_6516 == std::string ("dataTolCjLarge")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6516 == std::string ("dataTolCHuge")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6516 == std::string ("dataTolAijLarge")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6516 == std::string ("dataTolAijHuge")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6516 == std::string ("dataSymMatTol")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6516 == std::string ("dataSymMatTolLarge")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6516 == std::string ("dataSymMatTolHuge")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6516 == std::string ("dataTolBoundInf")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6516 == std::string ("dataTolBoundWrn")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6516 == std::string ("dataTolQij")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6516 == std::string ("dataTolX")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6516 == std::string ("semidefiniteTolApprox")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6516 == std::string ("optimizerMaxTime")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6516 == std::string ("lowerObjCut")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6516 == std::string ("upperObjCut")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6516 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6516 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolRelGap")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolStepSize")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6516 == std::string ("simLuTolRelPiv")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolRelStep")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolPath")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolPfeas")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolDfeas")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolMuRed")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolInfeas")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6516 == std::string ("intpntCoTolRelGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6516 == std::string ("intpntCoTolPfeas")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6516 == std::string ("intpntCoTolDfeas")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6516 == std::string ("intpntCoTolMuRed")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6516 == std::string ("intpntCoTolNearRel")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6516 == std::string ("intpntCoTolInfeas")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6516 == std::string ("intpntQoTolRelGap")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6516 == std::string ("intpntQoTolPfeas")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6516 == std::string ("intpntQoTolDfeas")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6516 == std::string ("intpntQoTolMuRed")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6516 == std::string ("intpntQoTolNearRel")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6516 == std::string ("intpntQoTolInfeas")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolPsafe")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6516 == std::string ("intpntTolDsafe")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6516 == std::string ("mioMaxTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6516 == std::string ("mioRelGapConst")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6516 == std::string ("mioTolRelGap")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6516 == std::string ("mioTolAbsGap")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6516 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6516 == std::string ("basisTolX")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6516 == std::string ("basisTolS")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6516 == std::string ("basisRelTolS")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6516 == std::string ("presolveTolX")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6516 == std::string ("presolveTolS")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6516 == std::string ("presolveTolAij")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6516 == std::string ("presolveTolAbsLindep")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6516 == std::string ("presolveTolRelLindep")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6516 == std::string ("simplexAbsTolPiv")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6516 == std::string ("mioTolFeas")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6516 == std::string ("anaSolInfeasTol")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6516 == std::string ("checkConvexityRelTol")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6516 == std::string ("qcqoReformulateRelDropTol")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6516 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      return (int)45;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_symmattype_value(const std::string & _6517){
  if ((_6517 == std::string ("sparse")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scopr_value(const std::string & _6518){
  if ((_6518 == std::string ("ent")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6518 == std::string ("exp")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6518 == std::string ("log")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6518 == std::string ("pow")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6518 == std::string ("sqrt")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solitem_value(const std::string & _6519){
  if ((_6519 == std::string ("xc")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6519 == std::string ("xx")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6519 == std::string ("y")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6519 == std::string ("slc")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6519 == std::string ("suc")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6519 == std::string ("slx")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6519 == std::string ("sux")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6519 == std::string ("snx")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_compresstype_value(const std::string & _6520){
  if ((_6520 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6520 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6520 == std::string ("gzip")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6520 == std::string ("zstd")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simhotstart_value(const std::string & _6521){
  if ((_6521 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6521 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6521 == std::string ("statusKeys")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdupvec_value(const std::string & _6522){
  if ((_6522 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6522 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6522 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solsta_value(const std::string & _6523){
  if ((_6523 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6523 == std::string ("optimal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6523 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6523 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6523 == std::string ("primAndDualFeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6523 == std::string ("primInfeasCer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6523 == std::string ("dualInfeasCer")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6523 == std::string ("primIllposedCer")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6523 == std::string ("dualIllposedCer")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6523 == std::string ("integerOptimal")))
  {
    {
      return (int)9;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solveform_value(const std::string & _6524){
  if ((_6524 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6524 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6524 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mark_value(const std::string & _6525){
  if ((_6525 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6525 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_parametertype_value(const std::string & _6526){
  if ((_6526 == std::string ("invalidType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6526 == std::string ("douType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6526 == std::string ("intType")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6526 == std::string ("strType")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_value_value(const std::string & _6527){
  if ((_6527 == std::string ("maxStrLen")))
  {
    {
      return (int)1024;
    }
  }
  {}
  if ((_6527 == std::string ("licenseBufferLength")))
  {
    {
      return (int)21;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dataformat_value(const std::string & _6528){
  if ((_6528 == std::string ("extension")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6528 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6528 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6528 == std::string ("op")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6528 == std::string ("freeMps")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6528 == std::string ("task")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6528 == std::string ("ptf")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6528 == std::string ("cb")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6528 == std::string ("jsonTask")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_callbackcode_value(const std::string & _6529){
  if ((_6529 == std::string ("beginRootCutgen")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6529 == std::string ("imRootCutgen")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6529 == std::string ("endRootCutgen")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6529 == std::string ("beginOptimizer")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6529 == std::string ("endOptimizer")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6529 == std::string ("beginPresolve")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6529 == std::string ("updatePresolve")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6529 == std::string ("imPresolve")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6529 == std::string ("endPresolve")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6529 == std::string ("beginIntpnt")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6529 == std::string ("intpnt")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6529 == std::string ("imIntpnt")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6529 == std::string ("endIntpnt")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6529 == std::string ("beginConic")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6529 == std::string ("conic")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6529 == std::string ("imConic")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6529 == std::string ("endConic")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6529 == std::string ("primalSimplex")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6529 == std::string ("dualSimplex")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6529 == std::string ("beginBi")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6529 == std::string ("imBi")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6529 == std::string ("endBi")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6529 == std::string ("beginPrimalBi")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6529 == std::string ("imPrimalBi")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6529 == std::string ("updatePrimalBi")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6529 == std::string ("endPrimalBi")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6529 == std::string ("beginDualBi")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6529 == std::string ("imDualBi")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6529 == std::string ("updateDualBi")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6529 == std::string ("endDualBi")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6529 == std::string ("beginSimplexBi")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6529 == std::string ("imSimplexBi")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6529 == std::string ("beginPrimalSimplexBi")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6529 == std::string ("updatePrimalSimplexBi")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6529 == std::string ("endPrimalSimplexBi")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6529 == std::string ("beginDualSimplexBi")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6529 == std::string ("updateDualSimplexBi")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6529 == std::string ("endDualSimplexBi")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6529 == std::string ("endSimplexBi")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6529 == std::string ("beginMio")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6529 == std::string ("imMio")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6529 == std::string ("newIntMio")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6529 == std::string ("endMio")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6529 == std::string ("beginSimplex")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6529 == std::string ("beginDualSimplex")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6529 == std::string ("imDualSimplex")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6529 == std::string ("updateDualSimplex")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6529 == std::string ("endDualSimplex")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6529 == std::string ("beginPrimalSimplex")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6529 == std::string ("imPrimalSimplex")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6529 == std::string ("updatePrimalSimplex")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6529 == std::string ("endPrimalSimplex")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6529 == std::string ("endSimplex")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6529 == std::string ("beginInfeasAna")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6529 == std::string ("endInfeasAna")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6529 == std::string ("imPrimalSensivity")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6529 == std::string ("imDualSensivity")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6529 == std::string ("imMioIntpnt")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6529 == std::string ("imMioPrimalSimplex")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6529 == std::string ("imMioDualSimplex")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6529 == std::string ("beginPrimalSetupBi")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6529 == std::string ("endPrimalSetupBi")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6529 == std::string ("beginDualSetupBi")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6529 == std::string ("endDualSetupBi")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6529 == std::string ("beginPrimalSensitivity")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6529 == std::string ("endPrimalSensitivity")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6529 == std::string ("beginDualSensitivity")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6529 == std::string ("endDualSensitivity")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6529 == std::string ("beginLicenseWait")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6529 == std::string ("endLicenseWait")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6529 == std::string ("imLicenseWait")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6529 == std::string ("beginQcqoReformulate")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6529 == std::string ("endQcqoReformulate")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6529 == std::string ("imQoReformulate")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6529 == std::string ("beginToConic")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6529 == std::string ("endToConic")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6529 == std::string ("beginFullConvexityCheck")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6529 == std::string ("endFullConvexityCheck")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6529 == std::string ("imFullConvexityCheck")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6529 == std::string ("beginPrimalRepair")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6529 == std::string ("endPrimalRepair")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6529 == std::string ("beginRead")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6529 == std::string ("imRead")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6529 == std::string ("endRead")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6529 == std::string ("beginWrite")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6529 == std::string ("endWrite")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6529 == std::string ("readOpfSection")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6529 == std::string ("imLu")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6529 == std::string ("imOrder")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6529 == std::string ("imSimplex")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6529 == std::string ("readOpf")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6529 == std::string ("writeOpf")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6529 == std::string ("solvingRemote")))
  {
    {
      return (int)84;
    }
  }
  {}
  return (-(int)1);
}
void mosek::fusion::p_Parameters::destroy(){}void mosek::fusion::Parameters::destroy() { mosek::fusion::p_Parameters::_get_impl(this)->destroy(); }