#ifndef __FUSION_P_H__
#define __FUSION_P_H__
#include "monty.h"
#include "mosektask_p.h"
#include "list"
#include "vector"
#include "unordered_map"
#include "fusion.h"
namespace mosek
{
namespace fusion
{
// mosek.fusion.BaseModel from file 'src/fusion/cxx/BaseModel_p.h'
// namespace mosek::fusion
struct p_BaseModel
{
  p_BaseModel(BaseModel * _pubthis);

  void _initialize( monty::rc_ptr<BaseModel> m);
  void _initialize( const std::string & name,
                    const std::string & licpath);

  virtual ~p_BaseModel() { /* std::cout << "~p_BaseModel()" << std::endl;*/  }

  static p_BaseModel * _get_impl(Model * _inst) { return _inst->_impl; }

  //----------------------

  bool synched;
  std::string taskname;

  monty::rc_ptr<SolutionStruct> sol_itr;
  monty::rc_ptr<SolutionStruct> sol_itg;
  monty::rc_ptr<SolutionStruct> sol_bas;

  //---------------------

  std::unique_ptr<Task> task;

  //---------------------
  void task_setLogHandler (const msghandler_t & handler);
  void task_setDataCallbackHandler (const datacbhandler_t & handler);
  void task_setCallbackHandler (const cbhandler_t & handler);

  int task_append_barvar(int size, int num);

  void task_var_name   (int index, const std::string & name);
  void task_con_name   (int index, const std::string & name);
  void task_cone_name  (int index, const std::string & name);
  void task_barvar_name(int index, const std::string & name);
  void task_objectivename(         const std::string & name);

  void task_format_var_names(const std::shared_ptr<monty::ndarray<int,1>> subj, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_con_names(const std::shared_ptr<monty::ndarray<int,1>> subi, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_cone_names(const std::shared_ptr<monty::ndarray<int,1>> subk, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);

  void task_break_solve();

  //--------------------------

  int task_numvar();
  int task_numcon();
  int task_numcone();
  int task_numbarvar();

  //--------------------------

  void task_put_param(const std::string & name, const std::string & value);
  void task_put_param(const std::string & name, int    value);
  void task_put_param(const std::string & name, double value);
  
  double    task_get_dinf (const std::string & name);
  int       task_get_iinf (const std::string & name);
  long long task_get_liinf(const std::string & name);
  
  //--------------------------

  void task_con_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_con_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );

  void task_var_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_var_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );
  
  void task_var_putintlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs);
  void task_var_putcontlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs); 
 
  //--------------------------

  void task_putbararowlist(const std::shared_ptr<monty::ndarray<int,1>>       subi,
                           const std::shared_ptr<monty::ndarray<long long,1>> ptr,
                           const std::shared_ptr<monty::ndarray<int,1>>       subj,
                           const std::shared_ptr<monty::ndarray<long long,1>> matidx);

  void task_putbaraijlist(const std::shared_ptr<monty::ndarray<int,1>> subi,
                          const std::shared_ptr<monty::ndarray<int,1>> subj,
                          std::shared_ptr<monty::ndarray<long long,1>> matidx);
  
  void task_putbarc(const std::shared_ptr<monty::ndarray<int,1>> subj,
                    const std::shared_ptr<monty::ndarray<int,1>> subl,
                    const std::shared_ptr<monty::ndarray<int,1>> subk,
                    const std::shared_ptr<monty::ndarray<double,1>> val);
  
  std::shared_ptr<monty::ndarray<long long,1>> task_appendsymmatlist (const std::shared_ptr<monty::ndarray<int,1>>       & dim, 
                                                                      const std::shared_ptr<monty::ndarray<long long,1>> & nz, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subk, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subl, 
                                                                      const std::shared_ptr<monty::ndarray<double,1>>    & val);
  int  task_barvar_dim(int j);
  void task_putbaraij (int i, int j, int k);
  void task_putbaraij (int i, int j, const std::shared_ptr<monty::ndarray<int,1>> & k);
  void task_putbarcj  (int j, int k);
  void task_putbarcj  (int j,        const std::shared_ptr<monty::ndarray<int,1>> & k);
  int  task_barvardim (int index);

  int task_append_var(int num);
  int task_append_con(int num);

  void task_append_zerocones (int numcone);
  void task_clear_cones   ( const std::shared_ptr<monty::ndarray<int,1>> & idxs );
  void task_put_zerocones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_quadcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_rquadcones( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_pexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_ppowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );
  void task_put_dexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_dpowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );

  void task_putarowlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & idxs, 
    const std::shared_ptr<monty::ndarray<long long,1>> & ptrb, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof);
  void task_putaijlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & subi, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof, 
    long long                           num);

  void task_setnumvar(int num);
  void task_cleanup(int oldnum, int oldnumcon, int oldnumcone, int oldnumbarvar);
  void task_solve();

  void task_putobjective( 
    bool                             maximize,
    const std::shared_ptr<monty::ndarray<int,1>>    & subj    ,
    const std::shared_ptr<monty::ndarray<double,1>> & cof     ,
    double                           cfix    );

  void task_putclist(   
    const std::shared_ptr<monty::ndarray<int,1>>    & subj,
    const std::shared_ptr<monty::ndarray<double,1>> & cof);


  void task_putobjectivename(const std::string & name);

  void task_write(const std::string & filename);
  void task_dump (const std::string & filename);

  MSKtask_t task_get();
  MSKtask_t __mosek_2fusion_2BaseModel__task_get();
  
  void dispose();

  void task_putxx_slice(SolutionType which, int first, int last, std::shared_ptr<monty::ndarray<double,1>> & xx);

  static void env_syeig (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);
  static void env_potrf (int n, std::shared_ptr<monty::ndarray<double,1>> & a);                        
  static void env_syevd (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);

  static void env_putlicensecode(std::shared_ptr<monty::ndarray<int,1>> code);
  static void env_putlicensepath(const std::string &licfile);
  static void env_putlicensewait(int wait);

  static std::string env_getversion();

  void convertSolutionStatus(MSKsoltypee soltype, p_SolutionStruct * sol, MSKsolstae status, MSKprostae prosta);


};

// End of file 'src/fusion/cxx/BaseModel_p.h'
struct p_Model : public ::mosek::fusion::p_BaseModel
{
Model * _pubthis;
static mosek::fusion::p_Model* _get_impl(mosek::fusion::Model * _inst){ return static_cast< mosek::fusion::p_Model* >(mosek::fusion::p_BaseModel::_get_impl(_inst)); }
static mosek::fusion::p_Model * _get_impl(mosek::fusion::Model::t _inst) { return _get_impl(_inst.get()); }
p_Model(Model * _pubthis);
virtual ~p_Model() { /* std::cout << "~p_Model" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::WorkStack > xs{};monty::rc_ptr< ::mosek::fusion::WorkStack > ws{};monty::rc_ptr< ::mosek::fusion::WorkStack > rs{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > con_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > cons{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_type{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_ub{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_lb{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_efix{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_idx{};std::shared_ptr< monty::ndarray< long long,1 > > natconmap_slackidx{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconmap{};std::shared_ptr< monty::ndarray< bool,1 > > initsol_xx_flag{};std::shared_ptr< monty::ndarray< double,1 > > initsol_xx{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > var_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > barvars{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_ptr{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_num{};int natbarvarmap_nblock{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_dim{};std::shared_ptr< monty::ndarray< long long,1 > > natbarvar_ptr{};int natbarvar_numbarvarelm{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_j{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_i{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_type{};std::shared_ptr< monty::ndarray< int,1 > > natconemap_dim{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconemap{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > vars{};int bfixidx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natvarmap{};mosek::fusion::SolutionType solutionptr{};mosek::fusion::AccSolutionStatus acceptable_sol{};std::string model_name{};virtual void destroy();
static Model::t _new_Model(monty::rc_ptr< ::mosek::fusion::Model > _464);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _464);
static Model::t _new_Model(const std::string &  _469);
void _initialize(const std::string &  _469);
static Model::t _new_Model();
void _initialize();
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474) ;
virtual void connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string &  _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478) ;
virtual void varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string &  _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482) ;
virtual void varname(int _483,const std::string &  _484) ;
virtual void natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486) ;
virtual void natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491) ;
virtual int natbarvarmap_alloc(int _498,int _499) ;
virtual int natvarmap_alloc(int _517) ;
virtual int natconmap_alloc(int _527) ;
virtual int natconemap_alloc(int _537) ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546) ;
static  void putlicensewait(bool _552);
static  void putlicensepath(const std::string &  _553);
static  void putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554);
virtual /* override */ void dispose() ;
virtual void nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558) ;
virtual MSKtask_t __mosek_2fusion_2Model__getTask() ;
virtual void getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) ;
virtual void getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573) ;
virtual void getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582) ;
virtual void setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590) ;
virtual void flushNames() ;
virtual void writeTask(const std::string &  _600) ;
virtual long long getSolverLIntInfo(const std::string &  _601) ;
virtual int getSolverIntInfo(const std::string &  _602) ;
virtual double getSolverDoubleInfo(const std::string &  _603) ;
virtual void setCallbackHandler(mosek::cbhandler_t  _604) ;
virtual void setDataCallbackHandler(mosek::datacbhandler_t  _605) ;
virtual void setLogHandler(mosek::msghandler_t  _606) ;
virtual void setSolverParam(const std::string &  _607,double _608) ;
virtual void setSolverParam(const std::string &  _609,int _610) ;
virtual void setSolverParam(const std::string &  _611,const std::string &  _612) ;
virtual void breakSolver() ;
virtual void solve() ;
virtual void flushSolutions() ;
virtual void flush_initsol(mosek::fusion::SolutionType _613) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus() ;
virtual mosek::fusion::ProblemStatus getProblemStatus() ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus() ;
virtual double dualObjValue() ;
virtual double primalObjValue() ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _620,bool _621,bool _622) ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _627,bool _628) ;
virtual void setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _629,std::shared_ptr< monty::ndarray< double,1 > > _630) ;
virtual void ensure_initsol_xx() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_bars(mosek::fusion::SolutionType _637) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_barx(mosek::fusion::SolutionType _638) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_y(mosek::fusion::SolutionType _639) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xc(mosek::fusion::SolutionType _640) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_snx(mosek::fusion::SolutionType _641) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_suc(mosek::fusion::SolutionType _642) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slc(mosek::fusion::SolutionType _643) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_sux(mosek::fusion::SolutionType _644) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slx(mosek::fusion::SolutionType _645) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_yx(mosek::fusion::SolutionType _646) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xx(mosek::fusion::SolutionType _647) ;
virtual void selectedSolution(mosek::fusion::SolutionType _648) ;
virtual mosek::fusion::AccSolutionStatus getAcceptedSolutionStatus() ;
virtual void acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _649) ;
virtual mosek::fusion::ProblemStatus getProblemStatus(mosek::fusion::SolutionType _650) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus(mosek::fusion::SolutionType _652) ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus(mosek::fusion::SolutionType _653) ;
virtual mosek::fusion::SolutionStatus getSolutionStatus(mosek::fusion::SolutionType _654,bool _655) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _658,monty::rc_ptr< ::mosek::fusion::Expression > _659) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _692,monty::rc_ptr< ::mosek::fusion::Expression > _693,std::shared_ptr< monty::ndarray< int,1 > > _694,bool _695) ;
virtual void updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _725,monty::rc_ptr< ::mosek::fusion::Variable > _726) ;
virtual void objective_(const std::string &  _760,mosek::fusion::ObjectiveSense _761,monty::rc_ptr< ::mosek::fusion::Expression > _762) ;
virtual void objective(double _791) ;
virtual void objective(mosek::fusion::ObjectiveSense _792,double _793) ;
virtual void objective(mosek::fusion::ObjectiveSense _794,monty::rc_ptr< ::mosek::fusion::Expression > _795) ;
virtual void objective(const std::string &  _796,double _797) ;
virtual void objective(const std::string &  _798,mosek::fusion::ObjectiveSense _799,double _800) ;
virtual void objective(const std::string &  _801,mosek::fusion::ObjectiveSense _802,monty::rc_ptr< ::mosek::fusion::Expression > _803) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _881) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _897,std::shared_ptr< monty::ndarray< int,1 > > _898) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _908,int _909) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _910) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__ranged_variable(const std::string &  _911,std::shared_ptr< monty::ndarray< int,1 > > _912,monty::rc_ptr< ::mosek::fusion::RangeDomain > _913) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _934,std::shared_ptr< monty::ndarray< int,1 > > _935,monty::rc_ptr< ::mosek::fusion::ConeDomain > _936) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _964,std::shared_ptr< monty::ndarray< int,1 > > _965,monty::rc_ptr< ::mosek::fusion::LinearDomain > _966) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _1008,std::shared_ptr< monty::ndarray< int,1 > > _1009,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1010) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricVariable > __mosek_2fusion_2Model__variable_(const std::string &  _1032,std::shared_ptr< monty::ndarray< int,1 > > _1033,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1034) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1049,monty::rc_ptr< ::mosek::fusion::Expression > _1050,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1051) ;
virtual void update_bfix(std::shared_ptr< monty::ndarray< int,1 > > _1091,std::shared_ptr< monty::ndarray< double,1 > > _1092) ;
virtual void putarows(std::shared_ptr< monty::ndarray< int,1 > > _1094,monty::rc_ptr< ::mosek::fusion::WorkStack > _1095,int _1096,int _1097,int _1098,int _1099,int _1100) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1137,monty::rc_ptr< ::mosek::fusion::Expression > _1138,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1139) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1205,monty::rc_ptr< ::mosek::fusion::Expression > _1206,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1207) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1258,monty::rc_ptr< ::mosek::fusion::Expression > _1259,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1260) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1310,monty::rc_ptr< ::mosek::fusion::Expression > _1311,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1312) ;
static  std::string getVersion();
virtual bool hasConstraint(const std::string &  _1359) ;
virtual bool hasVariable(const std::string &  _1360) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(int _1361) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(const std::string &  _1362) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(int _1363) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(const std::string &  _1364) ;
virtual std::string getName() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Model__clone() ;
}; // struct Model;

// mosek.fusion.Debug from file 'src/fusion/cxx/Debug_p.h'
// namespace mosek::fusion
struct p_Debug
{
  Debug * _pubthis;

  p_Debug(Debug * _pubthis) : _pubthis(_pubthis) {}

  static Debug::t o ()                 { return monty::rc_ptr<Debug>(new Debug()); }
  Debug::t p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (      int val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (long long val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (   double val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (     bool val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t lf()                        { std::cout << std::endl; return Debug::t(_pubthis); }

  static p_Debug * _get_impl(Debug * _inst) { return _inst->ptr; }

  template<typename T>
  Debug::t p(const std::shared_ptr<monty::ndarray<T,1>> & val)
  {
    if (val->size() > 0)
    {
      std::cout << (*val)[0];
      for (int i = 1; i < val->size(); ++i)
        std::cout << "," << (*val)[i];
    }
    return Debug::t(_pubthis);
  }

  Debug::t __mosek_2fusion_2Debug__p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }

  template<class C>
  Debug::t __mosek_2fusion_2Debug__p (C val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t __mosek_2fusion_2Debug__lf()      { std::cout << std::endl; return Debug::t(_pubthis); }
  
};
// End of file 'src/fusion/cxx/Debug_p.h'
struct p_Sort
{
Sort * _pubthis;
static mosek::fusion::p_Sort* _get_impl(mosek::fusion::Sort * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Sort * _get_impl(mosek::fusion::Sort::t _inst) { return _get_impl(_inst.get()); }
p_Sort(Sort * _pubthis);
virtual ~p_Sort() { /* std::cout << "~p_Sort" << std::endl;*/ };
virtual void destroy();
static  void argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274);
}; // struct Sort;

struct p_IndexCounter
{
IndexCounter * _pubthis;
static mosek::fusion::p_IndexCounter* _get_impl(mosek::fusion::IndexCounter * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_IndexCounter * _get_impl(mosek::fusion::IndexCounter::t _inst) { return _get_impl(_inst.get()); }
p_IndexCounter(IndexCounter * _pubthis);
virtual ~p_IndexCounter() { /* std::cout << "~p_IndexCounter" << std::endl;*/ };
long long start{};std::shared_ptr< monty::ndarray< int,1 > > dims{};std::shared_ptr< monty::ndarray< long long,1 > > strides{};std::shared_ptr< monty::ndarray< long long,1 > > st{};std::shared_ptr< monty::ndarray< int,1 > > ii{};int n{};virtual void destroy();
static IndexCounter::t _new_IndexCounter(std::shared_ptr< monty::ndarray< int,1 > > _276);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _276);
static IndexCounter::t _new_IndexCounter(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
void _initialize(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
static IndexCounter::t _new_IndexCounter(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
void _initialize(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
virtual bool atEnd() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getIndex() ;
virtual long long next() ;
virtual long long get() ;
virtual void inc() ;
virtual void reset() ;
}; // struct IndexCounter;

struct p_CommonTools
{
CommonTools * _pubthis;
static mosek::fusion::p_CommonTools* _get_impl(mosek::fusion::CommonTools * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_CommonTools * _get_impl(mosek::fusion::CommonTools::t _inst) { return _get_impl(_inst.get()); }
p_CommonTools(CommonTools * _pubthis);
virtual ~p_CommonTools() { /* std::cout << "~p_CommonTools" << std::endl;*/ };
virtual void destroy();
static  std::shared_ptr< monty::ndarray< long long,1 > > resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292);
static  std::shared_ptr< monty::ndarray< int,1 > > resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295);
static  std::shared_ptr< monty::ndarray< double,1 > > resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298);
static  int binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301);
static  int binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306);
static  int binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309);
static  int binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314);
static  void ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351);
static  void tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372);
static  void argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399);
static  void mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424);
}; // struct CommonTools;

struct p_SolutionStruct
{
SolutionStruct * _pubthis;
static mosek::fusion::p_SolutionStruct* _get_impl(mosek::fusion::SolutionStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SolutionStruct * _get_impl(mosek::fusion::SolutionStruct::t _inst) { return _get_impl(_inst.get()); }
p_SolutionStruct(SolutionStruct * _pubthis);
virtual ~p_SolutionStruct() { /* std::cout << "~p_SolutionStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > yx{};std::shared_ptr< monty::ndarray< double,1 > > snx{};std::shared_ptr< monty::ndarray< double,1 > > sux{};std::shared_ptr< monty::ndarray< double,1 > > slx{};std::shared_ptr< monty::ndarray< double,1 > > bars{};std::shared_ptr< monty::ndarray< double,1 > > barx{};std::shared_ptr< monty::ndarray< double,1 > > y{};std::shared_ptr< monty::ndarray< double,1 > > suc{};std::shared_ptr< monty::ndarray< double,1 > > slc{};std::shared_ptr< monty::ndarray< double,1 > > xx{};std::shared_ptr< monty::ndarray< double,1 > > xc{};double dobj{};double pobj{};mosek::fusion::ProblemStatus probstatus{};mosek::fusion::SolutionStatus dstatus{};mosek::fusion::SolutionStatus pstatus{};int sol_numbarvar{};int sol_numcone{};int sol_numvar{};int sol_numcon{};virtual void destroy();
static SolutionStruct::t _new_SolutionStruct(int _425,int _426,int _427,int _428);
void _initialize(int _425,int _426,int _427,int _428);
static SolutionStruct::t _new_SolutionStruct(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
void _initialize(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2SolutionStruct__clone() ;
virtual void resize(int _430,int _431,int _432,int _433) ;
virtual bool isDualAcceptable(mosek::fusion::AccSolutionStatus _453) ;
virtual bool isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) ;
virtual bool isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456) ;
}; // struct SolutionStruct;

struct p_ConNZStruct
{
ConNZStruct * _pubthis;
static mosek::fusion::p_ConNZStruct* _get_impl(mosek::fusion::ConNZStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConNZStruct * _get_impl(mosek::fusion::ConNZStruct::t _inst) { return _get_impl(_inst.get()); }
p_ConNZStruct(ConNZStruct * _pubthis);
virtual ~p_ConNZStruct() { /* std::cout << "~p_ConNZStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};virtual void destroy();
static ConNZStruct::t _new_ConNZStruct(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
}; // struct ConNZStruct;

struct p_BaseVariable : public /*implements*/ virtual ::mosek::fusion::Variable
{
BaseVariable * _pubthis;
static mosek::fusion::p_BaseVariable* _get_impl(mosek::fusion::BaseVariable * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseVariable * _get_impl(mosek::fusion::BaseVariable::t _inst) { return _get_impl(_inst.get()); }
p_BaseVariable(BaseVariable * _pubthis);
virtual ~p_BaseVariable() { /* std::cout << "~p_BaseVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};monty::rc_ptr< ::mosek::fusion::Model > model{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1604,monty::rc_ptr< ::mosek::fusion::Model > _1605);
void _initialize(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1604,monty::rc_ptr< ::mosek::fusion::Model > _1605);
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::Model > _1606,std::shared_ptr< monty::ndarray< int,1 > > _1607,std::shared_ptr< monty::ndarray< long long,1 > > _1608,std::shared_ptr< monty::ndarray< long long,1 > > _1609);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1606,std::shared_ptr< monty::ndarray< int,1 > > _1607,std::shared_ptr< monty::ndarray< long long,1 > > _1608,std::shared_ptr< monty::ndarray< long long,1 > > _1609);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseVariable__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1612,monty::rc_ptr< ::mosek::fusion::WorkStack > _1613,monty::rc_ptr< ::mosek::fusion::WorkStack > _1614) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1634) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1634) { return __mosek_2fusion_2BaseVariable__reshape(_1634); }
virtual void setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1638) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2BaseVariable__getModel() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
virtual int getND() ;
virtual int getDim(int _1641) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual long long getSize() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void makeContinuous() ;
virtual void makeInteger() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1662,int _1663,int _1664) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1662,int _1663,int _1664) { return __mosek_2fusion_2BaseVariable__index(_1662,_1663,_1664); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1665,int _1666) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1665,int _1666) { return __mosek_2fusion_2BaseVariable__index(_1665,_1666); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1667) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1667) { return __mosek_2fusion_2BaseVariable__index(_1667); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1670) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1670) { return __mosek_2fusion_2BaseVariable__index(_1670); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1671,std::shared_ptr< monty::ndarray< int,1 > > _1672,std::shared_ptr< monty::ndarray< int,1 > > _1673) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1671,std::shared_ptr< monty::ndarray< int,1 > > _1672,std::shared_ptr< monty::ndarray< int,1 > > _1673) { return __mosek_2fusion_2BaseVariable__pick(_1671,_1672,_1673); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1676,std::shared_ptr< monty::ndarray< int,1 > > _1677) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1676,std::shared_ptr< monty::ndarray< int,1 > > _1677) { return __mosek_2fusion_2BaseVariable__pick(_1676,_1677); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1680) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1680) { return __mosek_2fusion_2BaseVariable__pick(_1680); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1701) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1701) { return __mosek_2fusion_2BaseVariable__pick(_1701); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag(int _1711) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag(int _1711) { return __mosek_2fusion_2BaseVariable__antidiag(_1711); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag(int _1712) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag(int _1712) { return __mosek_2fusion_2BaseVariable__diag(_1712); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714,int _1715) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1736,std::shared_ptr< monty::ndarray< int,1 > > _1737) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1736,std::shared_ptr< monty::ndarray< int,1 > > _1737) { return __mosek_2fusion_2BaseVariable__slice(_1736,_1737); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1771,int _1772) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1771,int _1772) { return __mosek_2fusion_2BaseVariable__slice(_1771,_1772); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseVariable__asExpr() ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
virtual int inst(int _1781,std::shared_ptr< monty::ndarray< long long,1 > > _1782,int _1783,std::shared_ptr< monty::ndarray< long long,1 > > _1784) ;
virtual int numInst() ;
virtual void inst(int _1787,std::shared_ptr< monty::ndarray< long long,1 > > _1788) ;
virtual void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1795,bool _1796) ;
virtual void dual_lu(int _1801,std::shared_ptr< monty::ndarray< double,1 > > _1802,bool _1803) ;
virtual void values(int _1806,std::shared_ptr< monty::ndarray< double,1 > > _1807,bool _1808) ;
virtual void make_continuous() ;
virtual void make_integer() ;
}; // struct BaseVariable;

struct p_SliceVariable : public ::mosek::fusion::p_BaseVariable
{
SliceVariable * _pubthis;
static mosek::fusion::p_SliceVariable* _get_impl(mosek::fusion::SliceVariable * _inst){ return static_cast< mosek::fusion::p_SliceVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_SliceVariable * _get_impl(mosek::fusion::SliceVariable::t _inst) { return _get_impl(_inst.get()); }
p_SliceVariable(SliceVariable * _pubthis);
virtual ~p_SliceVariable() { /* std::cout << "~p_SliceVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};virtual void destroy();
static SliceVariable::t _new_SliceVariable(monty::rc_ptr< ::mosek::fusion::Model > _1366,std::shared_ptr< monty::ndarray< int,1 > > _1367,std::shared_ptr< monty::ndarray< long long,1 > > _1368,std::shared_ptr< monty::ndarray< long long,1 > > _1369);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1366,std::shared_ptr< monty::ndarray< int,1 > > _1367,std::shared_ptr< monty::ndarray< long long,1 > > _1368,std::shared_ptr< monty::ndarray< long long,1 > > _1369);
}; // struct SliceVariable;

struct p_ModelVariable : public ::mosek::fusion::p_BaseVariable
{
ModelVariable * _pubthis;
static mosek::fusion::p_ModelVariable* _get_impl(mosek::fusion::ModelVariable * _inst){ return static_cast< mosek::fusion::p_ModelVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_ModelVariable * _get_impl(mosek::fusion::ModelVariable::t _inst) { return _get_impl(_inst.get()); }
p_ModelVariable(ModelVariable * _pubthis);
virtual ~p_ModelVariable() { /* std::cout << "~p_ModelVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};long long varid{};std::string name{};virtual void destroy();
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1567,monty::rc_ptr< ::mosek::fusion::Model > _1568);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1567,monty::rc_ptr< ::mosek::fusion::Model > _1568);
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::Model > _1569,const std::string &  _1570,std::shared_ptr< monty::ndarray< int,1 > > _1571,long long _1572,std::shared_ptr< monty::ndarray< long long,1 > > _1573,std::shared_ptr< monty::ndarray< long long,1 > > _1574);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1569,const std::string &  _1570,std::shared_ptr< monty::ndarray< int,1 > > _1571,long long _1572,std::shared_ptr< monty::ndarray< long long,1 > > _1573,std::shared_ptr< monty::ndarray< long long,1 > > _1574);
virtual void flushNames() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void elementName(long long _1575,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1576) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1577) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelVariable;

struct p_SymRangedVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymRangedVariable * _pubthis;
static mosek::fusion::p_SymRangedVariable* _get_impl(mosek::fusion::SymRangedVariable * _inst){ return static_cast< mosek::fusion::p_SymRangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymRangedVariable * _get_impl(mosek::fusion::SymRangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymRangedVariable(SymRangedVariable * _pubthis);
virtual ~p_SymRangedVariable() { /* std::cout << "~p_SymRangedVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1370,monty::rc_ptr< ::mosek::fusion::Model > _1371);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1370,monty::rc_ptr< ::mosek::fusion::Model > _1371);
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1372,const std::string &  _1373,long long _1374,int _1375,std::shared_ptr< monty::ndarray< long long,1 > > _1376,std::shared_ptr< monty::ndarray< int,1 > > _1377);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1372,const std::string &  _1373,long long _1374,int _1375,std::shared_ptr< monty::ndarray< long long,1 > > _1376,std::shared_ptr< monty::ndarray< int,1 > > _1377);
virtual void dual_u(int _1378,std::shared_ptr< monty::ndarray< double,1 > > _1379) ;
virtual void dual_l(int _1380,std::shared_ptr< monty::ndarray< double,1 > > _1381) ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1385) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1385) { return __mosek_2fusion_2SymRangedVariable__clone(_1385); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1386,std::shared_ptr< monty::ndarray< long long,1 > > _1387,std::shared_ptr< monty::ndarray< int,1 > > _1388);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1404,std::shared_ptr< monty::ndarray< long long,1 > > _1405);
}; // struct SymRangedVariable;

struct p_RangedVariable : public ::mosek::fusion::p_ModelVariable
{
RangedVariable * _pubthis;
static mosek::fusion::p_RangedVariable* _get_impl(mosek::fusion::RangedVariable * _inst){ return static_cast< mosek::fusion::p_RangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_RangedVariable * _get_impl(mosek::fusion::RangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_RangedVariable(RangedVariable * _pubthis);
virtual ~p_RangedVariable() { /* std::cout << "~p_RangedVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};virtual void destroy();
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1416,monty::rc_ptr< ::mosek::fusion::Model > _1417);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1416,monty::rc_ptr< ::mosek::fusion::Model > _1417);
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1418,const std::string &  _1419,long long _1420,std::shared_ptr< monty::ndarray< int,1 > > _1421,std::shared_ptr< monty::ndarray< long long,1 > > _1422,std::shared_ptr< monty::ndarray< int,1 > > _1423);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1418,const std::string &  _1419,long long _1420,std::shared_ptr< monty::ndarray< int,1 > > _1421,std::shared_ptr< monty::ndarray< long long,1 > > _1422,std::shared_ptr< monty::ndarray< int,1 > > _1423);
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2RangedVariable__elementDesc(long long _1424,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1425) ;
virtual /* override */ void flushNames() ;
virtual void dual_u(int _1429,std::shared_ptr< monty::ndarray< double,1 > > _1430) ;
virtual void dual_l(int _1431,std::shared_ptr< monty::ndarray< double,1 > > _1432) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1433) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1433) { return __mosek_2fusion_2RangedVariable__clone(_1433); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1434);
}; // struct RangedVariable;

struct p_LinearPSDVariable : public ::mosek::fusion::p_ModelVariable
{
LinearPSDVariable * _pubthis;
static mosek::fusion::p_LinearPSDVariable* _get_impl(mosek::fusion::LinearPSDVariable * _inst){ return static_cast< mosek::fusion::p_LinearPSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDVariable * _get_impl(mosek::fusion::LinearPSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDVariable(LinearPSDVariable * _pubthis);
virtual ~p_LinearPSDVariable() { /* std::cout << "~p_LinearPSDVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};int varid{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int conedim{};virtual void destroy();
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1436,monty::rc_ptr< ::mosek::fusion::Model > _1437);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1436,monty::rc_ptr< ::mosek::fusion::Model > _1437);
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1438,const std::string &  _1439,int _1440,std::shared_ptr< monty::ndarray< int,1 > > _1441,int _1442,std::shared_ptr< monty::ndarray< long long,1 > > _1443);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1438,const std::string &  _1439,int _1440,std::shared_ptr< monty::ndarray< int,1 > > _1441,int _1442,std::shared_ptr< monty::ndarray< long long,1 > > _1443);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1446) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1447) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1448) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1448) { return __mosek_2fusion_2LinearPSDVariable__clone(_1448); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1449);
}; // struct LinearPSDVariable;

struct p_PSDVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
PSDVariable * _pubthis;
static mosek::fusion::p_PSDVariable* _get_impl(mosek::fusion::PSDVariable * _inst){ return static_cast< mosek::fusion::p_PSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_PSDVariable * _get_impl(mosek::fusion::PSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_PSDVariable(PSDVariable * _pubthis);
virtual ~p_PSDVariable() { /* std::cout << "~p_PSDVariable" << std::endl;*/ };
int conedim2{};int conedim1{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int varid{};virtual void destroy();
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1451,monty::rc_ptr< ::mosek::fusion::Model > _1452);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1451,monty::rc_ptr< ::mosek::fusion::Model > _1452);
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1453,const std::string &  _1454,int _1455,std::shared_ptr< monty::ndarray< int,1 > > _1456,int _1457,int _1458,std::shared_ptr< monty::ndarray< long long,1 > > _1459);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1453,const std::string &  _1454,int _1455,std::shared_ptr< monty::ndarray< int,1 > > _1456,int _1457,int _1458,std::shared_ptr< monty::ndarray< long long,1 > > _1459);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2PSDVariable__elementDesc(long long _1462,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1463) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1464) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1464) { return __mosek_2fusion_2PSDVariable__clone(_1464); }
static  std::shared_ptr< monty::ndarray< long long,1 > > fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1465,int _1466,int _1467,std::shared_ptr< monty::ndarray< long long,1 > > _1468);
}; // struct PSDVariable;

struct p_SymLinearVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymLinearVariable * _pubthis;
static mosek::fusion::p_SymLinearVariable* _get_impl(mosek::fusion::SymLinearVariable * _inst){ return static_cast< mosek::fusion::p_SymLinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymLinearVariable * _get_impl(mosek::fusion::SymLinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymLinearVariable(SymLinearVariable * _pubthis);
virtual ~p_SymLinearVariable() { /* std::cout << "~p_SymLinearVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1493,monty::rc_ptr< ::mosek::fusion::Model > _1494);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1493,monty::rc_ptr< ::mosek::fusion::Model > _1494);
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1495,const std::string &  _1496,long long _1497,int _1498,std::shared_ptr< monty::ndarray< long long,1 > > _1499,std::shared_ptr< monty::ndarray< int,1 > > _1500);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1495,const std::string &  _1496,long long _1497,int _1498,std::shared_ptr< monty::ndarray< long long,1 > > _1499,std::shared_ptr< monty::ndarray< int,1 > > _1500);
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1504) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1504) { return __mosek_2fusion_2SymLinearVariable__clone(_1504); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1505,std::shared_ptr< monty::ndarray< long long,1 > > _1506,std::shared_ptr< monty::ndarray< int,1 > > _1507);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1523,std::shared_ptr< monty::ndarray< long long,1 > > _1524);
}; // struct SymLinearVariable;

struct p_LinearVariable : public ::mosek::fusion::p_ModelVariable
{
LinearVariable * _pubthis;
static mosek::fusion::p_LinearVariable* _get_impl(mosek::fusion::LinearVariable * _inst){ return static_cast< mosek::fusion::p_LinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearVariable * _get_impl(mosek::fusion::LinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearVariable(LinearVariable * _pubthis);
virtual ~p_LinearVariable() { /* std::cout << "~p_LinearVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1535,monty::rc_ptr< ::mosek::fusion::Model > _1536);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1535,monty::rc_ptr< ::mosek::fusion::Model > _1536);
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1537,const std::string &  _1538,long long _1539,std::shared_ptr< monty::ndarray< int,1 > > _1540,std::shared_ptr< monty::ndarray< long long,1 > > _1541,std::shared_ptr< monty::ndarray< int,1 > > _1542);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1537,const std::string &  _1538,long long _1539,std::shared_ptr< monty::ndarray< int,1 > > _1540,std::shared_ptr< monty::ndarray< long long,1 > > _1541,std::shared_ptr< monty::ndarray< int,1 > > _1542);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1548) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1548) { return __mosek_2fusion_2LinearVariable__clone(_1548); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1549);
}; // struct LinearVariable;

struct p_ConicVariable : public ::mosek::fusion::p_ModelVariable
{
ConicVariable * _pubthis;
static mosek::fusion::p_ConicVariable* _get_impl(mosek::fusion::ConicVariable * _inst){ return static_cast< mosek::fusion::p_ConicVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_ConicVariable * _get_impl(mosek::fusion::ConicVariable::t _inst) { return _get_impl(_inst.get()); }
p_ConicVariable(ConicVariable * _pubthis);
virtual ~p_ConicVariable() { /* std::cout << "~p_ConicVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};int varid{};virtual void destroy();
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1552,monty::rc_ptr< ::mosek::fusion::Model > _1553);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1552,monty::rc_ptr< ::mosek::fusion::Model > _1553);
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::Model > _1554,const std::string &  _1555,int _1556,std::shared_ptr< monty::ndarray< int,1 > > _1557,std::shared_ptr< monty::ndarray< int,1 > > _1558);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1554,const std::string &  _1555,int _1556,std::shared_ptr< monty::ndarray< int,1 > > _1557,std::shared_ptr< monty::ndarray< int,1 > > _1558);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1564) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1564) { return __mosek_2fusion_2ConicVariable__clone(_1564); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1565);
}; // struct ConicVariable;

struct p_NilVariable : public ::mosek::fusion::p_BaseVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
NilVariable * _pubthis;
static mosek::fusion::p_NilVariable* _get_impl(mosek::fusion::NilVariable * _inst){ return static_cast< mosek::fusion::p_NilVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_NilVariable * _get_impl(mosek::fusion::NilVariable::t _inst) { return _get_impl(_inst.get()); }
p_NilVariable(NilVariable * _pubthis);
virtual ~p_NilVariable() { /* std::cout << "~p_NilVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static NilVariable::t _new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > > _1578);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _1578);
static NilVariable::t _new_NilVariable();
void _initialize();
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2NilVariable__elementDesc(long long _1580,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1581) ;
virtual void elementName(long long _1582,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1583) ;
virtual /* override */ int numInst() ;
virtual int inst(int _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585,std::shared_ptr< monty::ndarray< long long,1 > > _1586) ;
virtual /* override */ void inst(int _1587,std::shared_ptr< monty::ndarray< long long,1 > > _1588) ;
virtual /* override */ void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1589,bool _1590) ;
virtual /* override */ void values(int _1591,std::shared_ptr< monty::ndarray< double,1 > > _1592,bool _1593) ;
virtual /* override */ void make_continuous() ;
virtual /* override */ void make_integer() ;
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1594) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1594) { return __mosek_2fusion_2NilVariable__index(_1594); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1594) { return __mosek_2fusion_2NilVariable__index(_1594); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(int _1596) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1596) { return __mosek_2fusion_2NilVariable__index(_1596); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1596) { return __mosek_2fusion_2NilVariable__index(_1596); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__slice(_1598,_1599); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1598,std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__slice(_1598,_1599); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(int _1602,int _1603) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1602,int _1603) { return __mosek_2fusion_2NilVariable__slice(_1602,_1603); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1602,int _1603) { return __mosek_2fusion_2NilVariable__slice(_1602,_1603); }
}; // struct NilVariable;

struct p_Var
{
Var * _pubthis;
static mosek::fusion::p_Var* _get_impl(mosek::fusion::Var * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Var * _get_impl(mosek::fusion::Var::t _inst) { return _get_impl(_inst.get()); }
p_Var(Var * _pubthis);
virtual ~p_Var() { /* std::cout << "~p_Var" << std::endl;*/ };
virtual void destroy();
static  monty::rc_ptr< ::mosek::fusion::Variable > empty(std::shared_ptr< monty::ndarray< int,1 > > _1844);
static  monty::rc_ptr< ::mosek::fusion::Variable > compress(monty::rc_ptr< ::mosek::fusion::Variable > _1846);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1854,int _1855);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1856,int _1857,int _1858);
static  monty::rc_ptr< ::mosek::fusion::Variable > flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1859);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1860,std::shared_ptr< monty::ndarray< int,1 > > _1861);
static  monty::rc_ptr< ::mosek::fusion::Variable > index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1862,std::shared_ptr< monty::ndarray< int,1 > > _1863);
static  monty::rc_ptr< ::mosek::fusion::Variable > hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1892,int _1893);
static  monty::rc_ptr< ::mosek::fusion::Variable > vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1894,int _1895);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1896,int _1897);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1898,int _1899,int _1900);
static  monty::rc_ptr< ::mosek::fusion::Variable > drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1901,int _1902,int _1903);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1967);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1969,monty::rc_ptr< ::mosek::fusion::Variable > _1970,monty::rc_ptr< ::mosek::fusion::Variable > _1971);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1972,monty::rc_ptr< ::mosek::fusion::Variable > _1973);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1974);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1975,monty::rc_ptr< ::mosek::fusion::Variable > _1976,monty::rc_ptr< ::mosek::fusion::Variable > _1977);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1978,monty::rc_ptr< ::mosek::fusion::Variable > _1979);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1980);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _1981,monty::rc_ptr< ::mosek::fusion::Variable > _1982,monty::rc_ptr< ::mosek::fusion::Variable > _1983,int _1984);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _1985,monty::rc_ptr< ::mosek::fusion::Variable > _1986,int _1987);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1988,int _1989);
static  monty::rc_ptr< ::mosek::fusion::Variable > promote(monty::rc_ptr< ::mosek::fusion::Variable > _1992,int _1993);
static  monty::rc_ptr< ::mosek::fusion::Variable > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1998,int _1999);
}; // struct Var;

struct p_ConstraintCache
{
ConstraintCache * _pubthis;
static mosek::fusion::p_ConstraintCache* _get_impl(mosek::fusion::ConstraintCache * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConstraintCache * _get_impl(mosek::fusion::ConstraintCache::t _inst) { return _get_impl(_inst.get()); }
p_ConstraintCache(ConstraintCache * _pubthis);
virtual ~p_ConstraintCache() { /* std::cout << "~p_ConstraintCache" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmatidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};long long nbarnz{};long long nunordered{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subi{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subj{};std::shared_ptr< monty::ndarray< double,1 > > buffer_cof{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subi{};std::shared_ptr< monty::ndarray< int,1 > > subj{};long long nnz{};int nrows{};virtual void destroy();
static ConstraintCache::t _new_ConstraintCache(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2122);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2122);
static ConstraintCache::t _new_ConstraintCache(std::shared_ptr< monty::ndarray< long long,1 > > _2123,std::shared_ptr< monty::ndarray< double,1 > > _2124,std::shared_ptr< monty::ndarray< int,1 > > _2125,std::shared_ptr< monty::ndarray< double,1 > > _2126,std::shared_ptr< monty::ndarray< int,1 > > _2127,std::shared_ptr< monty::ndarray< int,1 > > _2128,std::shared_ptr< monty::ndarray< int,1 > > _2129);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _2123,std::shared_ptr< monty::ndarray< double,1 > > _2124,std::shared_ptr< monty::ndarray< int,1 > > _2125,std::shared_ptr< monty::ndarray< double,1 > > _2126,std::shared_ptr< monty::ndarray< int,1 > > _2127,std::shared_ptr< monty::ndarray< int,1 > > _2128,std::shared_ptr< monty::ndarray< int,1 > > _2129);
virtual void unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2132) ;
virtual long long order_barentries() ;
virtual void add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2142,std::shared_ptr< monty::ndarray< int,1 > > _2143,std::shared_ptr< monty::ndarray< int,1 > > _2144) ;
virtual void unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2150,std::shared_ptr< monty::ndarray< int,1 > > _2151,std::shared_ptr< monty::ndarray< double,1 > > _2152,std::shared_ptr< monty::ndarray< double,1 > > _2153) ;
virtual void add(std::shared_ptr< monty::ndarray< long long,1 > > _2162,std::shared_ptr< monty::ndarray< int,1 > > _2163,std::shared_ptr< monty::ndarray< double,1 > > _2164,std::shared_ptr< monty::ndarray< double,1 > > _2165) ;
virtual long long flush(std::shared_ptr< monty::ndarray< int,1 > > _2166,std::shared_ptr< monty::ndarray< int,1 > > _2167,std::shared_ptr< monty::ndarray< double,1 > > _2168,std::shared_ptr< monty::ndarray< double,1 > > _2169) ;
virtual long long numUnsorted() ;
virtual monty::rc_ptr< ::mosek::fusion::ConstraintCache > __mosek_2fusion_2ConstraintCache__clone() ;
}; // struct ConstraintCache;

struct p_Constraint
{
Constraint * _pubthis;
static mosek::fusion::p_Constraint* _get_impl(mosek::fusion::Constraint * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Constraint * _get_impl(mosek::fusion::Constraint::t _inst) { return _get_impl(_inst.get()); }
p_Constraint(Constraint * _pubthis);
virtual ~p_Constraint() { /* std::cout << "~p_Constraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::Model > model{};virtual void destroy();
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Constraint > _2243,monty::rc_ptr< ::mosek::fusion::Model > _2244);
void _initialize(monty::rc_ptr< ::mosek::fusion::Constraint > _2243,monty::rc_ptr< ::mosek::fusion::Model > _2244);
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Model > _2245,std::shared_ptr< monty::ndarray< int,1 > > _2246,std::shared_ptr< monty::ndarray< int,1 > > _2247);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2245,std::shared_ptr< monty::ndarray< int,1 > > _2246,std::shared_ptr< monty::ndarray< int,1 > > _2247);
virtual /* override */ std::string toString() ;
virtual void toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2248,long long _2249,std::shared_ptr< monty::ndarray< std::string,1 > > _2250) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void values(bool _2253,int _2254,std::shared_ptr< monty::ndarray< double,1 > > _2255) ;
virtual void update(std::shared_ptr< monty::ndarray< double,1 > > _2256) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2257) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2261,monty::rc_ptr< ::mosek::fusion::Variable > _2262,bool _2263) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2282,monty::rc_ptr< ::mosek::fusion::Variable > _2283) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__get_model() ;
virtual int get_nd() ;
virtual long long size() ;
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2286,int _2287);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2288,monty::rc_ptr< ::mosek::fusion::Constraint > _2289,monty::rc_ptr< ::mosek::fusion::Constraint > _2290,int _2291);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2292,monty::rc_ptr< ::mosek::fusion::Constraint > _2293,int _2294);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2295);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2296);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2297,monty::rc_ptr< ::mosek::fusion::Constraint > _2298,monty::rc_ptr< ::mosek::fusion::Constraint > _2299);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2300,monty::rc_ptr< ::mosek::fusion::Constraint > _2301,monty::rc_ptr< ::mosek::fusion::Constraint > _2302);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2303,monty::rc_ptr< ::mosek::fusion::Constraint > _2304);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2305,monty::rc_ptr< ::mosek::fusion::Constraint > _2306);
static  monty::rc_ptr< ::mosek::fusion::Constraint > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2307,int _2308);
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2359) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(int _2366) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2367,std::shared_ptr< monty::ndarray< int,1 > > _2368) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(int _2387,int _2388) ;
virtual int getND() ;
virtual int getSize() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__getModel() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct Constraint;

struct p_SliceConstraint : public ::mosek::fusion::p_Constraint
{
SliceConstraint * _pubthis;
static mosek::fusion::p_SliceConstraint* _get_impl(mosek::fusion::SliceConstraint * _inst){ return static_cast< mosek::fusion::p_SliceConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_SliceConstraint * _get_impl(mosek::fusion::SliceConstraint::t _inst) { return _get_impl(_inst.get()); }
p_SliceConstraint(SliceConstraint * _pubthis);
virtual ~p_SliceConstraint() { /* std::cout << "~p_SliceConstraint" << std::endl;*/ };
virtual void destroy();
static SliceConstraint::t _new_SliceConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2192,std::shared_ptr< monty::ndarray< int,1 > > _2193,std::shared_ptr< monty::ndarray< int,1 > > _2194);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2192,std::shared_ptr< monty::ndarray< int,1 > > _2193,std::shared_ptr< monty::ndarray< int,1 > > _2194);
virtual /* override */ std::string toString() ;
}; // struct SliceConstraint;

struct p_ModelConstraint : public ::mosek::fusion::p_Constraint
{
ModelConstraint * _pubthis;
static mosek::fusion::p_ModelConstraint* _get_impl(mosek::fusion::ModelConstraint * _inst){ return static_cast< mosek::fusion::p_ModelConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_ModelConstraint * _get_impl(mosek::fusion::ModelConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ModelConstraint(ModelConstraint * _pubthis);
virtual ~p_ModelConstraint() { /* std::cout << "~p_ModelConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2232,monty::rc_ptr< ::mosek::fusion::Model > _2233);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2232,monty::rc_ptr< ::mosek::fusion::Model > _2233);
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2234,const std::string &  _2235,std::shared_ptr< monty::ndarray< int,1 > > _2236,std::shared_ptr< monty::ndarray< int,1 > > _2237);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2234,const std::string &  _2235,std::shared_ptr< monty::ndarray< int,1 > > _2236,std::shared_ptr< monty::ndarray< int,1 > > _2237);
virtual /* override */ std::string toString() ;
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2242) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelConstraint;

struct p_LinearPSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearPSDConstraint * _pubthis;
static mosek::fusion::p_LinearPSDConstraint* _get_impl(mosek::fusion::LinearPSDConstraint * _inst){ return static_cast< mosek::fusion::p_LinearPSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDConstraint * _get_impl(mosek::fusion::LinearPSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDConstraint(LinearPSDConstraint * _pubthis);
virtual ~p_LinearPSDConstraint() { /* std::cout << "~p_LinearPSDConstraint" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};int conid{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};virtual void destroy();
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2068,monty::rc_ptr< ::mosek::fusion::Model > _2069);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2068,monty::rc_ptr< ::mosek::fusion::Model > _2069);
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2070,const std::string &  _2071,int _2072,std::shared_ptr< monty::ndarray< int,1 > > _2073,int _2074,std::shared_ptr< monty::ndarray< int,1 > > _2075,std::shared_ptr< monty::ndarray< long long,1 > > _2076);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2070,const std::string &  _2071,int _2072,std::shared_ptr< monty::ndarray< int,1 > > _2073,int _2074,std::shared_ptr< monty::ndarray< int,1 > > _2075,std::shared_ptr< monty::ndarray< long long,1 > > _2076);
virtual void domainToString(long long _2077,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2078) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2082) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2082) { return __mosek_2fusion_2LinearPSDConstraint__clone(_2082); }
}; // struct LinearPSDConstraint;

struct p_PSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
PSDConstraint * _pubthis;
static mosek::fusion::p_PSDConstraint* _get_impl(mosek::fusion::PSDConstraint * _inst){ return static_cast< mosek::fusion::p_PSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_PSDConstraint * _get_impl(mosek::fusion::PSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_PSDConstraint(PSDConstraint * _pubthis);
virtual ~p_PSDConstraint() { /* std::cout << "~p_PSDConstraint" << std::endl;*/ };
bool names_flushed{};int conedim1{};int conedim0{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};int conid{};virtual void destroy();
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2083,monty::rc_ptr< ::mosek::fusion::Model > _2084);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2083,monty::rc_ptr< ::mosek::fusion::Model > _2084);
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2085,const std::string &  _2086,int _2087,std::shared_ptr< monty::ndarray< int,1 > > _2088,int _2089,int _2090,std::shared_ptr< monty::ndarray< long long,1 > > _2091,std::shared_ptr< monty::ndarray< int,1 > > _2092);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2085,const std::string &  _2086,int _2087,std::shared_ptr< monty::ndarray< int,1 > > _2088,int _2089,int _2090,std::shared_ptr< monty::ndarray< long long,1 > > _2091,std::shared_ptr< monty::ndarray< int,1 > > _2092);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2093) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2093) { return __mosek_2fusion_2PSDConstraint__clone(_2093); }
static  std::shared_ptr< monty::ndarray< int,1 > > computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2094,int _2095,int _2096,std::shared_ptr< monty::ndarray< int,1 > > _2097);
}; // struct PSDConstraint;

struct p_RangedConstraint : public ::mosek::fusion::p_ModelConstraint
{
RangedConstraint * _pubthis;
static mosek::fusion::p_RangedConstraint* _get_impl(mosek::fusion::RangedConstraint * _inst){ return static_cast< mosek::fusion::p_RangedConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_RangedConstraint * _get_impl(mosek::fusion::RangedConstraint::t _inst) { return _get_impl(_inst.get()); }
p_RangedConstraint(RangedConstraint * _pubthis);
virtual ~p_RangedConstraint() { /* std::cout << "~p_RangedConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2196,monty::rc_ptr< ::mosek::fusion::Model > _2197);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2196,monty::rc_ptr< ::mosek::fusion::Model > _2197);
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2198,const std::string &  _2199,std::shared_ptr< monty::ndarray< int,1 > > _2200,std::shared_ptr< monty::ndarray< int,1 > > _2201);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2198,const std::string &  _2199,std::shared_ptr< monty::ndarray< int,1 > > _2200,std::shared_ptr< monty::ndarray< int,1 > > _2201);
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2202) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2202) { return __mosek_2fusion_2RangedConstraint__clone(_2202); }
}; // struct RangedConstraint;

struct p_ConicConstraint : public ::mosek::fusion::p_ModelConstraint
{
ConicConstraint * _pubthis;
static mosek::fusion::p_ConicConstraint* _get_impl(mosek::fusion::ConicConstraint * _inst){ return static_cast< mosek::fusion::p_ConicConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_ConicConstraint * _get_impl(mosek::fusion::ConicConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ConicConstraint(ConicConstraint * _pubthis);
virtual ~p_ConicConstraint() { /* std::cout << "~p_ConicConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeslack{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::ConeDomain > dom{};int conid{};virtual void destroy();
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2203,monty::rc_ptr< ::mosek::fusion::Model > _2204);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2203,monty::rc_ptr< ::mosek::fusion::Model > _2204);
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2205,const std::string &  _2206,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2207,std::shared_ptr< monty::ndarray< int,1 > > _2208,int _2209,std::shared_ptr< monty::ndarray< int,1 > > _2210,std::shared_ptr< monty::ndarray< int,1 > > _2211);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2205,const std::string &  _2206,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2207,std::shared_ptr< monty::ndarray< int,1 > > _2208,int _2209,std::shared_ptr< monty::ndarray< int,1 > > _2210,std::shared_ptr< monty::ndarray< int,1 > > _2211);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2218,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2219) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2220) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2220) { return __mosek_2fusion_2ConicConstraint__clone(_2220); }
}; // struct ConicConstraint;

struct p_LinearConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearConstraint * _pubthis;
static mosek::fusion::p_LinearConstraint* _get_impl(mosek::fusion::LinearConstraint * _inst){ return static_cast< mosek::fusion::p_LinearConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearConstraint * _get_impl(mosek::fusion::LinearConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearConstraint(LinearConstraint * _pubthis);
virtual ~p_LinearConstraint() { /* std::cout << "~p_LinearConstraint" << std::endl;*/ };
std::string name{};int conid{};virtual void destroy();
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2221,monty::rc_ptr< ::mosek::fusion::Model > _2222);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2221,monty::rc_ptr< ::mosek::fusion::Model > _2222);
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2223,const std::string &  _2224,int _2225,std::shared_ptr< monty::ndarray< int,1 > > _2226,std::shared_ptr< monty::ndarray< int,1 > > _2227);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2223,const std::string &  _2224,int _2225,std::shared_ptr< monty::ndarray< int,1 > > _2226,std::shared_ptr< monty::ndarray< int,1 > > _2227);
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2229,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2230) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2231) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2231) { return __mosek_2fusion_2LinearConstraint__clone(_2231); }
}; // struct LinearConstraint;

struct p_Set
{
Set * _pubthis;
static mosek::fusion::p_Set* _get_impl(mosek::fusion::Set * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Set * _get_impl(mosek::fusion::Set::t _inst) { return _get_impl(_inst.get()); }
p_Set(Set * _pubthis);
virtual ~p_Set() { /* std::cout << "~p_Set" << std::endl;*/ };
virtual void destroy();
static  long long size(std::shared_ptr< monty::ndarray< int,1 > > _2393);
static  bool match(std::shared_ptr< monty::ndarray< int,1 > > _2396,std::shared_ptr< monty::ndarray< int,1 > > _2397);
static  long long linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2399,std::shared_ptr< monty::ndarray< int,1 > > _2400);
static  std::shared_ptr< monty::ndarray< int,1 > > idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2403,long long _2404);
static  void idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2406,long long _2407,std::shared_ptr< monty::ndarray< int,1 > > _2408);
static  std::string indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2412,long long _2413);
static  std::string keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2420);
static  void indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2423,long long _2424,std::shared_ptr< monty::ndarray< int,1 > > _2425);
static  std::shared_ptr< monty::ndarray< long long,1 > > strides(std::shared_ptr< monty::ndarray< int,1 > > _2429);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2433,std::shared_ptr< monty::ndarray< int,1 > > _2434);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2438);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2440,int _2441,int _2442);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2443,int _2444);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2445);
static  std::shared_ptr< monty::ndarray< int,1 > > scalar();
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< std::string,1 > > _2446);
}; // struct Set;

struct p_ConeDomain
{
ConeDomain * _pubthis;
static mosek::fusion::p_ConeDomain* _get_impl(mosek::fusion::ConeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConeDomain * _get_impl(mosek::fusion::ConeDomain::t _inst) { return _get_impl(_inst.get()); }
p_ConeDomain(ConeDomain * _pubthis);
virtual ~p_ConeDomain() { /* std::cout << "~p_ConeDomain" << std::endl;*/ };
double alpha{};std::shared_ptr< monty::ndarray< int,1 > > shape{};bool int_flag{};bool axisset{};int axisidx{};mosek::fusion::QConeKey key{};virtual void destroy();
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2447,double _2448,std::shared_ptr< monty::ndarray< int,1 > > _2449);
void _initialize(mosek::fusion::QConeKey _2447,double _2448,std::shared_ptr< monty::ndarray< int,1 > > _2449);
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2450,std::shared_ptr< monty::ndarray< int,1 > > _2451);
void _initialize(mosek::fusion::QConeKey _2450,std::shared_ptr< monty::ndarray< int,1 > > _2451);
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2452) ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__integral() ;
virtual bool axisIsSet() ;
virtual int getAxis() ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__axis(int _2453) ;
}; // struct ConeDomain;

struct p_LinPSDDomain
{
LinPSDDomain * _pubthis;
static mosek::fusion::p_LinPSDDomain* _get_impl(mosek::fusion::LinPSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinPSDDomain * _get_impl(mosek::fusion::LinPSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinPSDDomain(LinPSDDomain * _pubthis);
virtual ~p_LinPSDDomain() { /* std::cout << "~p_LinPSDDomain" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2454,int _2455);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2454,int _2455);
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2456);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2456);
static LinPSDDomain::t _new_LinPSDDomain();
void _initialize();
}; // struct LinPSDDomain;

struct p_PSDDomain
{
PSDDomain * _pubthis;
static mosek::fusion::p_PSDDomain* _get_impl(mosek::fusion::PSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_PSDDomain * _get_impl(mosek::fusion::PSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_PSDDomain(PSDDomain * _pubthis);
virtual ~p_PSDDomain() { /* std::cout << "~p_PSDDomain" << std::endl;*/ };
bool axisIsSet{};int conedim2{};int conedim1{};mosek::fusion::PSDKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2457,std::shared_ptr< monty::ndarray< int,1 > > _2458,int _2459,int _2460);
void _initialize(mosek::fusion::PSDKey _2457,std::shared_ptr< monty::ndarray< int,1 > > _2458,int _2459,int _2460);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2462,std::shared_ptr< monty::ndarray< int,1 > > _2463);
void _initialize(mosek::fusion::PSDKey _2462,std::shared_ptr< monty::ndarray< int,1 > > _2463);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2464);
void _initialize(mosek::fusion::PSDKey _2464);
virtual monty::rc_ptr< ::mosek::fusion::PSDDomain > __mosek_2fusion_2PSDDomain__axis(int _2465,int _2466) ;
}; // struct PSDDomain;

struct p_RangeDomain
{
RangeDomain * _pubthis;
static mosek::fusion::p_RangeDomain* _get_impl(mosek::fusion::RangeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_RangeDomain * _get_impl(mosek::fusion::RangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_RangeDomain(RangeDomain * _pubthis);
virtual ~p_RangeDomain() { /* std::cout << "~p_RangeDomain" << std::endl;*/ };
bool cardinal_flag{};bool scalable{};std::shared_ptr< monty::ndarray< double,1 > > ub{};std::shared_ptr< monty::ndarray< double,1 > > lb{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool empty{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangeDomain::t _new_RangeDomain(bool _2468,std::shared_ptr< monty::ndarray< double,1 > > _2469,std::shared_ptr< monty::ndarray< double,1 > > _2470,std::shared_ptr< monty::ndarray< int,1 > > _2471);
void _initialize(bool _2468,std::shared_ptr< monty::ndarray< double,1 > > _2469,std::shared_ptr< monty::ndarray< double,1 > > _2470,std::shared_ptr< monty::ndarray< int,1 > > _2471);
static RangeDomain::t _new_RangeDomain(bool _2472,std::shared_ptr< monty::ndarray< double,1 > > _2473,std::shared_ptr< monty::ndarray< double,1 > > _2474,std::shared_ptr< monty::ndarray< int,1 > > _2475,std::shared_ptr< monty::ndarray< int,2 > > _2476);
void _initialize(bool _2472,std::shared_ptr< monty::ndarray< double,1 > > _2473,std::shared_ptr< monty::ndarray< double,1 > > _2474,std::shared_ptr< monty::ndarray< int,1 > > _2475,std::shared_ptr< monty::ndarray< int,2 > > _2476);
static RangeDomain::t _new_RangeDomain(bool _2477,std::shared_ptr< monty::ndarray< double,1 > > _2478,std::shared_ptr< monty::ndarray< double,1 > > _2479,std::shared_ptr< monty::ndarray< int,1 > > _2480,std::shared_ptr< monty::ndarray< int,2 > > _2481,int _2482);
void _initialize(bool _2477,std::shared_ptr< monty::ndarray< double,1 > > _2478,std::shared_ptr< monty::ndarray< double,1 > > _2479,std::shared_ptr< monty::ndarray< int,1 > > _2480,std::shared_ptr< monty::ndarray< int,2 > > _2481,int _2482);
static RangeDomain::t _new_RangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2483);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2483);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > __mosek_2fusion_2RangeDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2490) ;
}; // struct RangeDomain;

struct p_SymmetricRangeDomain : public ::mosek::fusion::p_RangeDomain
{
SymmetricRangeDomain * _pubthis;
static mosek::fusion::p_SymmetricRangeDomain* _get_impl(mosek::fusion::SymmetricRangeDomain * _inst){ return static_cast< mosek::fusion::p_SymmetricRangeDomain* >(mosek::fusion::p_RangeDomain::_get_impl(_inst)); }
static mosek::fusion::p_SymmetricRangeDomain * _get_impl(mosek::fusion::SymmetricRangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricRangeDomain(SymmetricRangeDomain * _pubthis);
virtual ~p_SymmetricRangeDomain() { /* std::cout << "~p_SymmetricRangeDomain" << std::endl;*/ };
int dim{};virtual void destroy();
static SymmetricRangeDomain::t _new_SymmetricRangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2467);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2467);
}; // struct SymmetricRangeDomain;

struct p_SymmetricLinearDomain
{
SymmetricLinearDomain * _pubthis;
static mosek::fusion::p_SymmetricLinearDomain* _get_impl(mosek::fusion::SymmetricLinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricLinearDomain * _get_impl(mosek::fusion::SymmetricLinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricLinearDomain(SymmetricLinearDomain * _pubthis);
virtual ~p_SymmetricLinearDomain() { /* std::cout << "~p_SymmetricLinearDomain" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::LinearDomain > dom{};int dim{};virtual void destroy();
static SymmetricLinearDomain::t _new_SymmetricLinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2492);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2492);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2493) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2496) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__integral() ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2498) ;
}; // struct SymmetricLinearDomain;

struct p_LinearDomain
{
LinearDomain * _pubthis;
static mosek::fusion::p_LinearDomain* _get_impl(mosek::fusion::LinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinearDomain * _get_impl(mosek::fusion::LinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinearDomain(LinearDomain * _pubthis);
virtual ~p_LinearDomain() { /* std::cout << "~p_LinearDomain" << std::endl;*/ };
bool empty{};bool scalable{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< double,1 > > bnd{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2500,bool _2501,std::shared_ptr< monty::ndarray< double,1 > > _2502,std::shared_ptr< monty::ndarray< int,1 > > _2503);
void _initialize(mosek::fusion::RelationKey _2500,bool _2501,std::shared_ptr< monty::ndarray< double,1 > > _2502,std::shared_ptr< monty::ndarray< int,1 > > _2503);
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2504,bool _2505,std::shared_ptr< monty::ndarray< double,1 > > _2506,std::shared_ptr< monty::ndarray< int,1 > > _2507,std::shared_ptr< monty::ndarray< int,2 > > _2508,int _2509);
void _initialize(mosek::fusion::RelationKey _2504,bool _2505,std::shared_ptr< monty::ndarray< double,1 > > _2506,std::shared_ptr< monty::ndarray< int,1 > > _2507,std::shared_ptr< monty::ndarray< int,2 > > _2508,int _2509);
static LinearDomain::t _new_LinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2510);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2510);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2LinearDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2511) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2514) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2516) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2517) ;
}; // struct LinearDomain;

struct p_Domain
{
Domain * _pubthis;
static mosek::fusion::p_Domain* _get_impl(mosek::fusion::Domain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Domain * _get_impl(mosek::fusion::Domain::t _inst) { return _get_impl(_inst.get()); }
p_Domain(Domain * _pubthis);
virtual ~p_Domain() { /* std::cout << "~p_Domain" << std::endl;*/ };
virtual void destroy();
static  long long dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2519);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > mkLinearDomain(mosek::fusion::RelationKey _2522,monty::rc_ptr< ::mosek::fusion::Matrix > _2523);
static  long long prod(std::shared_ptr< monty::ndarray< int,1 > > _2529);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(bool _2532,std::shared_ptr< monty::ndarray< double,1 > > _2533,std::shared_ptr< monty::ndarray< double,1 > > _2534,std::shared_ptr< monty::ndarray< int,2 > > _2535,std::shared_ptr< monty::ndarray< int,1 > > _2536);
static  monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2538);
static  monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2539);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2540,std::shared_ptr< monty::ndarray< int,2 > > _2541);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2542,std::shared_ptr< monty::ndarray< int,1 > > _2543);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2544,std::shared_ptr< monty::ndarray< int,2 > > _2545);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2546,std::shared_ptr< monty::ndarray< int,1 > > _2547);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2548);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2549);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2550);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2551,int _2552);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2553,std::shared_ptr< monty::ndarray< int,1 > > _2554);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2556,int _2557);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2558);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2559,std::shared_ptr< monty::ndarray< int,1 > > _2560);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2562,int _2563);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2564);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2565);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(int _2567);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2568);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(int _2570);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2571);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2573,int _2574);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2575);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2576);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2578,int _2579);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2580);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone();
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2581,int _2582);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2583);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2584,int _2585);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2586);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2587,int _2588);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2589);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(std::shared_ptr< monty::ndarray< int,1 > > _2590);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2591,int _2592);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2593);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2594,std::shared_ptr< monty::ndarray< double,1 > > _2595,std::shared_ptr< monty::ndarray< int,1 > > _2596);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2597,double _2598,std::shared_ptr< monty::ndarray< int,1 > > _2599);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2601,std::shared_ptr< monty::ndarray< double,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2605,double _2606,std::shared_ptr< monty::ndarray< int,1 > > _2607);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2608,std::shared_ptr< monty::ndarray< double,1 > > _2609);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2610,double _2611);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2613,std::shared_ptr< monty::ndarray< double,1 > > _2614);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2616,double _2617);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2618);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2619,std::shared_ptr< monty::ndarray< int,1 > > _2620);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2621);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2624);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2625,std::shared_ptr< monty::ndarray< int,1 > > _2626);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2628,int _2629,int _2630);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2632,int _2633);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2635);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2636);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2637,std::shared_ptr< monty::ndarray< int,1 > > _2638);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2639);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2642);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2643,std::shared_ptr< monty::ndarray< int,1 > > _2644);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2645,int _2646,int _2647);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2648,int _2649);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2650);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2651);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2652,std::shared_ptr< monty::ndarray< int,1 > > _2653);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2654);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2657);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2658,std::shared_ptr< monty::ndarray< int,1 > > _2659);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2660,int _2661,int _2662);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2663,int _2664);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2665);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2666);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2668,int _2669);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2670);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded();
}; // struct Domain;

struct p_BaseExpression : public /*implements*/ virtual ::mosek::fusion::Expression
{
BaseExpression * _pubthis;
static mosek::fusion::p_BaseExpression* _get_impl(mosek::fusion::BaseExpression * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseExpression * _get_impl(mosek::fusion::BaseExpression::t _inst) { return _get_impl(_inst.get()); }
p_BaseExpression(BaseExpression * _pubthis);
virtual ~p_BaseExpression() { /* std::cout << "~p_BaseExpression" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseExpression::t _new_BaseExpression(std::shared_ptr< monty::ndarray< int,1 > > _4824);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4824);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }
static  void storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4840,std::shared_ptr< monty::ndarray< int,1 > > _4841,std::shared_ptr< monty::ndarray< int,1 > > _4842,std::shared_ptr< monty::ndarray< long long,1 > > _4843,std::shared_ptr< monty::ndarray< long long,1 > > _4844,std::shared_ptr< monty::ndarray< double,1 > > _4845,std::shared_ptr< monty::ndarray< double,1 > > _4846);
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4857,monty::rc_ptr< ::mosek::fusion::WorkStack > _4858,monty::rc_ptr< ::mosek::fusion::WorkStack > _4859) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4860) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4860) { return __mosek_2fusion_2BaseExpression__pick(_4860); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4861) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4861) { return __mosek_2fusion_2BaseExpression__pick(_4861); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4864) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4864) { return __mosek_2fusion_2BaseExpression__index(_4864); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(int _4867) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(int _4867) { return __mosek_2fusion_2BaseExpression__index(_4867); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4869,std::shared_ptr< monty::ndarray< int,1 > > _4870) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4869,std::shared_ptr< monty::ndarray< int,1 > > _4870) { return __mosek_2fusion_2BaseExpression__slice(_4869,_4870); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(int _4871,int _4872) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(int _4871,int _4872) { return __mosek_2fusion_2BaseExpression__slice(_4871,_4872); }
virtual long long getSize() ;
virtual int getND() ;
virtual int getDim(int _4873) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct BaseExpression;

struct p_ExprConst : public ::mosek::fusion::p_BaseExpression
{
ExprConst * _pubthis;
static mosek::fusion::p_ExprConst* _get_impl(mosek::fusion::ExprConst * _inst){ return static_cast< mosek::fusion::p_ExprConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprConst * _get_impl(mosek::fusion::ExprConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprConst(ExprConst * _pubthis);
virtual ~p_ExprConst() { /* std::cout << "~p_ExprConst" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2671,std::shared_ptr< monty::ndarray< long long,1 > > _2672,std::shared_ptr< monty::ndarray< double,1 > > _2673);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2671,std::shared_ptr< monty::ndarray< long long,1 > > _2672,std::shared_ptr< monty::ndarray< double,1 > > _2673);
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2674,std::shared_ptr< monty::ndarray< long long,1 > > _2675,double _2676);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2674,std::shared_ptr< monty::ndarray< long long,1 > > _2675,double _2676);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2679,monty::rc_ptr< ::mosek::fusion::WorkStack > _2680,monty::rc_ptr< ::mosek::fusion::WorkStack > _2681) ;
static  void validate(std::shared_ptr< monty::ndarray< int,1 > > _2695,std::shared_ptr< monty::ndarray< double,1 > > _2696,std::shared_ptr< monty::ndarray< long long,1 > > _2697);
virtual /* override */ std::string toString() ;
}; // struct ExprConst;

struct p_ExprPick : public ::mosek::fusion::p_BaseExpression
{
ExprPick * _pubthis;
static mosek::fusion::p_ExprPick* _get_impl(mosek::fusion::ExprPick * _inst){ return static_cast< mosek::fusion::p_ExprPick* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPick * _get_impl(mosek::fusion::ExprPick::t _inst) { return _get_impl(_inst.get()); }
p_ExprPick(ExprPick * _pubthis);
virtual ~p_ExprPick() { /* std::cout << "~p_ExprPick" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > idxs{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2700,std::shared_ptr< monty::ndarray< int,2 > > _2701);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2700,std::shared_ptr< monty::ndarray< int,2 > > _2701);
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2712,std::shared_ptr< monty::ndarray< long long,1 > > _2713);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2712,std::shared_ptr< monty::ndarray< long long,1 > > _2713);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2717,monty::rc_ptr< ::mosek::fusion::WorkStack > _2718,monty::rc_ptr< ::mosek::fusion::WorkStack > _2719) ;
virtual /* override */ std::string toString() ;
}; // struct ExprPick;

struct p_ExprSlice : public ::mosek::fusion::p_BaseExpression
{
ExprSlice * _pubthis;
static mosek::fusion::p_ExprSlice* _get_impl(mosek::fusion::ExprSlice * _inst){ return static_cast< mosek::fusion::p_ExprSlice* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSlice * _get_impl(mosek::fusion::ExprSlice::t _inst) { return _get_impl(_inst.get()); }
p_ExprSlice(ExprSlice * _pubthis);
virtual ~p_ExprSlice() { /* std::cout << "~p_ExprSlice" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > last{};std::shared_ptr< monty::ndarray< int,1 > > first{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSlice::t _new_ExprSlice(monty::rc_ptr< ::mosek::fusion::Expression > _2771,std::shared_ptr< monty::ndarray< int,1 > > _2772,std::shared_ptr< monty::ndarray< int,1 > > _2773);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2771,std::shared_ptr< monty::ndarray< int,1 > > _2772,std::shared_ptr< monty::ndarray< int,1 > > _2773);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2774,monty::rc_ptr< ::mosek::fusion::WorkStack > _2775,monty::rc_ptr< ::mosek::fusion::WorkStack > _2776) ;
static  std::shared_ptr< monty::ndarray< int,1 > > makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2830,std::shared_ptr< monty::ndarray< int,1 > > _2831,std::shared_ptr< monty::ndarray< int,1 > > _2832);
virtual /* override */ std::string toString() ;
}; // struct ExprSlice;

struct p_ExprPermuteDims : public ::mosek::fusion::p_BaseExpression
{
ExprPermuteDims * _pubthis;
static mosek::fusion::p_ExprPermuteDims* _get_impl(mosek::fusion::ExprPermuteDims * _inst){ return static_cast< mosek::fusion::p_ExprPermuteDims* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPermuteDims * _get_impl(mosek::fusion::ExprPermuteDims::t _inst) { return _get_impl(_inst.get()); }
p_ExprPermuteDims(ExprPermuteDims * _pubthis);
virtual ~p_ExprPermuteDims() { /* std::cout << "~p_ExprPermuteDims" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > dperm{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2837,monty::rc_ptr< ::mosek::fusion::Expression > _2838);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2837,monty::rc_ptr< ::mosek::fusion::Expression > _2838);
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2844,monty::rc_ptr< ::mosek::fusion::Expression > _2845,int _2846);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2844,monty::rc_ptr< ::mosek::fusion::Expression > _2845,int _2846);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2847,monty::rc_ptr< ::mosek::fusion::WorkStack > _2848,monty::rc_ptr< ::mosek::fusion::WorkStack > _2849) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2901,std::shared_ptr< monty::ndarray< int,1 > > _2902);
}; // struct ExprPermuteDims;

struct p_ExprTranspose : public ::mosek::fusion::p_BaseExpression
{
ExprTranspose * _pubthis;
static mosek::fusion::p_ExprTranspose* _get_impl(mosek::fusion::ExprTranspose * _inst){ return static_cast< mosek::fusion::p_ExprTranspose* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprTranspose * _get_impl(mosek::fusion::ExprTranspose::t _inst) { return _get_impl(_inst.get()); }
p_ExprTranspose(ExprTranspose * _pubthis);
virtual ~p_ExprTranspose() { /* std::cout << "~p_ExprTranspose" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprTranspose::t _new_ExprTranspose(monty::rc_ptr< ::mosek::fusion::Expression > _2904);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2904);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2905,monty::rc_ptr< ::mosek::fusion::WorkStack > _2906,monty::rc_ptr< ::mosek::fusion::WorkStack > _2907) ;
virtual /* override */ std::string toString() ;
static  std::shared_ptr< monty::ndarray< int,1 > > transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2951);
}; // struct ExprTranspose;

struct p_ExprStack : public ::mosek::fusion::p_BaseExpression
{
ExprStack * _pubthis;
static mosek::fusion::p_ExprStack* _get_impl(mosek::fusion::ExprStack * _inst){ return static_cast< mosek::fusion::p_ExprStack* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprStack * _get_impl(mosek::fusion::ExprStack::t _inst) { return _get_impl(_inst.get()); }
p_ExprStack(ExprStack * _pubthis);
virtual ~p_ExprStack() { /* std::cout << "~p_ExprStack" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > exprs{};virtual void destroy();
static ExprStack::t _new_ExprStack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2952,int _2953);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2952,int _2953);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2955,monty::rc_ptr< ::mosek::fusion::WorkStack > _2956,monty::rc_ptr< ::mosek::fusion::WorkStack > _2957) ;
static  std::shared_ptr< monty::ndarray< int,1 > > getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3105,int _3106);
virtual /* override */ std::string toString() ;
}; // struct ExprStack;

struct p_ExprInner : public ::mosek::fusion::p_BaseExpression
{
ExprInner * _pubthis;
static mosek::fusion::p_ExprInner* _get_impl(mosek::fusion::ExprInner * _inst){ return static_cast< mosek::fusion::p_ExprInner* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprInner * _get_impl(mosek::fusion::ExprInner::t _inst) { return _get_impl(_inst.get()); }
p_ExprInner(ExprInner * _pubthis);
virtual ~p_ExprInner() { /* std::cout << "~p_ExprInner" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > vcof{};std::shared_ptr< monty::ndarray< long long,1 > > vsub{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3120,std::shared_ptr< monty::ndarray< long long,1 > > _3121,std::shared_ptr< monty::ndarray< double,1 > > _3122);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3120,std::shared_ptr< monty::ndarray< long long,1 > > _3121,std::shared_ptr< monty::ndarray< double,1 > > _3122);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3126,std::shared_ptr< monty::ndarray< double,1 > > _3127);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3126,std::shared_ptr< monty::ndarray< double,1 > > _3127);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3129,std::shared_ptr< monty::ndarray< int,2 > > _3130,std::shared_ptr< monty::ndarray< double,1 > > _3131);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3129,std::shared_ptr< monty::ndarray< int,2 > > _3130,std::shared_ptr< monty::ndarray< double,1 > > _3131);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3132,monty::rc_ptr< ::mosek::fusion::WorkStack > _3133,monty::rc_ptr< ::mosek::fusion::WorkStack > _3134) ;
static  std::shared_ptr< monty::ndarray< long long,1 > > range(int _3170);
static  std::shared_ptr< monty::ndarray< long long,1 > > convert(std::shared_ptr< monty::ndarray< int,1 > > _3172,std::shared_ptr< monty::ndarray< int,2 > > _3173);
virtual /* override */ std::string toString() ;
}; // struct ExprInner;

struct p_ExprMulDiagRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagRight * _pubthis;
static mosek::fusion::p_ExprMulDiagRight* _get_impl(mosek::fusion::ExprMulDiagRight * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagRight * _get_impl(mosek::fusion::ExprMulDiagRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagRight(ExprMulDiagRight * _pubthis);
virtual ~p_ExprMulDiagRight() { /* std::cout << "~p_ExprMulDiagRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3180,int _3181,std::shared_ptr< monty::ndarray< int,1 > > _3182,std::shared_ptr< monty::ndarray< int,1 > > _3183,std::shared_ptr< monty::ndarray< double,1 > > _3184,monty::rc_ptr< ::mosek::fusion::Expression > _3185,int _3186);
void _initialize(int _3180,int _3181,std::shared_ptr< monty::ndarray< int,1 > > _3182,std::shared_ptr< monty::ndarray< int,1 > > _3183,std::shared_ptr< monty::ndarray< double,1 > > _3184,monty::rc_ptr< ::mosek::fusion::Expression > _3185,int _3186);
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3187,int _3188,std::shared_ptr< monty::ndarray< int,1 > > _3189,std::shared_ptr< monty::ndarray< int,1 > > _3190,std::shared_ptr< monty::ndarray< double,1 > > _3191,monty::rc_ptr< ::mosek::fusion::Expression > _3192);
void _initialize(int _3187,int _3188,std::shared_ptr< monty::ndarray< int,1 > > _3189,std::shared_ptr< monty::ndarray< int,1 > > _3190,std::shared_ptr< monty::ndarray< double,1 > > _3191,monty::rc_ptr< ::mosek::fusion::Expression > _3192);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3193,monty::rc_ptr< ::mosek::fusion::WorkStack > _3194,monty::rc_ptr< ::mosek::fusion::WorkStack > _3195) ;
static  int validate(int _3287,int _3288,std::shared_ptr< monty::ndarray< int,1 > > _3289,std::shared_ptr< monty::ndarray< int,1 > > _3290,std::shared_ptr< monty::ndarray< double,1 > > _3291,monty::rc_ptr< ::mosek::fusion::Expression > _3292);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagRight;

struct p_ExprMulDiagLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagLeft * _pubthis;
static mosek::fusion::p_ExprMulDiagLeft* _get_impl(mosek::fusion::ExprMulDiagLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagLeft * _get_impl(mosek::fusion::ExprMulDiagLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagLeft(ExprMulDiagLeft * _pubthis);
virtual ~p_ExprMulDiagLeft() { /* std::cout << "~p_ExprMulDiagLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3300,int _3301,std::shared_ptr< monty::ndarray< int,1 > > _3302,std::shared_ptr< monty::ndarray< int,1 > > _3303,std::shared_ptr< monty::ndarray< double,1 > > _3304,monty::rc_ptr< ::mosek::fusion::Expression > _3305,int _3306);
void _initialize(int _3300,int _3301,std::shared_ptr< monty::ndarray< int,1 > > _3302,std::shared_ptr< monty::ndarray< int,1 > > _3303,std::shared_ptr< monty::ndarray< double,1 > > _3304,monty::rc_ptr< ::mosek::fusion::Expression > _3305,int _3306);
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3307,int _3308,std::shared_ptr< monty::ndarray< int,1 > > _3309,std::shared_ptr< monty::ndarray< int,1 > > _3310,std::shared_ptr< monty::ndarray< double,1 > > _3311,monty::rc_ptr< ::mosek::fusion::Expression > _3312);
void _initialize(int _3307,int _3308,std::shared_ptr< monty::ndarray< int,1 > > _3309,std::shared_ptr< monty::ndarray< int,1 > > _3310,std::shared_ptr< monty::ndarray< double,1 > > _3311,monty::rc_ptr< ::mosek::fusion::Expression > _3312);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3313,monty::rc_ptr< ::mosek::fusion::WorkStack > _3314,monty::rc_ptr< ::mosek::fusion::WorkStack > _3315) ;
static  int validate(int _3400,int _3401,std::shared_ptr< monty::ndarray< int,1 > > _3402,std::shared_ptr< monty::ndarray< int,1 > > _3403,std::shared_ptr< monty::ndarray< double,1 > > _3404,monty::rc_ptr< ::mosek::fusion::Expression > _3405);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagLeft;

struct p_ExprMulElement : public ::mosek::fusion::p_BaseExpression
{
ExprMulElement * _pubthis;
static mosek::fusion::p_ExprMulElement* _get_impl(mosek::fusion::ExprMulElement * _inst){ return static_cast< mosek::fusion::p_ExprMulElement* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulElement * _get_impl(mosek::fusion::ExprMulElement::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulElement(ExprMulElement * _pubthis);
virtual ~p_ExprMulElement() { /* std::cout << "~p_ExprMulElement" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< long long,1 > > msp{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};virtual void destroy();
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3413,std::shared_ptr< monty::ndarray< long long,1 > > _3414,monty::rc_ptr< ::mosek::fusion::Expression > _3415);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3413,std::shared_ptr< monty::ndarray< long long,1 > > _3414,monty::rc_ptr< ::mosek::fusion::Expression > _3415);
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3420,std::shared_ptr< monty::ndarray< long long,1 > > _3421,monty::rc_ptr< ::mosek::fusion::Expression > _3422,int _3423);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3420,std::shared_ptr< monty::ndarray< long long,1 > > _3421,monty::rc_ptr< ::mosek::fusion::Expression > _3422,int _3423);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3424,monty::rc_ptr< ::mosek::fusion::WorkStack > _3425,monty::rc_ptr< ::mosek::fusion::WorkStack > _3426) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulElement;

struct p_ExprMulScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarConst * _pubthis;
static mosek::fusion::p_ExprMulScalarConst* _get_impl(mosek::fusion::ExprMulScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarConst * _get_impl(mosek::fusion::ExprMulScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarConst(ExprMulScalarConst * _pubthis);
virtual ~p_ExprMulScalarConst() { /* std::cout << "~p_ExprMulScalarConst" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};double c{};virtual void destroy();
static ExprMulScalarConst::t _new_ExprMulScalarConst(double _3473,monty::rc_ptr< ::mosek::fusion::Expression > _3474);
void _initialize(double _3473,monty::rc_ptr< ::mosek::fusion::Expression > _3474);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3475,monty::rc_ptr< ::mosek::fusion::WorkStack > _3476,monty::rc_ptr< ::mosek::fusion::WorkStack > _3477) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarConst;

struct p_ExprScalarMul : public ::mosek::fusion::p_BaseExpression
{
ExprScalarMul * _pubthis;
static mosek::fusion::p_ExprScalarMul* _get_impl(mosek::fusion::ExprScalarMul * _inst){ return static_cast< mosek::fusion::p_ExprScalarMul* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprScalarMul * _get_impl(mosek::fusion::ExprScalarMul::t _inst) { return _get_impl(_inst.get()); }
p_ExprScalarMul(ExprScalarMul * _pubthis);
virtual ~p_ExprScalarMul() { /* std::cout << "~p_ExprScalarMul" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprScalarMul::t _new_ExprScalarMul(int _3485,int _3486,std::shared_ptr< monty::ndarray< int,1 > > _3487,std::shared_ptr< monty::ndarray< int,1 > > _3488,std::shared_ptr< monty::ndarray< double,1 > > _3489,monty::rc_ptr< ::mosek::fusion::Expression > _3490,int _3491);
void _initialize(int _3485,int _3486,std::shared_ptr< monty::ndarray< int,1 > > _3487,std::shared_ptr< monty::ndarray< int,1 > > _3488,std::shared_ptr< monty::ndarray< double,1 > > _3489,monty::rc_ptr< ::mosek::fusion::Expression > _3490,int _3491);
static ExprScalarMul::t _new_ExprScalarMul(int _3492,int _3493,std::shared_ptr< monty::ndarray< int,1 > > _3494,std::shared_ptr< monty::ndarray< int,1 > > _3495,std::shared_ptr< monty::ndarray< double,1 > > _3496,monty::rc_ptr< ::mosek::fusion::Expression > _3497);
void _initialize(int _3492,int _3493,std::shared_ptr< monty::ndarray< int,1 > > _3494,std::shared_ptr< monty::ndarray< int,1 > > _3495,std::shared_ptr< monty::ndarray< double,1 > > _3496,monty::rc_ptr< ::mosek::fusion::Expression > _3497);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3498,monty::rc_ptr< ::mosek::fusion::WorkStack > _3499,monty::rc_ptr< ::mosek::fusion::WorkStack > _3500) ;
static  int validate(int _3525,int _3526,std::shared_ptr< monty::ndarray< int,1 > > _3527,std::shared_ptr< monty::ndarray< int,1 > > _3528,std::shared_ptr< monty::ndarray< double,1 > > _3529,monty::rc_ptr< ::mosek::fusion::Expression > _3530);
virtual /* override */ std::string toString() ;
}; // struct ExprScalarMul;

struct p_ExprMulRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulRight * _pubthis;
static mosek::fusion::p_ExprMulRight* _get_impl(mosek::fusion::ExprMulRight * _inst){ return static_cast< mosek::fusion::p_ExprMulRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulRight * _get_impl(mosek::fusion::ExprMulRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulRight(ExprMulRight * _pubthis);
virtual ~p_ExprMulRight() { /* std::cout << "~p_ExprMulRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulRight::t _new_ExprMulRight(int _3536,int _3537,std::shared_ptr< monty::ndarray< int,1 > > _3538,std::shared_ptr< monty::ndarray< int,1 > > _3539,std::shared_ptr< monty::ndarray< double,1 > > _3540,monty::rc_ptr< ::mosek::fusion::Expression > _3541,int _3542);
void _initialize(int _3536,int _3537,std::shared_ptr< monty::ndarray< int,1 > > _3538,std::shared_ptr< monty::ndarray< int,1 > > _3539,std::shared_ptr< monty::ndarray< double,1 > > _3540,monty::rc_ptr< ::mosek::fusion::Expression > _3541,int _3542);
static ExprMulRight::t _new_ExprMulRight(int _3543,int _3544,std::shared_ptr< monty::ndarray< int,1 > > _3545,std::shared_ptr< monty::ndarray< int,1 > > _3546,std::shared_ptr< monty::ndarray< double,1 > > _3547,monty::rc_ptr< ::mosek::fusion::Expression > _3548);
void _initialize(int _3543,int _3544,std::shared_ptr< monty::ndarray< int,1 > > _3545,std::shared_ptr< monty::ndarray< int,1 > > _3546,std::shared_ptr< monty::ndarray< double,1 > > _3547,monty::rc_ptr< ::mosek::fusion::Expression > _3548);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3549,monty::rc_ptr< ::mosek::fusion::WorkStack > _3550,monty::rc_ptr< ::mosek::fusion::WorkStack > _3551) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3701,std::shared_ptr< monty::ndarray< int,1 > > _3702);
static  int validate(int _3703,int _3704,std::shared_ptr< monty::ndarray< int,1 > > _3705,std::shared_ptr< monty::ndarray< int,1 > > _3706,std::shared_ptr< monty::ndarray< double,1 > > _3707,monty::rc_ptr< ::mosek::fusion::Expression > _3708);
virtual /* override */ std::string toString() ;
}; // struct ExprMulRight;

struct p_ExprMulLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulLeft * _pubthis;
static mosek::fusion::p_ExprMulLeft* _get_impl(mosek::fusion::ExprMulLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulLeft * _get_impl(mosek::fusion::ExprMulLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulLeft(ExprMulLeft * _pubthis);
virtual ~p_ExprMulLeft() { /* std::cout << "~p_ExprMulLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulLeft::t _new_ExprMulLeft(int _3717,int _3718,std::shared_ptr< monty::ndarray< int,1 > > _3719,std::shared_ptr< monty::ndarray< int,1 > > _3720,std::shared_ptr< monty::ndarray< double,1 > > _3721,monty::rc_ptr< ::mosek::fusion::Expression > _3722,int _3723);
void _initialize(int _3717,int _3718,std::shared_ptr< monty::ndarray< int,1 > > _3719,std::shared_ptr< monty::ndarray< int,1 > > _3720,std::shared_ptr< monty::ndarray< double,1 > > _3721,monty::rc_ptr< ::mosek::fusion::Expression > _3722,int _3723);
static ExprMulLeft::t _new_ExprMulLeft(int _3724,int _3725,std::shared_ptr< monty::ndarray< int,1 > > _3726,std::shared_ptr< monty::ndarray< int,1 > > _3727,std::shared_ptr< monty::ndarray< double,1 > > _3728,monty::rc_ptr< ::mosek::fusion::Expression > _3729);
void _initialize(int _3724,int _3725,std::shared_ptr< monty::ndarray< int,1 > > _3726,std::shared_ptr< monty::ndarray< int,1 > > _3727,std::shared_ptr< monty::ndarray< double,1 > > _3728,monty::rc_ptr< ::mosek::fusion::Expression > _3729);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3730,monty::rc_ptr< ::mosek::fusion::WorkStack > _3731,monty::rc_ptr< ::mosek::fusion::WorkStack > _3732) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3830,int _3831,std::shared_ptr< monty::ndarray< int,1 > > _3832);
static  int validate(int _3833,int _3834,std::shared_ptr< monty::ndarray< int,1 > > _3835,std::shared_ptr< monty::ndarray< int,1 > > _3836,std::shared_ptr< monty::ndarray< double,1 > > _3837,monty::rc_ptr< ::mosek::fusion::Expression > _3838);
virtual /* override */ std::string toString() ;
}; // struct ExprMulLeft;

struct p_ExprMulVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulVar * _pubthis;
static mosek::fusion::p_ExprMulVar* _get_impl(mosek::fusion::ExprMulVar * _inst){ return static_cast< mosek::fusion::p_ExprMulVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVar * _get_impl(mosek::fusion::ExprMulVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVar(ExprMulVar * _pubthis);
virtual ~p_ExprMulVar() { /* std::cout << "~p_ExprMulVar" << std::endl;*/ };
bool left{};monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulVar::t _new_ExprMulVar(bool _3845,int _3846,int _3847,std::shared_ptr< monty::ndarray< int,1 > > _3848,std::shared_ptr< monty::ndarray< int,1 > > _3849,std::shared_ptr< monty::ndarray< double,1 > > _3850,monty::rc_ptr< ::mosek::fusion::Variable > _3851);
void _initialize(bool _3845,int _3846,int _3847,std::shared_ptr< monty::ndarray< int,1 > > _3848,std::shared_ptr< monty::ndarray< int,1 > > _3849,std::shared_ptr< monty::ndarray< double,1 > > _3850,monty::rc_ptr< ::mosek::fusion::Variable > _3851);
static ExprMulVar::t _new_ExprMulVar(bool _3854,int _3855,int _3856,std::shared_ptr< monty::ndarray< int,1 > > _3857,std::shared_ptr< monty::ndarray< int,1 > > _3858,std::shared_ptr< monty::ndarray< double,1 > > _3859,monty::rc_ptr< ::mosek::fusion::Variable > _3860,int _3861);
void _initialize(bool _3854,int _3855,int _3856,std::shared_ptr< monty::ndarray< int,1 > > _3857,std::shared_ptr< monty::ndarray< int,1 > > _3858,std::shared_ptr< monty::ndarray< double,1 > > _3859,monty::rc_ptr< ::mosek::fusion::Variable > _3860,int _3861);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3862,monty::rc_ptr< ::mosek::fusion::WorkStack > _3863,monty::rc_ptr< ::mosek::fusion::WorkStack > _3864) ;
virtual void eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3865,monty::rc_ptr< ::mosek::fusion::WorkStack > _3866,monty::rc_ptr< ::mosek::fusion::WorkStack > _3867) ;
virtual void eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3973,monty::rc_ptr< ::mosek::fusion::WorkStack > _3974,monty::rc_ptr< ::mosek::fusion::WorkStack > _3975) ;
virtual void validate(int _4041,int _4042,std::shared_ptr< monty::ndarray< int,1 > > _4043,std::shared_ptr< monty::ndarray< int,1 > > _4044,std::shared_ptr< monty::ndarray< double,1 > > _4045) ;
static  std::shared_ptr< monty::ndarray< int,1 > > resshape(int _4049,int _4050,std::shared_ptr< monty::ndarray< int,1 > > _4051,bool _4052);
virtual /* override */ std::string toString() ;
}; // struct ExprMulVar;

struct p_ExprMulScalarVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarVar * _pubthis;
static mosek::fusion::p_ExprMulScalarVar* _get_impl(mosek::fusion::ExprMulScalarVar * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarVar * _get_impl(mosek::fusion::ExprMulScalarVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarVar(ExprMulScalarVar * _pubthis);
virtual ~p_ExprMulScalarVar() { /* std::cout << "~p_ExprMulScalarVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4053,int _4054,std::shared_ptr< monty::ndarray< int,1 > > _4055,std::shared_ptr< monty::ndarray< int,1 > > _4056,std::shared_ptr< monty::ndarray< double,1 > > _4057,monty::rc_ptr< ::mosek::fusion::Variable > _4058);
void _initialize(int _4053,int _4054,std::shared_ptr< monty::ndarray< int,1 > > _4055,std::shared_ptr< monty::ndarray< int,1 > > _4056,std::shared_ptr< monty::ndarray< double,1 > > _4057,monty::rc_ptr< ::mosek::fusion::Variable > _4058);
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4061,int _4062,std::shared_ptr< monty::ndarray< int,1 > > _4063,std::shared_ptr< monty::ndarray< int,1 > > _4064,std::shared_ptr< monty::ndarray< double,1 > > _4065,monty::rc_ptr< ::mosek::fusion::Variable > _4066,int _4067);
void _initialize(int _4061,int _4062,std::shared_ptr< monty::ndarray< int,1 > > _4063,std::shared_ptr< monty::ndarray< int,1 > > _4064,std::shared_ptr< monty::ndarray< double,1 > > _4065,monty::rc_ptr< ::mosek::fusion::Variable > _4066,int _4067);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4068,monty::rc_ptr< ::mosek::fusion::WorkStack > _4069,monty::rc_ptr< ::mosek::fusion::WorkStack > _4070) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarVar;

struct p_ExprMulVarScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulVarScalarConst * _pubthis;
static mosek::fusion::p_ExprMulVarScalarConst* _get_impl(mosek::fusion::ExprMulVarScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulVarScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVarScalarConst * _get_impl(mosek::fusion::ExprMulVarScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVarScalarConst(ExprMulVarScalarConst * _pubthis);
virtual ~p_ExprMulVarScalarConst() { /* std::cout << "~p_ExprMulVarScalarConst" << std::endl;*/ };
double c{};monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprMulVarScalarConst::t _new_ExprMulVarScalarConst(monty::rc_ptr< ::mosek::fusion::Variable > _4089,double _4090);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4089,double _4090);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4091,monty::rc_ptr< ::mosek::fusion::WorkStack > _4092,monty::rc_ptr< ::mosek::fusion::WorkStack > _4093) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulVarScalarConst;

struct p_ExprAdd : public ::mosek::fusion::p_BaseExpression
{
ExprAdd * _pubthis;
static mosek::fusion::p_ExprAdd* _get_impl(mosek::fusion::ExprAdd * _inst){ return static_cast< mosek::fusion::p_ExprAdd* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprAdd * _get_impl(mosek::fusion::ExprAdd::t _inst) { return _get_impl(_inst.get()); }
p_ExprAdd(ExprAdd * _pubthis);
virtual ~p_ExprAdd() { /* std::cout << "~p_ExprAdd" << std::endl;*/ };
double m2{};double m1{};monty::rc_ptr< ::mosek::fusion::Expression > e2{};monty::rc_ptr< ::mosek::fusion::Expression > e1{};virtual void destroy();
static ExprAdd::t _new_ExprAdd(monty::rc_ptr< ::mosek::fusion::Expression > _4111,monty::rc_ptr< ::mosek::fusion::Expression > _4112,double _4113,double _4114);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4111,monty::rc_ptr< ::mosek::fusion::Expression > _4112,double _4113,double _4114);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4116,monty::rc_ptr< ::mosek::fusion::WorkStack > _4117,monty::rc_ptr< ::mosek::fusion::WorkStack > _4118) ;
virtual /* override */ std::string toString() ;
}; // struct ExprAdd;

struct p_ExprWSum : public ::mosek::fusion::p_BaseExpression
{
ExprWSum * _pubthis;
static mosek::fusion::p_ExprWSum* _get_impl(mosek::fusion::ExprWSum * _inst){ return static_cast< mosek::fusion::p_ExprWSum* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprWSum * _get_impl(mosek::fusion::ExprWSum::t _inst) { return _get_impl(_inst.get()); }
p_ExprWSum(ExprWSum * _pubthis);
virtual ~p_ExprWSum() { /* std::cout << "~p_ExprWSum" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > w{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > es{};virtual void destroy();
static ExprWSum::t _new_ExprWSum(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4228,std::shared_ptr< monty::ndarray< double,1 > > _4229);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4228,std::shared_ptr< monty::ndarray< double,1 > > _4229);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4236,monty::rc_ptr< ::mosek::fusion::WorkStack > _4237,monty::rc_ptr< ::mosek::fusion::WorkStack > _4238) ;
virtual /* override */ std::string toString() ;
}; // struct ExprWSum;

struct p_ExprSumReduce : public ::mosek::fusion::p_BaseExpression
{
ExprSumReduce * _pubthis;
static mosek::fusion::p_ExprSumReduce* _get_impl(mosek::fusion::ExprSumReduce * _inst){ return static_cast< mosek::fusion::p_ExprSumReduce* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSumReduce * _get_impl(mosek::fusion::ExprSumReduce::t _inst) { return _get_impl(_inst.get()); }
p_ExprSumReduce(ExprSumReduce * _pubthis);
virtual ~p_ExprSumReduce() { /* std::cout << "~p_ExprSumReduce" << std::endl;*/ };
int dim{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSumReduce::t _new_ExprSumReduce(int _4305,monty::rc_ptr< ::mosek::fusion::Expression > _4306);
void _initialize(int _4305,monty::rc_ptr< ::mosek::fusion::Expression > _4306);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4308,monty::rc_ptr< ::mosek::fusion::WorkStack > _4309,monty::rc_ptr< ::mosek::fusion::WorkStack > _4310) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeShape(int _4414,std::shared_ptr< monty::ndarray< int,1 > > _4415);
virtual /* override */ std::string toString() ;
}; // struct ExprSumReduce;

struct p_ExprDenseTril : public ::mosek::fusion::p_BaseExpression
{
ExprDenseTril * _pubthis;
static mosek::fusion::p_ExprDenseTril* _get_impl(mosek::fusion::ExprDenseTril * _inst){ return static_cast< mosek::fusion::p_ExprDenseTril* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDenseTril * _get_impl(mosek::fusion::ExprDenseTril::t _inst) { return _get_impl(_inst.get()); }
p_ExprDenseTril(ExprDenseTril * _pubthis);
virtual ~p_ExprDenseTril() { /* std::cout << "~p_ExprDenseTril" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDenseTril::t _new_ExprDenseTril(int _4419,int _4420,monty::rc_ptr< ::mosek::fusion::Expression > _4421,int _4422);
void _initialize(int _4419,int _4420,monty::rc_ptr< ::mosek::fusion::Expression > _4421,int _4422);
static ExprDenseTril::t _new_ExprDenseTril(int _4423,int _4424,monty::rc_ptr< ::mosek::fusion::Expression > _4425);
void _initialize(int _4423,int _4424,monty::rc_ptr< ::mosek::fusion::Expression > _4425);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4427,monty::rc_ptr< ::mosek::fusion::WorkStack > _4428,monty::rc_ptr< ::mosek::fusion::WorkStack > _4429) ;
}; // struct ExprDenseTril;

struct p_ExprDense : public ::mosek::fusion::p_BaseExpression
{
ExprDense * _pubthis;
static mosek::fusion::p_ExprDense* _get_impl(mosek::fusion::ExprDense * _inst){ return static_cast< mosek::fusion::p_ExprDense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDense * _get_impl(mosek::fusion::ExprDense::t _inst) { return _get_impl(_inst.get()); }
p_ExprDense(ExprDense * _pubthis);
virtual ~p_ExprDense() { /* std::cout << "~p_ExprDense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDense::t _new_ExprDense(monty::rc_ptr< ::mosek::fusion::Expression > _4502);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4502);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4503,monty::rc_ptr< ::mosek::fusion::WorkStack > _4504,monty::rc_ptr< ::mosek::fusion::WorkStack > _4505) ;
virtual /* override */ std::string toString() ;
}; // struct ExprDense;

struct p_ExprSymmetrize : public ::mosek::fusion::p_BaseExpression
{
ExprSymmetrize * _pubthis;
static mosek::fusion::p_ExprSymmetrize* _get_impl(mosek::fusion::ExprSymmetrize * _inst){ return static_cast< mosek::fusion::p_ExprSymmetrize* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSymmetrize * _get_impl(mosek::fusion::ExprSymmetrize::t _inst) { return _get_impl(_inst.get()); }
p_ExprSymmetrize(ExprSymmetrize * _pubthis);
virtual ~p_ExprSymmetrize() { /* std::cout << "~p_ExprSymmetrize" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSymmetrize::t _new_ExprSymmetrize(int _4528,int _4529,monty::rc_ptr< ::mosek::fusion::Expression > _4530,int _4531);
void _initialize(int _4528,int _4529,monty::rc_ptr< ::mosek::fusion::Expression > _4530,int _4531);
static ExprSymmetrize::t _new_ExprSymmetrize(int _4532,int _4533,monty::rc_ptr< ::mosek::fusion::Expression > _4534);
void _initialize(int _4532,int _4533,monty::rc_ptr< ::mosek::fusion::Expression > _4534);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4536,monty::rc_ptr< ::mosek::fusion::WorkStack > _4537,monty::rc_ptr< ::mosek::fusion::WorkStack > _4538) ;
}; // struct ExprSymmetrize;

struct p_ExprCompress : public ::mosek::fusion::p_BaseExpression
{
ExprCompress * _pubthis;
static mosek::fusion::p_ExprCompress* _get_impl(mosek::fusion::ExprCompress * _inst){ return static_cast< mosek::fusion::p_ExprCompress* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCompress * _get_impl(mosek::fusion::ExprCompress::t _inst) { return _get_impl(_inst.get()); }
p_ExprCompress(ExprCompress * _pubthis);
virtual ~p_ExprCompress() { /* std::cout << "~p_ExprCompress" << std::endl;*/ };
double eps{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4637);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4637);
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4638,double _4639);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4638,double _4639);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4640,monty::rc_ptr< ::mosek::fusion::WorkStack > _4641,monty::rc_ptr< ::mosek::fusion::WorkStack > _4642) ;
static  void arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4708,monty::rc_ptr< ::mosek::fusion::WorkStack > _4709,int _4710,int _4711,int _4712,int _4713,int _4714);
static  void merge_sort(int _4750,int _4751,int _4752,int _4753,int _4754,int _4755,std::shared_ptr< monty::ndarray< int,1 > > _4756,std::shared_ptr< monty::ndarray< long long,1 > > _4757);
virtual /* override */ std::string toString() ;
}; // struct ExprCompress;

struct p_ExprCondense : public ::mosek::fusion::p_BaseExpression
{
ExprCondense * _pubthis;
static mosek::fusion::p_ExprCondense* _get_impl(mosek::fusion::ExprCondense * _inst){ return static_cast< mosek::fusion::p_ExprCondense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCondense * _get_impl(mosek::fusion::ExprCondense::t _inst) { return _get_impl(_inst.get()); }
p_ExprCondense(ExprCondense * _pubthis);
virtual ~p_ExprCondense() { /* std::cout << "~p_ExprCondense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCondense::t _new_ExprCondense(monty::rc_ptr< ::mosek::fusion::Expression > _4780);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4780);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4781,monty::rc_ptr< ::mosek::fusion::WorkStack > _4782,monty::rc_ptr< ::mosek::fusion::WorkStack > _4783) ;
}; // struct ExprCondense;

struct p_ExprFromVar : public ::mosek::fusion::p_BaseExpression
{
ExprFromVar * _pubthis;
static mosek::fusion::p_ExprFromVar* _get_impl(mosek::fusion::ExprFromVar * _inst){ return static_cast< mosek::fusion::p_ExprFromVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprFromVar * _get_impl(mosek::fusion::ExprFromVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprFromVar(ExprFromVar * _pubthis);
virtual ~p_ExprFromVar() { /* std::cout << "~p_ExprFromVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprFromVar::t _new_ExprFromVar(monty::rc_ptr< ::mosek::fusion::Variable > _4790);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4790);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4791,monty::rc_ptr< ::mosek::fusion::WorkStack > _4792,monty::rc_ptr< ::mosek::fusion::WorkStack > _4793) ;
virtual /* override */ std::string toString() ;
}; // struct ExprFromVar;

struct p_ExprReshape : public ::mosek::fusion::p_BaseExpression
{
ExprReshape * _pubthis;
static mosek::fusion::p_ExprReshape* _get_impl(mosek::fusion::ExprReshape * _inst){ return static_cast< mosek::fusion::p_ExprReshape* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprReshape * _get_impl(mosek::fusion::ExprReshape::t _inst) { return _get_impl(_inst.get()); }
p_ExprReshape(ExprReshape * _pubthis);
virtual ~p_ExprReshape() { /* std::cout << "~p_ExprReshape" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};virtual void destroy();
static ExprReshape::t _new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > > _4811,monty::rc_ptr< ::mosek::fusion::Expression > _4812);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4811,monty::rc_ptr< ::mosek::fusion::Expression > _4812);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4814,monty::rc_ptr< ::mosek::fusion::WorkStack > _4815,monty::rc_ptr< ::mosek::fusion::WorkStack > _4816) ;
virtual /* override */ std::string toString() ;
}; // struct ExprReshape;

struct p_Expr : public ::mosek::fusion::p_BaseExpression
{
Expr * _pubthis;
static mosek::fusion::p_Expr* _get_impl(mosek::fusion::Expr * _inst){ return static_cast< mosek::fusion::p_Expr* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_Expr * _get_impl(mosek::fusion::Expr::t _inst) { return _get_impl(_inst.get()); }
p_Expr(Expr * _pubthis);
virtual ~p_Expr() { /* std::cout << "~p_Expr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< double,1 > > cof_v{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _4951,std::shared_ptr< monty::ndarray< long long,1 > > _4952,std::shared_ptr< monty::ndarray< double,1 > > _4953,std::shared_ptr< monty::ndarray< double,1 > > _4954,std::shared_ptr< monty::ndarray< int,1 > > _4955,std::shared_ptr< monty::ndarray< long long,1 > > _4956);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _4951,std::shared_ptr< monty::ndarray< long long,1 > > _4952,std::shared_ptr< monty::ndarray< double,1 > > _4953,std::shared_ptr< monty::ndarray< double,1 > > _4954,std::shared_ptr< monty::ndarray< int,1 > > _4955,std::shared_ptr< monty::ndarray< long long,1 > > _4956);
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _4967,std::shared_ptr< monty::ndarray< long long,1 > > _4968,std::shared_ptr< monty::ndarray< double,1 > > _4969,std::shared_ptr< monty::ndarray< double,1 > > _4970,std::shared_ptr< monty::ndarray< int,1 > > _4971,std::shared_ptr< monty::ndarray< long long,1 > > _4972,int _4973);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _4967,std::shared_ptr< monty::ndarray< long long,1 > > _4968,std::shared_ptr< monty::ndarray< double,1 > > _4969,std::shared_ptr< monty::ndarray< double,1 > > _4970,std::shared_ptr< monty::ndarray< int,1 > > _4971,std::shared_ptr< monty::ndarray< long long,1 > > _4972,int _4973);
static Expr::t _new_Expr(monty::rc_ptr< ::mosek::fusion::Expression > _4974);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4974);
virtual long long prod(std::shared_ptr< monty::ndarray< int,1 > > _4999) ;
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _5002);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5005,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5006);
static  monty::rc_ptr< ::mosek::fusion::Expression > condense(monty::rc_ptr< ::mosek::fusion::Expression > _5010);
static  monty::rc_ptr< ::mosek::fusion::Expression > flatten(monty::rc_ptr< ::mosek::fusion::Expression > _5011);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5012,int _5013,int _5014);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5015,int _5016);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5017,std::shared_ptr< monty::ndarray< int,1 > > _5018);
virtual long long size() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expr__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(std::shared_ptr< monty::ndarray< int,1 > > _5021);
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(int _5022);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones();
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _5023,std::shared_ptr< monty::ndarray< int,2 > > _5024);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _5025);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(int _5026);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5027);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _5028);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(double _5037);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5038,std::shared_ptr< monty::ndarray< int,2 > > _5039,double _5040);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5048,std::shared_ptr< monty::ndarray< int,2 > > _5049,std::shared_ptr< monty::ndarray< double,1 > > _5050);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5058,double _5059);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(int _5060,double _5061);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5063);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5066);
virtual long long numNonzeros() ;
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5067,int _5068);
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5069);
static  monty::rc_ptr< ::mosek::fusion::Expression > neg(monty::rc_ptr< ::mosek::fusion::Expression > _5070);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(bool _5071,monty::rc_ptr< ::mosek::fusion::Matrix > _5072,monty::rc_ptr< ::mosek::fusion::Expression > _5073);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5080,monty::rc_ptr< ::mosek::fusion::Matrix > _5081);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5082,monty::rc_ptr< ::mosek::fusion::Variable > _5083);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5084,monty::rc_ptr< ::mosek::fusion::Matrix > _5085);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5086,monty::rc_ptr< ::mosek::fusion::Expression > _5087);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5088,std::shared_ptr< monty::ndarray< double,2 > > _5089);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5096,std::shared_ptr< monty::ndarray< double,2 > > _5097);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5104,monty::rc_ptr< ::mosek::fusion::Variable > _5105);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5112,monty::rc_ptr< ::mosek::fusion::Expression > _5113);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5120,monty::rc_ptr< ::mosek::fusion::Expression > _5121);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5130,monty::rc_ptr< ::mosek::fusion::Expression > _5131);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5133,monty::rc_ptr< ::mosek::fusion::Expression > _5134);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5137,double _5138);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(double _5139,monty::rc_ptr< ::mosek::fusion::Expression > _5140);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5141,std::shared_ptr< monty::ndarray< double,1 > > _5142);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,1 > > _5143,monty::rc_ptr< ::mosek::fusion::Expression > _5144);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5145,std::shared_ptr< monty::ndarray< double,2 > > _5146);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,2 > > _5147,monty::rc_ptr< ::mosek::fusion::Expression > _5148);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5149,monty::rc_ptr< ::mosek::fusion::Matrix > _5150);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5151,monty::rc_ptr< ::mosek::fusion::Expression > _5152);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5153,std::shared_ptr< monty::ndarray< double,1 > > _5154,monty::rc_ptr< ::mosek::fusion::Expression > _5155);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5170,std::shared_ptr< monty::ndarray< double,2 > > _5171,monty::rc_ptr< ::mosek::fusion::Expression > _5172);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5187,monty::rc_ptr< ::mosek::fusion::Matrix > _5188,monty::rc_ptr< ::mosek::fusion::Expression > _5189);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Variable > _5198,monty::rc_ptr< ::mosek::fusion::Matrix > _5199);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5205,monty::rc_ptr< ::mosek::fusion::Variable > _5206);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5212,int _5213,int _5214,std::shared_ptr< monty::ndarray< int,1 > > _5215,std::shared_ptr< monty::ndarray< int,1 > > _5216,std::shared_ptr< monty::ndarray< double,1 > > _5217,monty::rc_ptr< ::mosek::fusion::Variable > _5218);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5220,monty::rc_ptr< ::mosek::fusion::Matrix > _5221);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5229,std::shared_ptr< monty::ndarray< double,2 > > _5230);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5234,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5235);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5236,std::shared_ptr< monty::ndarray< double,1 > > _5237);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5242,monty::rc_ptr< ::mosek::fusion::Expression > _5243);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5244,monty::rc_ptr< ::mosek::fusion::Expression > _5245);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,2 > > _5246,monty::rc_ptr< ::mosek::fusion::Expression > _5247);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,1 > > _5248,monty::rc_ptr< ::mosek::fusion::Expression > _5249);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5250,monty::rc_ptr< ::mosek::fusion::Expression > _5251);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Expression > _5255,std::shared_ptr< monty::ndarray< double,1 > > _5256);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5259,monty::rc_ptr< ::mosek::fusion::Variable > _5260);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5267,monty::rc_ptr< ::mosek::fusion::Matrix > _5268);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5275,monty::rc_ptr< ::mosek::fusion::Variable > _5276);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5278,std::shared_ptr< monty::ndarray< double,1 > > _5279);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(int _5281,std::shared_ptr< monty::ndarray< long long,1 > > _5282,std::shared_ptr< monty::ndarray< long long,1 > > _5283,std::shared_ptr< monty::ndarray< double,1 > > _5284,std::shared_ptr< monty::ndarray< double,1 > > _5285,std::shared_ptr< monty::ndarray< long long,1 > > _5286,std::shared_ptr< monty::ndarray< double,1 > > _5287,std::shared_ptr< monty::ndarray< int,1 > > _5288,int _5289,bool _5290);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5320,int _5321,std::shared_ptr< monty::ndarray< double,1 > > _5322,std::shared_ptr< monty::ndarray< int,1 > > _5323,int _5324,bool _5325);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5342);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5348,double _5349,double _5350);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5351,double _5352,monty::rc_ptr< ::mosek::fusion::Expression > _5353);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5354,monty::rc_ptr< ::mosek::fusion::Expression > _5355,double _5356);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5357,monty::rc_ptr< ::mosek::fusion::Expression > _5358,monty::rc_ptr< ::mosek::fusion::Expression > _5359);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5360,double _5361,double _5362);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5363,double _5364,monty::rc_ptr< ::mosek::fusion::Expression > _5365);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5366,monty::rc_ptr< ::mosek::fusion::Expression > _5367,double _5368);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5369,monty::rc_ptr< ::mosek::fusion::Expression > _5370,monty::rc_ptr< ::mosek::fusion::Expression > _5371);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5372,monty::rc_ptr< ::mosek::fusion::Expression > _5373);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5374,double _5375);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5376,monty::rc_ptr< ::mosek::fusion::Expression > _5377);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5378);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5380,monty::rc_ptr< ::mosek::fusion::Expression > _5381,monty::rc_ptr< ::mosek::fusion::Expression > _5382);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5383,monty::rc_ptr< ::mosek::fusion::Expression > _5384,double _5385);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5386,double _5387,monty::rc_ptr< ::mosek::fusion::Expression > _5388);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5389,double _5390,double _5391);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5392,monty::rc_ptr< ::mosek::fusion::Expression > _5393,monty::rc_ptr< ::mosek::fusion::Expression > _5394);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5395,monty::rc_ptr< ::mosek::fusion::Expression > _5396,double _5397);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5398,double _5399,monty::rc_ptr< ::mosek::fusion::Expression > _5400);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5401,monty::rc_ptr< ::mosek::fusion::Expression > _5402);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5403,double _5404);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5405,monty::rc_ptr< ::mosek::fusion::Expression > _5406);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5407);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5409,monty::rc_ptr< ::mosek::fusion::Expression > _5410,monty::rc_ptr< ::mosek::fusion::Expression > _5411,monty::rc_ptr< ::mosek::fusion::Expression > _5412);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5413,monty::rc_ptr< ::mosek::fusion::Expression > _5414,monty::rc_ptr< ::mosek::fusion::Expression > _5415,double _5416);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5417,monty::rc_ptr< ::mosek::fusion::Expression > _5418,double _5419,monty::rc_ptr< ::mosek::fusion::Expression > _5420);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5421,monty::rc_ptr< ::mosek::fusion::Expression > _5422,double _5423,double _5424);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5425,double _5426,monty::rc_ptr< ::mosek::fusion::Expression > _5427,monty::rc_ptr< ::mosek::fusion::Expression > _5428);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5429,double _5430,monty::rc_ptr< ::mosek::fusion::Expression > _5431,double _5432);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5433,double _5434,double _5435,monty::rc_ptr< ::mosek::fusion::Expression > _5436);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5437,double _5438,monty::rc_ptr< ::mosek::fusion::Expression > _5439);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441,double _5442);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5443,monty::rc_ptr< ::mosek::fusion::Expression > _5444,monty::rc_ptr< ::mosek::fusion::Expression > _5445);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5446,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5447);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5448,int _5449);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5450,int _5451);
static  monty::rc_ptr< ::mosek::fusion::Expression > repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5464,int _5465,int _5466);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5468);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5470);
static  monty::rc_ptr< ::mosek::fusion::Expression > add_(monty::rc_ptr< ::mosek::fusion::Expression > _5503,double _5504,monty::rc_ptr< ::mosek::fusion::Expression > _5505,double _5506);
static  monty::rc_ptr< ::mosek::fusion::Expression > transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5517);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5518,monty::rc_ptr< ::mosek::fusion::Expression > _5519);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5520,monty::rc_ptr< ::mosek::fusion::Expression > _5521);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5522,monty::rc_ptr< ::mosek::fusion::Expression > _5523);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5524,monty::rc_ptr< ::mosek::fusion::Expression > _5525);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5526,monty::rc_ptr< ::mosek::fusion::Matrix > _5527);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5528,std::shared_ptr< monty::ndarray< double,2 > > _5529);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5530,std::shared_ptr< monty::ndarray< double,1 > > _5531);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5532,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5533);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5534,monty::rc_ptr< ::mosek::fusion::Expression > _5535);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5536,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5537);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5538,monty::rc_ptr< ::mosek::fusion::Expression > _5539);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5540,monty::rc_ptr< ::mosek::fusion::Matrix > _5541);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(double _5542,monty::rc_ptr< ::mosek::fusion::Expression > _5543);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5544,double _5545);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,2 > > _5546,monty::rc_ptr< ::mosek::fusion::Expression > _5547);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,1 > > _5548,monty::rc_ptr< ::mosek::fusion::Expression > _5549);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5550,std::shared_ptr< monty::ndarray< double,2 > > _5551);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5552,std::shared_ptr< monty::ndarray< double,1 > > _5553);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5554,monty::rc_ptr< ::mosek::fusion::Expression > _5555);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5556,monty::rc_ptr< ::mosek::fusion::Expression > _5557);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5558,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5559);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Matrix > _5560,monty::rc_ptr< ::mosek::fusion::Expression > _5561);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5562,monty::rc_ptr< ::mosek::fusion::Matrix > _5563);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(double _5564,monty::rc_ptr< ::mosek::fusion::Expression > _5565);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5566,double _5567);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,2 > > _5568,monty::rc_ptr< ::mosek::fusion::Expression > _5569);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,1 > > _5570,monty::rc_ptr< ::mosek::fusion::Expression > _5571);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5572,std::shared_ptr< monty::ndarray< double,2 > > _5573);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5574,std::shared_ptr< monty::ndarray< double,1 > > _5575);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5576,monty::rc_ptr< ::mosek::fusion::Expression > _5577);
virtual /* override */ int getND() ;
virtual /* override */ std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5578,monty::rc_ptr< ::mosek::fusion::WorkStack > _5579,monty::rc_ptr< ::mosek::fusion::WorkStack > _5580) ;
static  void validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5582,std::shared_ptr< monty::ndarray< long long,1 > > _5583,std::shared_ptr< monty::ndarray< double,1 > > _5584,std::shared_ptr< monty::ndarray< double,1 > > _5585,std::shared_ptr< monty::ndarray< int,1 > > _5586,std::shared_ptr< monty::ndarray< long long,1 > > _5587);
static  monty::rc_ptr< ::mosek::fusion::Model > extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5600);
}; // struct Expr;

struct p_WorkStack
{
WorkStack * _pubthis;
static mosek::fusion::p_WorkStack* _get_impl(mosek::fusion::WorkStack * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_WorkStack * _get_impl(mosek::fusion::WorkStack::t _inst) { return _get_impl(_inst.get()); }
p_WorkStack(WorkStack * _pubthis);
virtual ~p_WorkStack() { /* std::cout << "~p_WorkStack" << std::endl;*/ };
int cof_base{};int bfix_base{};int nidxs_base{};int sp_base{};int shape_base{};int ptr_base{};bool hassp{};int nelem{};int nnz{};int nd{};int pf64{};int pi64{};int pi32{};std::shared_ptr< monty::ndarray< double,1 > > f64{};std::shared_ptr< monty::ndarray< long long,1 > > i64{};std::shared_ptr< monty::ndarray< int,1 > > i32{};virtual void destroy();
static WorkStack::t _new_WorkStack();
void _initialize();
virtual bool peek_hassp() ;
virtual int peek_nnz() ;
virtual int peek_nelem() ;
virtual int peek_dim(int _4874) ;
virtual int peek_nd() ;
virtual void alloc_expr(int _4875,int _4876,int _4877,bool _4878) ;
virtual void move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4879) ;
virtual void peek_expr() ;
virtual void pop_expr() ;
virtual void ensure_sparsity() ;
virtual void clear() ;
virtual int allocf64(int _4894) ;
virtual int alloci64(int _4897) ;
virtual int alloci32(int _4900) ;
virtual void pushf64(double _4903) ;
virtual void pushi64(long long _4904) ;
virtual void pushi32(int _4905) ;
virtual void ensuref64(int _4906) ;
virtual void ensurei64(int _4909) ;
virtual void ensurei32(int _4912) ;
virtual int popf64(int _4915) ;
virtual int popi64(int _4916) ;
virtual int popi32(int _4917) ;
virtual void popf64(int _4918,std::shared_ptr< monty::ndarray< double,1 > > _4919,int _4920) ;
virtual void popi64(int _4921,std::shared_ptr< monty::ndarray< long long,1 > > _4922,int _4923) ;
virtual void popi32(int _4924,std::shared_ptr< monty::ndarray< int,1 > > _4925,int _4926) ;
virtual double popf64() ;
virtual long long popi64() ;
virtual int popi32() ;
virtual double peekf64() ;
virtual long long peeki64() ;
virtual int peeki32() ;
virtual double peekf64(int _4927) ;
virtual long long peeki64(int _4928) ;
virtual int peeki32(int _4929) ;
}; // struct WorkStack;

struct p_SymmetricExpr
{
SymmetricExpr * _pubthis;
static mosek::fusion::p_SymmetricExpr* _get_impl(mosek::fusion::SymmetricExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricExpr * _get_impl(mosek::fusion::SymmetricExpr::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricExpr(SymmetricExpr * _pubthis);
virtual ~p_SymmetricExpr() { /* std::cout << "~p_SymmetricExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > xs{};monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > b{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > Ms{};int n{};virtual void destroy();
static SymmetricExpr::t _new_SymmetricExpr(int _4930,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4931,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4932,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4933);
void _initialize(int _4930,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4931,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4932,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4933);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4934,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4935);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4936,double _4937);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4939,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4940);
virtual /* override */ std::string toString() ;
}; // struct SymmetricExpr;

struct p_FlatExpr
{
FlatExpr * _pubthis;
static mosek::fusion::p_FlatExpr* _get_impl(mosek::fusion::FlatExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_FlatExpr * _get_impl(mosek::fusion::FlatExpr::t _inst) { return _get_impl(_inst.get()); }
p_FlatExpr(FlatExpr * _pubthis);
virtual ~p_FlatExpr() { /* std::cout << "~p_FlatExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > shape{};long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static FlatExpr::t _new_FlatExpr(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5613);
void _initialize(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5613);
static FlatExpr::t _new_FlatExpr(std::shared_ptr< monty::ndarray< double,1 > > _5614,std::shared_ptr< monty::ndarray< long long,1 > > _5615,std::shared_ptr< monty::ndarray< long long,1 > > _5616,std::shared_ptr< monty::ndarray< double,1 > > _5617,std::shared_ptr< monty::ndarray< int,1 > > _5618,std::shared_ptr< monty::ndarray< long long,1 > > _5619);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _5614,std::shared_ptr< monty::ndarray< long long,1 > > _5615,std::shared_ptr< monty::ndarray< long long,1 > > _5616,std::shared_ptr< monty::ndarray< double,1 > > _5617,std::shared_ptr< monty::ndarray< int,1 > > _5618,std::shared_ptr< monty::ndarray< long long,1 > > _5619);
virtual /* override */ std::string toString() ;
virtual int size() ;
}; // struct FlatExpr;

struct p_SymmetricMatrix
{
SymmetricMatrix * _pubthis;
static mosek::fusion::p_SymmetricMatrix* _get_impl(mosek::fusion::SymmetricMatrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricMatrix * _get_impl(mosek::fusion::SymmetricMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricMatrix(SymmetricMatrix * _pubthis);
virtual ~p_SymmetricMatrix() { /* std::cout << "~p_SymmetricMatrix" << std::endl;*/ };
int nnz{};double scale{};std::shared_ptr< monty::ndarray< double,1 > > vval{};std::shared_ptr< monty::ndarray< int,1 > > vsubj{};std::shared_ptr< monty::ndarray< int,1 > > vsubi{};std::shared_ptr< monty::ndarray< double,1 > > uval{};std::shared_ptr< monty::ndarray< int,1 > > usubj{};std::shared_ptr< monty::ndarray< int,1 > > usubi{};int d1{};int d0{};virtual void destroy();
static SymmetricMatrix::t _new_SymmetricMatrix(int _5621,int _5622,std::shared_ptr< monty::ndarray< int,1 > > _5623,std::shared_ptr< monty::ndarray< int,1 > > _5624,std::shared_ptr< monty::ndarray< double,1 > > _5625,std::shared_ptr< monty::ndarray< int,1 > > _5626,std::shared_ptr< monty::ndarray< int,1 > > _5627,std::shared_ptr< monty::ndarray< double,1 > > _5628,double _5629);
void _initialize(int _5621,int _5622,std::shared_ptr< monty::ndarray< int,1 > > _5623,std::shared_ptr< monty::ndarray< int,1 > > _5624,std::shared_ptr< monty::ndarray< double,1 > > _5625,std::shared_ptr< monty::ndarray< int,1 > > _5626,std::shared_ptr< monty::ndarray< int,1 > > _5627,std::shared_ptr< monty::ndarray< double,1 > > _5628,double _5629);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(int _5630,std::shared_ptr< monty::ndarray< int,1 > > _5631,std::shared_ptr< monty::ndarray< double,1 > > _5632);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5640);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5648);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5655);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5661) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5681) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__mul(double _5682) ;
virtual int getdim() ;
}; // struct SymmetricMatrix;

struct p_NDSparseArray
{
NDSparseArray * _pubthis;
static mosek::fusion::p_NDSparseArray* _get_impl(mosek::fusion::NDSparseArray * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_NDSparseArray * _get_impl(mosek::fusion::NDSparseArray::t _inst) { return _get_impl(_inst.get()); }
p_NDSparseArray(NDSparseArray * _pubthis);
virtual ~p_NDSparseArray() { /* std::cout << "~p_NDSparseArray" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > dims{};long long size{};virtual void destroy();
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5683,std::shared_ptr< monty::ndarray< int,2 > > _5684,std::shared_ptr< monty::ndarray< double,1 > > _5685);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5683,std::shared_ptr< monty::ndarray< int,2 > > _5684,std::shared_ptr< monty::ndarray< double,1 > > _5685);
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5705,std::shared_ptr< monty::ndarray< long long,1 > > _5706,std::shared_ptr< monty::ndarray< double,1 > > _5707);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5705,std::shared_ptr< monty::ndarray< long long,1 > > _5706,std::shared_ptr< monty::ndarray< double,1 > > _5707);
static NDSparseArray::t _new_NDSparseArray(monty::rc_ptr< ::mosek::fusion::Matrix > _5721);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5721);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(monty::rc_ptr< ::mosek::fusion::Matrix > _5729);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5730,std::shared_ptr< monty::ndarray< long long,1 > > _5731,std::shared_ptr< monty::ndarray< double,1 > > _5732);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5733,std::shared_ptr< monty::ndarray< int,2 > > _5734,std::shared_ptr< monty::ndarray< double,1 > > _5735);
}; // struct NDSparseArray;

struct p_Matrix
{
Matrix * _pubthis;
static mosek::fusion::p_Matrix* _get_impl(mosek::fusion::Matrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Matrix * _get_impl(mosek::fusion::Matrix::t _inst) { return _get_impl(_inst.get()); }
p_Matrix(Matrix * _pubthis);
virtual ~p_Matrix() { /* std::cout << "~p_Matrix" << std::endl;*/ };
int dimj{};int dimi{};virtual void destroy();
static Matrix::t _new_Matrix(int _5804,int _5805);
void _initialize(int _5804,int _5805);
virtual /* override */ std::string toString() ;
virtual void switchDims() ;
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5807,monty::rc_ptr< ::mosek::fusion::Matrix > _5808);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5810);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5828,double _5829,int _5830);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5831,double _5832);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5833,double _5834,int _5835);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5836,double _5837);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5838,int _5839);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5849);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5850,int _5851);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5859);
static  monty::rc_ptr< ::mosek::fusion::Matrix > ones(int _5860,int _5861);
static  monty::rc_ptr< ::mosek::fusion::Matrix > eye(int _5862);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5864);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5865,int _5866,double _5867);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5868,int _5869,std::shared_ptr< monty::ndarray< double,1 > > _5870);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(std::shared_ptr< monty::ndarray< double,2 > > _5871);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5872);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5876);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< double,2 > > _5907);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5920,int _5921);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5922,int _5923,std::shared_ptr< monty::ndarray< int,1 > > _5924,std::shared_ptr< monty::ndarray< int,1 > > _5925,double _5926);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5928,std::shared_ptr< monty::ndarray< int,1 > > _5929,double _5930);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5935,std::shared_ptr< monty::ndarray< int,1 > > _5936,std::shared_ptr< monty::ndarray< double,1 > > _5937);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5942,int _5943,std::shared_ptr< monty::ndarray< int,1 > > _5944,std::shared_ptr< monty::ndarray< int,1 > > _5945,std::shared_ptr< monty::ndarray< double,1 > > _5946);
virtual double get(int _5951,int _5952) { throw monty::AbstractClassError("Call to abstract method"); }
virtual bool isSparse() { throw monty::AbstractClassError("Call to abstract method"); }
virtual std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5953,std::shared_ptr< monty::ndarray< int,1 > > _5954,std::shared_ptr< monty::ndarray< double,1 > > _5955) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { throw monty::AbstractClassError("Call to abstract method"); }
virtual long long numNonzeros() { throw monty::AbstractClassError("Call to abstract method"); }
virtual int numColumns() ;
virtual int numRows() ;
}; // struct Matrix;

struct p_DenseMatrix : public ::mosek::fusion::p_Matrix
{
DenseMatrix * _pubthis;
static mosek::fusion::p_DenseMatrix* _get_impl(mosek::fusion::DenseMatrix * _inst){ return static_cast< mosek::fusion::p_DenseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_DenseMatrix * _get_impl(mosek::fusion::DenseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_DenseMatrix(DenseMatrix * _pubthis);
virtual ~p_DenseMatrix() { /* std::cout << "~p_DenseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > data{};virtual void destroy();
static DenseMatrix::t _new_DenseMatrix(int _5736,int _5737,std::shared_ptr< monty::ndarray< double,1 > > _5738);
void _initialize(int _5736,int _5737,std::shared_ptr< monty::ndarray< double,1 > > _5738);
static DenseMatrix::t _new_DenseMatrix(monty::rc_ptr< ::mosek::fusion::Matrix > _5739);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5739);
static DenseMatrix::t _new_DenseMatrix(std::shared_ptr< monty::ndarray< double,2 > > _5744);
void _initialize(std::shared_ptr< monty::ndarray< double,2 > > _5744);
static DenseMatrix::t _new_DenseMatrix(int _5747,int _5748,double _5749);
void _initialize(int _5747,int _5748,double _5749);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2DenseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5762,std::shared_ptr< monty::ndarray< int,1 > > _5763,std::shared_ptr< monty::ndarray< double,1 > > _5764) ;
virtual /* override */ double get(int _5768,int _5769) ;
virtual /* override */ long long numNonzeros() ;
}; // struct DenseMatrix;

struct p_SparseMatrix : public ::mosek::fusion::p_Matrix
{
SparseMatrix * _pubthis;
static mosek::fusion::p_SparseMatrix* _get_impl(mosek::fusion::SparseMatrix * _inst){ return static_cast< mosek::fusion::p_SparseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_SparseMatrix * _get_impl(mosek::fusion::SparseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SparseMatrix(SparseMatrix * _pubthis);
virtual ~p_SparseMatrix() { /* std::cout << "~p_SparseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > val{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< int,1 > > subi{};virtual void destroy();
static SparseMatrix::t _new_SparseMatrix(int _5770,int _5771,std::shared_ptr< monty::ndarray< int,1 > > _5772,std::shared_ptr< monty::ndarray< int,1 > > _5773,std::shared_ptr< monty::ndarray< double,1 > > _5774,long long _5775);
void _initialize(int _5770,int _5771,std::shared_ptr< monty::ndarray< int,1 > > _5772,std::shared_ptr< monty::ndarray< int,1 > > _5773,std::shared_ptr< monty::ndarray< double,1 > > _5774,long long _5775);
static SparseMatrix::t _new_SparseMatrix(int _5780,int _5781,std::shared_ptr< monty::ndarray< int,1 > > _5782,std::shared_ptr< monty::ndarray< int,1 > > _5783,std::shared_ptr< monty::ndarray< double,1 > > _5784);
void _initialize(int _5780,int _5781,std::shared_ptr< monty::ndarray< int,1 > > _5782,std::shared_ptr< monty::ndarray< int,1 > > _5783,std::shared_ptr< monty::ndarray< double,1 > > _5784);
virtual std::shared_ptr< monty::ndarray< long long,1 > > formPtrb() ;
virtual /* override */ std::string toString() ;
virtual /* override */ long long numNonzeros() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2SparseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5796,std::shared_ptr< monty::ndarray< int,1 > > _5797,std::shared_ptr< monty::ndarray< double,1 > > _5798) ;
virtual /* override */ double get(int _5799,int _5800) ;
}; // struct SparseMatrix;

struct p_LinkedBlocks
{
LinkedBlocks * _pubthis;
static mosek::fusion::p_LinkedBlocks* _get_impl(mosek::fusion::LinkedBlocks * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedBlocks * _get_impl(mosek::fusion::LinkedBlocks::t _inst) { return _get_impl(_inst.get()); }
p_LinkedBlocks(LinkedBlocks * _pubthis);
virtual ~p_LinkedBlocks() { /* std::cout << "~p_LinkedBlocks" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > bfirst{};std::shared_ptr< monty::ndarray< int,1 > > bsize{};monty::rc_ptr< ::mosek::fusion::LinkedInts > blocks{};monty::rc_ptr< ::mosek::fusion::LinkedInts > ints{};virtual void destroy();
static LinkedBlocks::t _new_LinkedBlocks();
void _initialize();
static LinkedBlocks::t _new_LinkedBlocks(int _5979);
void _initialize(int _5979);
static LinkedBlocks::t _new_LinkedBlocks(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5980);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5980);
virtual void free(int _5981) ;
virtual int alloc(int _5983) ;
virtual int maxidx(int _5988) ;
virtual void get(int _5989,std::shared_ptr< monty::ndarray< int,1 > > _5990,int _5991) ;
virtual int numblocks() ;
virtual int blocksize(int _5992) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedBlocks;

struct p_LinkedInts
{
LinkedInts * _pubthis;
static mosek::fusion::p_LinkedInts* _get_impl(mosek::fusion::LinkedInts * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedInts * _get_impl(mosek::fusion::LinkedInts::t _inst) { return _get_impl(_inst.get()); }
p_LinkedInts(LinkedInts * _pubthis);
virtual ~p_LinkedInts() { /* std::cout << "~p_LinkedInts" << std::endl;*/ };
int nfree{};int last_free{};int first_free{};int first_used{};std::shared_ptr< monty::ndarray< int,1 > > prev{};std::shared_ptr< monty::ndarray< int,1 > > next{};virtual void destroy();
static LinkedInts::t _new_LinkedInts(int _5993);
void _initialize(int _5993);
static LinkedInts::t _new_LinkedInts();
void _initialize();
static LinkedInts::t _new_LinkedInts(monty::rc_ptr< ::mosek::fusion::LinkedInts > _5996);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedInts > _5996);
virtual void free(int _5997,int _5998) ;
virtual int alloc() ;
virtual int alloc(int _6004) ;
virtual void alloc(int _6005,std::shared_ptr< monty::ndarray< int,1 > > _6006,int _6007) ;
virtual void get(int _6010,int _6011,std::shared_ptr< monty::ndarray< int,1 > > _6012,int _6013) ;
virtual int maxidx(int _6016,int _6017) ;
virtual int allocblock(int _6021) ;
virtual void recap(int _6027) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedInts;

struct p_Parameters
{
Parameters * _pubthis;
static mosek::fusion::p_Parameters* _get_impl(mosek::fusion::Parameters * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Parameters * _get_impl(mosek::fusion::Parameters::t _inst) { return _get_impl(_inst.get()); }
p_Parameters(Parameters * _pubthis);
virtual ~p_Parameters() { /* std::cout << "~p_Parameters" << std::endl;*/ };
virtual void destroy();
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6036,const std::string &  _6037,double _6038);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6132,const std::string &  _6133,int _6134);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6228,const std::string &  _6229,const std::string &  _6230);
static  int string_to_mionodeseltype_value(const std::string &  _6468);
static  int string_to_scalingtype_value(const std::string &  _6469);
static  int string_to_checkconvexitytype_value(const std::string &  _6470);
static  int string_to_feature_value(const std::string &  _6471);
static  int string_to_stakey_value(const std::string &  _6472);
static  int string_to_objsense_value(const std::string &  _6473);
static  int string_to_miomode_value(const std::string &  _6474);
static  int string_to_nametype_value(const std::string &  _6475);
static  int string_to_boundkey_value(const std::string &  _6476);
static  int string_to_scalingmethod_value(const std::string &  _6477);
static  int string_to_inftype_value(const std::string &  _6478);
static  int string_to_transpose_value(const std::string &  _6479);
static  int string_to_streamtype_value(const std::string &  _6480);
static  int string_to_conetype_value(const std::string &  _6481);
static  int string_to_simseltype_value(const std::string &  _6482);
static  int string_to_internal_iinf_value(const std::string &  _6483);
static  int string_to_variabletype_value(const std::string &  _6484);
static  int string_to_uplo_value(const std::string &  _6485);
static  int string_to_language_value(const std::string &  _6486);
static  int string_to_internal_dinf_value(const std::string &  _6487);
static  int string_to_sensitivitytype_value(const std::string &  _6488);
static  int string_to_prosta_value(const std::string &  _6489);
static  int string_to_sparam_value(const std::string &  _6490);
static  int string_to_iomode_value(const std::string &  _6491);
static  int string_to_branchdir_value(const std::string &  _6492);
static  int string_to_miocontsoltype_value(const std::string &  _6493);
static  int string_to_basindtype_value(const std::string &  _6494);
static  int string_to_xmlwriteroutputtype_value(const std::string &  _6495);
static  int string_to_optimizertype_value(const std::string &  _6496);
static  int string_to_simdegen_value(const std::string &  _6497);
static  int string_to_orderingtype_value(const std::string &  _6498);
static  int string_to_problemtype_value(const std::string &  _6499);
static  int string_to_rescodetype_value(const std::string &  _6500);
static  int string_to_purify_value(const std::string &  _6501);
static  int string_to_mpsformat_value(const std::string &  _6502);
static  int string_to_problemitem_value(const std::string &  _6503);
static  int string_to_internal_liinf_value(const std::string &  _6504);
static  int string_to_onoffkey_value(const std::string &  _6505);
static  int string_to_liinfitem_value(const std::string &  _6506);
static  int string_to_iparam_value(const std::string &  _6507);
static  int string_to_intpnthotstart_value(const std::string &  _6508);
static  int string_to_iinfitem_value(const std::string &  _6509);
static  int string_to_rescode_value(const std::string &  _6510);
static  int string_to_simreform_value(const std::string &  _6511);
static  int string_to_startpointtype_value(const std::string &  _6512);
static  int string_to_dinfitem_value(const std::string &  _6513);
static  int string_to_soltype_value(const std::string &  _6514);
static  int string_to_presolvemode_value(const std::string &  _6515);
static  int string_to_dparam_value(const std::string &  _6516);
static  int string_to_symmattype_value(const std::string &  _6517);
static  int string_to_scopr_value(const std::string &  _6518);
static  int string_to_solitem_value(const std::string &  _6519);
static  int string_to_compresstype_value(const std::string &  _6520);
static  int string_to_simhotstart_value(const std::string &  _6521);
static  int string_to_simdupvec_value(const std::string &  _6522);
static  int string_to_solsta_value(const std::string &  _6523);
static  int string_to_solveform_value(const std::string &  _6524);
static  int string_to_mark_value(const std::string &  _6525);
static  int string_to_parametertype_value(const std::string &  _6526);
static  int string_to_value_value(const std::string &  _6527);
static  int string_to_dataformat_value(const std::string &  _6528);
static  int string_to_callbackcode_value(const std::string &  _6529);
}; // struct Parameters;

}
}
namespace mosek
{
namespace fusion
{
namespace Utils
{
// mosek.fusion.Utils.IntMap from file 'src/fusion/cxx/IntMap_p.h'
struct p_IntMap 
{
  IntMap * _pubself;

  static p_IntMap * _get_impl(IntMap * _inst) { return _inst->_impl.get(); }

  p_IntMap(IntMap * _pubself) : _pubself(_pubself) {}

  static IntMap::t _new_IntMap() { return new IntMap(); }

  ::std::unordered_map<long long,int> m;

  bool hasItem (long long key) { return m.find(key) != m.end(); }
  int  getItem (long long key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (long long key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<long long,1>> keys()
  { 
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<long long,1>>(new monty::ndarray<long long,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;    
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  IntMap::t clone();
  IntMap::t __mosek_2fusion_2Utils_2IntMap__clone();
};



struct p_StringIntMap
{
  StringIntMap * _pubself;

  static p_StringIntMap * _get_impl(StringIntMap * _inst) { return _inst->_impl.get(); }

  p_StringIntMap(StringIntMap * _pubself) : _pubself(_pubself) {}

  static StringIntMap::t _new_StringIntMap() { return new StringIntMap(); }

  ::std::unordered_map<std::string,int> m;

  bool hasItem (const std::string & key) { return m.find(key) != m.end(); }
  int  getItem (const std::string & key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (const std::string & key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<std::string,1>> keys()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<std::string,1>>(new monty::ndarray<std::string,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  StringIntMap::t clone();
  StringIntMap::t __mosek_2fusion_2Utils_2StringIntMap__clone();
};
// End of file 'src/fusion/cxx/IntMap_p.h'
// mosek.fusion.Utils.StringBuffer from file 'src/fusion/cxx/StringBuffer_p.h'
// namespace mosek::fusion::Utils
struct p_StringBuffer
{
  StringBuffer * _pubthis; 
  std::stringstream ss;

  p_StringBuffer(StringBuffer * _pubthis) : _pubthis(_pubthis) {}

  static p_StringBuffer * _get_impl(StringBuffer::t ptr) { return ptr->_impl.get(); }
  static p_StringBuffer * _get_impl(StringBuffer * ptr) { return ptr->_impl.get(); }

  static StringBuffer::t _new_StringBuffer() { return new StringBuffer(); }

  StringBuffer::t clear ();
  
  StringBuffer::t a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t a (const monty::ndarray<int,1> & val);
  StringBuffer::t a (const monty::ndarray<long long,1> & val);
  StringBuffer::t a (const monty::ndarray<double,1> & val);
  

  StringBuffer::t a (const int & val);
  StringBuffer::t a (const long long & val);
  StringBuffer::t a (const double & val);
  StringBuffer::t a (const bool & val);
  StringBuffer::t a (const std::string & val);

  StringBuffer::t lf ();
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__clear ();

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<int,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<long long,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<double,1> & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const int & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const long long & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const double & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const bool & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const std::string & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__lf ();

  std::string toString () const;
};
// End of file 'src/fusion/cxx/StringBuffer_p.h'
}
}
}
#endif
